rule elf_mirai_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects elf.mirai."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/elf.mirai"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 6689432a e8???????? c7433400000000 894330 }
            // n = 4, score = 300
            //   6689432a             | mov                 word ptr [ebx + 0x2a], ax
            //   e8????????           |                     
            //   c7433400000000       | mov                 dword ptr [ebx + 0x34], 0
            //   894330               | mov                 dword ptr [ebx + 0x30], eax

        $sequence_1 = { 89d0 c1e005 01d0 89ca }
            // n = 4, score = 300
            //   89d0                 | mov                 eax, edx
            //   c1e005               | shl                 eax, 5
            //   01d0                 | add                 eax, edx
            //   89ca                 | mov                 edx, ecx

        $sequence_2 = { 894330 c6433801 c6433903 c6433a03 c6433b06 }
            // n = 5, score = 300
            //   894330               | mov                 dword ptr [ebx + 0x30], eax
            //   c6433801             | mov                 byte ptr [ebx + 0x38], 1
            //   c6433903             | mov                 byte ptr [ebx + 0x39], 3
            //   c6433a03             | mov                 byte ptr [ebx + 0x3a], 3
            //   c6433b06             | mov                 byte ptr [ebx + 0x3b], 6

        $sequence_3 = { 66c1e808 d0e8 8d04c0 28c2 }
            // n = 4, score = 300
            //   66c1e808             | shr                 ax, 8
            //   d0e8                 | shr                 al, 1
            //   8d04c0               | lea                 eax, [eax + eax*8]
            //   28c2                 | sub                 dl, al

        $sequence_4 = { 3c19 7705 8d42e0 8801 }
            // n = 4, score = 300
            //   3c19                 | cmp                 al, 0x19
            //   7705                 | ja                  7
            //   8d42e0               | lea                 eax, [edx - 0x20]
            //   8801                 | mov                 byte ptr [ecx], al

        $sequence_5 = { 807c242b00 66894304 7406 66c743064000 c643092f }
            // n = 5, score = 300
            //   807c242b00           | cmp                 byte ptr [esp + 0x2b], 0
            //   66894304             | mov                 word ptr [ebx + 4], ax
            //   7406                 | je                  8
            //   66c743064000         | mov                 word ptr [ebx + 6], 0x40
            //   c643092f             | mov                 byte ptr [ebx + 9], 0x2f

        $sequence_6 = { 66894104 7406 66c741064000 c6410911 }
            // n = 4, score = 300
            //   66894104             | mov                 word ptr [ecx + 4], ax
            //   7406                 | je                  8
            //   66c741064000         | mov                 word ptr [ecx + 6], 0x40
            //   c6410911             | mov                 byte ptr [ecx + 9], 0x11

        $sequence_7 = { 8b1408 895310 8b54080c 66895314 }
            // n = 4, score = 300
            //   8b1408               | mov                 edx, dword ptr [eax + ecx]
            //   895310               | mov                 dword ptr [ebx + 0x10], edx
            //   8b54080c             | mov                 edx, dword ptr [eax + ecx + 0xc]
            //   66895314             | mov                 word ptr [ebx + 0x14], dx

    condition:
        7 of them and filesize < 2228224
}