rule elf_persirai_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects elf.persirai."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/elf.persirai"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c3 c3 53 83ec08 e8???????? 31d2 8b5c2414 }
            // n = 7, score = 100
            //   c3                   | ret                 
            //   c3                   | ret                 
            //   53                   | push                ebx
            //   83ec08               | sub                 esp, 8
            //   e8????????           |                     
            //   31d2                 | xor                 edx, edx
            //   8b5c2414             | mov                 ebx, dword ptr [esp + 0x14]

        $sequence_1 = { 8b5c2410 837c241400 740b 83ec0c ff7304 ff13 83c410 }
            // n = 7, score = 100
            //   8b5c2410             | mov                 ebx, dword ptr [esp + 0x10]
            //   837c241400           | cmp                 dword ptr [esp + 0x14], 0
            //   740b                 | je                  0xd
            //   83ec0c               | sub                 esp, 0xc
            //   ff7304               | push                dword ptr [ebx + 4]
            //   ff13                 | call                dword ptr [ebx]
            //   83c410               | add                 esp, 0x10

        $sequence_2 = { 50 52 e8???????? 58 8d8424d8170000 50 e8???????? }
            // n = 7, score = 100
            //   50                   | push                eax
            //   52                   | push                edx
            //   e8????????           |                     
            //   58                   | pop                 eax
            //   8d8424d8170000       | lea                 eax, [esp + 0x17d8]
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_3 = { 8d4400e0 50 e8???????? 89c2 a3???????? 83c410 83c8ff }
            // n = 7, score = 100
            //   8d4400e0             | lea                 eax, [eax + eax - 0x20]
            //   50                   | push                eax
            //   e8????????           |                     
            //   89c2                 | mov                 edx, eax
            //   a3????????           |                     
            //   83c410               | add                 esp, 0x10
            //   83c8ff               | or                  eax, 0xffffffff

        $sequence_4 = { 817c2414ff030000 0f8770030000 8b442414 c1e004 83b888a2050800 0f85df000000 8b0d???????? }
            // n = 7, score = 100
            //   817c2414ff030000     | cmp                 dword ptr [esp + 0x14], 0x3ff
            //   0f8770030000         | ja                  0x376
            //   8b442414             | mov                 eax, dword ptr [esp + 0x14]
            //   c1e004               | shl                 eax, 4
            //   83b888a2050800       | cmp                 dword ptr [eax + 0x805a288], 0
            //   0f85df000000         | jne                 0xe5
            //   8b0d????????         |                     

        $sequence_5 = { c7042408000000 50 a1???????? 6a1a 6a01 50 e8???????? }
            // n = 7, score = 100
            //   c7042408000000       | mov                 dword ptr [esp], 8
            //   50                   | push                eax
            //   a1????????           |                     
            //   6a1a                 | push                0x1a
            //   6a01                 | push                1
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_6 = { 83c418 5b c3 81ecac000000 31d2 a1???????? }
            // n = 6, score = 100
            //   83c418               | add                 esp, 0x18
            //   5b                   | pop                 ebx
            //   c3                   | ret                 
            //   81ecac000000         | sub                 esp, 0xac
            //   31d2                 | xor                 edx, edx
            //   a1????????           |                     

        $sequence_7 = { 85c0 74cb e8???????? 52 52 8b00 }
            // n = 6, score = 100
            //   85c0                 | test                eax, eax
            //   74cb                 | je                  0xffffffcd
            //   e8????????           |                     
            //   52                   | push                edx
            //   52                   | push                edx
            //   8b00                 | mov                 eax, dword ptr [eax]

        $sequence_8 = { c680b901000000 8b45f0 e8???????? 89f0 8b55f0 e8???????? 8b45f0 }
            // n = 7, score = 100
            //   c680b901000000       | mov                 byte ptr [eax + 0x1b9], 0
            //   8b45f0               | mov                 eax, dword ptr [ebp - 0x10]
            //   e8????????           |                     
            //   89f0                 | mov                 eax, esi
            //   8b55f0               | mov                 edx, dword ptr [ebp - 0x10]
            //   e8????????           |                     
            //   8b45f0               | mov                 eax, dword ptr [ebp - 0x10]

        $sequence_9 = { 83c004 89442418 e9???????? bf0a000000 e9???????? bf10000000 e9???????? }
            // n = 7, score = 100
            //   83c004               | add                 eax, 4
            //   89442418             | mov                 dword ptr [esp + 0x18], eax
            //   e9????????           |                     
            //   bf0a000000           | mov                 edi, 0xa
            //   e9????????           |                     
            //   bf10000000           | mov                 edi, 0x10
            //   e9????????           |                     

    condition:
        7 of them and filesize < 229376
}