rule elf_satori_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects elf.satori."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/elf.satori"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 85c0 7804 8b542414 89d0 83c41c }
            // n = 5, score = 100
            //   85c0                 | test                eax, eax
            //   7804                 | js                  6
            //   8b542414             | mov                 edx, dword ptr [esp + 0x14]
            //   89d0                 | mov                 eax, edx
            //   83c41c               | add                 esp, 0x1c

        $sequence_1 = { e8???????? b9???????? b802000000 89ca e8???????? }
            // n = 5, score = 100
            //   e8????????           |                     
            //   b9????????           |                     
            //   b802000000           | mov                 eax, 2
            //   89ca                 | mov                 edx, ecx
            //   e8????????           |                     

        $sequence_2 = { 89c6 53 89d3 83ec10 52 e8???????? }
            // n = 6, score = 100
            //   89c6                 | mov                 esi, eax
            //   53                   | push                ebx
            //   89d3                 | mov                 ebx, edx
            //   83ec10               | sub                 esp, 0x10
            //   52                   | push                edx
            //   e8????????           |                     

        $sequence_3 = { b802000000 e8???????? b905000000 ba???????? b802000000 e8???????? b908000000 }
            // n = 7, score = 100
            //   b802000000           | mov                 eax, 2
            //   e8????????           |                     
            //   b905000000           | mov                 ecx, 5
            //   ba????????           |                     
            //   b802000000           | mov                 eax, 2
            //   e8????????           |                     
            //   b908000000           | mov                 ecx, 8

        $sequence_4 = { c744244800000000 e9???????? 8b542404 8b3482 6bc018 03442464 }
            // n = 6, score = 100
            //   c744244800000000     | mov                 dword ptr [esp + 0x48], 0
            //   e9????????           |                     
            //   8b542404             | mov                 edx, dword ptr [esp + 4]
            //   8b3482               | mov                 esi, dword ptr [edx + eax*4]
            //   6bc018               | imul                eax, eax, 0x18
            //   03442464             | add                 eax, dword ptr [esp + 0x64]

        $sequence_5 = { e8???????? 83c414 6a1f e8???????? c7042420000000 e8???????? c785280400001e000000 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   83c414               | add                 esp, 0x14
            //   6a1f                 | push                0x1f
            //   e8????????           |                     
            //   c7042420000000       | mov                 dword ptr [esp], 0x20
            //   e8????????           |                     
            //   c785280400001e000000     | mov    dword ptr [ebp + 0x428], 0x1e

        $sequence_6 = { 85c0 7416 83ec0c ff35???????? e8???????? 59 6a00 }
            // n = 7, score = 100
            //   85c0                 | test                eax, eax
            //   7416                 | je                  0x18
            //   83ec0c               | sub                 esp, 0xc
            //   ff35????????         |                     
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   6a00                 | push                0

        $sequence_7 = { 3b410c 747c 8b45bc 83ec0c 8b55cc 8d5def 8945e0 }
            // n = 7, score = 100
            //   3b410c               | cmp                 eax, dword ptr [ecx + 0xc]
            //   747c                 | je                  0x7e
            //   8b45bc               | mov                 eax, dword ptr [ebp - 0x44]
            //   83ec0c               | sub                 esp, 0xc
            //   8b55cc               | mov                 edx, dword ptr [ebp - 0x34]
            //   8d5def               | lea                 ebx, [ebp - 0x11]
            //   8945e0               | mov                 dword ptr [ebp - 0x20], eax

        $sequence_8 = { 6a04 56 53 e8???????? 8844243a 83c420 6a00 }
            // n = 7, score = 100
            //   6a04                 | push                4
            //   56                   | push                esi
            //   53                   | push                ebx
            //   e8????????           |                     
            //   8844243a             | mov                 byte ptr [esp + 0x3a], al
            //   83c420               | add                 esp, 0x20
            //   6a00                 | push                0

        $sequence_9 = { 6a15 68???????? 6a1d e8???????? 83c40c 6a15 68???????? }
            // n = 7, score = 100
            //   6a15                 | push                0x15
            //   68????????           |                     
            //   6a1d                 | push                0x1d
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   6a15                 | push                0x15
            //   68????????           |                     

    condition:
        7 of them and filesize < 122880
}