rule win_8t_dropper_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.8t_dropper."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.8t_dropper"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 741b 56 6800700000 6a01 68???????? }
            // n = 5, score = 200
            //   741b                 | je                  0x1d
            //   56                   | push                esi
            //   6800700000           | push                0x7000
            //   6a01                 | push                1
            //   68????????           |                     

        $sequence_1 = { ff74240c e8???????? 83c40c c3 8b442408 83f801 }
            // n = 6, score = 200
            //   ff74240c             | push                dword ptr [esp + 0xc]
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   c3                   | ret                 
            //   8b442408             | mov                 eax, dword ptr [esp + 8]
            //   83f801               | cmp                 eax, 1

        $sequence_2 = { c6440c0e6e 8d4c2408 51 683f000f00 50 }
            // n = 5, score = 200
            //   c6440c0e6e           | mov                 byte ptr [esp + ecx + 0xe], 0x6e
            //   8d4c2408             | lea                 ecx, [esp + 8]
            //   51                   | push                ecx
            //   683f000f00           | push                0xf003f
            //   50                   | push                eax

        $sequence_3 = { 68???????? 50 ff15???????? 85c0 7559 8b4c2408 51 }
            // n = 7, score = 200
            //   68????????           |                     
            //   50                   | push                eax
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7559                 | jne                 0x5b
            //   8b4c2408             | mov                 ecx, dword ptr [esp + 8]
            //   51                   | push                ecx

        $sequence_4 = { 50 ff15???????? 85c0 7559 8b4c2408 }
            // n = 5, score = 200
            //   50                   | push                eax
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7559                 | jne                 0x5b
            //   8b4c2408             | mov                 ecx, dword ptr [esp + 8]

        $sequence_5 = { 49 c6440c0c52 c6440c0d75 c6440c0e6e }
            // n = 4, score = 200
            //   49                   | dec                 ecx
            //   c6440c0c52           | mov                 byte ptr [esp + ecx + 0xc], 0x52
            //   c6440c0d75           | mov                 byte ptr [esp + ecx + 0xd], 0x75
            //   c6440c0e6e           | mov                 byte ptr [esp + ecx + 0xe], 0x6e

        $sequence_6 = { 68???????? 6a02 50 8b442418 }
            // n = 4, score = 200
            //   68????????           |                     
            //   6a02                 | push                2
            //   50                   | push                eax
            //   8b442418             | mov                 eax, dword ptr [esp + 0x18]

        $sequence_7 = { 7559 8b4c2408 51 ff15???????? }
            // n = 4, score = 200
            //   7559                 | jne                 0x5b
            //   8b4c2408             | mov                 ecx, dword ptr [esp + 8]
            //   51                   | push                ecx
            //   ff15????????         |                     

        $sequence_8 = { 6800700000 6a01 68???????? e8???????? 56 e8???????? }
            // n = 6, score = 200
            //   6800700000           | push                0x7000
            //   6a01                 | push                1
            //   68????????           |                     
            //   e8????????           |                     
            //   56                   | push                esi
            //   e8????????           |                     

        $sequence_9 = { ff15???????? 8d942410010000 6804010000 52 68???????? }
            // n = 5, score = 200
            //   ff15????????         |                     
            //   8d942410010000       | lea                 edx, [esp + 0x110]
            //   6804010000           | push                0x104
            //   52                   | push                edx
            //   68????????           |                     

    condition:
        7 of them and filesize < 147456
}