rule win_acridrain_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.acridrain."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.acridrain"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { eb03 8b4dd0 8b45e0 8b55cc 8945cc 8a45f0 8955e0 }
            // n = 7, score = 200
            //   eb03                 | jmp                 5
            //   8b4dd0               | mov                 ecx, dword ptr [ebp - 0x30]
            //   8b45e0               | mov                 eax, dword ptr [ebp - 0x20]
            //   8b55cc               | mov                 edx, dword ptr [ebp - 0x34]
            //   8945cc               | mov                 dword ptr [ebp - 0x34], eax
            //   8a45f0               | mov                 al, byte ptr [ebp - 0x10]
            //   8955e0               | mov                 dword ptr [ebp - 0x20], edx

        $sequence_1 = { ff76a4 53 e8???????? 83c428 8945dc e9???????? 6a00 }
            // n = 7, score = 200
            //   ff76a4               | push                dword ptr [esi - 0x5c]
            //   53                   | push                ebx
            //   e8????????           |                     
            //   83c428               | add                 esp, 0x28
            //   8945dc               | mov                 dword ptr [ebp - 0x24], eax
            //   e9????????           |                     
            //   6a00                 | push                0

        $sequence_2 = { ffd0 8b75f0 8bc8 83c414 85c9 0f85c5000000 0fce }
            // n = 7, score = 200
            //   ffd0                 | call                eax
            //   8b75f0               | mov                 esi, dword ptr [ebp - 0x10]
            //   8bc8                 | mov                 ecx, eax
            //   83c414               | add                 esp, 0x14
            //   85c9                 | test                ecx, ecx
            //   0f85c5000000         | jne                 0xcb
            //   0fce                 | bswap               esi

        $sequence_3 = { eb0c 8b4d9c 83c104 894d9c 8b41fc 8945a0 8bc8 }
            // n = 7, score = 200
            //   eb0c                 | jmp                 0xe
            //   8b4d9c               | mov                 ecx, dword ptr [ebp - 0x64]
            //   83c104               | add                 ecx, 4
            //   894d9c               | mov                 dword ptr [ebp - 0x64], ecx
            //   8b41fc               | mov                 eax, dword ptr [ecx - 4]
            //   8945a0               | mov                 dword ptr [ebp - 0x60], eax
            //   8bc8                 | mov                 ecx, eax

        $sequence_4 = { eb5d 8b03 8b8890860000 803900 7520 8d442414 6801040000 }
            // n = 7, score = 200
            //   eb5d                 | jmp                 0x5f
            //   8b03                 | mov                 eax, dword ptr [ebx]
            //   8b8890860000         | mov                 ecx, dword ptr [eax + 0x8690]
            //   803900               | cmp                 byte ptr [ecx], 0
            //   7520                 | jne                 0x22
            //   8d442414             | lea                 eax, [esp + 0x14]
            //   6801040000           | push                0x401

        $sequence_5 = { 8b8520ffffff 33ff 8b10 85d2 0f8ea6000000 33c9 898d50ffffff }
            // n = 7, score = 200
            //   8b8520ffffff         | mov                 eax, dword ptr [ebp - 0xe0]
            //   33ff                 | xor                 edi, edi
            //   8b10                 | mov                 edx, dword ptr [eax]
            //   85d2                 | test                edx, edx
            //   0f8ea6000000         | jle                 0xac
            //   33c9                 | xor                 ecx, ecx
            //   898d50ffffff         | mov                 dword ptr [ebp - 0xb0], ecx

        $sequence_6 = { f6459c01 0f84ae0b0000 8bc6 83e007 3bf0 0f83d50a0000 e9???????? }
            // n = 7, score = 200
            //   f6459c01             | test                byte ptr [ebp - 0x64], 1
            //   0f84ae0b0000         | je                  0xbb4
            //   8bc6                 | mov                 eax, esi
            //   83e007               | and                 eax, 7
            //   3bf0                 | cmp                 esi, eax
            //   0f83d50a0000         | jae                 0xadb
            //   e9????????           |                     

        $sequence_7 = { 8b4748 56 ffd0 8b7584 83c410 8bbd78ffffff eb09 }
            // n = 7, score = 200
            //   8b4748               | mov                 eax, dword ptr [edi + 0x48]
            //   56                   | push                esi
            //   ffd0                 | call                eax
            //   8b7584               | mov                 esi, dword ptr [ebp - 0x7c]
            //   83c410               | add                 esp, 0x10
            //   8bbd78ffffff         | mov                 edi, dword ptr [ebp - 0x88]
            //   eb09                 | jmp                 0xb

        $sequence_8 = { ffb5d0fdffff e8???????? 83c408 8985d4fdffff 85c0 0f85844b0000 ffb5d0fdffff }
            // n = 7, score = 200
            //   ffb5d0fdffff         | push                dword ptr [ebp - 0x230]
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   8985d4fdffff         | mov                 dword ptr [ebp - 0x22c], eax
            //   85c0                 | test                eax, eax
            //   0f85844b0000         | jne                 0x4b8a
            //   ffb5d0fdffff         | push                dword ptr [ebp - 0x230]

        $sequence_9 = { e9???????? 83fe02 750c c7872005000003000000 eb7b c7872005000000000000 83fe03 }
            // n = 7, score = 200
            //   e9????????           |                     
            //   83fe02               | cmp                 esi, 2
            //   750c                 | jne                 0xe
            //   c7872005000003000000     | mov    dword ptr [edi + 0x520], 3
            //   eb7b                 | jmp                 0x7d
            //   c7872005000000000000     | mov    dword ptr [edi + 0x520], 0
            //   83fe03               | cmp                 esi, 3

    condition:
        7 of them and filesize < 2244608
}