rule win_action_rat_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.action_rat."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.action_rat"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d4d0c e8???????? 8b4508 8b4df4 64890d00000000 59 5b }
            // n = 7, score = 100
            //   8d4d0c               | lea                 ecx, [ebp + 0xc]
            //   e8????????           |                     
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]
            //   64890d00000000       | mov                 dword ptr fs:[0], ecx
            //   59                   | pop                 ecx
            //   5b                   | pop                 ebx

        $sequence_1 = { 8b55f8 52 8b4dfc 83c134 e8???????? 8b00 50 }
            // n = 7, score = 100
            //   8b55f8               | mov                 edx, dword ptr [ebp - 8]
            //   52                   | push                edx
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   83c134               | add                 ecx, 0x34
            //   e8????????           |                     
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   50                   | push                eax

        $sequence_2 = { 83c270 52 8b4dfc 83c170 }
            // n = 4, score = 100
            //   83c270               | add                 edx, 0x70
            //   52                   | push                edx
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   83c170               | add                 ecx, 0x70

        $sequence_3 = { e8???????? c745d400000000 eb09 8b4dd4 83c101 894dd4 8d4d0c }
            // n = 7, score = 100
            //   e8????????           |                     
            //   c745d400000000       | mov                 dword ptr [ebp - 0x2c], 0
            //   eb09                 | jmp                 0xb
            //   8b4dd4               | mov                 ecx, dword ptr [ebp - 0x2c]
            //   83c101               | add                 ecx, 1
            //   894dd4               | mov                 dword ptr [ebp - 0x2c], ecx
            //   8d4d0c               | lea                 ecx, [ebp + 0xc]

        $sequence_4 = { 7420 0fb645fb 50 8b4df4 8b4918 e8???????? 0fb6d0 }
            // n = 7, score = 100
            //   7420                 | je                  0x22
            //   0fb645fb             | movzx               eax, byte ptr [ebp - 5]
            //   50                   | push                eax
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]
            //   8b4918               | mov                 ecx, dword ptr [ecx + 0x18]
            //   e8????????           |                     
            //   0fb6d0               | movzx               edx, al

        $sequence_5 = { 0fb74202 50 ff15???????? 0fb7c8 8b5514 890a }
            // n = 6, score = 100
            //   0fb74202             | movzx               eax, word ptr [edx + 2]
            //   50                   | push                eax
            //   ff15????????         |                     
            //   0fb7c8               | movzx               ecx, ax
            //   8b5514               | mov                 edx, dword ptr [ebp + 0x14]
            //   890a                 | mov                 dword ptr [edx], ecx

        $sequence_6 = { 6a00 8b45fc 50 8b4d08 51 e8???????? 83c418 }
            // n = 7, score = 100
            //   6a00                 | push                0
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   50                   | push                eax
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   51                   | push                ecx
            //   e8????????           |                     
            //   83c418               | add                 esp, 0x18

        $sequence_7 = { e8???????? 8d8ddcfbffff e8???????? c645fc0e 6a00 68e0930400 6a00 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8d8ddcfbffff         | lea                 ecx, [ebp - 0x424]
            //   e8????????           |                     
            //   c645fc0e             | mov                 byte ptr [ebp - 4], 0xe
            //   6a00                 | push                0
            //   68e0930400           | push                0x493e0
            //   6a00                 | push                0

        $sequence_8 = { 0de0000000 b901000000 6bd100 8b4d0c 880411 8b5508 c1fa06 }
            // n = 7, score = 100
            //   0de0000000           | or                  eax, 0xe0
            //   b901000000           | mov                 ecx, 1
            //   6bd100               | imul                edx, ecx, 0
            //   8b4d0c               | mov                 ecx, dword ptr [ebp + 0xc]
            //   880411               | mov                 byte ptr [ecx + edx], al
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]
            //   c1fa06               | sar                 edx, 6

        $sequence_9 = { 8b4df4 3b4df8 750b 68???????? ff15???????? 8b55ec 833a22 }
            // n = 7, score = 100
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]
            //   3b4df8               | cmp                 ecx, dword ptr [ebp - 8]
            //   750b                 | jne                 0xd
            //   68????????           |                     
            //   ff15????????         |                     
            //   8b55ec               | mov                 edx, dword ptr [ebp - 0x14]
            //   833a22               | cmp                 dword ptr [edx], 0x22

    condition:
        7 of them and filesize < 480256
}