rule win_adhubllka_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.adhubllka."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.adhubllka"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 8d8d60ffffff e8???????? 0f108560ffffff be18000000 0f1185c0feffff }
            // n = 6, score = 500
            //   e8????????           |                     
            //   8d8d60ffffff         | lea                 ecx, [ebp - 0xa0]
            //   e8????????           |                     
            //   0f108560ffffff       | movups              xmm0, xmmword ptr [ebp - 0xa0]
            //   be18000000           | mov                 esi, 0x18
            //   0f1185c0feffff       | movups              xmmword ptr [ebp - 0x140], xmm0

        $sequence_1 = { 0f104590 0f118540ffffff 0f1045a0 0f118550ffffff e8???????? 83c404 8d8d60ffffff }
            // n = 7, score = 500
            //   0f104590             | movups              xmm0, xmmword ptr [ebp - 0x70]
            //   0f118540ffffff       | movups              xmmword ptr [ebp - 0xc0], xmm0
            //   0f1045a0             | movups              xmm0, xmmword ptr [ebp - 0x60]
            //   0f118550ffffff       | movups              xmmword ptr [ebp - 0xb0], xmm0
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   8d8d60ffffff         | lea                 ecx, [ebp - 0xa0]

        $sequence_2 = { 894d9c 8b4dbc 89458c 8b45c4 897d98 8b7dc0 }
            // n = 6, score = 500
            //   894d9c               | mov                 dword ptr [ebp - 0x64], ecx
            //   8b4dbc               | mov                 ecx, dword ptr [ebp - 0x44]
            //   89458c               | mov                 dword ptr [ebp - 0x74], eax
            //   8b45c4               | mov                 eax, dword ptr [ebp - 0x3c]
            //   897d98               | mov                 dword ptr [ebp - 0x68], edi
            //   8b7dc0               | mov                 edi, dword ptr [ebp - 0x40]

        $sequence_3 = { 7410 f745d800000002 7407 b801000000 eb02 33c0 }
            // n = 6, score = 500
            //   7410                 | je                  0x12
            //   f745d800000002       | test                dword ptr [ebp - 0x28], 0x2000000
            //   7407                 | je                  9
            //   b801000000           | mov                 eax, 1
            //   eb02                 | jmp                 4
            //   33c0                 | xor                 eax, eax

        $sequence_4 = { 03c2 898534ffffff 33c7 c1c008 898520ffffff 03c1 8b4ddc }
            // n = 7, score = 500
            //   03c2                 | add                 eax, edx
            //   898534ffffff         | mov                 dword ptr [ebp - 0xcc], eax
            //   33c7                 | xor                 eax, edi
            //   c1c008               | rol                 eax, 8
            //   898520ffffff         | mov                 dword ptr [ebp - 0xe0], eax
            //   03c1                 | add                 eax, ecx
            //   8b4ddc               | mov                 ecx, dword ptr [ebp - 0x24]

        $sequence_5 = { 0fb605???????? c1e108 0bc8 0fb605???????? c1e108 0bc8 }
            // n = 6, score = 500
            //   0fb605????????       |                     
            //   c1e108               | shl                 ecx, 8
            //   0bc8                 | or                  ecx, eax
            //   0fb605????????       |                     
            //   c1e108               | shl                 ecx, 8
            //   0bc8                 | or                  ecx, eax

        $sequence_6 = { e8???????? 83c404 0f57c0 660f138424501a0000 6a02 }
            // n = 5, score = 500
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   0f57c0               | xorps               xmm0, xmm0
            //   660f138424501a0000     | movlpd    qword ptr [esp + 0x1a50], xmm0
            //   6a02                 | push                2

        $sequence_7 = { 8d8d60ffffff e8???????? 8d8d60ffffff e8???????? 0f108560ffffff be04000000 0f118510ffffff }
            // n = 7, score = 500
            //   8d8d60ffffff         | lea                 ecx, [ebp - 0xa0]
            //   e8????????           |                     
            //   8d8d60ffffff         | lea                 ecx, [ebp - 0xa0]
            //   e8????????           |                     
            //   0f108560ffffff       | movups              xmm0, xmmword ptr [ebp - 0xa0]
            //   be04000000           | mov                 esi, 4
            //   0f118510ffffff       | movups              xmmword ptr [ebp - 0xf0], xmm0

        $sequence_8 = { 0f1f440000 8b5cbc48 53 ff15???????? 83f801 }
            // n = 5, score = 500
            //   0f1f440000           | nop                 dword ptr [eax + eax]
            //   8b5cbc48             | mov                 ebx, dword ptr [esp + edi*4 + 0x48]
            //   53                   | push                ebx
            //   ff15????????         |                     
            //   83f801               | cmp                 eax, 1

        $sequence_9 = { ffb590fdffff ff15???????? 85c0 0f8481fdffff 56 e8???????? }
            // n = 6, score = 500
            //   ffb590fdffff         | push                dword ptr [ebp - 0x270]
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   0f8481fdffff         | je                  0xfffffd87
            //   56                   | push                esi
            //   e8????????           |                     

    condition:
        7 of them and filesize < 253952
}