rule win_adkoob_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.adkoob."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.adkoob"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ff706c ffb0b0000000 8bc7 6a14 59 99 f7f9 }
            // n = 7, score = 400
            //   ff706c               | push                dword ptr [eax + 0x6c]
            //   ffb0b0000000         | push                dword ptr [eax + 0xb0]
            //   8bc7                 | mov                 eax, edi
            //   6a14                 | push                0x14
            //   59                   | pop                 ecx
            //   99                   | cdq                 
            //   f7f9                 | idiv                ecx

        $sequence_1 = { ff75f0 6a38 5a e8???????? 83c40c 8bce 40 }
            // n = 7, score = 400
            //   ff75f0               | push                dword ptr [ebp - 0x10]
            //   6a38                 | push                0x38
            //   5a                   | pop                 edx
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   8bce                 | mov                 ecx, esi
            //   40                   | inc                 eax

        $sequence_2 = { 8d5801 e9???????? 53 8bcf e8???????? 8b5dd8 84c0 }
            // n = 7, score = 400
            //   8d5801               | lea                 ebx, [eax + 1]
            //   e9????????           |                     
            //   53                   | push                ebx
            //   8bcf                 | mov                 ecx, edi
            //   e8????????           |                     
            //   8b5dd8               | mov                 ebx, dword ptr [ebp - 0x28]
            //   84c0                 | test                al, al

        $sequence_3 = { 8955f8 8b90d4000000 0fb6443b06 c1e108 0bc8 897de8 2bf1 }
            // n = 7, score = 400
            //   8955f8               | mov                 dword ptr [ebp - 8], edx
            //   8b90d4000000         | mov                 edx, dword ptr [eax + 0xd4]
            //   0fb6443b06           | movzx               eax, byte ptr [ebx + edi + 6]
            //   c1e108               | shl                 ecx, 8
            //   0bc8                 | or                  ecx, eax
            //   897de8               | mov                 dword ptr [ebp - 0x18], edi
            //   2bf1                 | sub                 esi, ecx

        $sequence_4 = { ff504c 85c0 7536 8b75dc 56 ff15???????? 50 }
            // n = 7, score = 400
            //   ff504c               | call                dword ptr [eax + 0x4c]
            //   85c0                 | test                eax, eax
            //   7536                 | jne                 0x38
            //   8b75dc               | mov                 esi, dword ptr [ebp - 0x24]
            //   56                   | push                esi
            //   ff15????????         |                     
            //   50                   | push                eax

        $sequence_5 = { 8b7508 83fe09 7756 80beac1d4c0000 57 8b3d???????? 0f453d???????? }
            // n = 7, score = 400
            //   8b7508               | mov                 esi, dword ptr [ebp + 8]
            //   83fe09               | cmp                 esi, 9
            //   7756                 | ja                  0x58
            //   80beac1d4c0000       | cmp                 byte ptr [esi + 0x4c1dac], 0
            //   57                   | push                edi
            //   8b3d????????         |                     
            //   0f453d????????       |                     

        $sequence_6 = { ff75e8 ff15???????? 837dd000 8b35???????? 7405 ff75d0 ffd6 }
            // n = 7, score = 400
            //   ff75e8               | push                dword ptr [ebp - 0x18]
            //   ff15????????         |                     
            //   837dd000             | cmp                 dword ptr [ebp - 0x30], 0
            //   8b35????????         |                     
            //   7405                 | je                  7
            //   ff75d0               | push                dword ptr [ebp - 0x30]
            //   ffd6                 | call                esi

        $sequence_7 = { ff742418 68???????? e8???????? 83c40c 89442428 85c0 747b }
            // n = 7, score = 400
            //   ff742418             | push                dword ptr [esp + 0x18]
            //   68????????           |                     
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   89442428             | mov                 dword ptr [esp + 0x28], eax
            //   85c0                 | test                eax, eax
            //   747b                 | je                  0x7d

        $sequence_8 = { ff7510 8bce ffb578ffffff ff75b8 ff7598 ffb564ffffff ff75c4 }
            // n = 7, score = 400
            //   ff7510               | push                dword ptr [ebp + 0x10]
            //   8bce                 | mov                 ecx, esi
            //   ffb578ffffff         | push                dword ptr [ebp - 0x88]
            //   ff75b8               | push                dword ptr [ebp - 0x48]
            //   ff7598               | push                dword ptr [ebp - 0x68]
            //   ffb564ffffff         | push                dword ptr [ebp - 0x9c]
            //   ff75c4               | push                dword ptr [ebp - 0x3c]

        $sequence_9 = { 8b4744 52 50 8b08 ff5114 59 59 }
            // n = 7, score = 400
            //   8b4744               | mov                 eax, dword ptr [edi + 0x44]
            //   52                   | push                edx
            //   50                   | push                eax
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   ff5114               | call                dword ptr [ecx + 0x14]
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx

    condition:
        7 of them and filesize < 1867776
}