rule win_allaple_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.allaple."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.allaple"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 50 ff75a0 e8???????? 83f8ff 756a e8???????? 3d33270000 }
            // n = 7, score = 300
            //   50                   | push                eax
            //   ff75a0               | push                dword ptr [ebp - 0x60]
            //   e8????????           |                     
            //   83f8ff               | cmp                 eax, -1
            //   756a                 | jne                 0x6c
            //   e8????????           |                     
            //   3d33270000           | cmp                 eax, 0x2733

        $sequence_1 = { 7708 2b7b0c 037b14 eb0f 83c328 83c628 }
            // n = 6, score = 300
            //   7708                 | ja                  0xa
            //   2b7b0c               | sub                 edi, dword ptr [ebx + 0xc]
            //   037b14               | add                 edi, dword ptr [ebx + 0x14]
            //   eb0f                 | jmp                 0x11
            //   83c328               | add                 ebx, 0x28
            //   83c628               | add                 esi, 0x28

        $sequence_2 = { 6a40 8b55a8 8d4db0 e8???????? 8b55f8 2355f4 8b45f8 }
            // n = 7, score = 300
            //   6a40                 | push                0x40
            //   8b55a8               | mov                 edx, dword ptr [ebp - 0x58]
            //   8d4db0               | lea                 ecx, [ebp - 0x50]
            //   e8????????           |                     
            //   8b55f8               | mov                 edx, dword ptr [ebp - 8]
            //   2355f4               | and                 edx, dword ptr [ebp - 0xc]
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]

        $sequence_3 = { 6a14 ff7508 57 e8???????? 83c714 c70701000000 83c704 }
            // n = 7, score = 300
            //   6a14                 | push                0x14
            //   ff7508               | push                dword ptr [ebp + 8]
            //   57                   | push                edi
            //   e8????????           |                     
            //   83c714               | add                 edi, 0x14
            //   c70701000000         | mov                 dword ptr [edi], 1
            //   83c704               | add                 edi, 4

        $sequence_4 = { 6800800000 6a00 ff75e0 e8???????? eb09 0bc0 7505 }
            // n = 7, score = 300
            //   6800800000           | push                0x8000
            //   6a00                 | push                0
            //   ff75e0               | push                dword ptr [ebp - 0x20]
            //   e8????????           |                     
            //   eb09                 | jmp                 0xb
            //   0bc0                 | or                  eax, eax
            //   7505                 | jne                 7

        $sequence_5 = { 55 8bec 83ec24 8955e0 894de4 c745fc00000000 8b45fc }
            // n = 7, score = 300
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   83ec24               | sub                 esp, 0x24
            //   8955e0               | mov                 dword ptr [ebp - 0x20], edx
            //   894de4               | mov                 dword ptr [ebp - 0x1c], ecx
            //   c745fc00000000       | mov                 dword ptr [ebp - 4], 0
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]

        $sequence_6 = { 894174 8b55fc 8b4278 3345f4 8b4df8 894178 8b55fc }
            // n = 7, score = 300
            //   894174               | mov                 dword ptr [ecx + 0x74], eax
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   8b4278               | mov                 eax, dword ptr [edx + 0x78]
            //   3345f4               | xor                 eax, dword ptr [ebp - 0xc]
            //   8b4df8               | mov                 ecx, dword ptr [ebp - 8]
            //   894178               | mov                 dword ptr [ecx + 0x78], eax
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]

        $sequence_7 = { 0f8539010000 8145f8bc020000 ff75f8 e8???????? 8945f4 ff75fc ff75f4 }
            // n = 7, score = 300
            //   0f8539010000         | jne                 0x13f
            //   8145f8bc020000       | add                 dword ptr [ebp - 8], 0x2bc
            //   ff75f8               | push                dword ptr [ebp - 8]
            //   e8????????           |                     
            //   8945f4               | mov                 dword ptr [ebp - 0xc], eax
            //   ff75fc               | push                dword ptr [ebp - 4]
            //   ff75f4               | push                dword ptr [ebp - 0xc]

        $sequence_8 = { ff45fc 8b45fc 3b4510 7ce5 8be5 5d c3 }
            // n = 7, score = 300
            //   ff45fc               | inc                 dword ptr [ebp - 4]
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   3b4510               | cmp                 eax, dword ptr [ebp + 0x10]
            //   7ce5                 | jl                  0xffffffe7
            //   8be5                 | mov                 esp, ebp
            //   5d                   | pop                 ebp
            //   c3                   | ret                 

        $sequence_9 = { 8b4df8 894178 8b55fc 8b427c 3345f4 8b4df8 89417c }
            // n = 7, score = 300
            //   8b4df8               | mov                 ecx, dword ptr [ebp - 8]
            //   894178               | mov                 dword ptr [ecx + 0x78], eax
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   8b427c               | mov                 eax, dword ptr [edx + 0x7c]
            //   3345f4               | xor                 eax, dword ptr [ebp - 0xc]
            //   8b4df8               | mov                 ecx, dword ptr [ebp - 8]
            //   89417c               | mov                 dword ptr [ecx + 0x7c], eax

    condition:
        7 of them and filesize < 253952
}