rule win_alphanc_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.alphanc."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.alphanc"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c3 8b4c2428 85c9 757d 8b4c242c 85c9 7543 }
            // n = 7, score = 100
            //   c3                   | ret                 
            //   8b4c2428             | mov                 ecx, dword ptr [esp + 0x28]
            //   85c9                 | test                ecx, ecx
            //   757d                 | jne                 0x7f
            //   8b4c242c             | mov                 ecx, dword ptr [esp + 0x2c]
            //   85c9                 | test                ecx, ecx
            //   7543                 | jne                 0x45

        $sequence_1 = { e8???????? 83c40c 89442410 85c0 0f84f6010000 8b4d14 8b5510 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   89442410             | mov                 dword ptr [esp + 0x10], eax
            //   85c0                 | test                eax, eax
            //   0f84f6010000         | je                  0x1fc
            //   8b4d14               | mov                 ecx, dword ptr [ebp + 0x14]
            //   8b5510               | mov                 edx, dword ptr [ebp + 0x10]

        $sequence_2 = { eb0a 8b4554 c7400c01000000 8b442414 8b4d54 c74538f0000000 894550 }
            // n = 7, score = 100
            //   eb0a                 | jmp                 0xc
            //   8b4554               | mov                 eax, dword ptr [ebp + 0x54]
            //   c7400c01000000       | mov                 dword ptr [eax + 0xc], 1
            //   8b442414             | mov                 eax, dword ptr [esp + 0x14]
            //   8b4d54               | mov                 ecx, dword ptr [ebp + 0x54]
            //   c74538f0000000       | mov                 dword ptr [ebp + 0x38], 0xf0
            //   894550               | mov                 dword ptr [ebp + 0x50], eax

        $sequence_3 = { 03c1 8b4c2444 13d7 2bc1 8bce 1bd1 8b4c243c }
            // n = 7, score = 100
            //   03c1                 | add                 eax, ecx
            //   8b4c2444             | mov                 ecx, dword ptr [esp + 0x44]
            //   13d7                 | adc                 edx, edi
            //   2bc1                 | sub                 eax, ecx
            //   8bce                 | mov                 ecx, esi
            //   1bd1                 | sbb                 edx, ecx
            //   8b4c243c             | mov                 ecx, dword ptr [esp + 0x3c]

        $sequence_4 = { 8d55f0 6a00 52 6a04 68???????? 57 ff15???????? }
            // n = 7, score = 100
            //   8d55f0               | lea                 edx, [ebp - 0x10]
            //   6a00                 | push                0
            //   52                   | push                edx
            //   6a04                 | push                4
            //   68????????           |                     
            //   57                   | push                edi
            //   ff15????????         |                     

        $sequence_5 = { 8b4758 8b8840030000 83f90e 7533 c7805403000001000000 8b4f58 39a978010000 }
            // n = 7, score = 100
            //   8b4758               | mov                 eax, dword ptr [edi + 0x58]
            //   8b8840030000         | mov                 ecx, dword ptr [eax + 0x340]
            //   83f90e               | cmp                 ecx, 0xe
            //   7533                 | jne                 0x35
            //   c7805403000001000000     | mov    dword ptr [eax + 0x354], 1
            //   8b4f58               | mov                 ecx, dword ptr [edi + 0x58]
            //   39a978010000         | cmp                 dword ptr [ecx + 0x178], ebp

        $sequence_6 = { 33c0 56 f3ab 8b4e58 8b442424 89a9ec000000 8b5658 }
            // n = 7, score = 100
            //   33c0                 | xor                 eax, eax
            //   56                   | push                esi
            //   f3ab                 | rep stosd           dword ptr es:[edi], eax
            //   8b4e58               | mov                 ecx, dword ptr [esi + 0x58]
            //   8b442424             | mov                 eax, dword ptr [esp + 0x24]
            //   89a9ec000000         | mov                 dword ptr [ecx + 0xec], ebp
            //   8b5658               | mov                 edx, dword ptr [esi + 0x58]

        $sequence_7 = { 8b4c2430 83c420 8d0c49 8d440804 83f808 0f87d7000000 ff248574354600 }
            // n = 7, score = 100
            //   8b4c2430             | mov                 ecx, dword ptr [esp + 0x30]
            //   83c420               | add                 esp, 0x20
            //   8d0c49               | lea                 ecx, [ecx + ecx*2]
            //   8d440804             | lea                 eax, [eax + ecx + 4]
            //   83f808               | cmp                 eax, 8
            //   0f87d7000000         | ja                  0xdd
            //   ff248574354600       | jmp                 dword ptr [eax*4 + 0x463574]

        $sequence_8 = { 8d4c2424 51 e8???????? 8d542454 52 e8???????? 8d442470 }
            // n = 7, score = 100
            //   8d4c2424             | lea                 ecx, [esp + 0x24]
            //   51                   | push                ecx
            //   e8????????           |                     
            //   8d542454             | lea                 edx, [esp + 0x54]
            //   52                   | push                edx
            //   e8????????           |                     
            //   8d442470             | lea                 eax, [esp + 0x70]

        $sequence_9 = { 8b4804 83f905 8954241c 7529 8b5048 55 52 }
            // n = 7, score = 100
            //   8b4804               | mov                 ecx, dword ptr [eax + 4]
            //   83f905               | cmp                 ecx, 5
            //   8954241c             | mov                 dword ptr [esp + 0x1c], edx
            //   7529                 | jne                 0x2b
            //   8b5048               | mov                 edx, dword ptr [eax + 0x48]
            //   55                   | push                ebp
            //   52                   | push                edx

    condition:
        7 of them and filesize < 2015232
}