rule win_anchor_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.anchor."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.anchor"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 740c 66c740016578 c6400365 eb0a }
            // n = 4, score = 800
            //   740c                 | je                  0xe
            //   66c740016578         | mov                 word ptr [eax + 1], 0x7865
            //   c6400365             | mov                 byte ptr [eax + 3], 0x65
            //   eb0a                 | jmp                 0xc

        $sequence_1 = { c6400365 eb0a 66c74001646c c640036c }
            // n = 4, score = 800
            //   c6400365             | mov                 byte ptr [eax + 3], 0x65
            //   eb0a                 | jmp                 0xc
            //   66c74001646c         | mov                 word ptr [eax + 1], 0x6c64
            //   c640036c             | mov                 byte ptr [eax + 3], 0x6c

        $sequence_2 = { 56 8d8dbcfeffff e8???????? 68???????? 8d8dbcfeffff }
            // n = 5, score = 600
            //   56                   | push                esi
            //   8d8dbcfeffff         | lea                 ecx, [ebp - 0x144]
            //   e8????????           |                     
            //   68????????           |                     
            //   8d8dbcfeffff         | lea                 ecx, [ebp - 0x144]

        $sequence_3 = { b101 e8???????? e8???????? 84c0 }
            // n = 4, score = 600
            //   b101                 | mov                 cl, 1
            //   e8????????           |                     
            //   e8????????           |                     
            //   84c0                 | test                al, al

        $sequence_4 = { 56 e8???????? 8b30 837e0c00 }
            // n = 4, score = 600
            //   56                   | push                esi
            //   e8????????           |                     
            //   8b30                 | mov                 esi, dword ptr [eax]
            //   837e0c00             | cmp                 dword ptr [esi + 0xc], 0

        $sequence_5 = { 8b4638 5f 66894812 33c9 8b4638 }
            // n = 5, score = 600
            //   8b4638               | dec                 esp
            //   5f                   | cmovae              eax, dword ptr [esp + 0x68]
            //   66894812             | dec                 eax
            //   33c9                 | mov                 eax, dword ptr [ebx + 0x18]
            //   8b4638               | mov                 word ptr [eax + 2], cx

        $sequence_6 = { f2e965020000 e9???????? 53 56 57 }
            // n = 5, score = 600
            //   f2e965020000         | bnd jmp             0x26b
            //   e9????????           |                     
            //   53                   | push                ebx
            //   56                   | push                esi
            //   57                   | push                edi

        $sequence_7 = { 0f90c1 f7d9 0bc8 51 e8???????? 8b0d???????? c1e102 }
            // n = 7, score = 600
            //   0f90c1               | seto                cl
            //   f7d9                 | neg                 ecx
            //   0bc8                 | or                  ecx, eax
            //   51                   | push                ecx
            //   e8????????           |                     
            //   8b0d????????         |                     
            //   c1e102               | shl                 ecx, 2

        $sequence_8 = { 0fb7c1 6641 66890d???????? 50 }
            // n = 4, score = 600
            //   0fb7c1               | movzx               eax, cx
            //   6641                 | inc                 cx
            //   66890d????????       |                     
            //   50                   | push                eax

        $sequence_9 = { 7509 33d2 33c9 e8???????? }
            // n = 4, score = 400
            //   7509                 | jne                 0xb
            //   33d2                 | xor                 edx, edx
            //   33c9                 | xor                 ecx, ecx
            //   e8????????           |                     

        $sequence_10 = { 488d0d520b0400 e8???????? 488b8500010000 488b8d08010000 }
            // n = 4, score = 200
            //   488d0d520b0400       | dec                 eax
            //   e8????????           |                     
            //   488b8500010000       | mov                 eax, dword ptr [ebp + 0x100]
            //   488b8d08010000       | dec                 eax

        $sequence_11 = { 488d0d516d0200 e8???????? 488d8d680e0000 e8???????? }
            // n = 4, score = 200
            //   488d0d516d0200       | lea                 ecx, [0x41b51]
            //   e8????????           |                     
            //   488d8d680e0000       | nop                 
            //   e8????????           |                     

        $sequence_12 = { 488d0d50840200 e8???????? 488d0d48840200 e8???????? }
            // n = 4, score = 200
            //   488d0d50840200       | dec                 eax
            //   e8????????           |                     
            //   488d0d48840200       | lea                 esp, [ebp + 0xe8]
            //   e8????????           |                     

        $sequence_13 = { 4903c7 c64405b079 4903c7 c64405b073 4903c7 c64405b074 4903c7 }
            // n = 7, score = 200
            //   4903c7               | nop                 
            //   c64405b079           | dec                 eax
            //   4903c7               | mov                 ecx, dword ptr [ebp + 0x100]
            //   c64405b073           | nop                 
            //   4903c7               | dec                 eax
            //   c64405b074           | lea                 ecx, [0x3cd52]
            //   4903c7               | nop                 

        $sequence_14 = { 488d0d528a0300 e8???????? 488b8de0000000 e8???????? }
            // n = 4, score = 200
            //   488d0d528a0300       | lea                 ecx, [ebp + 0xe68]
            //   e8????????           |                     
            //   488b8de0000000       | dec                 eax
            //   e8????????           |                     

        $sequence_15 = { 488b4318 66894802 8d4f6e 488b4318 66894804 }
            // n = 5, score = 200
            //   488b4318             | dec                 eax
            //   66894802             | lea                 esp, [ebp + 0xe8]
            //   8d4f6e               | dec                 eax
            //   488b4318             | lea                 ecx, [0x34d53]
            //   66894804             | dec                 eax

        $sequence_16 = { 488d0d52b90200 e8???????? e8???????? 48894508 }
            // n = 4, score = 200
            //   488d0d52b90200       | mov                 dword ptr [ebp + 0xec0], eax
            //   e8????????           |                     
            //   e8????????           |                     
            //   48894508             | dec                 eax

        $sequence_17 = { e8???????? 4c8d442468 48837d8010 4c0f43442468 }
            // n = 4, score = 200
            //   e8????????           |                     
            //   4c8d442468           | dec                 eax
            //   48837d8010           | mov                 ecx, dword ptr [ebp + 0x100]
            //   4c0f43442468         | nop                 

        $sequence_18 = { 488d0d50480300 e8???????? 90 488b8500010000 488da5e8000000 5f }
            // n = 6, score = 200
            //   488d0d50480300       | dec                 eax
            //   e8????????           |                     
            //   90                   | lea                 ecx, [0x34850]
            //   488b8500010000       | nop                 
            //   488da5e8000000       | dec                 eax
            //   5f                   | mov                 eax, dword ptr [ebp + 0x100]

        $sequence_19 = { 4889442428 488d85d0030000 4889442420 4c8d4c2448 }
            // n = 4, score = 200
            //   4889442428           | mov                 ecx, dword ptr [ebp + 0x200]
            //   488d85d0030000       | je                  0xe
            //   4889442420           | mov                 word ptr [eax + 1], 0x7865
            //   4c8d4c2448           | mov                 byte ptr [eax + 3], 0x65

        $sequence_20 = { 488d0d52cd0300 e8???????? 90 488b8d00010000 }
            // n = 4, score = 200
            //   488d0d52cd0300       | mov                 dword ptr [eax + 8], ecx
            //   e8????????           |                     
            //   90                   | dec                 eax
            //   488b8d00010000       | lea                 ecx, [0x40b52]

    condition:
        7 of them and filesize < 778240
}