rule win_aperetif_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.aperetif."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.aperetif"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b4108 8975e4 c70100000000 c7410400000000 8945ec c7410800000000 c645f301 }
            // n = 7, score = 100
            //   8b4108               | mov                 eax, dword ptr [ecx + 8]
            //   8975e4               | mov                 dword ptr [ebp - 0x1c], esi
            //   c70100000000         | mov                 dword ptr [ecx], 0
            //   c7410400000000       | mov                 dword ptr [ecx + 4], 0
            //   8945ec               | mov                 dword ptr [ebp - 0x14], eax
            //   c7410800000000       | mov                 dword ptr [ecx + 8], 0
            //   c645f301             | mov                 byte ptr [ebp - 0xd], 1

        $sequence_1 = { e8???????? 8a45d8 884524 8b0e c645fc02 85c9 0f8412010000 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8a45d8               | mov                 al, byte ptr [ebp - 0x28]
            //   884524               | mov                 byte ptr [ebp + 0x24], al
            //   8b0e                 | mov                 ecx, dword ptr [esi]
            //   c645fc02             | mov                 byte ptr [ebp - 4], 2
            //   85c9                 | test                ecx, ecx
            //   0f8412010000         | je                  0x118

        $sequence_2 = { 50 8d45f4 64a300000000 8bd9 895db8 8b7508 837e1000 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   8d45f4               | lea                 eax, [ebp - 0xc]
            //   64a300000000         | mov                 dword ptr fs:[0], eax
            //   8bd9                 | mov                 ebx, ecx
            //   895db8               | mov                 dword ptr [ebp - 0x48], ebx
            //   8b7508               | mov                 esi, dword ptr [ebp + 8]
            //   837e1000             | cmp                 dword ptr [esi + 0x10], 0

        $sequence_3 = { f20f118424f8080000 8b0cb0 85c9 7422 8b742464 90 0fb7047e }
            // n = 7, score = 100
            //   f20f118424f8080000     | movsd    qword ptr [esp + 0x8f8], xmm0
            //   8b0cb0               | mov                 ecx, dword ptr [eax + esi*4]
            //   85c9                 | test                ecx, ecx
            //   7422                 | je                  0x24
            //   8b742464             | mov                 esi, dword ptr [esp + 0x64]
            //   90                   | nop                 
            //   0fb7047e             | movzx               eax, word ptr [esi + edi*2]

        $sequence_4 = { ff74242c 57 e8???????? 83c410 eb14 8b8724000800 b900000200 }
            // n = 7, score = 100
            //   ff74242c             | push                dword ptr [esp + 0x2c]
            //   57                   | push                edi
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10
            //   eb14                 | jmp                 0x16
            //   8b8724000800         | mov                 eax, dword ptr [edi + 0x80024]
            //   b900000200           | mov                 ecx, 0x20000

        $sequence_5 = { 8954242c 660f1f440000 53 ff742424 68c0000000 56 55 }
            // n = 7, score = 100
            //   8954242c             | mov                 dword ptr [esp + 0x2c], edx
            //   660f1f440000         | nop                 word ptr [eax + eax]
            //   53                   | push                ebx
            //   ff742424             | push                dword ptr [esp + 0x24]
            //   68c0000000           | push                0xc0
            //   56                   | push                esi
            //   55                   | push                ebp

        $sequence_6 = { ff742410 ff742424 e8???????? 83c408 897c2410 89742450 8b44245c }
            // n = 7, score = 100
            //   ff742410             | push                dword ptr [esp + 0x10]
            //   ff742424             | push                dword ptr [esp + 0x24]
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   897c2410             | mov                 dword ptr [esp + 0x10], edi
            //   89742450             | mov                 dword ptr [esp + 0x50], esi
            //   8b44245c             | mov                 eax, dword ptr [esp + 0x5c]

        $sequence_7 = { e8???????? ff742434 53 e8???????? ff742428 53 e8???????? }
            // n = 7, score = 100
            //   e8????????           |                     
            //   ff742434             | push                dword ptr [esp + 0x34]
            //   53                   | push                ebx
            //   e8????????           |                     
            //   ff742428             | push                dword ptr [esp + 0x28]
            //   53                   | push                ebx
            //   e8????????           |                     

        $sequence_8 = { ff5210 8b4dc8 c7451803000000 85c9 7418 8b11 8d45a4 }
            // n = 7, score = 100
            //   ff5210               | call                dword ptr [edx + 0x10]
            //   8b4dc8               | mov                 ecx, dword ptr [ebp - 0x38]
            //   c7451803000000       | mov                 dword ptr [ebp + 0x18], 3
            //   85c9                 | test                ecx, ecx
            //   7418                 | je                  0x1a
            //   8b11                 | mov                 edx, dword ptr [ecx]
            //   8d45a4               | lea                 eax, [ebp - 0x5c]

        $sequence_9 = { e8???????? c7868400000000000000 8b37 8b8e84000000 85c9 7506 8b8e88000000 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   c7868400000000000000     | mov    dword ptr [esi + 0x84], 0
            //   8b37                 | mov                 esi, dword ptr [edi]
            //   8b8e84000000         | mov                 ecx, dword ptr [esi + 0x84]
            //   85c9                 | test                ecx, ecx
            //   7506                 | jne                 8
            //   8b8e88000000         | mov                 ecx, dword ptr [esi + 0x88]

    condition:
        7 of them and filesize < 10500096
}