rule win_atmii_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.atmii."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.atmii"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 6a03 68000000c0 8b0d???????? 51 ff15???????? 8945fc }
            // n = 6, score = 100
            //   6a03                 | push                3
            //   68000000c0           | push                0xc0000000
            //   8b0d????????         |                     
            //   51                   | push                ecx
            //   ff15????????         |                     
            //   8945fc               | mov                 dword ptr [ebp - 4], eax

        $sequence_1 = { 8945ee 0fb705???????? 52 682e010000 50 895dd9 }
            // n = 6, score = 100
            //   8945ee               | mov                 dword ptr [ebp - 0x12], eax
            //   0fb705????????       |                     
            //   52                   | push                edx
            //   682e010000           | push                0x12e
            //   50                   | push                eax
            //   895dd9               | mov                 dword ptr [ebp - 0x27], ebx

        $sequence_2 = { 68???????? 50 ffd7 8d9dfcfbffff }
            // n = 4, score = 100
            //   68????????           |                     
            //   50                   | push                eax
            //   ffd7                 | call                edi
            //   8d9dfcfbffff         | lea                 ebx, [ebp - 0x404]

        $sequence_3 = { 8d8dd1f9ffff 51 8895c4f9ffff ff15???????? }
            // n = 4, score = 100
            //   8d8dd1f9ffff         | lea                 ecx, [ebp - 0x62f]
            //   51                   | push                ecx
            //   8895c4f9ffff         | mov                 byte ptr [ebp - 0x63c], dl
            //   ff15????????         |                     

        $sequence_4 = { 8d95fcfdffff 6a00 52 e8???????? 8b35???????? 83c424 68???????? }
            // n = 7, score = 100
            //   8d95fcfdffff         | lea                 edx, [ebp - 0x204]
            //   6a00                 | push                0
            //   52                   | push                edx
            //   e8????????           |                     
            //   8b35????????         |                     
            //   83c424               | add                 esp, 0x24
            //   68????????           |                     

        $sequence_5 = { 8945fc 837dfc00 7454 8b4dfc 0fb611 }
            // n = 5, score = 100
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   837dfc00             | cmp                 dword ptr [ebp - 4], 0
            //   7454                 | je                  0x56
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   0fb611               | movzx               edx, byte ptr [ecx]

        $sequence_6 = { 51 e8???????? 8b55f4 83c414 6a00 }
            // n = 5, score = 100
            //   51                   | push                ecx
            //   e8????????           |                     
            //   8b55f4               | mov                 edx, dword ptr [ebp - 0xc]
            //   83c414               | add                 esp, 0x14
            //   6a00                 | push                0

        $sequence_7 = { 83c414 8d9df8fcffff e8???????? 8b45f8 85c0 7407 }
            // n = 6, score = 100
            //   83c414               | add                 esp, 0x14
            //   8d9df8fcffff         | lea                 ebx, [ebp - 0x308]
            //   e8????????           |                     
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   85c0                 | test                eax, eax
            //   7407                 | je                  9

        $sequence_8 = { 68???????? 68c3000000 8d85f8fcffff 68???????? 50 }
            // n = 5, score = 100
            //   68????????           |                     
            //   68c3000000           | push                0xc3
            //   8d85f8fcffff         | lea                 eax, [ebp - 0x308]
            //   68????????           |                     
            //   50                   | push                eax

        $sequence_9 = { 5f 5b 8be5 5d c3 68???????? 680b010000 }
            // n = 7, score = 100
            //   5f                   | pop                 edi
            //   5b                   | pop                 ebx
            //   8be5                 | mov                 esp, ebp
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   68????????           |                     
            //   680b010000           | push                0x10b

        $sequence_10 = { 837d0803 0f8ceb000000 53 8b1d???????? 57 68???????? }
            // n = 6, score = 100
            //   837d0803             | cmp                 dword ptr [ebp + 8], 3
            //   0f8ceb000000         | jl                  0xf1
            //   53                   | push                ebx
            //   8b1d????????         |                     
            //   57                   | push                edi
            //   68????????           |                     

        $sequence_11 = { ffd3 68???????? 68???????? 8985c5f9ffff ffd7 }
            // n = 5, score = 100
            //   ffd3                 | call                ebx
            //   68????????           |                     
            //   68????????           |                     
            //   8985c5f9ffff         | mov                 dword ptr [ebp - 0x63b], eax
            //   ffd7                 | call                edi

        $sequence_12 = { c745f800000000 ff15???????? 85c0 0f94c0 8845ff 84c0 742e }
            // n = 7, score = 100
            //   c745f800000000       | mov                 dword ptr [ebp - 8], 0
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   0f94c0               | sete                al
            //   8845ff               | mov                 byte ptr [ebp - 1], al
            //   84c0                 | test                al, al
            //   742e                 | je                  0x30

        $sequence_13 = { 85ff 0f8448030000 8d55f0 52 6800040000 }
            // n = 5, score = 100
            //   85ff                 | test                edi, edi
            //   0f8448030000         | je                  0x34e
            //   8d55f0               | lea                 edx, [ebp - 0x10]
            //   52                   | push                edx
            //   6800040000           | push                0x400

        $sequence_14 = { ff2485181d0010 68???????? 8d8df8feffff 51 eb2f 68???????? }
            // n = 6, score = 100
            //   ff2485181d0010       | jmp                 dword ptr [eax*4 + 0x10001d18]
            //   68????????           |                     
            //   8d8df8feffff         | lea                 ecx, [ebp - 0x108]
            //   51                   | push                ecx
            //   eb2f                 | jmp                 0x31
            //   68????????           |                     

        $sequence_15 = { 81ea???????? 83c204 f7d2 8955ed }
            // n = 4, score = 100
            //   81ea????????         |                     
            //   83c204               | add                 edx, 4
            //   f7d2                 | not                 edx
            //   8955ed               | mov                 dword ptr [ebp - 0x13], edx

    condition:
        7 of them and filesize < 49152
}