rule win_atmosphere_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.atmosphere."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.atmosphere"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 83ec14 56 8b7104 85f6 }
            // n = 4, score = 400
            //   83ec14               | sub                 esp, 0x14
            //   56                   | push                esi
            //   8b7104               | mov                 esi, dword ptr [ecx + 4]
            //   85f6                 | test                esi, esi

        $sequence_1 = { 88460e 33c0 894612 894616 89461a 884e1e }
            // n = 6, score = 400
            //   88460e               | mov                 byte ptr [esi + 0xe], al
            //   33c0                 | xor                 eax, eax
            //   894612               | mov                 dword ptr [esi + 0x12], eax
            //   894616               | mov                 dword ptr [esi + 0x16], eax
            //   89461a               | mov                 dword ptr [esi + 0x1a], eax
            //   884e1e               | mov                 byte ptr [esi + 0x1e], cl

        $sequence_2 = { e8???????? 8b4604 85c0 7504 33f6 eb08 }
            // n = 6, score = 400
            //   e8????????           |                     
            //   8b4604               | mov                 eax, dword ptr [esi + 4]
            //   85c0                 | test                eax, eax
            //   7504                 | jne                 6
            //   33f6                 | xor                 esi, esi
            //   eb08                 | jmp                 0xa

        $sequence_3 = { 8bcf ff5338 5f 5e }
            // n = 4, score = 400
            //   8bcf                 | mov                 ecx, edi
            //   ff5338               | call                dword ptr [ebx + 0x38]
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi

        $sequence_4 = { c645fc02 8bcc 8965e8 50 51 e8???????? }
            // n = 6, score = 400
            //   c645fc02             | mov                 byte ptr [ebp - 4], 2
            //   8bcc                 | mov                 ecx, esp
            //   8965e8               | mov                 dword ptr [ebp - 0x18], esp
            //   50                   | push                eax
            //   51                   | push                ecx
            //   e8????????           |                     

        $sequence_5 = { 8bce 8975e8 8806 ff15???????? }
            // n = 4, score = 400
            //   8bce                 | mov                 ecx, esi
            //   8975e8               | mov                 dword ptr [ebp - 0x18], esi
            //   8806                 | mov                 byte ptr [esi], al
            //   ff15????????         |                     

        $sequence_6 = { 8bc4 89642410 50 e8???????? }
            // n = 4, score = 400
            //   8bc4                 | mov                 eax, esp
            //   89642410             | mov                 dword ptr [esp + 0x10], esp
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_7 = { 8b7c240c 8bf1 57 ff15???????? 8b470c }
            // n = 5, score = 400
            //   8b7c240c             | mov                 edi, dword ptr [esp + 0xc]
            //   8bf1                 | mov                 esi, ecx
            //   57                   | push                edi
            //   ff15????????         |                     
            //   8b470c               | mov                 eax, dword ptr [edi + 0xc]

        $sequence_8 = { 51 83ec10 8bc4 89642410 50 e8???????? }
            // n = 6, score = 400
            //   51                   | push                ecx
            //   83ec10               | sub                 esp, 0x10
            //   8bc4                 | mov                 eax, esp
            //   89642410             | mov                 dword ptr [esp + 0x10], esp
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_9 = { 8bcc 8965e8 50 51 }
            // n = 4, score = 400
            //   8bcc                 | mov                 ecx, esp
            //   8965e8               | mov                 dword ptr [ebp - 0x18], esp
            //   50                   | push                eax
            //   51                   | push                ecx

    condition:
        7 of them and filesize < 360448
}