rule win_aukill_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.aukill."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.aukill"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 85c0 751f 488b4c2458 ff15???????? }
            // n = 4, score = 200
            //   85c0                 | dec                 eax
            //   751f                 | lea                 eax, [0x14bb2]
            //   488b4c2458           | dec                 eax
            //   ff15????????         |                     

        $sequence_1 = { 0fb7da 8bf9 e8???????? 4c8bc8 4533c0 }
            // n = 5, score = 200
            //   0fb7da               | dec                 eax
            //   8bf9                 | mov                 ecx, esi
            //   e8????????           |                     
            //   4c8bc8               | jne                 0x19d3
            //   4533c0               | cmp                 byte ptr [esi + 0x30], 0

        $sequence_2 = { 4533c0 33d2 488bcb ff15???????? 85c0 7526 488bcb }
            // n = 7, score = 200
            //   4533c0               | lea                 edx, [0x2c79]
            //   33d2                 | dec                 eax
            //   488bcb               | lea                 ecx, [0x2c08]
            //   ff15????????         |                     
            //   85c0                 | dec                 eax
            //   7526                 | mov                 ecx, eax
            //   488bcb               | dec                 eax

        $sequence_3 = { 4889442420 ff15???????? 85c0 751f 488b4c2458 ff15???????? }
            // n = 6, score = 200
            //   4889442420           | dec                 eax
            //   ff15????????         |                     
            //   85c0                 | lea                 ecx, [0x578b]
            //   751f                 | jmp                 0x2fd
            //   488b4c2458           | je                  0x312
            //   ff15????????         |                     

        $sequence_4 = { 751d 488bcb ff15???????? ff15???????? }
            // n = 4, score = 200
            //   751d                 | dec                 eax
            //   488bcb               | lea                 ecx, [0x209bb]
            //   ff15????????         |                     
            //   ff15????????         |                     

        $sequence_5 = { 4489442420 453b01 7346 4b8d1440 410f104cd108 0f114c2428 f2410f1044d118 }
            // n = 7, score = 200
            //   4489442420           | dec                 eax
            //   453b01               | mov                 dword ptr [ecx + 0x30], eax
            //   7346                 | inc                 ecx
            //   4b8d1440             | mov                 al, dl
            //   410f104cd108         | dec                 eax
            //   0f114c2428           | lea                 ecx, [0x209cf]
            //   f2410f1044d118       | dec                 eax

        $sequence_6 = { 448d4920 48894c2450 488b0d???????? 48897c2458 }
            // n = 4, score = 200
            //   448d4920             | inc                 esp
            //   48894c2450           | mov                 esi, eax
            //   488b0d????????       |                     
            //   48897c2458           | mov                 dword ptr [esp + 0x20], eax

        $sequence_7 = { 488bd3 33c9 ff15???????? 85c0 751f }
            // n = 5, score = 200
            //   488bd3               | test                eax, eax
            //   33c9                 | jne                 0x473
            //   ff15????????         |                     
            //   85c0                 | mov                 edi, 0x208
            //   751f                 | inc                 ecx

        $sequence_8 = { 48895c2408 57 4883ec60 488bfa 8bd9 e8???????? 33c9 }
            // n = 7, score = 200
            //   48895c2408           | lea                 ecx, [ecx + ecx*8]
            //   57                   | dec                 ecx
            //   4883ec60             | mov                 ecx, ecx
            //   488bfa               | dec                 eax
            //   8bd9                 | mov                 eax, dword ptr [esp + 0x30]
            //   e8????????           |                     
            //   33c9                 | jmp                 0x16d9

        $sequence_9 = { ffc2 80f920 75ee 4c63c2 }
            // n = 4, score = 200
            //   ffc2                 | lea                 ecx, [0x217e0]
            //   80f920               | je                  0xe4d
            //   75ee                 | mov                 edx, eax
            //   4c63c2               | dec                 eax

    condition:
        7 of them and filesize < 446464
}