rule win_auriga_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.auriga."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.auriga"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 90 5f bb???????? 81eb???????? 2bfb 8bf7 e8???????? }
            // n = 7, score = 100
            //   90                   | nop                 
            //   5f                   | pop                 edi
            //   bb????????           |                     
            //   81eb????????         |                     
            //   2bfb                 | sub                 edi, ebx
            //   8bf7                 | mov                 esi, edi
            //   e8????????           |                     

        $sequence_1 = { 755b 817e0c03001200 7552 57 }
            // n = 4, score = 100
            //   755b                 | jne                 0x5d
            //   817e0c03001200       | cmp                 dword ptr [esi + 0xc], 0x120003
            //   7552                 | jne                 0x54
            //   57                   | push                edi

        $sequence_2 = { e8???????? c9 c20c00 ffb508fcffff 8b8504fcffff 8d8405fcfbffff }
            // n = 6, score = 100
            //   e8????????           |                     
            //   c9                   | leave               
            //   c20c00               | ret                 0xc
            //   ffb508fcffff         | push                dword ptr [ebp - 0x3f8]
            //   8b8504fcffff         | mov                 eax, dword ptr [ebp - 0x3fc]
            //   8d8405fcfbffff       | lea                 eax, [ebp + eax - 0x404]

        $sequence_3 = { 4a 3bda 745e 7345 2bd3 }
            // n = 5, score = 100
            //   4a                   | dec                 edx
            //   3bda                 | cmp                 ebx, edx
            //   745e                 | je                  0x60
            //   7345                 | jae                 0x47
            //   2bd3                 | sub                 edx, ebx

        $sequence_4 = { 7408 8b0d???????? 8908 56 8b7508 837e0400 7422 }
            // n = 7, score = 100
            //   7408                 | je                  0xa
            //   8b0d????????         |                     
            //   8908                 | mov                 dword ptr [eax], ecx
            //   56                   | push                esi
            //   8b7508               | mov                 esi, dword ptr [ebp + 8]
            //   837e0400             | cmp                 dword ptr [esi + 4], 0
            //   7422                 | je                  0x24

        $sequence_5 = { 53 53 6a01 6a01 56 ff15???????? 8945dc }
            // n = 7, score = 100
            //   53                   | push                ebx
            //   53                   | push                ebx
            //   6a01                 | push                1
            //   6a01                 | push                1
            //   56                   | push                esi
            //   ff15????????         |                     
            //   8945dc               | mov                 dword ptr [ebp - 0x24], eax

        $sequence_6 = { 84c0 7511 ff7510 ff15???????? }
            // n = 4, score = 100
            //   84c0                 | test                al, al
            //   7511                 | jne                 0x13
            //   ff7510               | push                dword ptr [ebp + 0x10]
            //   ff15????????         |                     

        $sequence_7 = { ff45fc 8b4dec ff4df8 2bcb 295df4 ff45f8 }
            // n = 6, score = 100
            //   ff45fc               | inc                 dword ptr [ebp - 4]
            //   8b4dec               | mov                 ecx, dword ptr [ebp - 0x14]
            //   ff4df8               | dec                 dword ptr [ebp - 8]
            //   2bcb                 | sub                 ecx, ebx
            //   295df4               | sub                 dword ptr [ebp - 0xc], ebx
            //   ff45f8               | inc                 dword ptr [ebp - 8]

        $sequence_8 = { ffd3 8b45fc 85c0 7539 ff750c 8d45f4 }
            // n = 6, score = 100
            //   ffd3                 | call                ebx
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   85c0                 | test                eax, eax
            //   7539                 | jne                 0x3b
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   8d45f4               | lea                 eax, [ebp - 0xc]

        $sequence_9 = { 8b85e8fbffff 85c0 7566 ffb5ecfbffff 8d85f0fbffff }
            // n = 5, score = 100
            //   8b85e8fbffff         | mov                 eax, dword ptr [ebp - 0x418]
            //   85c0                 | test                eax, eax
            //   7566                 | jne                 0x68
            //   ffb5ecfbffff         | push                dword ptr [ebp - 0x414]
            //   8d85f0fbffff         | lea                 eax, [ebp - 0x410]

    condition:
        7 of them and filesize < 75776
}