rule win_avaddon_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.avaddon."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.avaddon"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 55 8bec 83e4f8 8b11 83ec14 0faf5104 53 }
            // n = 7, score = 200
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   83e4f8               | and                 esp, 0xfffffff8
            //   8b11                 | mov                 edx, dword ptr [ecx]
            //   83ec14               | sub                 esp, 0x14
            //   0faf5104             | imul                edx, dword ptr [ecx + 4]
            //   53                   | push                ebx

        $sequence_1 = { 52 50 e8???????? 8bf0 8bfa 8b4508 03f3 }
            // n = 7, score = 200
            //   52                   | push                edx
            //   50                   | push                eax
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax
            //   8bfa                 | mov                 edi, edx
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   03f3                 | add                 esi, ebx

        $sequence_2 = { 8d4dcc e9???????? 8d4d88 e9???????? 8d4db4 e9???????? 8d4de4 }
            // n = 7, score = 200
            //   8d4dcc               | lea                 ecx, [ebp - 0x34]
            //   e9????????           |                     
            //   8d4d88               | lea                 ecx, [ebp - 0x78]
            //   e9????????           |                     
            //   8d4db4               | lea                 ecx, [ebp - 0x4c]
            //   e9????????           |                     
            //   8d4de4               | lea                 ecx, [ebp - 0x1c]

        $sequence_3 = { 8b4df0 e9???????? 8d4dbc e9???????? 8b542408 8d420c 8b4ac0 }
            // n = 7, score = 200
            //   8b4df0               | mov                 ecx, dword ptr [ebp - 0x10]
            //   e9????????           |                     
            //   8d4dbc               | lea                 ecx, [ebp - 0x44]
            //   e9????????           |                     
            //   8b542408             | mov                 edx, dword ptr [esp + 8]
            //   8d420c               | lea                 eax, [edx + 0xc]
            //   8b4ac0               | mov                 ecx, dword ptr [edx - 0x40]

        $sequence_4 = { 57 56 e8???????? 83c408 85c0 7535 837e6402 }
            // n = 7, score = 200
            //   57                   | push                edi
            //   56                   | push                esi
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   85c0                 | test                eax, eax
            //   7535                 | jne                 0x37
            //   837e6402             | cmp                 dword ptr [esi + 0x64], 2

        $sequence_5 = { 8bd0 e8???????? 8b5604 83c404 }
            // n = 4, score = 200
            //   8bd0                 | mov                 edx, eax
            //   e8????????           |                     
            //   8b5604               | mov                 edx, dword ptr [esi + 4]
            //   83c404               | add                 esp, 4

        $sequence_6 = { ff75b4 e8???????? 83c408 47 897dac 81fffe000000 0f8654feffff }
            // n = 7, score = 200
            //   ff75b4               | push                dword ptr [ebp - 0x4c]
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   47                   | inc                 edi
            //   897dac               | mov                 dword ptr [ebp - 0x54], edi
            //   81fffe000000         | cmp                 edi, 0xfe
            //   0f8654feffff         | jbe                 0xfffffe5a

        $sequence_7 = { 8bc8 2bce 0fafcb 890a 83c204 8b4de4 41 }
            // n = 7, score = 200
            //   8bc8                 | mov                 ecx, eax
            //   2bce                 | sub                 ecx, esi
            //   0fafcb               | imul                ecx, ebx
            //   890a                 | mov                 dword ptr [edx], ecx
            //   83c204               | add                 edx, 4
            //   8b4de4               | mov                 ecx, dword ptr [ebp - 0x1c]
            //   41                   | inc                 ecx

        $sequence_8 = { 034b08 4e 8b4588 6a00 52 51 56 }
            // n = 7, score = 200
            //   034b08               | add                 ecx, dword ptr [ebx + 8]
            //   4e                   | dec                 esi
            //   8b4588               | mov                 eax, dword ptr [ebp - 0x78]
            //   6a00                 | push                0
            //   52                   | push                edx
            //   51                   | push                ecx
            //   56                   | push                esi

        $sequence_9 = { 8d4dd8 e8???????? c645fc0d 8b4f14 3b4f18 7437 c7411000000000 }
            // n = 7, score = 200
            //   8d4dd8               | lea                 ecx, [ebp - 0x28]
            //   e8????????           |                     
            //   c645fc0d             | mov                 byte ptr [ebp - 4], 0xd
            //   8b4f14               | mov                 ecx, dword ptr [edi + 0x14]
            //   3b4f18               | cmp                 ecx, dword ptr [edi + 0x18]
            //   7437                 | je                  0x39
            //   c7411000000000       | mov                 dword ptr [ecx + 0x10], 0

    condition:
        7 of them and filesize < 2343936
}