rule win_avcrypt_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.avcrypt."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.avcrypt"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 68???????? ffd3 834dfcff 8d4dd8 56 6a01 e8???????? }
            // n = 7, score = 100
            //   68????????           |                     
            //   ffd3                 | call                ebx
            //   834dfcff             | or                  dword ptr [ebp - 4], 0xffffffff
            //   8d4dd8               | lea                 ecx, [ebp - 0x28]
            //   56                   | push                esi
            //   6a01                 | push                1
            //   e8????????           |                     

        $sequence_1 = { 8bc7 8bcf c1f805 83e11f c1e106 030c8580b54300 eb05 }
            // n = 7, score = 100
            //   8bc7                 | mov                 eax, edi
            //   8bcf                 | mov                 ecx, edi
            //   c1f805               | sar                 eax, 5
            //   83e11f               | and                 ecx, 0x1f
            //   c1e106               | shl                 ecx, 6
            //   030c8580b54300       | add                 ecx, dword ptr [eax*4 + 0x43b580]
            //   eb05                 | jmp                 7

        $sequence_2 = { 8d4dc0 56 e8???????? 59 6a0e 33f6 5b }
            // n = 7, score = 100
            //   8d4dc0               | lea                 ecx, [ebp - 0x40]
            //   56                   | push                esi
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   6a0e                 | push                0xe
            //   33f6                 | xor                 esi, esi
            //   5b                   | pop                 ebx

        $sequence_3 = { c705????????70484300 c705????????8cbf4300 890d???????? 8935???????? }
            // n = 4, score = 100
            //   c705????????70484300     |     
            //   c705????????8cbf4300     |     
            //   890d????????         |                     
            //   8935????????         |                     

        $sequence_4 = { 50 ff15???????? 83c8ff e9???????? 57 6a09 59 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   ff15????????         |                     
            //   83c8ff               | or                  eax, 0xffffffff
            //   e9????????           |                     
            //   57                   | push                edi
            //   6a09                 | push                9
            //   59                   | pop                 ecx

        $sequence_5 = { ff15???????? 85c0 7507 68???????? ffd6 895de4 837dd000 }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7507                 | jne                 9
            //   68????????           |                     
            //   ffd6                 | call                esi
            //   895de4               | mov                 dword ptr [ebp - 0x1c], ebx
            //   837dd000             | cmp                 dword ptr [ebp - 0x30], 0

        $sequence_6 = { 68???????? e8???????? 83ec18 c745fc15000000 8bcc 8965d4 53 }
            // n = 7, score = 100
            //   68????????           |                     
            //   e8????????           |                     
            //   83ec18               | sub                 esp, 0x18
            //   c745fc15000000       | mov                 dword ptr [ebp - 4], 0x15
            //   8bcc                 | mov                 ecx, esp
            //   8965d4               | mov                 dword ptr [ebp - 0x2c], esp
            //   53                   | push                ebx

        $sequence_7 = { c645fc0e 837db800 7519 68???????? 8d8d78ffffff e8???????? }
            // n = 6, score = 100
            //   c645fc0e             | mov                 byte ptr [ebp - 4], 0xe
            //   837db800             | cmp                 dword ptr [ebp - 0x48], 0
            //   7519                 | jne                 0x1b
            //   68????????           |                     
            //   8d8d78ffffff         | lea                 ecx, [ebp - 0x88]
            //   e8????????           |                     

        $sequence_8 = { e8???????? 68???????? 8d8d84feffff c645fc08 e8???????? 68???????? 8d8d9cfeffff }
            // n = 7, score = 100
            //   e8????????           |                     
            //   68????????           |                     
            //   8d8d84feffff         | lea                 ecx, [ebp - 0x17c]
            //   c645fc08             | mov                 byte ptr [ebp - 4], 8
            //   e8????????           |                     
            //   68????????           |                     
            //   8d8d9cfeffff         | lea                 ecx, [ebp - 0x164]

        $sequence_9 = { e8???????? c645fc01 8b5de0 85db 7404 8b13 }
            // n = 6, score = 100
            //   e8????????           |                     
            //   c645fc01             | mov                 byte ptr [ebp - 4], 1
            //   8b5de0               | mov                 ebx, dword ptr [ebp - 0x20]
            //   85db                 | test                ebx, ebx
            //   7404                 | je                  6
            //   8b13                 | mov                 edx, dword ptr [ebx]

    condition:
        7 of them and filesize < 6160384
}