rule win_babuk_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.babuk."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.babuk"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ff15???????? 6800000100 e8???????? 83c404 }
            // n = 4, score = 800
            //   ff15????????         |                     
            //   6800000100           | push                0x10000
            //   e8????????           |                     
            //   83c404               | add                 esp, 4

        $sequence_1 = { 50 ff15???????? 83f803 7502 }
            // n = 4, score = 800
            //   50                   | push                eax
            //   ff15????????         |                     
            //   83f803               | cmp                 eax, 3
            //   7502                 | jne                 4

        $sequence_2 = { 8b45fc 83c002 8945fc 837dfc0a 0f83dc000000 8b4dfc }
            // n = 6, score = 600
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   83c002               | add                 eax, 2
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   837dfc0a             | cmp                 dword ptr [ebp - 4], 0xa
            //   0f83dc000000         | jae                 0xe2
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]

        $sequence_3 = { 8b4d08 8b540104 52 8b0401 50 e8???????? }
            // n = 6, score = 600
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   8b540104             | mov                 edx, dword ptr [ecx + eax + 4]
            //   52                   | push                edx
            //   8b0401               | mov                 eax, dword ptr [ecx + eax]
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_4 = { 8b4dfc c1e108 ba01000000 d1e2 8b4508 }
            // n = 5, score = 600
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   c1e108               | shl                 ecx, 8
            //   ba01000000           | mov                 edx, 1
            //   d1e2                 | shl                 edx, 1
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]

        $sequence_5 = { 8b95ccfdffff 83c201 8995ccfdffff 83bdccfdffff1f 735f 8d85f4fdffff }
            // n = 6, score = 600
            //   8b95ccfdffff         | mov                 edx, dword ptr [ebp - 0x234]
            //   83c201               | add                 edx, 1
            //   8995ccfdffff         | mov                 dword ptr [ebp - 0x234], edx
            //   83bdccfdffff1f       | cmp                 dword ptr [ebp - 0x234], 0x1f
            //   735f                 | jae                 0x61
            //   8d85f4fdffff         | lea                 eax, [ebp - 0x20c]

        $sequence_6 = { 8b4dfc 8b5508 8b44ca04 50 }
            // n = 4, score = 600
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]
            //   8b44ca04             | mov                 eax, dword ptr [edx + ecx*8 + 4]
            //   50                   | push                eax

        $sequence_7 = { 8b4d08 c7040100000000 c744010400000000 ba08000000 }
            // n = 4, score = 600
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   c7040100000000       | mov                 dword ptr [ecx + eax], 0
            //   c744010400000000     | mov                 dword ptr [ecx + eax + 4], 0
            //   ba08000000           | mov                 edx, 8

        $sequence_8 = { 0bca 894dfc 8b45fc c1e008 b901000000 }
            // n = 5, score = 600
            //   0bca                 | or                  ecx, edx
            //   894dfc               | mov                 dword ptr [ebp - 4], ecx
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   c1e008               | shl                 eax, 8
            //   b901000000           | mov                 ecx, 1

        $sequence_9 = { 8b0401 50 e8???????? 83c408 8945ec 8955f0 }
            // n = 6, score = 600
            //   8b0401               | mov                 eax, dword ptr [ecx + eax]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   8945ec               | mov                 dword ptr [ebp - 0x14], eax
            //   8955f0               | mov                 dword ptr [ebp - 0x10], edx

        $sequence_10 = { c744010400000000 ba08000000 6bc200 8b4d08 }
            // n = 4, score = 600
            //   c744010400000000     | mov                 dword ptr [ecx + eax + 4], 0
            //   ba08000000           | mov                 edx, 8
            //   6bc200               | imul                eax, edx, 0
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]

        $sequence_11 = { 8b4508 c704107465206b c745fc00000000 eb09 }
            // n = 4, score = 600
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   c704107465206b       | mov                 dword ptr [eax + edx], 0x6b206574
            //   c745fc00000000       | mov                 dword ptr [ebp - 4], 0
            //   eb09                 | jmp                 0xb

        $sequence_12 = { 744a 837dd801 7444 8b55ec 52 ff15???????? 8d45ac }
            // n = 7, score = 600
            //   744a                 | je                  0x4c
            //   837dd801             | cmp                 dword ptr [ebp - 0x28], 1
            //   7444                 | je                  0x46
            //   8b55ec               | mov                 edx, dword ptr [ebp - 0x14]
            //   52                   | push                edx
            //   ff15????????         |                     
            //   8d45ac               | lea                 eax, [ebp - 0x54]

        $sequence_13 = { e8???????? 83c410 c78574ffffff00000000 eb0f }
            // n = 4, score = 600
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10
            //   c78574ffffff00000000     | mov    dword ptr [ebp - 0x8c], 0
            //   eb0f                 | jmp                 0x11

        $sequence_14 = { 57 b808000000 6bc80a 8b5508 c7040a00000000 c7440a0400000000 c745fc00000000 }
            // n = 7, score = 600
            //   57                   | push                edi
            //   b808000000           | mov                 eax, 8
            //   6bc80a               | imul                ecx, eax, 0xa
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]
            //   c7040a00000000       | mov                 dword ptr [edx + ecx], 0
            //   c7440a0400000000     | mov                 dword ptr [edx + ecx + 4], 0
            //   c745fc00000000       | mov                 dword ptr [ebp - 4], 0

        $sequence_15 = { 51 e8???????? 83c408 8945f4 8955f8 }
            // n = 5, score = 600
            //   51                   | push                ecx
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   8945f4               | mov                 dword ptr [ebp - 0xc], eax
            //   8955f8               | mov                 dword ptr [ebp - 8], edx

    condition:
        7 of them and filesize < 183296
}