rule win_backspace_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.backspace."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.backspace"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 57 40 50 ff15???????? 85c0 0f8fa3000000 }
            // n = 6, score = 100
            //   57                   | push                edi
            //   40                   | inc                 eax
            //   50                   | push                eax
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   0f8fa3000000         | jg                  0xa9

        $sequence_1 = { 3bfb 59 7405 83c705 }
            // n = 4, score = 100
            //   3bfb                 | cmp                 edi, ebx
            //   59                   | pop                 ecx
            //   7405                 | je                  7
            //   83c705               | add                 edi, 5

        $sequence_2 = { 8d8500feffff 50 e8???????? 83c424 85c0 740b ff750c }
            // n = 7, score = 100
            //   8d8500feffff         | lea                 eax, [ebp - 0x200]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c424               | add                 esp, 0x24
            //   85c0                 | test                eax, eax
            //   740b                 | je                  0xd
            //   ff750c               | push                dword ptr [ebp + 0xc]

        $sequence_3 = { 8b45f8 ff45f8 3d88130000 7f51 ebc9 8a06 }
            // n = 6, score = 100
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   ff45f8               | inc                 dword ptr [ebp - 8]
            //   3d88130000           | cmp                 eax, 0x1388
            //   7f51                 | jg                  0x53
            //   ebc9                 | jmp                 0xffffffcb
            //   8a06                 | mov                 al, byte ptr [esi]

        $sequence_4 = { 885d91 885d92 885d93 885d94 }
            // n = 4, score = 100
            //   885d91               | mov                 byte ptr [ebp - 0x6f], bl
            //   885d92               | mov                 byte ptr [ebp - 0x6e], bl
            //   885d93               | mov                 byte ptr [ebp - 0x6d], bl
            //   885d94               | mov                 byte ptr [ebp - 0x6c], bl

        $sequence_5 = { ff15???????? f7d8 1bc0 59 83e002 59 48 }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   f7d8                 | neg                 eax
            //   1bc0                 | sbb                 eax, eax
            //   59                   | pop                 ecx
            //   83e002               | and                 eax, 2
            //   59                   | pop                 ecx
            //   48                   | dec                 eax

        $sequence_6 = { 393d???????? 7552 be00200000 ff75f8 8d85f8dfffff }
            // n = 5, score = 100
            //   393d????????         |                     
            //   7552                 | jne                 0x54
            //   be00200000           | mov                 esi, 0x2000
            //   ff75f8               | push                dword ptr [ebp - 8]
            //   8d85f8dfffff         | lea                 eax, [ebp - 0x2008]

        $sequence_7 = { 50 e8???????? 56 e8???????? 8bd8 be???????? 83c306 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   e8????????           |                     
            //   56                   | push                esi
            //   e8????????           |                     
            //   8bd8                 | mov                 ebx, eax
            //   be????????           |                     
            //   83c306               | add                 ebx, 6

        $sequence_8 = { 8d85f8dfffff 50 e8???????? 59 8bc3 59 e9???????? }
            // n = 7, score = 100
            //   8d85f8dfffff         | lea                 eax, [ebp - 0x2008]
            //   50                   | push                eax
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   8bc3                 | mov                 eax, ebx
            //   59                   | pop                 ecx
            //   e9????????           |                     

        $sequence_9 = { a3???????? ff75fc ffd6 395dfc }
            // n = 4, score = 100
            //   a3????????           |                     
            //   ff75fc               | push                dword ptr [ebp - 4]
            //   ffd6                 | call                esi
            //   395dfc               | cmp                 dword ptr [ebp - 4], ebx

    condition:
        7 of them and filesize < 131072
}