rule win_balkan_door_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.balkan_door."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.balkan_door"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 50 ff15???????? 8bf8 89bd3cefffff }
            // n = 4, score = 700
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8bf8                 | mov                 edi, eax
            //   89bd3cefffff         | mov                 dword ptr [ebp - 0x10c4], edi

        $sequence_1 = { 8bf0 85f6 740b 6a00 6a00 56 ff15???????? }
            // n = 7, score = 700
            //   8bf0                 | mov                 esi, eax
            //   85f6                 | test                esi, esi
            //   740b                 | je                  0xd
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   56                   | push                esi
            //   ff15????????         |                     

        $sequence_2 = { ffd7 85c0 741a 8d85d0fdffff c785d0fdffff2c020000 50 56 }
            // n = 7, score = 700
            //   ffd7                 | call                edi
            //   85c0                 | test                eax, eax
            //   741a                 | je                  0x1c
            //   8d85d0fdffff         | lea                 eax, [ebp - 0x230]
            //   c785d0fdffff2c020000     | mov    dword ptr [ebp - 0x230], 0x22c
            //   50                   | push                eax
            //   56                   | push                esi

        $sequence_3 = { 8d85f4fdffff 50 ffd7 85c0 741a 8d85d0fdffff c785d0fdffff2c020000 }
            // n = 7, score = 700
            //   8d85f4fdffff         | lea                 eax, [ebp - 0x20c]
            //   50                   | push                eax
            //   ffd7                 | call                edi
            //   85c0                 | test                eax, eax
            //   741a                 | je                  0x1c
            //   8d85d0fdffff         | lea                 eax, [ebp - 0x230]
            //   c785d0fdffff2c020000     | mov    dword ptr [ebp - 0x230], 0x22c

        $sequence_4 = { c785d0fdffff2c020000 50 56 ffd3 }
            // n = 4, score = 700
            //   c785d0fdffff2c020000     | mov    dword ptr [ebp - 0x230], 0x22c
            //   50                   | push                eax
            //   56                   | push                esi
            //   ffd3                 | call                ebx

        $sequence_5 = { 56 ff15???????? 8b4dfc 8b85ccfdffff 33cd 5e e8???????? }
            // n = 7, score = 700
            //   56                   | push                esi
            //   ff15????????         |                     
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   8b85ccfdffff         | mov                 eax, dword ptr [ebp - 0x234]
            //   33cd                 | xor                 ecx, ebp
            //   5e                   | pop                 esi
            //   e8????????           |                     

        $sequence_6 = { e8???????? 83c404 8bbd3cefffff 6a00 }
            // n = 4, score = 700
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   8bbd3cefffff         | mov                 edi, dword ptr [ebp - 0x10c4]
            //   6a00                 | push                0

        $sequence_7 = { 8b85d8fdffff 8985ccfdffff 5f 5b 56 }
            // n = 5, score = 700
            //   8b85d8fdffff         | mov                 eax, dword ptr [ebp - 0x228]
            //   8985ccfdffff         | mov                 dword ptr [ebp - 0x234], eax
            //   5f                   | pop                 edi
            //   5b                   | pop                 ebx
            //   56                   | push                esi

        $sequence_8 = { 683f000f00 68???????? 57 ff15???????? }
            // n = 4, score = 700
            //   683f000f00           | push                0xf003f
            //   68????????           |                     
            //   57                   | push                edi
            //   ff15????????         |                     

        $sequence_9 = { 50 57 6a00 6a13 ffb53cefffff ff15???????? 85c0 }
            // n = 7, score = 700
            //   50                   | push                eax
            //   57                   | push                edi
            //   6a00                 | push                0
            //   6a13                 | push                0x13
            //   ffb53cefffff         | push                dword ptr [ebp - 0x10c4]
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax

    condition:
        7 of them and filesize < 352256
}