rule win_bamital_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.bamital."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.bamital"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { eb05 83c001 ebe0 52 ff75fc e8???????? }
            // n = 6, score = 300
            //   eb05                 | jmp                 7
            //   83c001               | add                 eax, 1
            //   ebe0                 | jmp                 0xffffffe2
            //   52                   | push                edx
            //   ff75fc               | push                dword ptr [ebp - 4]
            //   e8????????           |                     

        $sequence_1 = { 8ac4 8807 83c701 e2d8 c9 c20800 55 }
            // n = 7, score = 300
            //   8ac4                 | mov                 al, ah
            //   8807                 | mov                 byte ptr [edi], al
            //   83c701               | add                 edi, 1
            //   e2d8                 | loop                0xffffffda
            //   c9                   | leave               
            //   c20800               | ret                 8
            //   55                   | push                ebp

        $sequence_2 = { ff75dc ff75d4 57 e8???????? 8b55fc 8945fc 0bd2 }
            // n = 7, score = 300
            //   ff75dc               | push                dword ptr [ebp - 0x24]
            //   ff75d4               | push                dword ptr [ebp - 0x2c]
            //   57                   | push                edi
            //   e8????????           |                     
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   0bd2                 | or                  edx, edx

        $sequence_3 = { e8???????? 8b55fc 8945fc 0bd2 }
            // n = 4, score = 300
            //   e8????????           |                     
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   0bd2                 | or                  edx, edx

        $sequence_4 = { 0bc0 741f 50 83c001 50 }
            // n = 5, score = 300
            //   0bc0                 | or                  eax, eax
            //   741f                 | je                  0x21
            //   50                   | push                eax
            //   83c001               | add                 eax, 1
            //   50                   | push                eax

        $sequence_5 = { b800000000 c9 c20400 55 8bec 83c4f0 }
            // n = 6, score = 300
            //   b800000000           | mov                 eax, 0
            //   c9                   | leave               
            //   c20400               | ret                 4
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   83c4f0               | add                 esp, -0x10

        $sequence_6 = { 56 57 53 8b5d0c 8b7508 }
            // n = 5, score = 300
            //   56                   | push                esi
            //   57                   | push                edi
            //   53                   | push                ebx
            //   8b5d0c               | mov                 ebx, dword ptr [ebp + 0xc]
            //   8b7508               | mov                 esi, dword ptr [ebp + 8]

        $sequence_7 = { ff7508 ff75f4 e8???????? 68e8070000 }
            // n = 4, score = 300
            //   ff7508               | push                dword ptr [ebp + 8]
            //   ff75f4               | push                dword ptr [ebp - 0xc]
            //   e8????????           |                     
            //   68e8070000           | push                0x7e8

        $sequence_8 = { 6a28 e8???????? 8945fc ff7508 e8???????? 8945f8 e8???????? }
            // n = 7, score = 300
            //   6a28                 | push                0x28
            //   e8????????           |                     
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   ff7508               | push                dword ptr [ebp + 8]
            //   e8????????           |                     
            //   8945f8               | mov                 dword ptr [ebp - 8], eax
            //   e8????????           |                     

        $sequence_9 = { 8a07 3c39 7208 3c7e 7704 2c19 eb13 }
            // n = 7, score = 300
            //   8a07                 | mov                 al, byte ptr [edi]
            //   3c39                 | cmp                 al, 0x39
            //   7208                 | jb                  0xa
            //   3c7e                 | cmp                 al, 0x7e
            //   7704                 | ja                  6
            //   2c19                 | sub                 al, 0x19
            //   eb13                 | jmp                 0x15

    condition:
        7 of them and filesize < 90112
}