rule win_bandook_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.bandook."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.bandook"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 68???????? ffd6 68???????? 6a01 6a00 ff15???????? 68e8030000 }
            // n = 7, score = 100
            //   68????????           |                     
            //   ffd6                 | call                esi
            //   68????????           |                     
            //   6a01                 | push                1
            //   6a00                 | push                0
            //   ff15????????         |                     
            //   68e8030000           | push                0x3e8

        $sequence_1 = { 8b7c2410 8d442438 50 53 ff15???????? 85c0 0f8529ffffff }
            // n = 7, score = 100
            //   8b7c2410             | mov                 edi, dword ptr [esp + 0x10]
            //   8d442438             | lea                 eax, [esp + 0x38]
            //   50                   | push                eax
            //   53                   | push                ebx
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   0f8529ffffff         | jne                 0xffffff2f

        $sequence_2 = { 8d95f8f3ffff 8bce 2bd6 0f1f00 8a01 8d4901 }
            // n = 6, score = 100
            //   8d95f8f3ffff         | lea                 edx, [ebp - 0xc08]
            //   8bce                 | mov                 ecx, esi
            //   2bd6                 | sub                 edx, esi
            //   0f1f00               | nop                 dword ptr [eax]
            //   8a01                 | mov                 al, byte ptr [ecx]
            //   8d4901               | lea                 ecx, [ecx + 1]

        $sequence_3 = { ff15???????? ff35???????? ff15???????? 68???????? 68???????? 8d8424a8010000 68???????? }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   ff35????????         |                     
            //   ff15????????         |                     
            //   68????????           |                     
            //   68????????           |                     
            //   8d8424a8010000       | lea                 eax, [esp + 0x1a8]
            //   68????????           |                     

        $sequence_4 = { 8bf9 897da0 8b7308 8d4dbc 897d9c 6a24 68???????? }
            // n = 7, score = 100
            //   8bf9                 | mov                 edi, ecx
            //   897da0               | mov                 dword ptr [ebp - 0x60], edi
            //   8b7308               | mov                 esi, dword ptr [ebx + 8]
            //   8d4dbc               | lea                 ecx, [ebp - 0x44]
            //   897d9c               | mov                 dword ptr [ebp - 0x64], edi
            //   6a24                 | push                0x24
            //   68????????           |                     

        $sequence_5 = { 83e103 f3a4 8d442428 50 53 ff15???????? 85c0 }
            // n = 7, score = 100
            //   83e103               | and                 ecx, 3
            //   f3a4                 | rep movsb           byte ptr es:[edi], byte ptr [esi]
            //   8d442428             | lea                 eax, [esp + 0x28]
            //   50                   | push                eax
            //   53                   | push                ebx
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax

        $sequence_6 = { 51 e8???????? 83c408 837dbc10 8d45a8 0f4345a8 50 }
            // n = 7, score = 100
            //   51                   | push                ecx
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   837dbc10             | cmp                 dword ptr [ebp - 0x44], 0x10
            //   8d45a8               | lea                 eax, [ebp - 0x58]
            //   0f4345a8             | cmovae              eax, dword ptr [ebp - 0x58]
            //   50                   | push                eax

        $sequence_7 = { 88811744c213 84c0 75ed 0fb605???????? f30f7e05???????? a2???????? a1???????? }
            // n = 7, score = 100
            //   88811744c213         | mov                 byte ptr [ecx + 0x13c24417], al
            //   84c0                 | test                al, al
            //   75ed                 | jne                 0xffffffef
            //   0fb605????????       |                     
            //   f30f7e05????????     |                     
            //   a2????????           |                     
            //   a1????????           |                     

        $sequence_8 = { c705????????80381713 c705????????003a1713 c705????????c03f1713 c705????????80401713 c705????????c0491713 c705????????704b1713 c705????????30451713 }
            // n = 7, score = 100
            //   c705????????80381713     |     
            //   c705????????003a1713     |     
            //   c705????????c03f1713     |     
            //   c705????????80401713     |     
            //   c705????????c0491713     |     
            //   c705????????704b1713     |     
            //   c705????????30451713     |     

        $sequence_9 = { 83c40c 8d842498040000 6a64 50 6a07 6800040000 ff15???????? }
            // n = 7, score = 100
            //   83c40c               | add                 esp, 0xc
            //   8d842498040000       | lea                 eax, [esp + 0x498]
            //   6a64                 | push                0x64
            //   50                   | push                eax
            //   6a07                 | push                7
            //   6800040000           | push                0x400
            //   ff15????????         |                     

    condition:
        7 of them and filesize < 23088128
}