rule win_bangat_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.bangat."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.bangat"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 6a01 6800000040 50 e8???????? 83c43c 8bf0 83feff }
            // n = 7, score = 100
            //   6a01                 | push                1
            //   6800000040           | push                0x40000000
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c43c               | add                 esp, 0x3c
            //   8bf0                 | mov                 esi, eax
            //   83feff               | cmp                 esi, -1

        $sequence_1 = { 13f9 03f0 13fd 8b6c2434 89742418 03de 8b74245c }
            // n = 7, score = 100
            //   13f9                 | adc                 edi, ecx
            //   03f0                 | add                 esi, eax
            //   13fd                 | adc                 edi, ebp
            //   8b6c2434             | mov                 ebp, dword ptr [esp + 0x34]
            //   89742418             | mov                 dword ptr [esp + 0x18], esi
            //   03de                 | add                 ebx, esi
            //   8b74245c             | mov                 esi, dword ptr [esp + 0x5c]

        $sequence_2 = { 8b442424 99 f7fe 83c408 85d2 7425 6815050000 }
            // n = 7, score = 100
            //   8b442424             | mov                 eax, dword ptr [esp + 0x24]
            //   99                   | cdq                 
            //   f7fe                 | idiv                esi
            //   83c408               | add                 esp, 8
            //   85d2                 | test                edx, edx
            //   7425                 | je                  0x27
            //   6815050000           | push                0x515

        $sequence_3 = { ff750c 50 ff15???????? 8bf0 ff15???????? 83f850 }
            // n = 6, score = 100
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8bf0                 | mov                 esi, eax
            //   ff15????????         |                     
            //   83f850               | cmp                 eax, 0x50

        $sequence_4 = { 8b4c2474 0bc8 8b442464 0bc2 8b54244c 33f1 33f8 }
            // n = 7, score = 100
            //   8b4c2474             | mov                 ecx, dword ptr [esp + 0x74]
            //   0bc8                 | or                  ecx, eax
            //   8b442464             | mov                 eax, dword ptr [esp + 0x64]
            //   0bc2                 | or                  eax, edx
            //   8b54244c             | mov                 edx, dword ptr [esp + 0x4c]
            //   33f1                 | xor                 esi, ecx
            //   33f8                 | xor                 edi, eax

        $sequence_5 = { 83cbff eb11 83fb01 750c 8b5004 85d2 7505 }
            // n = 7, score = 100
            //   83cbff               | or                  ebx, 0xffffffff
            //   eb11                 | jmp                 0x13
            //   83fb01               | cmp                 ebx, 1
            //   750c                 | jne                 0xe
            //   8b5004               | mov                 edx, dword ptr [eax + 4]
            //   85d2                 | test                edx, edx
            //   7505                 | jne                 7

        $sequence_6 = { 8b5704 8b0e 8b3a 8bc1 2bc7 7511 8b7a08 }
            // n = 7, score = 100
            //   8b5704               | mov                 edx, dword ptr [edi + 4]
            //   8b0e                 | mov                 ecx, dword ptr [esi]
            //   8b3a                 | mov                 edi, dword ptr [edx]
            //   8bc1                 | mov                 eax, ecx
            //   2bc7                 | sub                 eax, edi
            //   7511                 | jne                 0x13
            //   8b7a08               | mov                 edi, dword ptr [edx + 8]

        $sequence_7 = { 8b35???????? 8d45e8 68???????? 50 ffd6 8bf8 59 }
            // n = 7, score = 100
            //   8b35????????         |                     
            //   8d45e8               | lea                 eax, [ebp - 0x18]
            //   68????????           |                     
            //   50                   | push                eax
            //   ffd6                 | call                esi
            //   8bf8                 | mov                 edi, eax
            //   59                   | pop                 ecx

        $sequence_8 = { 8b4b58 898184030000 8b03 3d00030000 0f8ebf000000 8b442418 8b4c2414 }
            // n = 7, score = 100
            //   8b4b58               | mov                 ecx, dword ptr [ebx + 0x58]
            //   898184030000         | mov                 dword ptr [ecx + 0x384], eax
            //   8b03                 | mov                 eax, dword ptr [ebx]
            //   3d00030000           | cmp                 eax, 0x300
            //   0f8ebf000000         | jle                 0xc5
            //   8b442418             | mov                 eax, dword ptr [esp + 0x18]
            //   8b4c2414             | mov                 ecx, dword ptr [esp + 0x14]

        $sequence_9 = { 75f3 5f 5e 5d b830000000 }
            // n = 5, score = 100
            //   75f3                 | jne                 0xfffffff5
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5d                   | pop                 ebp
            //   b830000000           | mov                 eax, 0x30

    condition:
        7 of them and filesize < 1228800
}