rule win_batel_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.batel."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.batel"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 33c0 5b c21000 3b0d???????? 7502 f3c3 }
            // n = 6, score = 200
            //   33c0                 | xor                 eax, eax
            //   5b                   | pop                 ebx
            //   c21000               | ret                 0x10
            //   3b0d????????         |                     
            //   7502                 | jne                 4
            //   f3c3                 | ret                 

        $sequence_1 = { 56 b858212300 be58212300 57 8bf8 3bc6 }
            // n = 6, score = 100
            //   56                   | push                esi
            //   b858212300           | mov                 eax, 0x232158
            //   be58212300           | mov                 esi, 0x232158
            //   57                   | push                edi
            //   8bf8                 | mov                 edi, eax
            //   3bc6                 | cmp                 eax, esi

        $sequence_2 = { 7429 68f4202300 56 ff15???????? }
            // n = 4, score = 100
            //   7429                 | je                  0x2b
            //   68f4202300           | push                0x2320f4
            //   56                   | push                esi
            //   ff15????????         |                     

        $sequence_3 = { 7cec 56 57 6a40 6800100000 }
            // n = 5, score = 100
            //   7cec                 | jl                  0xffffffee
            //   56                   | push                esi
            //   57                   | push                edi
            //   6a40                 | push                0x40
            //   6800100000           | push                0x1000

        $sequence_4 = { 7ccd 5f 5e 5d 33c0 5b c21000 }
            // n = 7, score = 100
            //   7ccd                 | jl                  0xffffffcf
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5d                   | pop                 ebp
            //   33c0                 | xor                 eax, eax
            //   5b                   | pop                 ebx
            //   c21000               | ret                 0x10

        $sequence_5 = { c745fc00000000 6800002300 e8???????? 83c404 }
            // n = 4, score = 100
            //   c745fc00000000       | mov                 dword ptr [ebp - 4], 0
            //   6800002300           | push                0x230000
            //   e8????????           |                     
            //   83c404               | add                 esp, 4

        $sequence_6 = { 689d020000 8d8561fdffff 6a00 50 c68560fdffff00 }
            // n = 5, score = 100
            //   689d020000           | push                0x29d
            //   8d8561fdffff         | lea                 eax, [ebp - 0x29f]
            //   6a00                 | push                0
            //   50                   | push                eax
            //   c68560fdffff00       | mov                 byte ptr [ebp - 0x2a0], 0

        $sequence_7 = { 8b1d???????? bf01000000 8d642400 68???????? ff15???????? }
            // n = 5, score = 100
            //   8b1d????????         |                     
            //   bf01000000           | mov                 edi, 1
            //   8d642400             | lea                 esp, [esp]
            //   68????????           |                     
            //   ff15????????         |                     

        $sequence_8 = { b8???????? 8a10 88940d60fdffff 83c003 }
            // n = 4, score = 100
            //   b8????????           |                     
            //   8a10                 | mov                 dl, byte ptr [eax]
            //   88940d60fdffff       | mov                 byte ptr [ebp + ecx - 0x2a0], dl
            //   83c003               | add                 eax, 3

        $sequence_9 = { a1???????? 85c0 752c 8935???????? 68d0202300 }
            // n = 5, score = 100
            //   a1????????           |                     
            //   85c0                 | test                eax, eax
            //   752c                 | jne                 0x2e
            //   8935????????         |                     
            //   68d0202300           | push                0x2320d0

        $sequence_10 = { 40 c20c00 55 8bec 81eca0020000 68ee020000 ff15???????? }
            // n = 7, score = 100
            //   40                   | inc                 eax
            //   c20c00               | ret                 0xc
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   81eca0020000         | sub                 esp, 0x2a0
            //   68ee020000           | push                0x2ee
            //   ff15????????         |                     

        $sequence_11 = { b90b010000 66398818002300 75dd 83b8740023000e 76d4 }
            // n = 5, score = 100
            //   b90b010000           | mov                 ecx, 0x10b
            //   66398818002300       | cmp                 word ptr [eax + 0x230018], cx
            //   75dd                 | jne                 0xffffffdf
            //   83b8740023000e       | cmp                 dword ptr [eax + 0x230074], 0xe
            //   76d4                 | jbe                 0xffffffd6

        $sequence_12 = { ffd3 68005c2605 ffd5 47 83ff5a 7ccd 5f }
            // n = 7, score = 100
            //   ffd3                 | call                ebx
            //   68005c2605           | push                0x5265c00
            //   ffd5                 | call                ebp
            //   47                   | inc                 edi
            //   83ff5a               | cmp                 edi, 0x5a
            //   7ccd                 | jl                  0xffffffcf
            //   5f                   | pop                 edi

        $sequence_13 = { 55 8b2d???????? 56 57 68a00f0000 ffd5 }
            // n = 6, score = 100
            //   55                   | push                ebp
            //   8b2d????????         |                     
            //   56                   | push                esi
            //   57                   | push                edi
            //   68a00f0000           | push                0xfa0
            //   ffd5                 | call                ebp

        $sequence_14 = { 85c0 7412 ffd0 56 }
            // n = 4, score = 100
            //   85c0                 | test                eax, eax
            //   7412                 | je                  0x14
            //   ffd0                 | call                eax
            //   56                   | push                esi

        $sequence_15 = { 59 6a00 ff15???????? 68d8202300 ff15???????? 833d????????00 }
            // n = 6, score = 100
            //   59                   | pop                 ecx
            //   6a00                 | push                0
            //   ff15????????         |                     
            //   68d8202300           | push                0x2320d8
            //   ff15????????         |                     
            //   833d????????00       |                     

        $sequence_16 = { 68a00f0000 ffd5 8b1d???????? bf01000000 }
            // n = 4, score = 100
            //   68a00f0000           | push                0xfa0
            //   ffd5                 | call                ebp
            //   8b1d????????         |                     
            //   bf01000000           | mov                 edi, 1

        $sequence_17 = { 50 c68560fdffff00 e8???????? 83c40c 33c9 }
            // n = 5, score = 100
            //   50                   | push                eax
            //   c68560fdffff00       | mov                 byte ptr [ebp - 0x2a0], 0
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   33c9                 | xor                 ecx, ecx

        $sequence_18 = { 85f6 7422 68???????? 56 ff15???????? 85c0 7412 }
            // n = 7, score = 100
            //   85f6                 | test                esi, esi
            //   7422                 | je                  0x24
            //   68????????           |                     
            //   56                   | push                esi
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7412                 | je                  0x14

        $sequence_19 = { 6a00 ff15???????? 8bf8 b9a7000000 8db560fdffff f3a5 66a5 }
            // n = 7, score = 100
            //   6a00                 | push                0
            //   ff15????????         |                     
            //   8bf8                 | mov                 edi, eax
            //   b9a7000000           | mov                 ecx, 0xa7
            //   8db560fdffff         | lea                 esi, [ebp - 0x2a0]
            //   f3a5                 | rep movsd           dword ptr es:[edi], dword ptr [esi]
            //   66a5                 | movsw               word ptr es:[edi], word ptr [esi]

        $sequence_20 = { 6a40 6800100000 689e020000 6a00 ff15???????? }
            // n = 5, score = 100
            //   6a40                 | push                0x40
            //   6800100000           | push                0x1000
            //   689e020000           | push                0x29e
            //   6a00                 | push                0
            //   ff15????????         |                     

        $sequence_21 = { 83b8740023000e 76d4 33c9 3988e8002300 0f95c1 8bc1 6a02 }
            // n = 7, score = 100
            //   83b8740023000e       | cmp                 dword ptr [eax + 0x230074], 0xe
            //   76d4                 | jbe                 0xffffffd6
            //   33c9                 | xor                 ecx, ecx
            //   3988e8002300         | cmp                 dword ptr [eax + 0x2300e8], ecx
            //   0f95c1               | setne               cl
            //   8bc1                 | mov                 eax, ecx
            //   6a02                 | push                2

        $sequence_22 = { 66a5 ffd0 5f 5e }
            // n = 4, score = 100
            //   66a5                 | movsw               word ptr es:[edi], word ptr [esi]
            //   ffd0                 | call                eax
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi

    condition:
        7 of them and filesize < 49152
}