rule win_bee_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.bee."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.bee"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 0f8326010000 8bce d1e9 ba49922409 2bd1 3bd6 7304 }
            // n = 7, score = 100
            //   0f8326010000         | jae                 0x12c
            //   8bce                 | mov                 ecx, esi
            //   d1e9                 | shr                 ecx, 1
            //   ba49922409           | mov                 edx, 0x9249249
            //   2bd1                 | sub                 edx, ecx
            //   3bd6                 | cmp                 edx, esi
            //   7304                 | jae                 6

        $sequence_1 = { 83c404 89742418 c644244806 3bf3 741d 8b542414 }
            // n = 6, score = 100
            //   83c404               | add                 esp, 4
            //   89742418             | mov                 dword ptr [esp + 0x18], esi
            //   c644244806           | mov                 byte ptr [esp + 0x48], 6
            //   3bf3                 | cmp                 esi, ebx
            //   741d                 | je                  0x1f
            //   8b542414             | mov                 edx, dword ptr [esp + 0x14]

        $sequence_2 = { 668944241c 52 8d44241c 50 8d4c2438 c744242000000000 e8???????? }
            // n = 7, score = 100
            //   668944241c           | mov                 word ptr [esp + 0x1c], ax
            //   52                   | push                edx
            //   8d44241c             | lea                 eax, [esp + 0x1c]
            //   50                   | push                eax
            //   8d4c2438             | lea                 ecx, [esp + 0x38]
            //   c744242000000000     | mov                 dword ptr [esp + 0x20], 0
            //   e8????????           |                     

        $sequence_3 = { e8???????? 8b542424 56 6a00 52 e8???????? 8b7c2434 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8b542424             | mov                 edx, dword ptr [esp + 0x24]
            //   56                   | push                esi
            //   6a00                 | push                0
            //   52                   | push                edx
            //   e8????????           |                     
            //   8b7c2434             | mov                 edi, dword ptr [esp + 0x34]

        $sequence_4 = { 8d8424a4000000 8a10 3a11 751a 3ad3 7412 }
            // n = 6, score = 100
            //   8d8424a4000000       | lea                 eax, [esp + 0xa4]
            //   8a10                 | mov                 dl, byte ptr [eax]
            //   3a11                 | cmp                 dl, byte ptr [ecx]
            //   751a                 | jne                 0x1c
            //   3ad3                 | cmp                 dl, bl
            //   7412                 | je                  0x14

        $sequence_5 = { 8bf9 80bfd800000000 754e 6a11 6a02 6a02 }
            // n = 6, score = 100
            //   8bf9                 | mov                 edi, ecx
            //   80bfd800000000       | cmp                 byte ptr [edi + 0xd8], 0
            //   754e                 | jne                 0x50
            //   6a11                 | push                0x11
            //   6a02                 | push                2
            //   6a02                 | push                2

        $sequence_6 = { e8???????? 8d0cb6 c1e104 03c8 89470c 894710 }
            // n = 6, score = 100
            //   e8????????           |                     
            //   8d0cb6               | lea                 ecx, [esi + esi*4]
            //   c1e104               | shl                 ecx, 4
            //   03c8                 | add                 ecx, eax
            //   89470c               | mov                 dword ptr [edi + 0xc], eax
            //   894710               | mov                 dword ptr [edi + 0x10], eax

        $sequence_7 = { 8bc3 8bcf e8???????? 2bf7 b867666666 f7ee }
            // n = 6, score = 100
            //   8bc3                 | mov                 eax, ebx
            //   8bcf                 | mov                 ecx, edi
            //   e8????????           |                     
            //   2bf7                 | sub                 esi, edi
            //   b867666666           | mov                 eax, 0x66666667
            //   f7ee                 | imul                esi

        $sequence_8 = { e8???????? 83c414 8b45fc ff34c5e4314200 }
            // n = 4, score = 100
            //   e8????????           |                     
            //   83c414               | add                 esp, 0x14
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   ff34c5e4314200       | push                dword ptr [eax*8 + 0x4231e4]

        $sequence_9 = { 64a300000000 8b6c2420 33db 895d04 885d0c }
            // n = 5, score = 100
            //   64a300000000         | mov                 dword ptr fs:[0], eax
            //   8b6c2420             | mov                 ebp, dword ptr [esp + 0x20]
            //   33db                 | xor                 ebx, ebx
            //   895d04               | mov                 dword ptr [ebp + 4], ebx
            //   885d0c               | mov                 byte ptr [ebp + 0xc], bl

    condition:
        7 of them and filesize < 394240
}