rule win_bernhardpos_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.bernhardpos."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.bernhardpos"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 0f840a010000 8d85ecfbffff 50 682a020000 68???????? 8b8df0fbffff }
            // n = 6, score = 200
            //   0f840a010000         | je                  0x110
            //   8d85ecfbffff         | lea                 eax, [ebp - 0x414]
            //   50                   | push                eax
            //   682a020000           | push                0x22a
            //   68????????           |                     
            //   8b8df0fbffff         | mov                 ecx, dword ptr [ebp - 0x410]

        $sequence_1 = { ff15???????? 8b8d54feffff 668901 6a10 8d855cfeffff 50 }
            // n = 6, score = 200
            //   ff15????????         |                     
            //   8b8d54feffff         | mov                 ecx, dword ptr [ebp - 0x1ac]
            //   668901               | mov                 word ptr [ecx], ax
            //   6a10                 | push                0x10
            //   8d855cfeffff         | lea                 eax, [ebp - 0x1a4]
            //   50                   | push                eax

        $sequence_2 = { 0fbe5415f8 33ca 8b4508 0345f4 8808 ebc7 5f }
            // n = 7, score = 200
            //   0fbe5415f8           | movsx               edx, byte ptr [ebp + edx - 8]
            //   33ca                 | xor                 ecx, edx
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   0345f4               | add                 eax, dword ptr [ebp - 0xc]
            //   8808                 | mov                 byte ptr [eax], cl
            //   ebc7                 | jmp                 0xffffffc9
            //   5f                   | pop                 edi

        $sequence_3 = { 8945fc 8b45fc 8b4d08 03483c 894df4 }
            // n = 5, score = 200
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   03483c               | add                 ecx, dword ptr [eax + 0x3c]
            //   894df4               | mov                 dword ptr [ebp - 0xc], ecx

        $sequence_4 = { 8808 ebc7 5f 5e 5b }
            // n = 5, score = 200
            //   8808                 | mov                 byte ptr [eax], cl
            //   ebc7                 | jmp                 0xffffffc9
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx

        $sequence_5 = { 668b0d???????? 66894dfc 8a15???????? 8855fe 8d45f8 50 ff15???????? }
            // n = 7, score = 200
            //   668b0d????????       |                     
            //   66894dfc             | mov                 word ptr [ebp - 4], cx
            //   8a15????????         |                     
            //   8855fe               | mov                 byte ptr [ebp - 2], dl
            //   8d45f8               | lea                 eax, [ebp - 8]
            //   50                   | push                eax
            //   ff15????????         |                     

        $sequence_6 = { 83e863 5f 5e 5b }
            // n = 4, score = 200
            //   83e863               | sub                 eax, 0x63
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx

        $sequence_7 = { 51 ff15???????? 8d85ecfeffff 50 e8???????? 83c404 85c0 }
            // n = 7, score = 200
            //   51                   | push                ecx
            //   ff15????????         |                     
            //   8d85ecfeffff         | lea                 eax, [ebp - 0x114]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   85c0                 | test                eax, eax

        $sequence_8 = { eb2c 33c0 eb2d 33c0 eb29 }
            // n = 5, score = 200
            //   eb2c                 | jmp                 0x2e
            //   33c0                 | xor                 eax, eax
            //   eb2d                 | jmp                 0x2f
            //   33c0                 | xor                 eax, eax
            //   eb29                 | jmp                 0x2b

        $sequence_9 = { e8???????? 83c404 6a01 8d85d0feffff 50 ff15???????? }
            // n = 6, score = 200
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   6a01                 | push                1
            //   8d85d0feffff         | lea                 eax, [ebp - 0x130]
            //   50                   | push                eax
            //   ff15????????         |                     

    condition:
        7 of them and filesize < 368640
}