rule win_bka_trojaner_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.bka_trojaner."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.bka_trojaner"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 2bc1 33ff 89442428 397c2420 894c2438 897c242c }
            // n = 6, score = 100
            //   2bc1                 | sub                 eax, ecx
            //   33ff                 | xor                 edi, edi
            //   89442428             | mov                 dword ptr [esp + 0x28], eax
            //   397c2420             | cmp                 dword ptr [esp + 0x20], edi
            //   894c2438             | mov                 dword ptr [esp + 0x38], ecx
            //   897c242c             | mov                 dword ptr [esp + 0x2c], edi

        $sequence_1 = { 8b542414 68ff030000 8d8c2468040000 03da 8b54241c 51 }
            // n = 6, score = 100
            //   8b542414             | mov                 edx, dword ptr [esp + 0x14]
            //   68ff030000           | push                0x3ff
            //   8d8c2468040000       | lea                 ecx, [esp + 0x468]
            //   03da                 | add                 ebx, edx
            //   8b54241c             | mov                 edx, dword ptr [esp + 0x1c]
            //   51                   | push                ecx

        $sequence_2 = { 50 57 e8???????? 85c0 75c6 5d }
            // n = 6, score = 100
            //   50                   | push                eax
            //   57                   | push                edi
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   75c6                 | jne                 0xffffffc8
            //   5d                   | pop                 ebp

        $sequence_3 = { 56 ff5124 85c0 7517 8b44247c 5f }
            // n = 6, score = 100
            //   56                   | push                esi
            //   ff5124               | call                dword ptr [ecx + 0x24]
            //   85c0                 | test                eax, eax
            //   7517                 | jne                 0x19
            //   8b44247c             | mov                 eax, dword ptr [esp + 0x7c]
            //   5f                   | pop                 edi

        $sequence_4 = { 85c0 7439 53 8b1d???????? 55 8b2d???????? 8bff }
            // n = 7, score = 100
            //   85c0                 | test                eax, eax
            //   7439                 | je                  0x3b
            //   53                   | push                ebx
            //   8b1d????????         |                     
            //   55                   | push                ebp
            //   8b2d????????         |                     
            //   8bff                 | mov                 edi, edi

        $sequence_5 = { 8b54240c 8b4c2404 8b8170ffffff 52 8b54240c 81c170ffffff 52 }
            // n = 7, score = 100
            //   8b54240c             | mov                 edx, dword ptr [esp + 0xc]
            //   8b4c2404             | mov                 ecx, dword ptr [esp + 4]
            //   8b8170ffffff         | mov                 eax, dword ptr [ecx - 0x90]
            //   52                   | push                edx
            //   8b54240c             | mov                 edx, dword ptr [esp + 0xc]
            //   81c170ffffff         | add                 ecx, 0xffffff70
            //   52                   | push                edx

        $sequence_6 = { 6a10 68???????? 68???????? 52 ff15???????? 83c8ff }
            // n = 6, score = 100
            //   6a10                 | push                0x10
            //   68????????           |                     
            //   68????????           |                     
            //   52                   | push                edx
            //   ff15????????         |                     
            //   83c8ff               | or                  eax, 0xffffffff

        $sequence_7 = { e8???????? 59 59 8945c4 a1???????? }
            // n = 5, score = 100
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx
            //   8945c4               | mov                 dword ptr [ebp - 0x3c], eax
            //   a1????????           |                     

        $sequence_8 = { c7440a04???????? 8b4104 8b4004 8d9078ffffff 891408 8b4104 }
            // n = 6, score = 100
            //   c7440a04????????     |                     
            //   8b4104               | mov                 eax, dword ptr [ecx + 4]
            //   8b4004               | mov                 eax, dword ptr [eax + 4]
            //   8d9078ffffff         | lea                 edx, [eax - 0x88]
            //   891408               | mov                 dword ptr [eax + ecx], edx
            //   8b4104               | mov                 eax, dword ptr [ecx + 4]

        $sequence_9 = { 752d 837df800 7424 ff7508 8d4608 e8???????? ff7508 }
            // n = 7, score = 100
            //   752d                 | jne                 0x2f
            //   837df800             | cmp                 dword ptr [ebp - 8], 0
            //   7424                 | je                  0x26
            //   ff7508               | push                dword ptr [ebp + 8]
            //   8d4608               | lea                 eax, [esi + 8]
            //   e8????????           |                     
            //   ff7508               | push                dword ptr [ebp + 8]

    condition:
        7 of them and filesize < 221184
}