rule win_blackmatter_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.blackmatter."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.blackmatter"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 57 c745fc00000000 ff35???????? e8???????? 8bf8 }
            // n = 5, score = 400
            //   57                   | push                edi
            //   c745fc00000000       | mov                 dword ptr [ebp - 4], 0
            //   ff35????????         |                     
            //   e8????????           |                     
            //   8bf8                 | mov                 edi, eax

        $sequence_1 = { ff75f8 ff15???????? 85c0 0f85e7000000 68???????? }
            // n = 5, score = 400
            //   ff75f8               | push                dword ptr [ebp - 8]
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   0f85e7000000         | jne                 0xed
            //   68????????           |                     

        $sequence_2 = { 83c4d8 53 56 57 c745fc00000000 c745f800000000 }
            // n = 6, score = 400
            //   83c4d8               | add                 esp, -0x28
            //   53                   | push                ebx
            //   56                   | push                esi
            //   57                   | push                edi
            //   c745fc00000000       | mov                 dword ptr [ebp - 4], 0
            //   c745f800000000       | mov                 dword ptr [ebp - 8], 0

        $sequence_3 = { e8???????? 8945fc eb0c 83c702 ff4df8 837df800 }
            // n = 6, score = 400
            //   e8????????           |                     
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   eb0c                 | jmp                 0xe
            //   83c702               | add                 edi, 2
            //   ff4df8               | dec                 dword ptr [ebp - 8]
            //   837df800             | cmp                 dword ptr [ebp - 8], 0

        $sequence_4 = { e9???????? ff75c8 e8???????? 8945c4 }
            // n = 4, score = 400
            //   e9????????           |                     
            //   ff75c8               | push                dword ptr [ebp - 0x38]
            //   e8????????           |                     
            //   8945c4               | mov                 dword ptr [ebp - 0x3c], eax

        $sequence_5 = { ff15???????? 83c40c 8d047500000000 50 8d45da }
            // n = 5, score = 400
            //   ff15????????         |                     
            //   83c40c               | add                 esp, 0xc
            //   8d047500000000       | lea                 eax, [esi*2]
            //   50                   | push                eax
            //   8d45da               | lea                 eax, [ebp - 0x26]

        $sequence_6 = { 85f6 0f842c010000 56 ff35???????? e8???????? ff35???????? e8???????? }
            // n = 7, score = 400
            //   85f6                 | test                esi, esi
            //   0f842c010000         | je                  0x132
            //   56                   | push                esi
            //   ff35????????         |                     
            //   e8????????           |                     
            //   ff35????????         |                     
            //   e8????????           |                     

        $sequence_7 = { f7f1 92 3b4508 720b 3b450c }
            // n = 5, score = 400
            //   f7f1                 | div                 ecx
            //   92                   | xchg                eax, edx
            //   3b4508               | cmp                 eax, dword ptr [ebp + 8]
            //   720b                 | jb                  0xd
            //   3b450c               | cmp                 eax, dword ptr [ebp + 0xc]

        $sequence_8 = { 8945ec e8???????? e8???????? 803d????????00 7405 }
            // n = 5, score = 400
            //   8945ec               | mov                 dword ptr [ebp - 0x14], eax
            //   e8????????           |                     
            //   e8????????           |                     
            //   803d????????00       |                     
            //   7405                 | je                  7

        $sequence_9 = { ff75f4 e8???????? 5e 5b 8be5 5d c3 }
            // n = 7, score = 400
            //   ff75f4               | push                dword ptr [ebp - 0xc]
            //   e8????????           |                     
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx
            //   8be5                 | mov                 esp, ebp
            //   5d                   | pop                 ebp
            //   c3                   | ret                 

    condition:
        7 of them and filesize < 194560
}