rule win_blacksoul_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.blacksoul."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.blacksoul"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b7508 33c0 884508 8bce ff7508 }
            // n = 5, score = 200
            //   8b7508               | mov                 esi, dword ptr [ebp + 8]
            //   33c0                 | xor                 eax, eax
            //   884508               | mov                 byte ptr [ebp + 8], al
            //   8bce                 | mov                 ecx, esi
            //   ff7508               | push                dword ptr [ebp + 8]

        $sequence_1 = { 8d4dd8 c645fc0c e8???????? ff758c 33f6 57 }
            // n = 6, score = 200
            //   8d4dd8               | lea                 ecx, [ebp - 0x28]
            //   c645fc0c             | mov                 byte ptr [ebp - 4], 0xc
            //   e8????????           |                     
            //   ff758c               | push                dword ptr [ebp - 0x74]
            //   33f6                 | xor                 esi, esi
            //   57                   | push                edi

        $sequence_2 = { 8b4dbc eb03 8b4588 3a45a2 7528 }
            // n = 5, score = 200
            //   8b4dbc               | mov                 ecx, dword ptr [ebp - 0x44]
            //   eb03                 | jmp                 5
            //   8b4588               | mov                 eax, dword ptr [ebp - 0x78]
            //   3a45a2               | cmp                 al, byte ptr [ebp - 0x5e]
            //   7528                 | jne                 0x2a

        $sequence_3 = { 8d4db8 50 e8???????? 8b750c 46 89750c 3bf3 }
            // n = 7, score = 200
            //   8d4db8               | lea                 ecx, [ebp - 0x48]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b750c               | mov                 esi, dword ptr [ebp + 0xc]
            //   46                   | inc                 esi
            //   89750c               | mov                 dword ptr [ebp + 0xc], esi
            //   3bf3                 | cmp                 esi, ebx

        $sequence_4 = { 803c3000 743a 807f0400 750a 8bcf e8???????? }
            // n = 6, score = 200
            //   803c3000             | cmp                 byte ptr [eax + esi], 0
            //   743a                 | je                  0x3c
            //   807f0400             | cmp                 byte ptr [edi + 4], 0
            //   750a                 | jne                 0xc
            //   8bcf                 | mov                 ecx, edi
            //   e8????????           |                     

        $sequence_5 = { 8bb570ffffff 8bbd5cffffff 56 53 c6458200 }
            // n = 5, score = 200
            //   8bb570ffffff         | mov                 esi, dword ptr [ebp - 0x90]
            //   8bbd5cffffff         | mov                 edi, dword ptr [ebp - 0xa4]
            //   56                   | push                esi
            //   53                   | push                ebx
            //   c6458200             | mov                 byte ptr [ebp - 0x7e], 0

        $sequence_6 = { 50 8d55a8 8d4d90 e8???????? c645fc03 }
            // n = 5, score = 200
            //   50                   | push                eax
            //   8d55a8               | lea                 edx, [ebp - 0x58]
            //   8d4d90               | lea                 ecx, [ebp - 0x70]
            //   e8????????           |                     
            //   c645fc03             | mov                 byte ptr [ebp - 4], 3

        $sequence_7 = { 803c3200 0f8e81000000 46 eb06 8b4db0 8b459c }
            // n = 6, score = 200
            //   803c3200             | cmp                 byte ptr [edx + esi], 0
            //   0f8e81000000         | jle                 0x87
            //   46                   | inc                 esi
            //   eb06                 | jmp                 8
            //   8b4db0               | mov                 ecx, dword ptr [ebp - 0x50]
            //   8b459c               | mov                 eax, dword ptr [ebp - 0x64]

        $sequence_8 = { 8b5590 3a559e 752e 6a00 8d4db8 }
            // n = 5, score = 200
            //   8b5590               | mov                 edx, dword ptr [ebp - 0x70]
            //   3a559e               | cmp                 dl, byte ptr [ebp - 0x62]
            //   752e                 | jne                 0x30
            //   6a00                 | push                0
            //   8d4db8               | lea                 ecx, [ebp - 0x48]

        $sequence_9 = { 83f80a 7345 8b4d8c 398d6cffffff 7f0d ff4594 85c0 }
            // n = 7, score = 200
            //   83f80a               | cmp                 eax, 0xa
            //   7345                 | jae                 0x47
            //   8b4d8c               | mov                 ecx, dword ptr [ebp - 0x74]
            //   398d6cffffff         | cmp                 dword ptr [ebp - 0x94], ecx
            //   7f0d                 | jg                  0xf
            //   ff4594               | inc                 dword ptr [ebp - 0x6c]
            //   85c0                 | test                eax, eax

    condition:
        7 of them and filesize < 1823640
}