rule win_blacksuit_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.blacksuit."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.blacksuit"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d4608 85c0 7416 ff74240c 50 e8???????? 83c408 }
            // n = 7, score = 100
            //   8d4608               | lea                 eax, [esi + 8]
            //   85c0                 | test                eax, eax
            //   7416                 | je                  0x18
            //   ff74240c             | push                dword ptr [esp + 0xc]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c408               | add                 esp, 8

        $sequence_1 = { e8???????? 8bf0 83c408 85f6 7510 8bf7 8d4e01 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax
            //   83c408               | add                 esp, 8
            //   85f6                 | test                esi, esi
            //   7510                 | jne                 0x12
            //   8bf7                 | mov                 esi, edi
            //   8d4e01               | lea                 ecx, [esi + 1]

        $sequence_2 = { e8???????? 83c408 5f 5e 8bc3 5b 83c428 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   8bc3                 | mov                 eax, ebx
            //   5b                   | pop                 ebx
            //   83c428               | add                 esp, 0x28

        $sequence_3 = { ffe0 e8???????? 68???????? 6a2f 68???????? e8???????? 6a00 }
            // n = 7, score = 100
            //   ffe0                 | jmp                 eax
            //   e8????????           |                     
            //   68????????           |                     
            //   6a2f                 | push                0x2f
            //   68????????           |                     
            //   e8????????           |                     
            //   6a00                 | push                0

        $sequence_4 = { eb37 e8???????? 68???????? 68cb000000 68???????? e8???????? 6a00 }
            // n = 7, score = 100
            //   eb37                 | jmp                 0x39
            //   e8????????           |                     
            //   68????????           |                     
            //   68cb000000           | push                0xcb
            //   68????????           |                     
            //   e8????????           |                     
            //   6a00                 | push                0

        $sequence_5 = { 895c2444 8b5c243c 89742440 e9???????? ff7608 ff74243c e8???????? }
            // n = 7, score = 100
            //   895c2444             | mov                 dword ptr [esp + 0x44], ebx
            //   8b5c243c             | mov                 ebx, dword ptr [esp + 0x3c]
            //   89742440             | mov                 dword ptr [esp + 0x40], esi
            //   e9????????           |                     
            //   ff7608               | push                dword ptr [esi + 8]
            //   ff74243c             | push                dword ptr [esp + 0x3c]
            //   e8????????           |                     

        $sequence_6 = { ff742440 53 83fd01 750f ff74242c 56 e8???????? }
            // n = 7, score = 100
            //   ff742440             | push                dword ptr [esp + 0x40]
            //   53                   | push                ebx
            //   83fd01               | cmp                 ebp, 1
            //   750f                 | jne                 0x11
            //   ff74242c             | push                dword ptr [esp + 0x2c]
            //   56                   | push                esi
            //   e8????????           |                     

        $sequence_7 = { e9???????? 55 8d442420 50 8d442420 50 8d44242c }
            // n = 7, score = 100
            //   e9????????           |                     
            //   55                   | push                ebp
            //   8d442420             | lea                 eax, [esp + 0x20]
            //   50                   | push                eax
            //   8d442420             | lea                 eax, [esp + 0x20]
            //   50                   | push                eax
            //   8d44242c             | lea                 eax, [esp + 0x2c]

        $sequence_8 = { ff7648 e8???????? 8bc8 83c404 85c9 7530 e8???????? }
            // n = 7, score = 100
            //   ff7648               | push                dword ptr [esi + 0x48]
            //   e8????????           |                     
            //   8bc8                 | mov                 ecx, eax
            //   83c404               | add                 esp, 4
            //   85c9                 | test                ecx, ecx
            //   7530                 | jne                 0x32
            //   e8????????           |                     

        $sequence_9 = { e8???????? ff37 e8???????? 83c408 891f 5e 5b }
            // n = 7, score = 100
            //   e8????????           |                     
            //   ff37                 | push                dword ptr [edi]
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   891f                 | mov                 dword ptr [edi], ebx
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx

    condition:
        7 of them and filesize < 4764672
}