rule win_bluelight_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.bluelight."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.bluelight"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c7466400000000 6a01 8d4510 c645fc03 50 8d45e0 68???????? }
            // n = 7, score = 100
            //   c7466400000000       | mov                 dword ptr [esi + 0x64], 0
            //   6a01                 | push                1
            //   8d4510               | lea                 eax, [ebp + 0x10]
            //   c645fc03             | mov                 byte ptr [ebp - 4], 3
            //   50                   | push                eax
            //   8d45e0               | lea                 eax, [ebp - 0x20]
            //   68????????           |                     

        $sequence_1 = { e8???????? 85c0 0f85e1040000 8b55c0 8b4638 8d4aff 0fc9 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   0f85e1040000         | jne                 0x4e7
            //   8b55c0               | mov                 edx, dword ptr [ebp - 0x40]
            //   8b4638               | mov                 eax, dword ptr [esi + 0x38]
            //   8d4aff               | lea                 ecx, [edx - 1]
            //   0fc9                 | bswap               ecx

        $sequence_2 = { b97bfe0000 e8???????? 8945f8 8b4dfc e8???????? 83670c00 8b45f8 }
            // n = 7, score = 100
            //   b97bfe0000           | mov                 ecx, 0xfe7b
            //   e8????????           |                     
            //   8945f8               | mov                 dword ptr [ebp - 8], eax
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   e8????????           |                     
            //   83670c00             | and                 dword ptr [edi + 0xc], 0
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]

        $sequence_3 = { 8bce e8???????? 8bd8 895dc4 85db 0f84bf0e0000 8b5348 }
            // n = 7, score = 100
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     
            //   8bd8                 | mov                 ebx, eax
            //   895dc4               | mov                 dword ptr [ebp - 0x3c], ebx
            //   85db                 | test                ebx, ebx
            //   0f84bf0e0000         | je                  0xec5
            //   8b5348               | mov                 edx, dword ptr [ebx + 0x48]

        $sequence_4 = { 884508 8b4204 8945d8 8b02 8b75d8 3b30 8b75f0 }
            // n = 7, score = 100
            //   884508               | mov                 byte ptr [ebp + 8], al
            //   8b4204               | mov                 eax, dword ptr [edx + 4]
            //   8945d8               | mov                 dword ptr [ebp - 0x28], eax
            //   8b02                 | mov                 eax, dword ptr [edx]
            //   8b75d8               | mov                 esi, dword ptr [ebp - 0x28]
            //   3b30                 | cmp                 esi, dword ptr [eax]
            //   8b75f0               | mov                 esi, dword ptr [ebp - 0x10]

        $sequence_5 = { f3a5 eb23 ff742420 68???????? eb92 8d4101 8bcb }
            // n = 7, score = 100
            //   f3a5                 | rep movsd           dword ptr es:[edi], dword ptr [esi]
            //   eb23                 | jmp                 0x25
            //   ff742420             | push                dword ptr [esp + 0x20]
            //   68????????           |                     
            //   eb92                 | jmp                 0xffffff94
            //   8d4101               | lea                 eax, [ecx + 1]
            //   8bcb                 | mov                 ecx, ebx

        $sequence_6 = { ff248504d44600 6a00 c743140f000000 8bcb c7431000000000 68???????? c60300 }
            // n = 7, score = 100
            //   ff248504d44600       | jmp                 dword ptr [eax*4 + 0x46d404]
            //   6a00                 | push                0
            //   c743140f000000       | mov                 dword ptr [ebx + 0x14], 0xf
            //   8bcb                 | mov                 ecx, ebx
            //   c7431000000000       | mov                 dword ptr [ebx + 0x10], 0
            //   68????????           |                     
            //   c60300               | mov                 byte ptr [ebx], 0

        $sequence_7 = { 7414 8bce e8???????? 814b0400000100 894308 8b45fc 8bd0 }
            // n = 7, score = 100
            //   7414                 | je                  0x16
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     
            //   814b0400000100       | or                  dword ptr [ebx + 4], 0x10000
            //   894308               | mov                 dword ptr [ebx + 8], eax
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   8bd0                 | mov                 edx, eax

        $sequence_8 = { e8???????? 8bd0 52 e8???????? 83c404 8b4518 8b4df4 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8bd0                 | mov                 edx, eax
            //   52                   | push                edx
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   8b4518               | mov                 eax, dword ptr [ebp + 0x18]
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]

        $sequence_9 = { f7410400000400 7408 8b4114 8b4804 eb03 8b490c 85c9 }
            // n = 7, score = 100
            //   f7410400000400       | test                dword ptr [ecx + 4], 0x40000
            //   7408                 | je                  0xa
            //   8b4114               | mov                 eax, dword ptr [ecx + 0x14]
            //   8b4804               | mov                 ecx, dword ptr [eax + 4]
            //   eb03                 | jmp                 5
            //   8b490c               | mov                 ecx, dword ptr [ecx + 0xc]
            //   85c9                 | test                ecx, ecx

    condition:
        7 of them and filesize < 2191360
}