rule win_boldmove_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.boldmove."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.boldmove"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 0fb655e4 d3e2 8b8b24300000 09d0 880431 31c0 }
            // n = 6, score = 100
            //   0fb655e4             | movzx               edx, byte ptr [ebp - 0x1c]
            //   d3e2                 | shl                 edx, cl
            //   8b8b24300000         | mov                 ecx, dword ptr [ebx + 0x3024]
            //   09d0                 | or                  eax, edx
            //   880431               | mov                 byte ptr [ecx + esi], al
            //   31c0                 | xor                 eax, eax

        $sequence_1 = { 891c24 e8???????? 893424 e8???????? 8b442434 85c0 }
            // n = 6, score = 100
            //   891c24               | mov                 dword ptr [esp], ebx
            //   e8????????           |                     
            //   893424               | mov                 dword ptr [esp], esi
            //   e8????????           |                     
            //   8b442434             | mov                 eax, dword ptr [esp + 0x34]
            //   85c0                 | test                eax, eax

        $sequence_2 = { 0f85cf060000 c744246800000000 8b4c2434 b801000000 85c9 0f4fc1 8984249c000000 }
            // n = 7, score = 100
            //   0f85cf060000         | jne                 0x6d5
            //   c744246800000000     | mov                 dword ptr [esp + 0x68], 0
            //   8b4c2434             | mov                 ecx, dword ptr [esp + 0x34]
            //   b801000000           | mov                 eax, 1
            //   85c9                 | test                ecx, ecx
            //   0f4fc1               | cmovg               eax, ecx
            //   8984249c000000       | mov                 dword ptr [esp + 0x9c], eax

        $sequence_3 = { 83cd02 89442448 e9???????? 8d4701 83cd08 89442448 }
            // n = 6, score = 100
            //   83cd02               | or                  ebp, 2
            //   89442448             | mov                 dword ptr [esp + 0x48], eax
            //   e9????????           |                     
            //   8d4701               | lea                 eax, [edi + 1]
            //   83cd08               | or                  ebp, 8
            //   89442448             | mov                 dword ptr [esp + 0x48], eax

        $sequence_4 = { e8???????? 89c5 8b442438 892c24 89442404 e8???????? 8b4c2424 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   89c5                 | mov                 ebp, eax
            //   8b442438             | mov                 eax, dword ptr [esp + 0x38]
            //   892c24               | mov                 dword ptr [esp], ebp
            //   89442404             | mov                 dword ptr [esp + 4], eax
            //   e8????????           |                     
            //   8b4c2424             | mov                 ecx, dword ptr [esp + 0x24]

        $sequence_5 = { 8b442420 89fb 8b10 e9???????? 85f6 7e03 83ee01 }
            // n = 7, score = 100
            //   8b442420             | mov                 eax, dword ptr [esp + 0x20]
            //   89fb                 | mov                 ebx, edi
            //   8b10                 | mov                 edx, dword ptr [eax]
            //   e9????????           |                     
            //   85f6                 | test                esi, esi
            //   7e03                 | jle                 5
            //   83ee01               | sub                 esi, 1

        $sequence_6 = { 8b8314100000 31d2 39d0 740c 39b49318100000 7418 42 }
            // n = 7, score = 100
            //   8b8314100000         | mov                 eax, dword ptr [ebx + 0x1014]
            //   31d2                 | xor                 edx, edx
            //   39d0                 | cmp                 eax, edx
            //   740c                 | je                  0xe
            //   39b49318100000       | cmp                 dword ptr [ebx + edx*4 + 0x1018], esi
            //   7418                 | je                  0x1a
            //   42                   | inc                 edx

        $sequence_7 = { 85db 0f84561d0000 81fe00040000 b800040000 0f4ec6 890424 89442440 }
            // n = 7, score = 100
            //   85db                 | test                ebx, ebx
            //   0f84561d0000         | je                  0x1d5c
            //   81fe00040000         | cmp                 esi, 0x400
            //   b800040000           | mov                 eax, 0x400
            //   0f4ec6               | cmovle              eax, esi
            //   890424               | mov                 dword ptr [esp], eax
            //   89442440             | mov                 dword ptr [esp + 0x40], eax

        $sequence_8 = { 8d4f04 7415 837c242801 0f8473050000 837c242805 7503 0fbec0 }
            // n = 7, score = 100
            //   8d4f04               | lea                 ecx, [edi + 4]
            //   7415                 | je                  0x17
            //   837c242801           | cmp                 dword ptr [esp + 0x28], 1
            //   0f8473050000         | je                  0x579
            //   837c242805           | cmp                 dword ptr [esp + 0x28], 5
            //   7503                 | jne                 5
            //   0fbec0               | movsx               eax, al

        $sequence_9 = { 8b8310080000 31d2 39d0 740c 39b49314080000 }
            // n = 5, score = 100
            //   8b8310080000         | mov                 eax, dword ptr [ebx + 0x810]
            //   31d2                 | xor                 edx, edx
            //   39d0                 | cmp                 eax, edx
            //   740c                 | je                  0xe
            //   39b49314080000       | cmp                 dword ptr [ebx + edx*4 + 0x814], esi

    condition:
        7 of them and filesize < 242688
}