rule win_bolek_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.bolek."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.bolek"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 894c2454 8bc7 8b8c24ac000000 8bdf 0facc808 33ed c1e318 }
            // n = 7, score = 600
            //   894c2454             | mov                 dword ptr [esp + 0x54], ecx
            //   8bc7                 | mov                 eax, edi
            //   8b8c24ac000000       | mov                 ecx, dword ptr [esp + 0xac]
            //   8bdf                 | mov                 ebx, edi
            //   0facc808             | shrd                eax, ecx, 8
            //   33ed                 | xor                 ebp, ebp
            //   c1e318               | shl                 ebx, 0x18

        $sequence_1 = { 3b31 72e1 51 e8???????? 59 8bc7 5f }
            // n = 7, score = 600
            //   3b31                 | cmp                 esi, dword ptr [ecx]
            //   72e1                 | jb                  0xffffffe3
            //   51                   | push                ecx
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   8bc7                 | mov                 eax, edi
            //   5f                   | pop                 edi

        $sequence_2 = { 8bcd 0fa4c117 0bf9 c1e017 0bd8 8bcd 8b442460 }
            // n = 7, score = 600
            //   8bcd                 | mov                 ecx, ebp
            //   0fa4c117             | shld                ecx, eax, 0x17
            //   0bf9                 | or                  edi, ecx
            //   c1e017               | shl                 eax, 0x17
            //   0bd8                 | or                  ebx, eax
            //   8bcd                 | mov                 ecx, ebp
            //   8b442460             | mov                 eax, dword ptr [esp + 0x60]

        $sequence_3 = { 8d86f4000000 50 e8???????? 83c418 56 6880000000 ff750c }
            // n = 7, score = 600
            //   8d86f4000000         | lea                 eax, [esi + 0xf4]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c418               | add                 esp, 0x18
            //   56                   | push                esi
            //   6880000000           | push                0x80
            //   ff750c               | push                dword ptr [ebp + 0xc]

        $sequence_4 = { dd442418 dc0d???????? dd1c24 68???????? 8b1d???????? 8d44242c 6a40 }
            // n = 7, score = 600
            //   dd442418             | fld                 qword ptr [esp + 0x18]
            //   dc0d????????         |                     
            //   dd1c24               | fstp                qword ptr [esp]
            //   68????????           |                     
            //   8b1d????????         |                     
            //   8d44242c             | lea                 eax, [esp + 0x2c]
            //   6a40                 | push                0x40

        $sequence_5 = { eb7a 3c03 0f85bf000000 53 6a01 8d442428 50 }
            // n = 7, score = 600
            //   eb7a                 | jmp                 0x7c
            //   3c03                 | cmp                 al, 3
            //   0f85bf000000         | jne                 0xc5
            //   53                   | push                ebx
            //   6a01                 | push                1
            //   8d442428             | lea                 eax, [esp + 0x28]
            //   50                   | push                eax

        $sequence_6 = { 85c9 746f 803900 746a 6a2c 51 890f }
            // n = 7, score = 600
            //   85c9                 | test                ecx, ecx
            //   746f                 | je                  0x71
            //   803900               | cmp                 byte ptr [ecx], 0
            //   746a                 | je                  0x6c
            //   6a2c                 | push                0x2c
            //   51                   | push                ecx
            //   890f                 | mov                 dword ptr [edi], ecx

        $sequence_7 = { e8???????? eb07 814f7c00040000 5f 5e 5d 5b }
            // n = 7, score = 600
            //   e8????????           |                     
            //   eb07                 | jmp                 9
            //   814f7c00040000       | or                  dword ptr [edi + 0x7c], 0x400
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5d                   | pop                 ebp
            //   5b                   | pop                 ebx

        $sequence_8 = { 89448c20 41 83c304 ebd0 8bac2434030000 8b9c2430030000 85db }
            // n = 7, score = 600
            //   89448c20             | mov                 dword ptr [esp + ecx*4 + 0x20], eax
            //   41                   | inc                 ecx
            //   83c304               | add                 ebx, 4
            //   ebd0                 | jmp                 0xffffffd2
            //   8bac2434030000       | mov                 ebp, dword ptr [esp + 0x334]
            //   8b9c2430030000       | mov                 ebx, dword ptr [esp + 0x330]
            //   85db                 | test                ebx, ebx

        $sequence_9 = { 83e4f8 83ec68 8364242000 8364242400 8b450c c744241001234567 c744241489abcdef }
            // n = 7, score = 600
            //   83e4f8               | and                 esp, 0xfffffff8
            //   83ec68               | sub                 esp, 0x68
            //   8364242000           | and                 dword ptr [esp + 0x20], 0
            //   8364242400           | and                 dword ptr [esp + 0x24], 0
            //   8b450c               | mov                 eax, dword ptr [ebp + 0xc]
            //   c744241001234567     | mov                 dword ptr [esp + 0x10], 0x67452301
            //   c744241489abcdef     | mov                 dword ptr [esp + 0x14], 0xefcdab89

    condition:
        7 of them and filesize < 892928
}