rule win_breach_rat_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.breach_rat."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.breach_rat"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 5e 5b 8be5 5d c20400 884c240f 8d442418 }
            // n = 7, score = 200
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx
            //   8be5                 | mov                 esp, ebp
            //   5d                   | pop                 ebp
            //   c20400               | ret                 4
            //   884c240f             | mov                 byte ptr [esp + 0xf], cl
            //   8d442418             | lea                 eax, [esp + 0x18]

        $sequence_1 = { 50 8bce e8???????? 8bc8 e8???????? 8d8dacf6ffff c745fcffffffff }
            // n = 7, score = 200
            //   50                   | push                eax
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     
            //   8bc8                 | mov                 ecx, eax
            //   e8????????           |                     
            //   8d8dacf6ffff         | lea                 ecx, [ebp - 0x954]
            //   c745fcffffffff       | mov                 dword ptr [ebp - 4], 0xffffffff

        $sequence_2 = { c1e81f 03c2 8985d8feffff 0f8479080000 83c724 89bde0feffff 8d9b00000000 }
            // n = 7, score = 200
            //   c1e81f               | shr                 eax, 0x1f
            //   03c2                 | add                 eax, edx
            //   8985d8feffff         | mov                 dword ptr [ebp - 0x128], eax
            //   0f8479080000         | je                  0x87f
            //   83c724               | add                 edi, 0x24
            //   89bde0feffff         | mov                 dword ptr [ebp - 0x120], edi
            //   8d9b00000000         | lea                 ebx, [ebx]

        $sequence_3 = { c741140f000000 c7411000000000 c60100 e8???????? ff7510 8d4dd4 ff750c }
            // n = 7, score = 200
            //   c741140f000000       | mov                 dword ptr [ecx + 0x14], 0xf
            //   c7411000000000       | mov                 dword ptr [ecx + 0x10], 0
            //   c60100               | mov                 byte ptr [ecx], 0
            //   e8????????           |                     
            //   ff7510               | push                dword ptr [ebp + 0x10]
            //   8d4dd4               | lea                 ecx, [ebp - 0x2c]
            //   ff750c               | push                dword ptr [ebp + 0xc]

        $sequence_4 = { 8be5 5d c3 68???????? 8bce e8???????? b001 }
            // n = 7, score = 200
            //   8be5                 | mov                 esp, ebp
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   68????????           |                     
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     
            //   b001                 | mov                 al, 1

        $sequence_5 = { 8b5508 8bcb 0fb712 8bff 663910 7408 83c002 }
            // n = 7, score = 200
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]
            //   8bcb                 | mov                 ecx, ebx
            //   0fb712               | movzx               edx, word ptr [edx]
            //   8bff                 | mov                 edi, edi
            //   663910               | cmp                 word ptr [eax], dx
            //   7408                 | je                  0xa
            //   83c002               | add                 eax, 2

        $sequence_6 = { 42 8b5de0 3bd6 72f2 8b45a4 2bc6 50 }
            // n = 7, score = 200
            //   42                   | inc                 edx
            //   8b5de0               | mov                 ebx, dword ptr [ebp - 0x20]
            //   3bd6                 | cmp                 edx, esi
            //   72f2                 | jb                  0xfffffff4
            //   8b45a4               | mov                 eax, dword ptr [ebp - 0x5c]
            //   2bc6                 | sub                 eax, esi
            //   50                   | push                eax

        $sequence_7 = { c7471800010000 8b4df4 8bc7 c7470400000000 c7470800000000 5f 5e }
            // n = 7, score = 200
            //   c7471800010000       | mov                 dword ptr [edi + 0x18], 0x100
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]
            //   8bc7                 | mov                 eax, edi
            //   c7470400000000       | mov                 dword ptr [edi + 4], 0
            //   c7470800000000       | mov                 dword ptr [edi + 8], 0
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi

        $sequence_8 = { eb20 84c9 74ed 8b4df0 8d45d8 50 e8???????? }
            // n = 7, score = 200
            //   eb20                 | jmp                 0x22
            //   84c9                 | test                cl, cl
            //   74ed                 | je                  0xffffffef
            //   8b4df0               | mov                 ecx, dword ptr [ebp - 0x10]
            //   8d45d8               | lea                 eax, [ebp - 0x28]
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_9 = { e8???????? 68???????? 8d859cf4ffff c745fc5c000000 50 8bce e8???????? }
            // n = 7, score = 200
            //   e8????????           |                     
            //   68????????           |                     
            //   8d859cf4ffff         | lea                 eax, [ebp - 0xb64]
            //   c745fc5c000000       | mov                 dword ptr [ebp - 4], 0x5c
            //   50                   | push                eax
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     

    condition:
        7 of them and filesize < 645120
}