rule win_buzus_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.buzus."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.buzus"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 5d 7413 68???????? 50 ffd6 3bc3 a3???????? }
            // n = 7, score = 100
            //   5d                   | pop                 ebp
            //   7413                 | je                  0x15
            //   68????????           |                     
            //   50                   | push                eax
            //   ffd6                 | call                esi
            //   3bc3                 | cmp                 eax, ebx
            //   a3????????           |                     

        $sequence_1 = { 4e 46 897508 ebbd 803e2a 750b 83f801 }
            // n = 7, score = 100
            //   4e                   | dec                 esi
            //   46                   | inc                 esi
            //   897508               | mov                 dword ptr [ebp + 8], esi
            //   ebbd                 | jmp                 0xffffffbf
            //   803e2a               | cmp                 byte ptr [esi], 0x2a
            //   750b                 | jne                 0xd
            //   83f801               | cmp                 eax, 1

        $sequence_2 = { ff75c0 ff75bc 50 e8???????? 83c40c 83f801 0f85e4000000 }
            // n = 7, score = 100
            //   ff75c0               | push                dword ptr [ebp - 0x40]
            //   ff75bc               | push                dword ptr [ebp - 0x44]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   83f801               | cmp                 eax, 1
            //   0f85e4000000         | jne                 0xea

        $sequence_3 = { e8???????? 8d8554fdffff 50 8d85ccfdffff 50 68???????? }
            // n = 6, score = 100
            //   e8????????           |                     
            //   8d8554fdffff         | lea                 eax, [ebp - 0x2ac]
            //   50                   | push                eax
            //   8d85ccfdffff         | lea                 eax, [ebp - 0x234]
            //   50                   | push                eax
            //   68????????           |                     

        $sequence_4 = { 68???????? 6a01 56 68???????? 33ff 8975f0 8975f4 }
            // n = 7, score = 100
            //   68????????           |                     
            //   6a01                 | push                1
            //   56                   | push                esi
            //   68????????           |                     
            //   33ff                 | xor                 edi, edi
            //   8975f0               | mov                 dword ptr [ebp - 0x10], esi
            //   8975f4               | mov                 dword ptr [ebp - 0xc], esi

        $sequence_5 = { 50 ff15???????? be???????? 8d84242c280000 }
            // n = 4, score = 100
            //   50                   | push                eax
            //   ff15????????         |                     
            //   be????????           |                     
            //   8d84242c280000       | lea                 eax, [esp + 0x282c]

        $sequence_6 = { 898524ffffff 8b45bc 89850cffffff 8b45d8 898514ffffff 6bc03c 6a31 }
            // n = 7, score = 100
            //   898524ffffff         | mov                 dword ptr [ebp - 0xdc], eax
            //   8b45bc               | mov                 eax, dword ptr [ebp - 0x44]
            //   89850cffffff         | mov                 dword ptr [ebp - 0xf4], eax
            //   8b45d8               | mov                 eax, dword ptr [ebp - 0x28]
            //   898514ffffff         | mov                 dword ptr [ebp - 0xec], eax
            //   6bc03c               | imul                eax, eax, 0x3c
            //   6a31                 | push                0x31

        $sequence_7 = { 385802 750e 0fbe5001 c68415b0feffff01 eb28 80fa2d 7539 }
            // n = 7, score = 100
            //   385802               | cmp                 byte ptr [eax + 2], bl
            //   750e                 | jne                 0x10
            //   0fbe5001             | movsx               edx, byte ptr [eax + 1]
            //   c68415b0feffff01     | mov                 byte ptr [ebp + edx - 0x150], 1
            //   eb28                 | jmp                 0x2a
            //   80fa2d               | cmp                 dl, 0x2d
            //   7539                 | jne                 0x3b

        $sequence_8 = { 6a03 58 8945b8 6a3c 59 3bc1 7603 }
            // n = 7, score = 100
            //   6a03                 | push                3
            //   58                   | pop                 eax
            //   8945b8               | mov                 dword ptr [ebp - 0x48], eax
            //   6a3c                 | push                0x3c
            //   59                   | pop                 ecx
            //   3bc1                 | cmp                 eax, ecx
            //   7603                 | jbe                 5

        $sequence_9 = { 68???????? 50 ff7508 e8???????? 83c41c 8b45d4 68b80b0000 }
            // n = 7, score = 100
            //   68????????           |                     
            //   50                   | push                eax
            //   ff7508               | push                dword ptr [ebp + 8]
            //   e8????????           |                     
            //   83c41c               | add                 esp, 0x1c
            //   8b45d4               | mov                 eax, dword ptr [ebp - 0x2c]
            //   68b80b0000           | push                0xbb8

    condition:
        7 of them and filesize < 679936
}