rule win_cabart_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.cabart."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.cabart"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8930 8b4510 eb16 395d10 740f }
            // n = 5, score = 300
            //   8930                 | mov                 dword ptr [eax], esi
            //   8b4510               | mov                 eax, dword ptr [ebp + 0x10]
            //   eb16                 | jmp                 0x18
            //   395d10               | cmp                 dword ptr [ebp + 0x10], ebx
            //   740f                 | je                  0x11

        $sequence_1 = { 8d8500fcffff 50 ff35???????? be00020000 ff35???????? }
            // n = 5, score = 300
            //   8d8500fcffff         | lea                 eax, [ebp - 0x400]
            //   50                   | push                eax
            //   ff35????????         |                     
            //   be00020000           | mov                 esi, 0x200
            //   ff35????????         |                     

        $sequence_2 = { 3bc3 7620 8d4df0 51 50 }
            // n = 5, score = 300
            //   3bc3                 | cmp                 eax, ebx
            //   7620                 | jbe                 0x22
            //   8d4df0               | lea                 ecx, [ebp - 0x10]
            //   51                   | push                ecx
            //   50                   | push                eax

        $sequence_3 = { 33c0 66898506fcffff 8d8500fcffff 50 ff35???????? be00020000 }
            // n = 6, score = 300
            //   33c0                 | xor                 eax, eax
            //   66898506fcffff       | mov                 word ptr [ebp - 0x3fa], ax
            //   8d8500fcffff         | lea                 eax, [ebp - 0x400]
            //   50                   | push                eax
            //   ff35????????         |                     
            //   be00020000           | mov                 esi, 0x200

        $sequence_4 = { 8d0c30 3bcf 7732 3bc3 }
            // n = 4, score = 300
            //   8d0c30               | lea                 ecx, [eax + esi]
            //   3bcf                 | cmp                 ecx, edi
            //   7732                 | ja                  0x34
            //   3bc3                 | cmp                 eax, ebx

        $sequence_5 = { 8d85fcfeffff 68???????? 6804010000 50 ff15???????? 83c410 6a10 }
            // n = 7, score = 300
            //   8d85fcfeffff         | lea                 eax, [ebp - 0x104]
            //   68????????           |                     
            //   6804010000           | push                0x104
            //   50                   | push                eax
            //   ff15????????         |                     
            //   83c410               | add                 esp, 0x10
            //   6a10                 | push                0x10

        $sequence_6 = { 85db 750a 68b90b0000 e8???????? 85ed }
            // n = 5, score = 300
            //   85db                 | test                ebx, ebx
            //   750a                 | jne                 0xc
            //   68b90b0000           | push                0xbb9
            //   e8????????           |                     
            //   85ed                 | test                ebp, ebp

        $sequence_7 = { 3bc7 750a 68ec030000 e9???????? 8bc8 }
            // n = 5, score = 300
            //   3bc7                 | cmp                 eax, edi
            //   750a                 | jne                 0xc
            //   68ec030000           | push                0x3ec
            //   e9????????           |                     
            //   8bc8                 | mov                 ecx, eax

        $sequence_8 = { 57 8d45e8 50 6a58 56 }
            // n = 5, score = 300
            //   57                   | push                edi
            //   8d45e8               | lea                 eax, [ebp - 0x18]
            //   50                   | push                eax
            //   6a58                 | push                0x58
            //   56                   | push                esi

        $sequence_9 = { ff15???????? 57 8d45f4 50 6a3f 56 c745f40a000000 }
            // n = 7, score = 300
            //   ff15????????         |                     
            //   57                   | push                edi
            //   8d45f4               | lea                 eax, [ebp - 0xc]
            //   50                   | push                eax
            //   6a3f                 | push                0x3f
            //   56                   | push                esi
            //   c745f40a000000       | mov                 dword ptr [ebp - 0xc], 0xa

    condition:
        7 of them and filesize < 32768
}