rule win_carbanak_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.carbanak."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.carbanak"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 7f05 83c061 eb03 83c027 }
            // n = 4, score = 500
            //   7f05                 | arpl                word ptr [ecx + 0x10], cx
            //   83c061               | push                edi
            //   eb03                 | dec                 eax
            //   83c027               | sub                 esp, 0x20

        $sequence_1 = { 7907 32c0 e9???????? 7507 b001 }
            // n = 5, score = 500
            //   7907                 | cmp                 eax, 0x100
            //   32c0                 | jne                 0xff8
            //   e9????????           |                     
            //   7507                 | dec                 eax
            //   b001                 | lea                 ecx, [esp + 0x20]

        $sequence_2 = { 32c0 e9???????? 7507 b001 }
            // n = 4, score = 500
            //   32c0                 | mov                 edx, eax
            //   e9????????           |                     
            //   7507                 | sub                 eax, dword ptr [ecx + 4]
            //   b001                 | cmp                 eax, dword ptr [ebp + 8]

        $sequence_3 = { 2bd1 81e921100000 8bc1 c1f80e 0cc0 }
            // n = 5, score = 500
            //   2bd1                 | inc                 ecx
            //   81e921100000         | mov                 eax, 0xf01ff
            //   8bc1                 | dec                 eax
            //   c1f80e               | mov                 edx, esi
            //   0cc0                 | dec                 eax

        $sequence_4 = { 8b4608 eb02 8bc3 85c0 }
            // n = 4, score = 500
            //   8b4608               | mov                 eax, dword ptr [ebp - 4]
            //   eb02                 | jge                 0x176b
            //   8bc3                 | mov                 edi, dword ptr [ebp + 0x10]
            //   85c0                 | mov                 eax, dword ptr [ebp + 0xc]

        $sequence_5 = { c3 8d4120 3c1f 7705 0fb6c1 }
            // n = 5, score = 500
            //   c3                   | push                ecx
            //   8d4120               | mov                 ecx, eax
            //   3c1f                 | je                  0x124
            //   7705                 | push                5
            //   0fb6c1               | push                dword ptr [ebp - 0x114]

        $sequence_6 = { 7c0d e8???????? 84c0 7504 }
            // n = 4, score = 500
            //   7c0d                 | push                0x4c
            //   e8????????           |                     
            //   84c0                 | push                0
            //   7504                 | push                ebp

        $sequence_7 = { 7c0d e8???????? 84c0 7504 33c0 }
            // n = 5, score = 500
            //   7c0d                 | dec                 eax
            //   e8????????           |                     
            //   84c0                 | lea                 ecx, [esp + 0x30]
            //   7504                 | inc                 esp
            //   33c0                 | mov                 eax, dword ptr [eax + 0x34]

        $sequence_8 = { e9???????? 3d2c5c0700 750a e8???????? }
            // n = 4, score = 500
            //   e9????????           |                     
            //   3d2c5c0700           | dec                 esi
            //   750a                 | mov                 dword ptr [ebp - 8], esi
            //   e8????????           |                     

        $sequence_9 = { 3d2c5c0700 750a e8???????? e9???????? }
            // n = 4, score = 500
            //   3d2c5c0700           | cmp                 dword ptr [ebp + 0x67], edi
            //   750a                 | jle                 0xfd
            //   e8????????           |                     
            //   e9????????           |                     

    condition:
        7 of them and filesize < 658432
}