rule win_cerber_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.cerber."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.cerber"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 4a 79f6 5f 8bc6 }
            // n = 4, score = 1200
            //   4a                   | dec                 edx
            //   79f6                 | jns                 0xfffffff8
            //   5f                   | pop                 edi
            //   8bc6                 | mov                 eax, esi

        $sequence_1 = { 85c0 750c 8b33 e8???????? 832300 eb0e 8b4dfc }
            // n = 7, score = 1200
            //   85c0                 | test                eax, eax
            //   750c                 | jne                 0xe
            //   8b33                 | mov                 esi, dword ptr [ebx]
            //   e8????????           |                     
            //   832300               | and                 dword ptr [ebx], 0
            //   eb0e                 | jmp                 0x10
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]

        $sequence_2 = { 33f9 8b88e0000000 894dd0 8b88e4000000 899864010000 8b5dd8 }
            // n = 6, score = 1200
            //   33f9                 | xor                 edi, ecx
            //   8b88e0000000         | mov                 ecx, dword ptr [eax + 0xe0]
            //   894dd0               | mov                 dword ptr [ebp - 0x30], ecx
            //   8b88e4000000         | mov                 ecx, dword ptr [eax + 0xe4]
            //   899864010000         | mov                 dword ptr [eax + 0x164], ebx
            //   8b5dd8               | mov                 ebx, dword ptr [ebp - 0x28]

        $sequence_3 = { 4a 79e6 47 3b7d0c }
            // n = 4, score = 1200
            //   4a                   | dec                 edx
            //   79e6                 | jns                 0xffffffe8
            //   47                   | inc                 edi
            //   3b7d0c               | cmp                 edi, dword ptr [ebp + 0xc]

        $sequence_4 = { 51 53 56 8bf0 57 85f6 7508 }
            // n = 7, score = 1200
            //   51                   | push                ecx
            //   53                   | push                ebx
            //   56                   | push                esi
            //   8bf0                 | mov                 esi, eax
            //   57                   | push                edi
            //   85f6                 | test                esi, esi
            //   7508                 | jne                 0xa

        $sequence_5 = { 4a b800000080 83e904 eb02 }
            // n = 4, score = 1200
            //   4a                   | dec                 edx
            //   b800000080           | mov                 eax, 0x80000000
            //   83e904               | sub                 ecx, 4
            //   eb02                 | jmp                 4

        $sequence_6 = { 895df4 33c9 83fa08 0f9dc1 854df4 7515 }
            // n = 6, score = 1200
            //   895df4               | mov                 dword ptr [ebp - 0xc], ebx
            //   33c9                 | xor                 ecx, ecx
            //   83fa08               | cmp                 edx, 8
            //   0f9dc1               | setge               cl
            //   854df4               | test                dword ptr [ebp - 0xc], ecx
            //   7515                 | jne                 0x17

        $sequence_7 = { 33f9 8b88e8feffff 234808 8998fc000000 8b5874 }
            // n = 5, score = 1200
            //   33f9                 | xor                 edi, ecx
            //   8b88e8feffff         | mov                 ecx, dword ptr [eax - 0x118]
            //   234808               | and                 ecx, dword ptr [eax + 8]
            //   8998fc000000         | mov                 dword ptr [eax + 0xfc], ebx
            //   8b5874               | mov                 ebx, dword ptr [eax + 0x74]

    condition:
        7 of them and filesize < 573440
}