rule win_chairsmack_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.chairsmack."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.chairsmack"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d8c2410010000 c68424840300003a e8???????? 83ec1c 8d842428010000 8bcc 8964242c }
            // n = 7, score = 200
            //   8d8c2410010000       | lea                 ecx, [esp + 0x110]
            //   c68424840300003a     | mov                 byte ptr [esp + 0x384], 0x3a
            //   e8????????           |                     
            //   83ec1c               | sub                 esp, 0x1c
            //   8d842428010000       | lea                 eax, [esp + 0x128]
            //   8bcc                 | mov                 ecx, esp
            //   8964242c             | mov                 dword ptr [esp + 0x2c], esp

        $sequence_1 = { 8d4de8 56 c745fc01000000 e8???????? 8b7df0 8d4de8 2b7e08 }
            // n = 7, score = 200
            //   8d4de8               | lea                 ecx, [ebp - 0x18]
            //   56                   | push                esi
            //   c745fc01000000       | mov                 dword ptr [ebp - 4], 1
            //   e8????????           |                     
            //   8b7df0               | mov                 edi, dword ptr [ebp - 0x10]
            //   8d4de8               | lea                 ecx, [ebp - 0x18]
            //   2b7e08               | sub                 edi, dword ptr [esi + 8]

        $sequence_2 = { 8d4c2464 e8???????? e9???????? 68???????? 8d8c24bc000000 e8???????? 8bd0 }
            // n = 7, score = 200
            //   8d4c2464             | lea                 ecx, [esp + 0x64]
            //   e8????????           |                     
            //   e9????????           |                     
            //   68????????           |                     
            //   8d8c24bc000000       | lea                 ecx, [esp + 0xbc]
            //   e8????????           |                     
            //   8bd0                 | mov                 edx, eax

        $sequence_3 = { 8b4004 eb03 83c004 51 50 ffb4249c000000 51 }
            // n = 7, score = 200
            //   8b4004               | mov                 eax, dword ptr [eax + 4]
            //   eb03                 | jmp                 5
            //   83c004               | add                 eax, 4
            //   51                   | push                ecx
            //   50                   | push                eax
            //   ffb4249c000000       | push                dword ptr [esp + 0x9c]
            //   51                   | push                ecx

        $sequence_4 = { 660f57c4 8b7c2414 8d442421 c644242025 8b5714 f6c220 7409 }
            // n = 7, score = 200
            //   660f57c4             | xorpd               xmm0, xmm4
            //   8b7c2414             | mov                 edi, dword ptr [esp + 0x14]
            //   8d442421             | lea                 eax, [esp + 0x21]
            //   c644242025           | mov                 byte ptr [esp + 0x20], 0x25
            //   8b5714               | mov                 edx, dword ptr [edi + 0x14]
            //   f6c220               | test                dl, 0x20
            //   7409                 | je                  0xb

        $sequence_5 = { 7613 b8feffff7f 8d3419 2bc1 3bd8 7605 befeffff7f }
            // n = 7, score = 200
            //   7613                 | jbe                 0x15
            //   b8feffff7f           | mov                 eax, 0x7ffffffe
            //   8d3419               | lea                 esi, [ecx + ebx]
            //   2bc1                 | sub                 eax, ecx
            //   3bd8                 | cmp                 ebx, eax
            //   7605                 | jbe                 7
            //   befeffff7f           | mov                 esi, 0x7ffffffe

        $sequence_6 = { 8d8db8fcffff e9???????? 8d8dd0fdffff e9???????? 8d8dbcfcffff e9???????? 8d8dc0fdffff }
            // n = 7, score = 200
            //   8d8db8fcffff         | lea                 ecx, [ebp - 0x348]
            //   e9????????           |                     
            //   8d8dd0fdffff         | lea                 ecx, [ebp - 0x230]
            //   e9????????           |                     
            //   8d8dbcfcffff         | lea                 ecx, [ebp - 0x344]
            //   e9????????           |                     
            //   8d8dc0fdffff         | lea                 ecx, [ebp - 0x240]

        $sequence_7 = { c68424b8030000b9 8bcc 68???????? e8???????? c68424b8030000b6 e8???????? 83c430 }
            // n = 7, score = 200
            //   c68424b8030000b9     | mov                 byte ptr [esp + 0x3b8], 0xb9
            //   8bcc                 | mov                 ecx, esp
            //   68????????           |                     
            //   e8????????           |                     
            //   c68424b8030000b6     | mov                 byte ptr [esp + 0x3b8], 0xb6
            //   e8????????           |                     
            //   83c430               | add                 esp, 0x30

        $sequence_8 = { 8b148dd06d4a00 81c200080000 3955e4 7366 8b45e4 c6400400 8b4de4 }
            // n = 7, score = 200
            //   8b148dd06d4a00       | mov                 edx, dword ptr [ecx*4 + 0x4a6dd0]
            //   81c200080000         | add                 edx, 0x800
            //   3955e4               | cmp                 dword ptr [ebp - 0x1c], edx
            //   7366                 | jae                 0x68
            //   8b45e4               | mov                 eax, dword ptr [ebp - 0x1c]
            //   c6400400             | mov                 byte ptr [eax + 4], 0
            //   8b4de4               | mov                 ecx, dword ptr [ebp - 0x1c]

        $sequence_9 = { 0fbe02 85c0 0f848e010000 8b4dfc 51 }
            // n = 5, score = 200
            //   0fbe02               | movsx               eax, byte ptr [edx]
            //   85c0                 | test                eax, eax
            //   0f848e010000         | je                  0x194
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   51                   | push                ecx

    condition:
        7 of them and filesize < 1974272
}