rule win_chches_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.chches."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.chches"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b45f4 8b7dfc 50 8b8628020000 ffd0 8b45f8 85c0 }
            // n = 7, score = 200
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]
            //   8b7dfc               | mov                 edi, dword ptr [ebp - 4]
            //   50                   | push                eax
            //   8b8628020000         | mov                 eax, dword ptr [esi + 0x228]
            //   ffd0                 | call                eax
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   85c0                 | test                eax, eax

        $sequence_1 = { 85c0 7e0b 8b55f8 8b435c 6aff 52 }
            // n = 6, score = 200
            //   85c0                 | test                eax, eax
            //   7e0b                 | jle                 0xd
            //   8b55f8               | mov                 edx, dword ptr [ebp - 8]
            //   8b435c               | mov                 eax, dword ptr [ebx + 0x5c]
            //   6aff                 | push                -1
            //   52                   | push                edx

        $sequence_2 = { 8d5f18 85db 7477 8b16 8b4244 8b4018 }
            // n = 6, score = 200
            //   8d5f18               | lea                 ebx, [edi + 0x18]
            //   85db                 | test                ebx, ebx
            //   7477                 | je                  0x79
            //   8b16                 | mov                 edx, dword ptr [esi]
            //   8b4244               | mov                 eax, dword ptr [edx + 0x44]
            //   8b4018               | mov                 eax, dword ptr [eax + 0x18]

        $sequence_3 = { 8b16 8945fc 8b4244 3bc7 0f842b020000 8b00 8b7dfc }
            // n = 7, score = 200
            //   8b16                 | mov                 edx, dword ptr [esi]
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   8b4244               | mov                 eax, dword ptr [edx + 0x44]
            //   3bc7                 | cmp                 eax, edi
            //   0f842b020000         | je                  0x231
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   8b7dfc               | mov                 edi, dword ptr [ebp - 4]

        $sequence_4 = { b810000000 e8???????? 83c420 8945f0 c745f400000000 85c0 0f8405010000 }
            // n = 7, score = 200
            //   b810000000           | mov                 eax, 0x10
            //   e8????????           |                     
            //   83c420               | add                 esp, 0x20
            //   8945f0               | mov                 dword ptr [ebp - 0x10], eax
            //   c745f400000000       | mov                 dword ptr [ebp - 0xc], 0
            //   85c0                 | test                eax, eax
            //   0f8405010000         | je                  0x10b

        $sequence_5 = { 66890c78 47 ba2a000000 8d8d98fdffff 66891478 8b9680020000 51 }
            // n = 7, score = 200
            //   66890c78             | mov                 word ptr [eax + edi*2], cx
            //   47                   | inc                 edi
            //   ba2a000000           | mov                 edx, 0x2a
            //   8d8d98fdffff         | lea                 ecx, [ebp - 0x268]
            //   66891478             | mov                 word ptr [eax + edi*2], dx
            //   8b9680020000         | mov                 edx, dword ptr [esi + 0x280]
            //   51                   | push                ecx

        $sequence_6 = { 8b4004 85c0 7475 3902 746d 8b4e64 50 }
            // n = 7, score = 200
            //   8b4004               | mov                 eax, dword ptr [eax + 4]
            //   85c0                 | test                eax, eax
            //   7475                 | je                  0x77
            //   3902                 | cmp                 dword ptr [edx], eax
            //   746d                 | je                  0x6f
            //   8b4e64               | mov                 ecx, dword ptr [esi + 0x64]
            //   50                   | push                eax

        $sequence_7 = { 81e980191001 03c1 50 68bfa2c2cd 687f90b056 68a71001fe 686021a031 }
            // n = 7, score = 200
            //   81e980191001         | sub                 ecx, 0x1101980
            //   03c1                 | add                 eax, ecx
            //   50                   | push                eax
            //   68bfa2c2cd           | push                0xcdc2a2bf
            //   687f90b056           | push                0x56b0907f
            //   68a71001fe           | push                0xfe0110a7
            //   686021a031           | push                0x31a02160

        $sequence_8 = { 895da0 85db 740f 8b87b8010000 8d5594 52 53 }
            // n = 7, score = 200
            //   895da0               | mov                 dword ptr [ebp - 0x60], ebx
            //   85db                 | test                ebx, ebx
            //   740f                 | je                  0x11
            //   8b87b8010000         | mov                 eax, dword ptr [edi + 0x1b8]
            //   8d5594               | lea                 edx, [ebp - 0x6c]
            //   52                   | push                edx
            //   53                   | push                ebx

        $sequence_9 = { c745f401000000 eb1c 50 6a08 ffd2 50 }
            // n = 6, score = 200
            //   c745f401000000       | mov                 dword ptr [ebp - 0xc], 1
            //   eb1c                 | jmp                 0x1e
            //   50                   | push                eax
            //   6a08                 | push                8
            //   ffd2                 | call                edx
            //   50                   | push                eax

    condition:
        7 of them and filesize < 122880
}