rule win_chinad_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.chinad."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.chinad"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c7850cffffff00000000 eb55 c78550ffffffbc264300 8b9550ffffff 83c201 8995b4feffff 8b8550ffffff }
            // n = 7, score = 200
            //   c7850cffffff00000000     | mov    dword ptr [ebp - 0xf4], 0
            //   eb55                 | jmp                 0x57
            //   c78550ffffffbc264300     | mov    dword ptr [ebp - 0xb0], 0x4326bc
            //   8b9550ffffff         | mov                 edx, dword ptr [ebp - 0xb0]
            //   83c201               | add                 edx, 1
            //   8995b4feffff         | mov                 dword ptr [ebp - 0x14c], edx
            //   8b8550ffffff         | mov                 eax, dword ptr [ebp - 0xb0]

        $sequence_1 = { 8b85a8feffff 899485acfeffff e9???????? b904000000 6bd100 8b4508 8b0c10 }
            // n = 7, score = 200
            //   8b85a8feffff         | mov                 eax, dword ptr [ebp - 0x158]
            //   899485acfeffff       | mov                 dword ptr [ebp + eax*4 - 0x154], edx
            //   e9????????           |                     
            //   b904000000           | mov                 ecx, 4
            //   6bd100               | imul                edx, ecx, 0
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   8b0c10               | mov                 ecx, dword ptr [eax + edx]

        $sequence_2 = { 2bf8 8bc2 c1f819 03f0 897dec c1e019 }
            // n = 6, score = 200
            //   2bf8                 | sub                 edi, eax
            //   8bc2                 | mov                 eax, edx
            //   c1f819               | sar                 eax, 0x19
            //   03f0                 | add                 esi, eax
            //   897dec               | mov                 dword ptr [ebp - 0x14], edi
            //   c1e019               | shl                 eax, 0x19

        $sequence_3 = { 895de8 1bde 0145f4 8b75ac 119d7cffffff 8b5dec 81c300001000 }
            // n = 7, score = 200
            //   895de8               | mov                 dword ptr [ebp - 0x18], ebx
            //   1bde                 | sbb                 ebx, esi
            //   0145f4               | add                 dword ptr [ebp - 0xc], eax
            //   8b75ac               | mov                 esi, dword ptr [ebp - 0x54]
            //   119d7cffffff         | adc                 dword ptr [ebp - 0x84], ebx
            //   8b5dec               | mov                 ebx, dword ptr [ebp - 0x14]
            //   81c300001000         | add                 ebx, 0x100000

        $sequence_4 = { 0fa4c119 c1ee07 c1e019 0bd1 0bf0 31b514fdffff }
            // n = 6, score = 200
            //   0fa4c119             | shld                ecx, eax, 0x19
            //   c1ee07               | shr                 esi, 7
            //   c1e019               | shl                 eax, 0x19
            //   0bd1                 | or                  edx, ecx
            //   0bf0                 | or                  esi, eax
            //   31b514fdffff         | xor                 dword ptr [ebp - 0x2ec], esi

        $sequence_5 = { 0fa4f701 6a13 03f6 03b55cffffff 89b560ffffff 137dcc 81c600000001 }
            // n = 7, score = 200
            //   0fa4f701             | shld                edi, esi, 1
            //   6a13                 | push                0x13
            //   03f6                 | add                 esi, esi
            //   03b55cffffff         | add                 esi, dword ptr [ebp - 0xa4]
            //   89b560ffffff         | mov                 dword ptr [ebp - 0xa0], esi
            //   137dcc               | adc                 edi, dword ptr [ebp - 0x34]
            //   81c600000001         | add                 esi, 0x1000000

        $sequence_6 = { c1c802 33c8 8b85d4feffff 8bd8 03ca 2385d8feffff }
            // n = 6, score = 200
            //   c1c802               | ror                 eax, 2
            //   33c8                 | xor                 ecx, eax
            //   8b85d4feffff         | mov                 eax, dword ptr [ebp - 0x12c]
            //   8bd8                 | mov                 ebx, eax
            //   03ca                 | add                 ecx, edx
            //   2385d8feffff         | and                 eax, dword ptr [ebp - 0x128]

        $sequence_7 = { 81d7745dbe72 019d14fdffff 11bd38fdffff 33d2 0facc81c c1e604 }
            // n = 6, score = 200
            //   81d7745dbe72         | adc                 edi, 0x72be5d74
            //   019d14fdffff         | add                 dword ptr [ebp - 0x2ec], ebx
            //   11bd38fdffff         | adc                 dword ptr [ebp - 0x2c8], edi
            //   33d2                 | xor                 edx, edx
            //   0facc81c             | shrd                eax, ecx, 0x1c
            //   c1e604               | shl                 esi, 4

        $sequence_8 = { 8b4e24 83c40c c1e903 b838000000 83e13f 83f938 7205 }
            // n = 7, score = 200
            //   8b4e24               | mov                 ecx, dword ptr [esi + 0x24]
            //   83c40c               | add                 esp, 0xc
            //   c1e903               | shr                 ecx, 3
            //   b838000000           | mov                 eax, 0x38
            //   83e13f               | and                 ecx, 0x3f
            //   83f938               | cmp                 ecx, 0x38
            //   7205                 | jb                  7

        $sequence_9 = { b894280000 e8???????? a1???????? 33c5 8945fc c78570d7ffff80280000 8d8570d7ffff }
            // n = 7, score = 200
            //   b894280000           | mov                 eax, 0x2894
            //   e8????????           |                     
            //   a1????????           |                     
            //   33c5                 | xor                 eax, ebp
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   c78570d7ffff80280000     | mov    dword ptr [ebp - 0x2890], 0x2880
            //   8d8570d7ffff         | lea                 eax, [ebp - 0x2890]

    condition:
        7 of them and filesize < 598016
}