rule win_chir_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.chir."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.chir"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 47 8811 3bf8 72e7 }
            // n = 4, score = 300
            //   47                   | inc                 edi
            //   8811                 | mov                 byte ptr [ecx], dl
            //   3bf8                 | cmp                 edi, eax
            //   72e7                 | jb                  0xffffffe9

        $sequence_1 = { 8d4c3df0 8a11 80f2fc 80c202 }
            // n = 4, score = 300
            //   8d4c3df0             | lea                 ecx, [ebp + edi - 0x10]
            //   8a11                 | mov                 dl, byte ptr [ecx]
            //   80f2fc               | xor                 dl, 0xfc
            //   80c202               | add                 dl, 2

        $sequence_2 = { e8???????? 48 59 8bcb 7419 }
            // n = 5, score = 300
            //   e8????????           |                     
            //   48                   | dec                 eax
            //   59                   | pop                 ecx
            //   8bcb                 | mov                 ecx, ebx
            //   7419                 | je                  0x1b

        $sequence_3 = { 5e 7419 8d4c35f8 8a11 80f2fc }
            // n = 5, score = 300
            //   5e                   | pop                 esi
            //   7419                 | je                  0x1b
            //   8d4c35f8             | lea                 ecx, [ebp + esi - 8]
            //   8a11                 | mov                 dl, byte ptr [ecx]
            //   80f2fc               | xor                 dl, 0xfc

        $sequence_4 = { 8d45f0 50 c745f021352432 c745f451173300 e8???????? 48 }
            // n = 6, score = 300
            //   8d45f0               | lea                 eax, [ebp - 0x10]
            //   50                   | push                eax
            //   c745f021352432       | mov                 dword ptr [ebp - 0x10], 0x32243521
            //   c745f451173300       | mov                 dword ptr [ebp - 0xc], 0x331751
            //   e8????????           |                     
            //   48                   | dec                 eax

        $sequence_5 = { c745f451173300 e8???????? 48 59 8bfb }
            // n = 5, score = 300
            //   c745f451173300       | mov                 dword ptr [ebp - 0xc], 0x331751
            //   e8????????           |                     
            //   48                   | dec                 eax
            //   59                   | pop                 ecx
            //   8bfb                 | mov                 edi, ebx

        $sequence_6 = { 8d4c35f0 8a11 80f2fc 80c202 80f201 }
            // n = 5, score = 300
            //   8d4c35f0             | lea                 ecx, [ebp + esi - 0x10]
            //   8a11                 | mov                 dl, byte ptr [ecx]
            //   80f2fc               | xor                 dl, 0xfc
            //   80c202               | add                 dl, 2
            //   80f201               | xor                 dl, 1

        $sequence_7 = { 8a19 80f3fc 80c302 80f301 80c303 42 }
            // n = 6, score = 300
            //   8a19                 | mov                 bl, byte ptr [ecx]
            //   80f3fc               | xor                 bl, 0xfc
            //   80c302               | add                 bl, 2
            //   80f301               | xor                 bl, 1
            //   80c303               | add                 bl, 3
            //   42                   | inc                 edx

        $sequence_8 = { 7415 8d4c15f8 8a01 34fc }
            // n = 4, score = 300
            //   7415                 | je                  0x17
            //   8d4c15f8             | lea                 ecx, [ebp + edx - 8]
            //   8a01                 | mov                 al, byte ptr [ecx]
            //   34fc                 | xor                 al, 0xfc

        $sequence_9 = { 8a11 80f2fc 80c202 80f201 80c203 46 8811 }
            // n = 7, score = 300
            //   8a11                 | mov                 dl, byte ptr [ecx]
            //   80f2fc               | xor                 dl, 0xfc
            //   80c202               | add                 dl, 2
            //   80f201               | xor                 dl, 1
            //   80c203               | add                 dl, 3
            //   46                   | inc                 esi
            //   8811                 | mov                 byte ptr [ecx], dl

    condition:
        7 of them and filesize < 286720
}