rule win_client_maximus_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.client_maximus."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.client_maximus"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 89f0 0fb6c0 0fb61403 88140b 83c101 89fa 81f900010000 }
            // n = 7, score = 300
            //   89f0                 | mov                 eax, esi
            //   0fb6c0               | movzx               eax, al
            //   0fb61403             | movzx               edx, byte ptr [ebx + eax]
            //   88140b               | mov                 byte ptr [ebx + ecx], dl
            //   83c101               | add                 ecx, 1
            //   89fa                 | mov                 edx, edi
            //   81f900010000         | cmp                 ecx, 0x100

        $sequence_1 = { 89e5 56 53 83ec10 8b1d???????? }
            // n = 5, score = 300
            //   89e5                 | mov                 ebp, esp
            //   56                   | push                esi
            //   53                   | push                ebx
            //   83ec10               | sub                 esp, 0x10
            //   8b1d????????         |                     

        $sequence_2 = { 893424 ff15???????? 83ec08 85c0 7411 }
            // n = 5, score = 300
            //   893424               | mov                 dword ptr [esp], esi
            //   ff15????????         |                     
            //   83ec08               | sub                 esp, 8
            //   85c0                 | test                eax, eax
            //   7411                 | je                  0x13

        $sequence_3 = { e8???????? 8b4304 85c0 741d 8b5330 c744240800800000 c744240400000000 }
            // n = 7, score = 300
            //   e8????????           |                     
            //   8b4304               | mov                 eax, dword ptr [ebx + 4]
            //   85c0                 | test                eax, eax
            //   741d                 | je                  0x1f
            //   8b5330               | mov                 edx, dword ptr [ebx + 0x30]
            //   c744240800800000     | mov                 dword ptr [esp + 8], 0x8000
            //   c744240400000000     | mov                 dword ptr [esp + 4], 0

        $sequence_4 = { 39730c 7fe1 891424 e8???????? }
            // n = 4, score = 300
            //   39730c               | cmp                 dword ptr [ebx + 0xc], esi
            //   7fe1                 | jg                  0xffffffe3
            //   891424               | mov                 dword ptr [esp], edx
            //   e8????????           |                     

        $sequence_5 = { 7429 c70424???????? ff15???????? 83ec04 a3???????? }
            // n = 5, score = 300
            //   7429                 | je                  0x2b
            //   c70424????????       |                     
            //   ff15????????         |                     
            //   83ec04               | sub                 esp, 4
            //   a3????????           |                     

        $sequence_6 = { 8b4628 85c0 7535 c70424???????? }
            // n = 4, score = 300
            //   8b4628               | mov                 eax, dword ptr [esi + 0x28]
            //   85c0                 | test                eax, eax
            //   7535                 | jne                 0x37
            //   c70424????????       |                     

        $sequence_7 = { a3???????? c7442404???????? 893424 ff15???????? 83ec08 85c0 7411 }
            // n = 7, score = 300
            //   a3????????           |                     
            //   c7442404????????     |                     
            //   893424               | mov                 dword ptr [esp], esi
            //   ff15????????         |                     
            //   83ec08               | sub                 esp, 8
            //   85c0                 | test                eax, eax
            //   7411                 | je                  0x13

        $sequence_8 = { 89c8 0fb63c0b 99 f77c241c 89f8 }
            // n = 5, score = 300
            //   89c8                 | mov                 eax, ecx
            //   0fb63c0b             | movzx               edi, byte ptr [ebx + ecx]
            //   99                   | cdq                 
            //   f77c241c             | idiv                dword ptr [esp + 0x1c]
            //   89f8                 | mov                 eax, edi

        $sequence_9 = { 89f8 02441500 01c6 89f0 0fb6c0 }
            // n = 5, score = 300
            //   89f8                 | mov                 eax, edi
            //   02441500             | add                 al, byte ptr [ebp + edx]
            //   01c6                 | add                 esi, eax
            //   89f0                 | mov                 eax, esi
            //   0fb6c0               | movzx               eax, al

    condition:
        7 of them and filesize < 106496
}