rule win_cloudeye_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.cloudeye."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.cloudeye"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 83c002 668b1c08 668b140e 6639d3 75e4 83e902 83f900 }
            // n = 7, score = 100
            //   83c002               | add                 eax, 2
            //   668b1c08             | mov                 bx, word ptr [eax + ecx]
            //   668b140e             | mov                 dx, word ptr [esi + ecx]
            //   6639d3               | cmp                 bx, dx
            //   75e4                 | jne                 0xffffffe6
            //   83e902               | sub                 ecx, 2
            //   83f900               | cmp                 ecx, 0

        $sequence_1 = { 7545 66f7c14179 685595db6d e8???????? }
            // n = 4, score = 100
            //   7545                 | jne                 0x47
            //   66f7c14179           | test                cx, 0x7941
            //   685595db6d           | push                0x6ddb9555
            //   e8????????           |                     

        $sequence_2 = { e8???????? 5f 59 83c628 41 3b8f04080000 75a8 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   5f                   | pop                 edi
            //   59                   | pop                 ecx
            //   83c628               | add                 esi, 0x28
            //   41                   | inc                 ecx
            //   3b8f04080000         | cmp                 ecx, dword ptr [edi + 0x804]
            //   75a8                 | jne                 0xffffffaa

        $sequence_3 = { 7408 0185f4000000 eba4 85d8 }
            // n = 4, score = 100
            //   7408                 | je                  0xa
            //   0185f4000000         | add                 dword ptr [ebp + 0xf4], eax
            //   eba4                 | jmp                 0xffffffa6
            //   85d8                 | test                eax, ebx

        $sequence_4 = { 89f8 0500080000 50 6aff }
            // n = 4, score = 100
            //   89f8                 | mov                 eax, edi
            //   0500080000           | add                 eax, 0x800
            //   50                   | push                eax
            //   6aff                 | push                -1

        $sequence_5 = { 6685d2 e8???????? 84ef 80fd37 57 e8???????? 58 }
            // n = 7, score = 100
            //   6685d2               | test                dx, dx
            //   e8????????           |                     
            //   84ef                 | test                bh, ch
            //   80fd37               | cmp                 ch, 0x37
            //   57                   | push                edi
            //   e8????????           |                     
            //   58                   | pop                 eax

        $sequence_6 = { c3 38ed 817e24200000e0 7473 }
            // n = 4, score = 100
            //   c3                   | ret                 
            //   38ed                 | cmp                 ch, ch
            //   817e24200000e0       | cmp                 dword ptr [esi + 0x24], 0xe0000020
            //   7473                 | je                  0x75

        $sequence_7 = { 668b00 6631c8 39c8 6631c3 6681fb4d5a 7407 6639c1 }
            // n = 7, score = 100
            //   668b00               | mov                 ax, word ptr [eax]
            //   6631c8               | xor                 ax, cx
            //   39c8                 | cmp                 eax, ecx
            //   6631c3               | xor                 bx, ax
            //   6681fb4d5a           | cmp                 bx, 0x5a4d
            //   7407                 | je                  9
            //   6639c1               | cmp                 cx, ax

        $sequence_8 = { 0fbae11f 0f82d63c0000 61 0faee8 0f31 0faee8 c1e220 }
            // n = 7, score = 100
            //   0fbae11f             | bt                  ecx, 0x1f
            //   0f82d63c0000         | jb                  0x3cdc
            //   61                   | popal               
            //   0faee8               | lfence              
            //   0f31                 | rdtsc               
            //   0faee8               | lfence              
            //   c1e220               | shl                 edx, 0x20

        $sequence_9 = { 75e4 83e902 83f900 7deb ff742404 }
            // n = 5, score = 100
            //   75e4                 | jne                 0xffffffe6
            //   83e902               | sub                 ecx, 2
            //   83f900               | cmp                 ecx, 0
            //   7deb                 | jge                 0xffffffed
            //   ff742404             | push                dword ptr [esp + 4]

    condition:
        7 of them and filesize < 90112
}