rule win_cloudwizard_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.cloudwizard."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.cloudwizard"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c3 8d85d4fdffff 50 57 c785d4fdffff2c020000 e8???????? }
            // n = 6, score = 100
            //   c3                   | ret                 
            //   8d85d4fdffff         | lea                 eax, [ebp - 0x22c]
            //   50                   | push                eax
            //   57                   | push                edi
            //   c785d4fdffff2c020000     | mov    dword ptr [ebp - 0x22c], 0x22c
            //   e8????????           |                     

        $sequence_1 = { 668945ee 58 6a7c 668945f0 58 6a6d }
            // n = 6, score = 100
            //   668945ee             | mov                 word ptr [ebp - 0x12], ax
            //   58                   | pop                 eax
            //   6a7c                 | push                0x7c
            //   668945f0             | mov                 word ptr [ebp - 0x10], ax
            //   58                   | pop                 eax
            //   6a6d                 | push                0x6d

        $sequence_2 = { 8d45ec 663118 40 40 }
            // n = 4, score = 100
            //   8d45ec               | lea                 eax, [ebp - 0x14]
            //   663118               | xor                 word ptr [eax], bx
            //   40                   | inc                 eax
            //   40                   | inc                 eax

        $sequence_3 = { 8bc8 8d8618060000 8d7802 668b18 40 40 6685db }
            // n = 7, score = 100
            //   8bc8                 | mov                 ecx, eax
            //   8d8618060000         | lea                 eax, [esi + 0x618]
            //   8d7802               | lea                 edi, [eax + 2]
            //   668b18               | mov                 bx, word ptr [eax]
            //   40                   | inc                 eax
            //   40                   | inc                 eax
            //   6685db               | test                bx, bx

        $sequence_4 = { ebd6 55 8bec 81ecb80e0000 }
            // n = 4, score = 100
            //   ebd6                 | jmp                 0xffffffd8
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   81ecb80e0000         | sub                 esp, 0xeb8

        $sequence_5 = { 6a01 897dfc 57 c706???????? 897e30 ff15???????? 894634 }
            // n = 7, score = 100
            //   6a01                 | push                1
            //   897dfc               | mov                 dword ptr [ebp - 4], edi
            //   57                   | push                edi
            //   c706????????         |                     
            //   897e30               | mov                 dword ptr [esi + 0x30], edi
            //   ff15????????         |                     
            //   894634               | mov                 dword ptr [esi + 0x34], eax

        $sequence_6 = { 8d4530 d1f9 50 8d044e 50 e8???????? }
            // n = 6, score = 100
            //   8d4530               | lea                 eax, [ebp + 0x30]
            //   d1f9                 | sar                 ecx, 1
            //   50                   | push                eax
            //   8d044e               | lea                 eax, [esi + ecx*2]
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_7 = { 668945b8 8d45a0 663108 40 40 663918 }
            // n = 6, score = 100
            //   668945b8             | mov                 word ptr [ebp - 0x48], ax
            //   8d45a0               | lea                 eax, [ebp - 0x60]
            //   663108               | xor                 word ptr [eax], cx
            //   40                   | inc                 eax
            //   40                   | inc                 eax
            //   663918               | cmp                 word ptr [eax], bx

        $sequence_8 = { 40 6685d2 75f6 2bc1 8d8e18060000 }
            // n = 5, score = 100
            //   40                   | inc                 eax
            //   6685d2               | test                dx, dx
            //   75f6                 | jne                 0xfffffff8
            //   2bc1                 | sub                 eax, ecx
            //   8d8e18060000         | lea                 ecx, [esi + 0x618]

        $sequence_9 = { 6a5b 6689451e 58 6a5c 66894520 58 6a4d }
            // n = 7, score = 100
            //   6a5b                 | push                0x5b
            //   6689451e             | mov                 word ptr [ebp + 0x1e], ax
            //   58                   | pop                 eax
            //   6a5c                 | push                0x5c
            //   66894520             | mov                 word ptr [ebp + 0x20], ax
            //   58                   | pop                 eax
            //   6a4d                 | push                0x4d

    condition:
        7 of them and filesize < 134144
}