rule win_cmsbrute_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.cmsbrute."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.cmsbrute"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ff7004 51 ff7510 8b4d08 ff750c 56 e8???????? }
            // n = 7, score = 500
            //   ff7004               | push                dword ptr [eax + 4]
            //   51                   | push                ecx
            //   ff7510               | push                dword ptr [ebp + 0x10]
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   56                   | push                esi
            //   e8????????           |                     

        $sequence_1 = { e8???????? ff4de0 8bde 75e4 8b75d8 832700 6a00 }
            // n = 7, score = 500
            //   e8????????           |                     
            //   ff4de0               | dec                 dword ptr [ebp - 0x20]
            //   8bde                 | mov                 ebx, esi
            //   75e4                 | jne                 0xffffffe6
            //   8b75d8               | mov                 esi, dword ptr [ebp - 0x28]
            //   832700               | and                 dword ptr [edi], 0
            //   6a00                 | push                0

        $sequence_2 = { ffb068010000 ff15???????? 8b06 83a06801000000 8b442418 59 59 }
            // n = 7, score = 500
            //   ffb068010000         | push                dword ptr [eax + 0x168]
            //   ff15????????         |                     
            //   8b06                 | mov                 eax, dword ptr [esi]
            //   83a06801000000       | and                 dword ptr [eax + 0x168], 0
            //   8b442418             | mov                 eax, dword ptr [esp + 0x18]
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx

        $sequence_3 = { eb0f e8???????? 59 50 8d75b4 e8???????? 59 }
            // n = 7, score = 500
            //   eb0f                 | jmp                 0x11
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   50                   | push                eax
            //   8d75b4               | lea                 esi, [ebp - 0x4c]
            //   e8????????           |                     
            //   59                   | pop                 ecx

        $sequence_4 = { eb02 8b01 3945fc 0f8d8a000000 8b45fc e8???????? 8bf0 }
            // n = 7, score = 500
            //   eb02                 | jmp                 4
            //   8b01                 | mov                 eax, dword ptr [ecx]
            //   3945fc               | cmp                 dword ptr [ebp - 4], eax
            //   0f8d8a000000         | jge                 0x90
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax

        $sequence_5 = { ff75c4 8b4dcc ff75d4 8bd8 0fb7463e 50 53 }
            // n = 7, score = 500
            //   ff75c4               | push                dword ptr [ebp - 0x3c]
            //   8b4dcc               | mov                 ecx, dword ptr [ebp - 0x34]
            //   ff75d4               | push                dword ptr [ebp - 0x2c]
            //   8bd8                 | mov                 ebx, eax
            //   0fb7463e             | movzx               eax, word ptr [esi + 0x3e]
            //   50                   | push                eax
            //   53                   | push                ebx

        $sequence_6 = { eb02 33ff 8bb59cfdffff 51 e8???????? 59 85ff }
            // n = 7, score = 500
            //   eb02                 | jmp                 4
            //   33ff                 | xor                 edi, edi
            //   8bb59cfdffff         | mov                 esi, dword ptr [ebp - 0x264]
            //   51                   | push                ecx
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   85ff                 | test                edi, edi

        $sequence_7 = { ff75e4 57 e8???????? 83c414 85c0 7425 8bf7 }
            // n = 7, score = 500
            //   ff75e4               | push                dword ptr [ebp - 0x1c]
            //   57                   | push                edi
            //   e8????????           |                     
            //   83c414               | add                 esp, 0x14
            //   85c0                 | test                eax, eax
            //   7425                 | je                  0x27
            //   8bf7                 | mov                 esi, edi

        $sequence_8 = { ff742430 e8???????? 89442430 8b4304 8378041b 8b30 8b7808 }
            // n = 7, score = 500
            //   ff742430             | push                dword ptr [esp + 0x30]
            //   e8????????           |                     
            //   89442430             | mov                 dword ptr [esp + 0x30], eax
            //   8b4304               | mov                 eax, dword ptr [ebx + 4]
            //   8378041b             | cmp                 dword ptr [eax + 4], 0x1b
            //   8b30                 | mov                 esi, dword ptr [eax]
            //   8b7808               | mov                 edi, dword ptr [eax + 8]

        $sequence_9 = { ff15???????? 8945cc 8b35???????? 83cfff 3bdf 7403 53 }
            // n = 7, score = 500
            //   ff15????????         |                     
            //   8945cc               | mov                 dword ptr [ebp - 0x34], eax
            //   8b35????????         |                     
            //   83cfff               | or                  edi, 0xffffffff
            //   3bdf                 | cmp                 ebx, edi
            //   7403                 | je                  5
            //   53                   | push                ebx

    condition:
        7 of them and filesize < 5275648
}