rule win_cotx_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.cotx."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.cotx"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c705????????890e9944 c705????????dbd99823 c705????????d468bcb5 c705????????a1a14538 c705????????2086e659 }
            // n = 5, score = 500
            //   c705????????890e9944     |     
            //   c705????????dbd99823     |     
            //   c705????????d468bcb5     |     
            //   c705????????a1a14538     |     
            //   c705????????2086e659     |     

        $sequence_1 = { 740e 3d10b6afa6 7407 3d36ce164d }
            // n = 4, score = 500
            //   740e                 | je                  0x10
            //   3d10b6afa6           | cmp                 eax, 0xa6afb610
            //   7407                 | je                  9
            //   3d36ce164d           | cmp                 eax, 0x4d16ce36

        $sequence_2 = { 6800f00000 81c600f00000 68???????? 56 e8???????? }
            // n = 5, score = 500
            //   6800f00000           | push                0xf000
            //   81c600f00000         | add                 esi, 0xf000
            //   68????????           |                     
            //   56                   | push                esi
            //   e8????????           |                     

        $sequence_3 = { 50 51 8d85bcebffff 50 56 }
            // n = 5, score = 500
            //   50                   | push                eax
            //   51                   | push                ecx
            //   8d85bcebffff         | lea                 eax, [ebp - 0x1444]
            //   50                   | push                eax
            //   56                   | push                esi

        $sequence_4 = { c705????????d468bcb5 c705????????a1a14538 c705????????2086e659 c705????????eec45abf }
            // n = 4, score = 500
            //   c705????????d468bcb5     |     
            //   c705????????a1a14538     |     
            //   c705????????2086e659     |     
            //   c705????????eec45abf     |     

        $sequence_5 = { c705????????9cb95b4c c705????????2d494a94 c705????????8db133d4 c705????????8e220b1d }
            // n = 4, score = 500
            //   c705????????9cb95b4c     |     
            //   c705????????2d494a94     |     
            //   c705????????8db133d4     |     
            //   c705????????8e220b1d     |     

        $sequence_6 = { 6800040000 8d8598f6ffff 6a00 50 e8???????? 83c40c 8d8598feffff }
            // n = 7, score = 500
            //   6800040000           | push                0x400
            //   8d8598f6ffff         | lea                 eax, [ebp - 0x968]
            //   6a00                 | push                0
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   8d8598feffff         | lea                 eax, [ebp - 0x168]

        $sequence_7 = { 8d850af8ffff c78500f8ffff52617354 6a00 50 }
            // n = 4, score = 500
            //   8d850af8ffff         | lea                 eax, [ebp - 0x7f6]
            //   c78500f8ffff52617354     | mov    dword ptr [ebp - 0x800], 0x54736152
            //   6a00                 | push                0
            //   50                   | push                eax

        $sequence_8 = { f3a4 50 0f1185a8faffff e8???????? }
            // n = 4, score = 500
            //   f3a4                 | rep movsb           byte ptr es:[edi], byte ptr [esi]
            //   50                   | push                eax
            //   0f1185a8faffff       | movups              xmmword ptr [ebp - 0x558], xmm0
            //   e8????????           |                     

        $sequence_9 = { 8bce a3???????? e8???????? 8b15???????? 8b4dfc }
            // n = 5, score = 500
            //   8bce                 | mov                 ecx, esi
            //   a3????????           |                     
            //   e8????????           |                     
            //   8b15????????         |                     
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]

    condition:
        7 of them and filesize < 1171456
}