rule win_cova_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.cova."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.cova"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b430c 8905???????? 8bd7 4c8d0558bbffff }
            // n = 4, score = 100
            //   8b430c               | lea                 edx, [ebp + 0x1270]
            //   8905????????         |                     
            //   8bd7                 | call                dword ptr [ebp + 0xa0]
            //   4c8d0558bbffff       | lea                 edx, [esi + 6]

        $sequence_1 = { eb7c 4c8d258e800000 488b0d???????? eb6c }
            // n = 4, score = 100
            //   eb7c                 | mov                 eax, ecx
            //   4c8d258e800000       | dec                 esp
            //   488b0d????????       |                     
            //   eb6c                 | lea                 eax, [0x31ae]

        $sequence_2 = { 4881c354020000 83fe06 7298 488d8d70040000 baf80d0000 }
            // n = 5, score = 100
            //   4881c354020000       | dec                 eax
            //   83fe06               | mov                 dword ptr [esp + 0x20], eax
            //   7298                 | call                dword ptr [ebp + 0xb0]
            //   488d8d70040000       | inc                 ebp
            //   baf80d0000           | xor                 ecx, ecx

        $sequence_3 = { 3d80000000 751d 4c8be6 448bfe 4839742450 7419 ff5500 }
            // n = 7, score = 100
            //   3d80000000           | dec                 eax
            //   751d                 | mov                 ecx, eax
            //   4c8be6               | dec                 eax
            //   448bfe               | lea                 edx, [0x25b5]
            //   4839742450           | dec                 eax
            //   7419                 | mov                 ecx, esi
            //   ff5500               | dec                 eax

        $sequence_4 = { 4863ca 0fb7444b10 664189844898c90000 ffc2 }
            // n = 4, score = 100
            //   4863ca               | mov                 edx, eax
            //   0fb7444b10           | call                dword ptr [esi + 0xa0]
            //   664189844898c90000     | inc    esp
            //   ffc2                 | mov                 edi, dword ptr [ebx + 4]

        $sequence_5 = { 488b0d???????? e9???????? 4c8d25a6800000 488b0d???????? }
            // n = 4, score = 100
            //   488b0d????????       |                     
            //   e9????????           |                     
            //   4c8d25a6800000       | mov                 byte ptr [ecx + eax + 0xaa30], al
            //   488b0d????????       |                     

        $sequence_6 = { eb06 8d4257 418800 ffc2 49ffc0 83fa10 }
            // n = 6, score = 100
            //   eb06                 | mov                 ecx, dword ptr [eax]
            //   8d4257               | dec                 eax
            //   418800               | mov                 edi, dword ptr [ecx + 0x20]
            //   ffc2                 | dec                 eax
            //   49ffc0               | arpl                word ptr [edi + 0x3c], ax
            //   83fa10               | mov                 esi, dword ptr [eax + edi + 0x88]

        $sequence_7 = { e8???????? 482be0 488b05???????? 4833c4 48898510170000 488dbde0000000 }
            // n = 6, score = 100
            //   e8????????           |                     
            //   482be0               | lea                 ebx, [0x68e8]
            //   488b05????????       |                     
            //   4833c4               | mov                 esi, edi
            //   48898510170000       | dec                 eax
            //   488dbde0000000       | mov                 dword ptr [esp + 0x20], esi

        $sequence_8 = { ff15???????? 488d1574260000 488bce 488905???????? ff15???????? }
            // n = 5, score = 100
            //   ff15????????         |                     
            //   488d1574260000       | test                eax, eax
            //   488bce               | je                  0x81d
            //   488905????????       |                     
            //   ff15????????         |                     

        $sequence_9 = { 41bc14030000 4c8d0520320000 488bcd 418bd4 }
            // n = 4, score = 100
            //   41bc14030000         | mov                 edi, esi
            //   4c8d0520320000       | cmp                 eax, 0x80
            //   488bcd               | je                  0x5c
            //   418bd4               | test                eax, eax

    condition:
        7 of them and filesize < 123904
}