rule win_cradlecore_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.cradlecore."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.cradlecore"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 03f2 eb5c 8b45f4 8b0c85f01f4300 f644190448 7437 }
            // n = 6, score = 100
            //   03f2                 | add                 esi, edx
            //   eb5c                 | jmp                 0x5e
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]
            //   8b0c85f01f4300       | mov                 ecx, dword ptr [eax*4 + 0x431ff0]
            //   f644190448           | test                byte ptr [ecx + ebx + 4], 0x48
            //   7437                 | je                  0x39

        $sequence_1 = { 720f 8b06 5f c60000 8bc6 }
            // n = 5, score = 100
            //   720f                 | jb                  0x11
            //   8b06                 | mov                 eax, dword ptr [esi]
            //   5f                   | pop                 edi
            //   c60000               | mov                 byte ptr [eax], 0
            //   8bc6                 | mov                 eax, esi

        $sequence_2 = { 83e908 8d7608 660fd60f 8d7f08 8b048db8734000 ffe0 f7c703000000 }
            // n = 7, score = 100
            //   83e908               | sub                 ecx, 8
            //   8d7608               | lea                 esi, [esi + 8]
            //   660fd60f             | movq                qword ptr [edi], xmm1
            //   8d7f08               | lea                 edi, [edi + 8]
            //   8b048db8734000       | mov                 eax, dword ptr [ecx*4 + 0x4073b8]
            //   ffe0                 | jmp                 eax
            //   f7c703000000         | test                edi, 3

        $sequence_3 = { e8???????? 51 51 53 8bd9 33c0 8945f0 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   51                   | push                ecx
            //   51                   | push                ecx
            //   53                   | push                ebx
            //   8bd9                 | mov                 ebx, ecx
            //   33c0                 | xor                 eax, eax
            //   8945f0               | mov                 dword ptr [ebp - 0x10], eax

        $sequence_4 = { e8???????? 83c410 3bc3 75cf 0fb644240f e9???????? c74424340f000000 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10
            //   3bc3                 | cmp                 eax, ebx
            //   75cf                 | jne                 0xffffffd1
            //   0fb644240f           | movzx               eax, byte ptr [esp + 0xf]
            //   e9????????           |                     
            //   c74424340f000000     | mov                 dword ptr [esp + 0x34], 0xf

        $sequence_5 = { 80fb5a 7e53 80fb2d 744e 80fb2e }
            // n = 5, score = 100
            //   80fb5a               | cmp                 bl, 0x5a
            //   7e53                 | jle                 0x55
            //   80fb2d               | cmp                 bl, 0x2d
            //   744e                 | je                  0x50
            //   80fb2e               | cmp                 bl, 0x2e

        $sequence_6 = { 8b5df4 8b7df0 33f6 8bce 8b75fc }
            // n = 5, score = 100
            //   8b5df4               | mov                 ebx, dword ptr [ebp - 0xc]
            //   8b7df0               | mov                 edi, dword ptr [ebp - 0x10]
            //   33f6                 | xor                 esi, esi
            //   8bce                 | mov                 ecx, esi
            //   8b75fc               | mov                 esi, dword ptr [ebp - 4]

        $sequence_7 = { 7204 8b1e eb02 8bde 8b450c 33d2 8b4d08 }
            // n = 7, score = 100
            //   7204                 | jb                  6
            //   8b1e                 | mov                 ebx, dword ptr [esi]
            //   eb02                 | jmp                 4
            //   8bde                 | mov                 ebx, esi
            //   8b450c               | mov                 eax, dword ptr [ebp + 0xc]
            //   33d2                 | xor                 edx, edx
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]

        $sequence_8 = { 59 50 8d45d0 8bce 50 e8???????? 837da010 }
            // n = 7, score = 100
            //   59                   | pop                 ecx
            //   50                   | push                eax
            //   8d45d0               | lea                 eax, [ebp - 0x30]
            //   8bce                 | mov                 ecx, esi
            //   50                   | push                eax
            //   e8????????           |                     
            //   837da010             | cmp                 dword ptr [ebp - 0x60], 0x10

        $sequence_9 = { 53 50 68???????? 53 ff15???????? 8d4de8 c745e868747470 }
            // n = 7, score = 100
            //   53                   | push                ebx
            //   50                   | push                eax
            //   68????????           |                     
            //   53                   | push                ebx
            //   ff15????????         |                     
            //   8d4de8               | lea                 ecx, [ebp - 0x18]
            //   c745e868747470       | mov                 dword ptr [ebp - 0x18], 0x70747468

    condition:
        7 of them and filesize < 450560
}