rule win_cruloader_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.cruloader."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.cruloader"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 53 ff15???????? 6a04 6800100000 ff35???????? 6a00 }
            // n = 6, score = 100
            //   53                   | push                ebx
            //   ff15????????         |                     
            //   6a04                 | push                4
            //   6800100000           | push                0x1000
            //   ff35????????         |                     
            //   6a00                 | push                0

        $sequence_1 = { 6bf638 8b0c8dd85e4100 80643128fd 5f 5e c9 c3 }
            // n = 7, score = 100
            //   6bf638               | imul                esi, esi, 0x38
            //   8b0c8dd85e4100       | mov                 ecx, dword ptr [ecx*4 + 0x415ed8]
            //   80643128fd           | and                 byte ptr [ecx + esi + 0x28], 0xfd
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   c9                   | leave               
            //   c3                   | ret                 

        $sequence_2 = { 0f1005???????? 50 0f1145e0 ff15???????? 33c9 90 8a540dd0 }
            // n = 7, score = 100
            //   0f1005????????       |                     
            //   50                   | push                eax
            //   0f1145e0             | movups              xmmword ptr [ebp - 0x20], xmm0
            //   ff15????????         |                     
            //   33c9                 | xor                 ecx, ecx
            //   90                   | nop                 
            //   8a540dd0             | mov                 dl, byte ptr [ebp + ecx - 0x30]

        $sequence_3 = { 3bf7 72e9 5f f7d0 5e 8be5 }
            // n = 6, score = 100
            //   3bf7                 | cmp                 esi, edi
            //   72e9                 | jb                  0xffffffeb
            //   5f                   | pop                 edi
            //   f7d0                 | not                 eax
            //   5e                   | pop                 esi
            //   8be5                 | mov                 esp, ebp

        $sequence_4 = { 88540dc0 41 3bc8 7ced }
            // n = 4, score = 100
            //   88540dc0             | mov                 byte ptr [ebp + ecx - 0x40], dl
            //   41                   | inc                 ecx
            //   3bc8                 | cmp                 ecx, eax
            //   7ced                 | jl                  0xffffffef

        $sequence_5 = { 83c404 0f1000 6a00 0f1185ccfbffff ff15???????? }
            // n = 5, score = 100
            //   83c404               | add                 esp, 4
            //   0f1000               | movups              xmm0, xmmword ptr [eax]
            //   6a00                 | push                0
            //   0f1185ccfbffff       | movups              xmmword ptr [ebp - 0x434], xmm0
            //   ff15????????         |                     

        $sequence_6 = { 833d????????00 0f851c0e0000 8d0db02f4100 ba1b000000 e9???????? a900000080 7517 }
            // n = 7, score = 100
            //   833d????????00       |                     
            //   0f851c0e0000         | jne                 0xe22
            //   8d0db02f4100         | lea                 ecx, [0x412fb0]
            //   ba1b000000           | mov                 edx, 0x1b
            //   e9????????           |                     
            //   a900000080           | test                eax, 0x80000000
            //   7517                 | jne                 0x19

        $sequence_7 = { 7309 80341961 41 3bca 72f7 e8???????? 8d45ec }
            // n = 7, score = 100
            //   7309                 | jae                 0xb
            //   80341961             | xor                 byte ptr [ecx + ebx], 0x61
            //   41                   | inc                 ecx
            //   3bca                 | cmp                 ecx, edx
            //   72f7                 | jb                  0xfffffff9
            //   e8????????           |                     
            //   8d45ec               | lea                 eax, [ebp - 0x14]

        $sequence_8 = { 0f8c5cffffff c705????????01000000 8b7d08 83c8ff }
            // n = 4, score = 100
            //   0f8c5cffffff         | jl                  0xffffff62
            //   c705????????01000000     |     
            //   8b7d08               | mov                 edi, dword ptr [ebp + 8]
            //   83c8ff               | or                  eax, 0xffffffff

        $sequence_9 = { 0f8494010000 8bb5e4fcffff 8d45f4 50 ff7354 57 ff75e8 }
            // n = 7, score = 100
            //   0f8494010000         | je                  0x19a
            //   8bb5e4fcffff         | mov                 esi, dword ptr [ebp - 0x31c]
            //   8d45f4               | lea                 eax, [ebp - 0xc]
            //   50                   | push                eax
            //   ff7354               | push                dword ptr [ebx + 0x54]
            //   57                   | push                edi
            //   ff75e8               | push                dword ptr [ebp - 0x18]

    condition:
        7 of them and filesize < 196608
}