rule win_crylocker_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.crylocker."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.crylocker"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 51 8d542458 52 e8???????? 8d44245c }
            // n = 5, score = 100
            //   51                   | push                ecx
            //   8d542458             | lea                 edx, [esp + 0x58]
            //   52                   | push                edx
            //   e8????????           |                     
            //   8d44245c             | lea                 eax, [esp + 0x5c]

        $sequence_1 = { 50 e8???????? 8d4c2404 6a01 51 e8???????? }
            // n = 6, score = 100
            //   50                   | push                eax
            //   e8????????           |                     
            //   8d4c2404             | lea                 ecx, [esp + 4]
            //   6a01                 | push                1
            //   51                   | push                ecx
            //   e8????????           |                     

        $sequence_2 = { 6a03 50 e8???????? 8b5c2448 8b0b 51 8d54243c }
            // n = 7, score = 100
            //   6a03                 | push                3
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b5c2448             | mov                 ebx, dword ptr [esp + 0x48]
            //   8b0b                 | mov                 ecx, dword ptr [ebx]
            //   51                   | push                ecx
            //   8d54243c             | lea                 edx, [esp + 0x3c]

        $sequence_3 = { 68???????? 53 e8???????? 83c408 53 85c0 7440 }
            // n = 7, score = 100
            //   68????????           |                     
            //   53                   | push                ebx
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   53                   | push                ebx
            //   85c0                 | test                eax, eax
            //   7440                 | je                  0x42

        $sequence_4 = { 85c0 750b 5b b8f9ffffff 5d 83c410 c3 }
            // n = 7, score = 100
            //   85c0                 | test                eax, eax
            //   750b                 | jne                 0xd
            //   5b                   | pop                 ebx
            //   b8f9ffffff           | mov                 eax, 0xfffffff9
            //   5d                   | pop                 ebp
            //   83c410               | add                 esp, 0x10
            //   c3                   | ret                 

        $sequence_5 = { 8d442430 50 e8???????? 8d4c2434 68???????? 51 e8???????? }
            // n = 7, score = 100
            //   8d442430             | lea                 eax, [esp + 0x30]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8d4c2434             | lea                 ecx, [esp + 0x34]
            //   68????????           |                     
            //   51                   | push                ecx
            //   e8????????           |                     

        $sequence_6 = { 50 50 8b44244c 50 6a00 6a00 56 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   50                   | push                eax
            //   8b44244c             | mov                 eax, dword ptr [esp + 0x4c]
            //   50                   | push                eax
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   56                   | push                esi

        $sequence_7 = { 0f8430020000 8d4c2404 51 e8???????? 8d542408 }
            // n = 5, score = 100
            //   0f8430020000         | je                  0x236
            //   8d4c2404             | lea                 ecx, [esp + 4]
            //   51                   | push                ecx
            //   e8????????           |                     
            //   8d542408             | lea                 edx, [esp + 8]

        $sequence_8 = { e8???????? 8b1d???????? 83c428 50 ffd3 8b542430 }
            // n = 6, score = 100
            //   e8????????           |                     
            //   8b1d????????         |                     
            //   83c428               | add                 esp, 0x28
            //   50                   | push                eax
            //   ffd3                 | call                ebx
            //   8b542430             | mov                 edx, dword ptr [esp + 0x30]

        $sequence_9 = { e8???????? 8d4c2408 6aff 51 e8???????? 8d542410 6a02 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8d4c2408             | lea                 ecx, [esp + 8]
            //   6aff                 | push                -1
            //   51                   | push                ecx
            //   e8????????           |                     
            //   8d542410             | lea                 edx, [esp + 0x10]
            //   6a02                 | push                2

    condition:
        7 of them and filesize < 139264
}