rule win_cuegoe_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.cuegoe."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.cuegoe"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 397d68 7409 ff7568 e8???????? 59 6a57 5e }
            // n = 7, score = 200
            //   397d68               | cmp                 dword ptr [ebp + 0x68], edi
            //   7409                 | je                  0xb
            //   ff7568               | push                dword ptr [ebp + 0x68]
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   6a57                 | push                0x57
            //   5e                   | pop                 esi

        $sequence_1 = { 50 895de4 e8???????? 837d2808 8b4514 }
            // n = 5, score = 200
            //   50                   | push                eax
            //   895de4               | mov                 dword ptr [ebp - 0x1c], ebx
            //   e8????????           |                     
            //   837d2808             | cmp                 dword ptr [ebp + 0x28], 8
            //   8b4514               | mov                 eax, dword ptr [ebp + 0x14]

        $sequence_2 = { 0f8390feffff 8b0488 0fb6c8 894538 c16d3808 894d3c }
            // n = 6, score = 200
            //   0f8390feffff         | jae                 0xfffffe96
            //   8b0488               | mov                 eax, dword ptr [eax + ecx*4]
            //   0fb6c8               | movzx               ecx, al
            //   894538               | mov                 dword ptr [ebp + 0x38], eax
            //   c16d3808             | shr                 dword ptr [ebp + 0x38], 8
            //   894d3c               | mov                 dword ptr [ebp + 0x3c], ecx

        $sequence_3 = { 6a00 50 e8???????? 83c40c 33c0 89442410 e9???????? }
            // n = 7, score = 200
            //   6a00                 | push                0
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   33c0                 | xor                 eax, eax
            //   89442410             | mov                 dword ptr [esp + 0x10], eax
            //   e9????????           |                     

        $sequence_4 = { 6a0a 8d45e8 8975e4 e8???????? 8d5dd0 e8???????? }
            // n = 6, score = 200
            //   6a0a                 | push                0xa
            //   8d45e8               | lea                 eax, [ebp - 0x18]
            //   8975e4               | mov                 dword ptr [ebp - 0x1c], esi
            //   e8????????           |                     
            //   8d5dd0               | lea                 ebx, [ebp - 0x30]
            //   e8????????           |                     

        $sequence_5 = { 50 e8???????? 8d4570 50 ff750c 8d85d0030000 56 }
            // n = 7, score = 200
            //   50                   | push                eax
            //   e8????????           |                     
            //   8d4570               | lea                 eax, [ebp + 0x70]
            //   50                   | push                eax
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   8d85d0030000         | lea                 eax, [ebp + 0x3d0]
            //   56                   | push                esi

        $sequence_6 = { 69c0a0860100 8a563c c7460c01000000 885608 89442410 3bd8 0f8387050000 }
            // n = 7, score = 200
            //   69c0a0860100         | imul                eax, eax, 0x186a0
            //   8a563c               | mov                 dl, byte ptr [esi + 0x3c]
            //   c7460c01000000       | mov                 dword ptr [esi + 0xc], 1
            //   885608               | mov                 byte ptr [esi + 8], dl
            //   89442410             | mov                 dword ptr [esp + 0x10], eax
            //   3bd8                 | cmp                 ebx, eax
            //   0f8387050000         | jae                 0x58d

        $sequence_7 = { 8b0488 0fb6c8 894538 c16d3808 894d3c 899d40040000 8b15???????? }
            // n = 7, score = 200
            //   8b0488               | mov                 eax, dword ptr [eax + ecx*4]
            //   0fb6c8               | movzx               ecx, al
            //   894538               | mov                 dword ptr [ebp + 0x38], eax
            //   c16d3808             | shr                 dword ptr [ebp + 0x38], 8
            //   894d3c               | mov                 dword ptr [ebp + 0x3c], ecx
            //   899d40040000         | mov                 dword ptr [ebp + 0x440], ebx
            //   8b15????????         |                     

        $sequence_8 = { 8d858c000000 50 8d8574ffffff 6a4c 50 e8???????? 59 }
            // n = 7, score = 200
            //   8d858c000000         | lea                 eax, [ebp + 0x8c]
            //   50                   | push                eax
            //   8d8574ffffff         | lea                 eax, [ebp - 0x8c]
            //   6a4c                 | push                0x4c
            //   50                   | push                eax
            //   e8????????           |                     
            //   59                   | pop                 ecx

        $sequence_9 = { 0f94c1 888c286c0d0000 03c7 89442410 837c241010 0f8c7affffff }
            // n = 6, score = 200
            //   0f94c1               | sete                cl
            //   888c286c0d0000       | mov                 byte ptr [eax + ebp + 0xd6c], cl
            //   03c7                 | add                 eax, edi
            //   89442410             | mov                 dword ptr [esp + 0x10], eax
            //   837c241010           | cmp                 dword ptr [esp + 0x10], 0x10
            //   0f8c7affffff         | jl                  0xffffff80

    condition:
        7 of them and filesize < 540672
}