rule win_danabot_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.danabot."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.danabot"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 7405 83e804 8b00 83f814 7e18 8b45fc 50 }
            // n = 7, score = 400
            //   7405                 | je                  7
            //   83e804               | sub                 eax, 4
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   83f814               | cmp                 eax, 0x14
            //   7e18                 | jle                 0x1a
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   50                   | push                eax

        $sequence_1 = { c1e803 83e03f 83f838 730b ba38000000 }
            // n = 5, score = 400
            //   c1e803               | shr                 eax, 3
            //   83e03f               | and                 eax, 0x3f
            //   83f838               | cmp                 eax, 0x38
            //   730b                 | jae                 0xd
            //   ba38000000           | mov                 edx, 0x38

        $sequence_2 = { 8b03 50 8b44242c 50 6a14 }
            // n = 5, score = 400
            //   8b03                 | mov                 eax, dword ptr [ebx]
            //   50                   | push                eax
            //   8b44242c             | mov                 eax, dword ptr [esp + 0x2c]
            //   50                   | push                eax
            //   6a14                 | push                0x14

        $sequence_3 = { 8b45f8 85c0 7407 83e804 }
            // n = 4, score = 400
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   85c0                 | test                eax, eax
            //   7407                 | je                  9
            //   83e804               | sub                 eax, 4

        $sequence_4 = { 8b16 e8???????? 8b07 50 8b442428 50 6a0a }
            // n = 7, score = 400
            //   8b16                 | mov                 edx, dword ptr [esi]
            //   e8????????           |                     
            //   8b07                 | mov                 eax, dword ptr [edi]
            //   50                   | push                eax
            //   8b442428             | mov                 eax, dword ptr [esp + 0x28]
            //   50                   | push                eax
            //   6a0a                 | push                0xa

        $sequence_5 = { 50 6a14 688a4c2a8d 8bc6 8b4d00 8b17 }
            // n = 6, score = 400
            //   50                   | push                eax
            //   6a14                 | push                0x14
            //   688a4c2a8d           | push                0x8d2a4c8a
            //   8bc6                 | mov                 eax, esi
            //   8b4d00               | mov                 ecx, dword ptr [ebp]
            //   8b17                 | mov                 edx, dword ptr [edi]

        $sequence_6 = { 3b85d0feffff 7452 8b85d0feffff 50 6a00 }
            // n = 5, score = 400
            //   3b85d0feffff         | cmp                 eax, dword ptr [ebp - 0x130]
            //   7452                 | je                  0x54
            //   8b85d0feffff         | mov                 eax, dword ptr [ebp - 0x130]
            //   50                   | push                eax
            //   6a00                 | push                0

        $sequence_7 = { 6a00 49 75f9 51 53 56 bb???????? }
            // n = 7, score = 400
            //   6a00                 | push                0
            //   49                   | dec                 ecx
            //   75f9                 | jne                 0xfffffffb
            //   51                   | push                ecx
            //   53                   | push                ebx
            //   56                   | push                esi
            //   bb????????           |                     

        $sequence_8 = { 8b0f 8b16 e8???????? 8b07 50 8b442454 50 }
            // n = 7, score = 400
            //   8b0f                 | mov                 ecx, dword ptr [edi]
            //   8b16                 | mov                 edx, dword ptr [esi]
            //   e8????????           |                     
            //   8b07                 | mov                 eax, dword ptr [edi]
            //   50                   | push                eax
            //   8b442454             | mov                 eax, dword ptr [esp + 0x54]
            //   50                   | push                eax

        $sequence_9 = { 56 57 8bf1 8955f8 8945fc 8d45fc }
            // n = 6, score = 400
            //   56                   | push                esi
            //   57                   | push                edi
            //   8bf1                 | mov                 esi, ecx
            //   8955f8               | mov                 dword ptr [ebp - 8], edx
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   8d45fc               | lea                 eax, [ebp - 4]

    condition:
        7 of them and filesize < 237568
}