rule win_darkcloud_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.darkcloud."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.darkcloud"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 83c414 8d4db0 ff15???????? c745fc23000000 8b4d08 894da8 }
            // n = 6, score = 100
            //   83c414               | add                 esp, 0x14
            //   8d4db0               | lea                 ecx, [ebp - 0x50]
            //   ff15????????         |                     
            //   c745fc23000000       | mov                 dword ptr [ebp - 4], 0x23
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   894da8               | mov                 dword ptr [ebp - 0x58], ecx

        $sequence_1 = { 894598 894db0 8945a8 894dc0 8945b8 ff15???????? 50 }
            // n = 7, score = 100
            //   894598               | mov                 dword ptr [ebp - 0x68], eax
            //   894db0               | mov                 dword ptr [ebp - 0x50], ecx
            //   8945a8               | mov                 dword ptr [ebp - 0x58], eax
            //   894dc0               | mov                 dword ptr [ebp - 0x40], ecx
            //   8945b8               | mov                 dword ptr [ebp - 0x48], eax
            //   ff15????????         |                     
            //   50                   | push                eax

        $sequence_2 = { 6a00 51 8bf0 ff15???????? 50 56 6a00 }
            // n = 7, score = 100
            //   6a00                 | push                0
            //   51                   | push                ecx
            //   8bf0                 | mov                 esi, eax
            //   ff15????????         |                     
            //   50                   | push                eax
            //   56                   | push                esi
            //   6a00                 | push                0

        $sequence_3 = { 8d8d68ffffff 51 ff15???????? c745fc06000000 ba???????? 8d4dcc ff15???????? }
            // n = 7, score = 100
            //   8d8d68ffffff         | lea                 ecx, [ebp - 0x98]
            //   51                   | push                ecx
            //   ff15????????         |                     
            //   c745fc06000000       | mov                 dword ptr [ebp - 4], 6
            //   ba????????           |                     
            //   8d4dcc               | lea                 ecx, [ebp - 0x34]
            //   ff15????????         |                     

        $sequence_4 = { 8d855cffffff 8d8df8feffff 50 8d954cffffff 51 52 c7851cffffff08000000 }
            // n = 7, score = 100
            //   8d855cffffff         | lea                 eax, [ebp - 0xa4]
            //   8d8df8feffff         | lea                 ecx, [ebp - 0x108]
            //   50                   | push                eax
            //   8d954cffffff         | lea                 edx, [ebp - 0xb4]
            //   51                   | push                ecx
            //   52                   | push                edx
            //   c7851cffffff08000000     | mov    dword ptr [ebp - 0xe4], 8

        $sequence_5 = { 668b55dc 663b954cffffff 0f8ff4000000 c745fc0c000000 8d45dc 894584 c7857cffffff02400000 }
            // n = 7, score = 100
            //   668b55dc             | mov                 dx, word ptr [ebp - 0x24]
            //   663b954cffffff       | cmp                 dx, word ptr [ebp - 0xb4]
            //   0f8ff4000000         | jg                  0xfa
            //   c745fc0c000000       | mov                 dword ptr [ebp - 4], 0xc
            //   8d45dc               | lea                 eax, [ebp - 0x24]
            //   894584               | mov                 dword ptr [ebp - 0x7c], eax
            //   c7857cffffff02400000     | mov    dword ptr [ebp - 0x84], 0x4002

        $sequence_6 = { ff15???????? 8bd0 8d8df0feffff ff15???????? 50 8b559c 52 }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   8bd0                 | mov                 edx, eax
            //   8d8df0feffff         | lea                 ecx, [ebp - 0x110]
            //   ff15????????         |                     
            //   50                   | push                eax
            //   8b559c               | mov                 edx, dword ptr [ebp - 0x64]
            //   52                   | push                edx

        $sequence_7 = { 668b00 8975dc 662d0100 8975cc 0f80e4000000 8975ac 894584 }
            // n = 7, score = 100
            //   668b00               | mov                 ax, word ptr [eax]
            //   8975dc               | mov                 dword ptr [ebp - 0x24], esi
            //   662d0100             | sub                 ax, 1
            //   8975cc               | mov                 dword ptr [ebp - 0x34], esi
            //   0f80e4000000         | jo                  0xea
            //   8975ac               | mov                 dword ptr [ebp - 0x54], esi
            //   894584               | mov                 dword ptr [ebp - 0x7c], eax

        $sequence_8 = { 50 8d4d94 51 e8???????? 8bd0 8d4d84 ff15???????? }
            // n = 7, score = 100
            //   50                   | push                eax
            //   8d4d94               | lea                 ecx, [ebp - 0x6c]
            //   51                   | push                ecx
            //   e8????????           |                     
            //   8bd0                 | mov                 edx, eax
            //   8d4d84               | lea                 ecx, [ebp - 0x7c]
            //   ff15????????         |                     

        $sequence_9 = { ff15???????? 8bd0 8d4da8 ff15???????? 8d5588 52 8d458c }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   8bd0                 | mov                 edx, eax
            //   8d4da8               | lea                 ecx, [ebp - 0x58]
            //   ff15????????         |                     
            //   8d5588               | lea                 edx, [ebp - 0x78]
            //   52                   | push                edx
            //   8d458c               | lea                 eax, [ebp - 0x74]

    condition:
        7 of them and filesize < 622592
}