rule win_darkloader_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.darkloader."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.darkloader"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 8bb42434020000 c1e607 68???????? 89b42438020000 8dbe10a10010 }
            // n = 6, score = 100
            //   e8????????           |                     
            //   8bb42434020000       | mov                 esi, dword ptr [esp + 0x234]
            //   c1e607               | shl                 esi, 7
            //   68????????           |                     
            //   89b42438020000       | mov                 dword ptr [esp + 0x238], esi
            //   8dbe10a10010         | lea                 edi, [esi + 0x1000a110]

        $sequence_1 = { c70424???????? e8???????? c70424???????? 8bf8 56 e8???????? }
            // n = 6, score = 100
            //   c70424????????       |                     
            //   e8????????           |                     
            //   c70424????????       |                     
            //   8bf8                 | mov                 edi, eax
            //   56                   | push                esi
            //   e8????????           |                     

        $sequence_2 = { 51 ff36 8b00 8b00 8986b0010000 ff96bc010000 }
            // n = 6, score = 100
            //   51                   | push                ecx
            //   ff36                 | push                dword ptr [esi]
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   8986b0010000         | mov                 dword ptr [esi + 0x1b0], eax
            //   ff96bc010000         | call                dword ptr [esi + 0x1bc]

        $sequence_3 = { 57 ff74241c e8???????? 03c3 0fb73470 }
            // n = 5, score = 100
            //   57                   | push                edi
            //   ff74241c             | push                dword ptr [esp + 0x1c]
            //   e8????????           |                     
            //   03c3                 | add                 eax, ebx
            //   0fb73470             | movzx               esi, word ptr [eax + esi*2]

        $sequence_4 = { 3c5f 7447 3c2e 7443 3c7e }
            // n = 5, score = 100
            //   3c5f                 | cmp                 al, 0x5f
            //   7447                 | je                  0x49
            //   3c2e                 | cmp                 al, 0x2e
            //   7443                 | je                  0x45
            //   3c7e                 | cmp                 al, 0x7e

        $sequence_5 = { 8b7c240c 8bcf 8906 8d5101 8a01 41 84c0 }
            // n = 7, score = 100
            //   8b7c240c             | mov                 edi, dword ptr [esp + 0xc]
            //   8bcf                 | mov                 ecx, edi
            //   8906                 | mov                 dword ptr [esi], eax
            //   8d5101               | lea                 edx, [ecx + 1]
            //   8a01                 | mov                 al, byte ptr [ecx]
            //   41                   | inc                 ecx
            //   84c0                 | test                al, al

        $sequence_6 = { 84c0 740b 80f90d 7519 }
            // n = 4, score = 100
            //   84c0                 | test                al, al
            //   740b                 | je                  0xd
            //   80f90d               | cmp                 cl, 0xd
            //   7519                 | jne                 0x1b

        $sequence_7 = { 894c241c 85c9 0f84b3000000 8b4020 }
            // n = 4, score = 100
            //   894c241c             | mov                 dword ptr [esp + 0x1c], ecx
            //   85c9                 | test                ecx, ecx
            //   0f84b3000000         | je                  0xb9
            //   8b4020               | mov                 eax, dword ptr [eax + 0x20]

        $sequence_8 = { 6bc503 40 50 e8???????? be???????? 8d7c2418 }
            // n = 6, score = 100
            //   6bc503               | imul                eax, ebp, 3
            //   40                   | inc                 eax
            //   50                   | push                eax
            //   e8????????           |                     
            //   be????????           |                     
            //   8d7c2418             | lea                 edi, [esp + 0x18]

        $sequence_9 = { 83c428 50 6a40 6a05 53 ffd6 }
            // n = 6, score = 100
            //   83c428               | add                 esp, 0x28
            //   50                   | push                eax
            //   6a40                 | push                0x40
            //   6a05                 | push                5
            //   53                   | push                ebx
            //   ffd6                 | call                esi

    condition:
        7 of them and filesize < 124928
}