rule win_darkme_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.darkme."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.darkme"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8dbddcfcffff f3ab b964000000 8dbd18fbffff 68???????? 8985d8fcffff 8985d4fcffff }
            // n = 7, score = 100
            //   8dbddcfcffff         | lea                 edi, [ebp - 0x324]
            //   f3ab                 | rep stosd           dword ptr es:[edi], eax
            //   b964000000           | mov                 ecx, 0x64
            //   8dbd18fbffff         | lea                 edi, [ebp - 0x4e8]
            //   68????????           |                     
            //   8985d8fcffff         | mov                 dword ptr [ebp - 0x328], eax
            //   8985d4fcffff         | mov                 dword ptr [ebp - 0x32c], eax

        $sequence_1 = { 51 8d55d4 52 6a02 ff15???????? 83c40c 8d45c4 }
            // n = 7, score = 100
            //   51                   | push                ecx
            //   8d55d4               | lea                 edx, [ebp - 0x2c]
            //   52                   | push                edx
            //   6a02                 | push                2
            //   ff15????????         |                     
            //   83c40c               | add                 esp, 0xc
            //   8d45c4               | lea                 eax, [ebp - 0x3c]

        $sequence_2 = { 8b8518ffffff 8b08 8b9518ffffff 52 ff5114 dbe2 }
            // n = 6, score = 100
            //   8b8518ffffff         | mov                 eax, dword ptr [ebp - 0xe8]
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   8b9518ffffff         | mov                 edx, dword ptr [ebp - 0xe8]
            //   52                   | push                edx
            //   ff5114               | call                dword ptr [ecx + 0x14]
            //   dbe2                 | fnclex              

        $sequence_3 = { 6a00 ff15???????? 50 8b558c 81c2???????? 52 ff15???????? }
            // n = 7, score = 100
            //   6a00                 | push                0
            //   ff15????????         |                     
            //   50                   | push                eax
            //   8b558c               | mov                 edx, dword ptr [ebp - 0x74]
            //   81c2????????         |                     
            //   52                   | push                edx
            //   ff15????????         |                     

        $sequence_4 = { c745880a000000 8b8530ffffff 50 ff15???????? 8945a0 c7459808000000 8b4dd4 }
            // n = 7, score = 100
            //   c745880a000000       | mov                 dword ptr [ebp - 0x78], 0xa
            //   8b8530ffffff         | mov                 eax, dword ptr [ebp - 0xd0]
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8945a0               | mov                 dword ptr [ebp - 0x60], eax
            //   c7459808000000       | mov                 dword ptr [ebp - 0x68], 8
            //   8b4dd4               | mov                 ecx, dword ptr [ebp - 0x2c]

        $sequence_5 = { 8b8500ffffff 50 8b8dfcfeffff 51 ff15???????? 898594feffff eb0a }
            // n = 7, score = 100
            //   8b8500ffffff         | mov                 eax, dword ptr [ebp - 0x100]
            //   50                   | push                eax
            //   8b8dfcfeffff         | mov                 ecx, dword ptr [ebp - 0x104]
            //   51                   | push                ecx
            //   ff15????????         |                     
            //   898594feffff         | mov                 dword ptr [ebp - 0x16c], eax
            //   eb0a                 | jmp                 0xc

        $sequence_6 = { 05???????? 898588feffff eb12 8b8db4feffff 81c1???????? 898d88feffff 8b9588feffff }
            // n = 7, score = 100
            //   05????????           |                     
            //   898588feffff         | mov                 dword ptr [ebp - 0x178], eax
            //   eb12                 | jmp                 0x14
            //   8b8db4feffff         | mov                 ecx, dword ptr [ebp - 0x14c]
            //   81c1????????         |                     
            //   898d88feffff         | mov                 dword ptr [ebp - 0x178], ecx
            //   8b9588feffff         | mov                 edx, dword ptr [ebp - 0x178]

        $sequence_7 = { 83c42c 51 68???????? ff15???????? 85c0 0f851afeffff }
            // n = 6, score = 100
            //   83c42c               | add                 esp, 0x2c
            //   51                   | push                ecx
            //   68????????           |                     
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   0f851afeffff         | jne                 0xfffffe20

        $sequence_8 = { 8b5144 52 8d8524ffffff 50 8d8d54ffffff 51 ff15???????? }
            // n = 7, score = 100
            //   8b5144               | mov                 edx, dword ptr [ecx + 0x44]
            //   52                   | push                edx
            //   8d8524ffffff         | lea                 eax, [ebp - 0xdc]
            //   50                   | push                eax
            //   8d8d54ffffff         | lea                 ecx, [ebp - 0xac]
            //   51                   | push                ecx
            //   ff15????????         |                     

        $sequence_9 = { 8b08 8b95fcfeffff 52 ff5120 }
            // n = 4, score = 100
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   8b95fcfeffff         | mov                 edx, dword ptr [ebp - 0x104]
            //   52                   | push                edx
            //   ff5120               | call                dword ptr [ecx + 0x20]

    condition:
        7 of them and filesize < 1515520
}