rule win_darkpulsar_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.darkpulsar."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.darkpulsar"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ff25???????? 33c0 40 c20c00 68???????? 64ff3500000000 }
            // n = 6, score = 600
            //   ff25????????         |                     
            //   33c0                 | xor                 eax, eax
            //   40                   | inc                 eax
            //   c20c00               | ret                 0xc
            //   68????????           |                     
            //   64ff3500000000       | push                dword ptr fs:[0]

        $sequence_1 = { c20c00 68???????? 64ff3500000000 8b442410 896c2410 8d6c2410 2be0 }
            // n = 7, score = 600
            //   c20c00               | ret                 0xc
            //   68????????           |                     
            //   64ff3500000000       | push                dword ptr fs:[0]
            //   8b442410             | mov                 eax, dword ptr [esp + 0x10]
            //   896c2410             | mov                 dword ptr [esp + 0x10], ebp
            //   8d6c2410             | lea                 ebp, [esp + 0x10]
            //   2be0                 | sub                 esp, eax

        $sequence_2 = { c21000 ff25???????? ff25???????? ff25???????? 33c0 }
            // n = 5, score = 600
            //   c21000               | ret                 0x10
            //   ff25????????         |                     
            //   ff25????????         |                     
            //   ff25????????         |                     
            //   33c0                 | xor                 eax, eax

        $sequence_3 = { 3a01 1bc0 83e0fe 40 5f }
            // n = 5, score = 400
            //   3a01                 | cmp                 al, byte ptr [ecx]
            //   1bc0                 | sbb                 eax, eax
            //   83e0fe               | and                 eax, 0xfffffffe
            //   40                   | inc                 eax
            //   5f                   | pop                 edi

        $sequence_4 = { 803f00 742e 47 ff450c 0fbe07 }
            // n = 5, score = 300
            //   803f00               | cmp                 byte ptr [edi], 0
            //   742e                 | je                  0x30
            //   47                   | inc                 edi
            //   ff450c               | inc                 dword ptr [ebp + 0xc]
            //   0fbe07               | movsx               eax, byte ptr [edi]

        $sequence_5 = { 56 8b35???????? 57 8b7d08 eb09 }
            // n = 5, score = 300
            //   56                   | push                esi
            //   8b35????????         |                     
            //   57                   | push                edi
            //   8b7d08               | mov                 edi, dword ptr [ebp + 8]
            //   eb09                 | jmp                 0xb

        $sequence_6 = { 59 59 3bd8 74e0 0fb607 }
            // n = 5, score = 300
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx
            //   3bd8                 | cmp                 ebx, eax
            //   74e0                 | je                  0xffffffe2
            //   0fb607               | movzx               eax, byte ptr [edi]

        $sequence_7 = { 50 ffd6 8bd8 8b450c 0fbe00 50 ffd6 }
            // n = 7, score = 300
            //   50                   | push                eax
            //   ffd6                 | call                esi
            //   8bd8                 | mov                 ebx, eax
            //   8b450c               | mov                 eax, dword ptr [ebp + 0xc]
            //   0fbe00               | movsx               eax, byte ptr [eax]
            //   50                   | push                eax
            //   ffd6                 | call                esi

        $sequence_8 = { 56 e8???????? ff742414 50 e8???????? 83c410 }
            // n = 6, score = 200
            //   56                   | push                esi
            //   e8????????           |                     
            //   ff742414             | push                dword ptr [esp + 0x14]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10

        $sequence_9 = { 6a01 50 ff15???????? 8bf0 59 }
            // n = 5, score = 200
            //   6a01                 | push                1
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8bf0                 | mov                 esi, eax
            //   59                   | pop                 ecx

        $sequence_10 = { 83c410 83f8ff 0f95c1 49 8bc1 }
            // n = 5, score = 200
            //   83c410               | add                 esp, 0x10
            //   83f8ff               | cmp                 eax, -1
            //   0f95c1               | setne               cl
            //   49                   | dec                 ecx
            //   8bc1                 | mov                 eax, ecx

        $sequence_11 = { 53 33d2 56 57 33c0 }
            // n = 5, score = 200
            //   53                   | push                ebx
            //   33d2                 | xor                 edx, edx
            //   56                   | push                esi
            //   57                   | push                edi
            //   33c0                 | xor                 eax, eax

        $sequence_12 = { ffd7 59 5f 5e c3 8b4c2404 85c9 }
            // n = 7, score = 200
            //   ffd7                 | call                edi
            //   59                   | pop                 ecx
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   c3                   | ret                 
            //   8b4c2404             | mov                 ecx, dword ptr [esp + 4]
            //   85c9                 | test                ecx, ecx

        $sequence_13 = { 8d45cc 50 57 e8???????? 83c410 85c0 }
            // n = 6, score = 200
            //   8d45cc               | lea                 eax, [ebp - 0x34]
            //   50                   | push                eax
            //   57                   | push                edi
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10
            //   85c0                 | test                eax, eax

        $sequence_14 = { ffd6 59 59 8945f8 }
            // n = 4, score = 200
            //   ffd6                 | call                esi
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx
            //   8945f8               | mov                 dword ptr [ebp - 8], eax

        $sequence_15 = { f7d8 59 1bc0 59 40 c3 e9???????? }
            // n = 7, score = 200
            //   f7d8                 | neg                 eax
            //   59                   | pop                 ecx
            //   1bc0                 | sbb                 eax, eax
            //   59                   | pop                 ecx
            //   40                   | inc                 eax
            //   c3                   | ret                 
            //   e9????????           |                     

        $sequence_16 = { 8b5d10 56 8b7508 33d2 }
            // n = 4, score = 200
            //   8b5d10               | mov                 ebx, dword ptr [ebp + 0x10]
            //   56                   | push                esi
            //   8b7508               | mov                 esi, dword ptr [ebp + 8]
            //   33d2                 | xor                 edx, edx

        $sequence_17 = { e8???????? ff7514 89460c e8???????? }
            // n = 4, score = 200
            //   e8????????           |                     
            //   ff7514               | push                dword ptr [ebp + 0x14]
            //   89460c               | mov                 dword ptr [esi + 0xc], eax
            //   e8????????           |                     

        $sequence_18 = { ff15???????? 8bf8 59 59 85ff 7502 }
            // n = 6, score = 200
            //   ff15????????         |                     
            //   8bf8                 | mov                 edi, eax
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx
            //   85ff                 | test                edi, edi
            //   7502                 | jne                 4

        $sequence_19 = { 8bc1 c3 8b442404 85c0 7501 c3 }
            // n = 6, score = 200
            //   8bc1                 | mov                 eax, ecx
            //   c3                   | ret                 
            //   8b442404             | mov                 eax, dword ptr [esp + 4]
            //   85c0                 | test                eax, eax
            //   7501                 | jne                 3
            //   c3                   | ret                 

        $sequence_20 = { 33c0 33d2 c3 8bff 55 8bec b863736de0 }
            // n = 7, score = 200
            //   33c0                 | xor                 eax, eax
            //   33d2                 | xor                 edx, edx
            //   c3                   | ret                 
            //   8bff                 | mov                 edi, edi
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   b863736de0           | mov                 eax, 0xe06d7363

        $sequence_21 = { e8???????? 59 5e 83f8ff }
            // n = 4, score = 200
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   5e                   | pop                 esi
            //   83f8ff               | cmp                 eax, -1

        $sequence_22 = { 59 5e 8b45fc c9 c3 }
            // n = 5, score = 200
            //   59                   | pop                 ecx
            //   5e                   | pop                 esi
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   c9                   | leave               
            //   c3                   | ret                 

        $sequence_23 = { 56 e8???????? 59 85c0 7625 }
            // n = 5, score = 200
            //   56                   | push                esi
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   85c0                 | test                eax, eax
            //   7625                 | jbe                 0x27

        $sequence_24 = { e8???????? 8bf0 46 56 ff15???????? 59 }
            // n = 6, score = 200
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax
            //   46                   | inc                 esi
            //   56                   | push                esi
            //   ff15????????         |                     
            //   59                   | pop                 ecx

        $sequence_25 = { 40 894588 83659800 85c0 }
            // n = 4, score = 100
            //   40                   | inc                 eax
            //   894588               | mov                 dword ptr [ebp - 0x78], eax
            //   83659800             | and                 dword ptr [ebp - 0x68], 0
            //   85c0                 | test                eax, eax

        $sequence_26 = { 8903 894304 5f 8bc6 }
            // n = 4, score = 100
            //   8903                 | mov                 dword ptr [ebx], eax
            //   894304               | mov                 dword ptr [ebx + 4], eax
            //   5f                   | pop                 edi
            //   8bc6                 | mov                 eax, esi

        $sequence_27 = { ff75f0 56 57 ff15???????? 83c40c }
            // n = 5, score = 100
            //   ff75f0               | push                dword ptr [ebp - 0x10]
            //   56                   | push                esi
            //   57                   | push                edi
            //   ff15????????         |                     
            //   83c40c               | add                 esp, 0xc

        $sequence_28 = { 00db 7313 752f 3b742404 0f830b010000 }
            // n = 5, score = 100
            //   00db                 | add                 bl, bl
            //   7313                 | jae                 0x15
            //   752f                 | jne                 0x31
            //   3b742404             | cmp                 esi, dword ptr [esp + 4]
            //   0f830b010000         | jae                 0x111

        $sequence_29 = { 8945cc 8945d0 8b4608 6a05 50 885dec }
            // n = 6, score = 100
            //   8945cc               | mov                 dword ptr [ebp - 0x34], eax
            //   8945d0               | mov                 dword ptr [ebp - 0x30], eax
            //   8b4608               | mov                 eax, dword ptr [esi + 8]
            //   6a05                 | push                5
            //   50                   | push                eax
            //   885dec               | mov                 byte ptr [ebp - 0x14], bl

        $sequence_30 = { 66894df5 c745f702000000 e8???????? 83c408 }
            // n = 4, score = 100
            //   66894df5             | mov                 word ptr [ebp - 0xb], cx
            //   c745f702000000       | mov                 dword ptr [ebp - 9], 2
            //   e8????????           |                     
            //   83c408               | add                 esp, 8

        $sequence_31 = { 0fb606 50 ff15???????? 83c41c 85c0 }
            // n = 5, score = 100
            //   0fb606               | movzx               eax, byte ptr [esi]
            //   50                   | push                eax
            //   ff15????????         |                     
            //   83c41c               | add                 esp, 0x1c
            //   85c0                 | test                eax, eax

        $sequence_32 = { 48 4e 897c2414 75eb 5f 8d4240 }
            // n = 6, score = 100
            //   48                   | dec                 eax
            //   4e                   | dec                 esi
            //   897c2414             | mov                 dword ptr [esp + 0x14], edi
            //   75eb                 | jne                 0xffffffed
            //   5f                   | pop                 edi
            //   8d4240               | lea                 eax, [edx + 0x40]

        $sequence_33 = { 668903 8b45e8 8930 33c0 ebdc ff742408 ff15???????? }
            // n = 7, score = 100
            //   668903               | mov                 word ptr [ebx], ax
            //   8b45e8               | mov                 eax, dword ptr [ebp - 0x18]
            //   8930                 | mov                 dword ptr [eax], esi
            //   33c0                 | xor                 eax, eax
            //   ebdc                 | jmp                 0xffffffde
            //   ff742408             | push                dword ptr [esp + 8]
            //   ff15????????         |                     

        $sequence_34 = { 00db 7309 75f4 8a1e 46 10db }
            // n = 6, score = 100
            //   00db                 | add                 bl, bl
            //   7309                 | jae                 0xb
            //   75f4                 | jne                 0xfffffff6
            //   8a1e                 | mov                 bl, byte ptr [esi]
            //   46                   | inc                 esi
            //   10db                 | adc                 bl, bl

        $sequence_35 = { 00db 7313 75e1 3b742404 0f8318010000 }
            // n = 5, score = 100
            //   00db                 | add                 bl, bl
            //   7313                 | jae                 0x15
            //   75e1                 | jne                 0xffffffe3
            //   3b742404             | cmp                 esi, dword ptr [esp + 4]
            //   0f8318010000         | jae                 0x11e

        $sequence_36 = { 51 51 8b4508 8b4d0c 894dfc }
            // n = 5, score = 100
            //   51                   | push                ecx
            //   51                   | push                ecx
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   8b4d0c               | mov                 ecx, dword ptr [ebp + 0xc]
            //   894dfc               | mov                 dword ptr [ebp - 4], ecx

        $sequence_37 = { 0facf908 c1ef08 48 4e }
            // n = 4, score = 100
            //   0facf908             | shrd                ecx, edi, 8
            //   c1ef08               | shr                 edi, 8
            //   48                   | dec                 eax
            //   4e                   | dec                 esi

        $sequence_38 = { 8945e0 8945e4 8945d4 8945d8 8b450c 897de8 897ddc }
            // n = 7, score = 100
            //   8945e0               | mov                 dword ptr [ebp - 0x20], eax
            //   8945e4               | mov                 dword ptr [ebp - 0x1c], eax
            //   8945d4               | mov                 dword ptr [ebp - 0x2c], eax
            //   8945d8               | mov                 dword ptr [ebp - 0x28], eax
            //   8b450c               | mov                 eax, dword ptr [ebp + 0xc]
            //   897de8               | mov                 dword ptr [ebp - 0x18], edi
            //   897ddc               | mov                 dword ptr [ebp - 0x24], edi

        $sequence_39 = { 8d8df9feffff 53 51 899d5ceeffff 899d60eeffff }
            // n = 5, score = 100
            //   8d8df9feffff         | lea                 ecx, [ebp - 0x107]
            //   53                   | push                ebx
            //   51                   | push                ecx
            //   899d5ceeffff         | mov                 dword ptr [ebp - 0x11a4], ebx
            //   899d60eeffff         | mov                 dword ptr [ebp - 0x11a0], ebx

        $sequence_40 = { 8b4d08 8d7d0c 31c0 f3aa }
            // n = 4, score = 100
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   8d7d0c               | lea                 edi, [ebp + 0xc]
            //   31c0                 | xor                 eax, eax
            //   f3aa                 | rep stosb           byte ptr es:[edi], al

        $sequence_41 = { ffd3 ff7594 ff15???????? 83c414 837d9c00 741c 837d0c07 }
            // n = 7, score = 100
            //   ffd3                 | call                ebx
            //   ff7594               | push                dword ptr [ebp - 0x6c]
            //   ff15????????         |                     
            //   83c414               | add                 esp, 0x14
            //   837d9c00             | cmp                 dword ptr [ebp - 0x64], 0
            //   741c                 | je                  0x1e
            //   837d0c07             | cmp                 dword ptr [ebp + 0xc], 7

        $sequence_42 = { 33d7 c1ea10 5f 33d1 }
            // n = 4, score = 100
            //   33d7                 | xor                 edx, edi
            //   c1ea10               | shr                 edx, 0x10
            //   5f                   | pop                 edi
            //   33d1                 | xor                 edx, ecx

        $sequence_43 = { 8bec 8b4508 894508 d94508 5d }
            // n = 5, score = 100
            //   8bec                 | mov                 ebp, esp
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   894508               | mov                 dword ptr [ebp + 8], eax
            //   d94508               | fld                 dword ptr [ebp + 8]
            //   5d                   | pop                 ebp

    condition:
        7 of them and filesize < 491520
}