rule win_darkrat_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.darkrat."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.darkrat"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 837de810 895510 8b4804 8d45d4 0f4345d4 2975b4 }
            // n = 6, score = 200
            //   837de810             | cmp                 dword ptr [ebp - 0x18], 0x10
            //   895510               | mov                 dword ptr [ebp + 0x10], edx
            //   8b4804               | mov                 ecx, dword ptr [eax + 4]
            //   8d45d4               | lea                 eax, [ebp - 0x2c]
            //   0f4345d4             | cmovae              eax, dword ptr [ebp - 0x2c]
            //   2975b4               | sub                 dword ptr [ebp - 0x4c], esi

        $sequence_1 = { 51 03f8 52 57 e8???????? 8b45c8 83c40c }
            // n = 7, score = 200
            //   51                   | push                ecx
            //   03f8                 | add                 edi, eax
            //   52                   | push                edx
            //   57                   | push                edi
            //   e8????????           |                     
            //   8b45c8               | mov                 eax, dword ptr [ebp - 0x38]
            //   83c40c               | add                 esp, 0xc

        $sequence_2 = { 51 56 e8???????? 83c40c c6043e00 eb17 57 }
            // n = 7, score = 200
            //   51                   | push                ecx
            //   56                   | push                esi
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   c6043e00             | mov                 byte ptr [esi + edi], 0
            //   eb17                 | jmp                 0x19
            //   57                   | push                edi

        $sequence_3 = { 8b7dd4 0f8514ffffff 8b55ec 83fa10 }
            // n = 4, score = 200
            //   8b7dd4               | mov                 edi, dword ptr [ebp - 0x2c]
            //   0f8514ffffff         | jne                 0xffffff1a
            //   8b55ec               | mov                 edx, dword ptr [ebp - 0x14]
            //   83fa10               | cmp                 edx, 0x10

        $sequence_4 = { 8bd0 b805000000 2bd6 8a0e 8d7601 884c32ff 83e801 }
            // n = 7, score = 200
            //   8bd0                 | mov                 edx, eax
            //   b805000000           | mov                 eax, 5
            //   2bd6                 | sub                 edx, esi
            //   8a0e                 | mov                 cl, byte ptr [esi]
            //   8d7601               | lea                 esi, [esi + 1]
            //   884c32ff             | mov                 byte ptr [edx + esi - 1], cl
            //   83e801               | sub                 eax, 1

        $sequence_5 = { e8???????? 83c408 c745e800000000 8d4dd8 }
            // n = 4, score = 200
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   c745e800000000       | mov                 dword ptr [ebp - 0x18], 0
            //   8d4dd8               | lea                 ecx, [ebp - 0x28]

        $sequence_6 = { 0b510c 52 e8???????? c745fc04000000 e8???????? 84c0 7507 }
            // n = 7, score = 200
            //   0b510c               | or                  edx, dword ptr [ecx + 0xc]
            //   52                   | push                edx
            //   e8????????           |                     
            //   c745fc04000000       | mov                 dword ptr [ebp - 4], 4
            //   e8????????           |                     
            //   84c0                 | test                al, al
            //   7507                 | jne                 9

        $sequence_7 = { 83c408 c745e800000000 8d4dd8 c745ec0f000000 c645d800 }
            // n = 5, score = 200
            //   83c408               | add                 esp, 8
            //   c745e800000000       | mov                 dword ptr [ebp - 0x18], 0
            //   8d4dd8               | lea                 ecx, [ebp - 0x28]
            //   c745ec0f000000       | mov                 dword ptr [ebp - 0x14], 0xf
            //   c645d800             | mov                 byte ptr [ebp - 0x28], 0

        $sequence_8 = { ff75d0 51 8bcb e8???????? 8b75b8 c645fc01 }
            // n = 6, score = 200
            //   ff75d0               | push                dword ptr [ebp - 0x30]
            //   51                   | push                ecx
            //   8bcb                 | mov                 ecx, ebx
            //   e8????????           |                     
            //   8b75b8               | mov                 esi, dword ptr [ebp - 0x48]
            //   c645fc01             | mov                 byte ptr [ebp - 4], 1

        $sequence_9 = { 895510 8b4804 8d45d4 0f4345d4 2975b4 03c6 ff75b4 }
            // n = 7, score = 200
            //   895510               | mov                 dword ptr [ebp + 0x10], edx
            //   8b4804               | mov                 ecx, dword ptr [eax + 4]
            //   8d45d4               | lea                 eax, [ebp - 0x2c]
            //   0f4345d4             | cmovae              eax, dword ptr [ebp - 0x2c]
            //   2975b4               | sub                 dword ptr [ebp - 0x4c], esi
            //   03c6                 | add                 eax, esi
            //   ff75b4               | push                dword ptr [ebp - 0x4c]

    condition:
        7 of them and filesize < 884736
}