rule win_darkshell_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.darkshell."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.darkshell"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 83c004 8901 83c014 8902 6681380b01 7511 }
            // n = 6, score = 300
            //   83c004               | add                 eax, 4
            //   8901                 | mov                 dword ptr [ecx], eax
            //   83c014               | add                 eax, 0x14
            //   8902                 | mov                 dword ptr [edx], eax
            //   6681380b01           | cmp                 word ptr [eax], 0x10b
            //   7511                 | jne                 0x13

        $sequence_1 = { 6a00 6a00 50 53 ffd5 8be8 }
            // n = 6, score = 300
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   50                   | push                eax
            //   53                   | push                ebx
            //   ffd5                 | call                ebp
            //   8be8                 | mov                 ebp, eax

        $sequence_2 = { 7413 8b4c2410 8b54240c 51 52 ffd0 }
            // n = 6, score = 300
            //   7413                 | je                  0x15
            //   8b4c2410             | mov                 ecx, dword ptr [esp + 0x10]
            //   8b54240c             | mov                 edx, dword ptr [esp + 0xc]
            //   51                   | push                ecx
            //   52                   | push                edx
            //   ffd0                 | call                eax

        $sequence_3 = { ff542414 53 ff542414 56 ff15???????? }
            // n = 5, score = 300
            //   ff542414             | call                dword ptr [esp + 0x14]
            //   53                   | push                ebx
            //   ff542414             | call                dword ptr [esp + 0x14]
            //   56                   | push                esi
            //   ff15????????         |                     

        $sequence_4 = { 8d542418 6a04 52 684be12200 50 }
            // n = 5, score = 300
            //   8d542418             | lea                 edx, [esp + 0x18]
            //   6a04                 | push                4
            //   52                   | push                edx
            //   684be12200           | push                0x22e14b
            //   50                   | push                eax

        $sequence_5 = { e8???????? 8b4c2414 8bf0 8b442418 6800400000 50 }
            // n = 6, score = 300
            //   e8????????           |                     
            //   8b4c2414             | mov                 ecx, dword ptr [esp + 0x14]
            //   8bf0                 | mov                 esi, eax
            //   8b442418             | mov                 eax, dword ptr [esp + 0x18]
            //   6800400000           | push                0x4000
            //   50                   | push                eax

        $sequence_6 = { 89442418 ffd7 6a00 6a00 6a00 6a00 }
            // n = 6, score = 300
            //   89442418             | mov                 dword ptr [esp + 0x18], eax
            //   ffd7                 | call                edi
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   6a00                 | push                0

        $sequence_7 = { 55 ff542424 55 ff542414 53 }
            // n = 5, score = 300
            //   55                   | push                ebp
            //   ff542424             | call                dword ptr [esp + 0x24]
            //   55                   | push                ebp
            //   ff542414             | call                dword ptr [esp + 0x14]
            //   53                   | push                ebx

        $sequence_8 = { 8902 6681380b01 7511 8b4c2410 05e0000000 8901 b801000000 }
            // n = 7, score = 300
            //   8902                 | mov                 dword ptr [edx], eax
            //   6681380b01           | cmp                 word ptr [eax], 0x10b
            //   7511                 | jne                 0x13
            //   8b4c2410             | mov                 ecx, dword ptr [esp + 0x10]
            //   05e0000000           | add                 eax, 0xe0
            //   8901                 | mov                 dword ptr [ecx], eax
            //   b801000000           | mov                 eax, 1

        $sequence_9 = { ff15???????? 8b542410 8d4c2414 51 6a04 52 }
            // n = 6, score = 300
            //   ff15????????         |                     
            //   8b542410             | mov                 edx, dword ptr [esp + 0x10]
            //   8d4c2414             | lea                 ecx, [esp + 0x14]
            //   51                   | push                ecx
            //   6a04                 | push                4
            //   52                   | push                edx

    condition:
        7 of them and filesize < 344064
}