rule win_darkside_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.darkside."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.darkside"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8bd8 68ff000000 57 e8???????? 81c7ff000000 }
            // n = 5, score = 1100
            //   8bd8                 | mov                 ebx, eax
            //   68ff000000           | push                0xff
            //   57                   | push                edi
            //   e8????????           |                     
            //   81c7ff000000         | add                 edi, 0xff

        $sequence_1 = { 85d2 7407 52 57 }
            // n = 4, score = 1100
            //   85d2                 | test                edx, edx
            //   7407                 | je                  9
            //   52                   | push                edx
            //   57                   | push                edi

        $sequence_2 = { b9ff000000 33d2 f7f1 85c0 7418 }
            // n = 5, score = 1100
            //   b9ff000000           | mov                 ecx, 0xff
            //   33d2                 | xor                 edx, edx
            //   f7f1                 | div                 ecx
            //   85c0                 | test                eax, eax
            //   7418                 | je                  0x1a

        $sequence_3 = { 57 e8???????? 81c7ff000000 4b }
            // n = 4, score = 1100
            //   57                   | push                edi
            //   e8????????           |                     
            //   81c7ff000000         | add                 edi, 0xff
            //   4b                   | dec                 ebx

        $sequence_4 = { fec1 75d2 5f 5e 5a 59 5b }
            // n = 7, score = 1100
            //   fec1                 | inc                 cl
            //   75d2                 | jne                 0xffffffd4
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5a                   | pop                 edx
            //   59                   | pop                 ecx
            //   5b                   | pop                 ebx

        $sequence_5 = { 56 57 b9f0000000 be???????? }
            // n = 4, score = 1100
            //   56                   | push                esi
            //   57                   | push                edi
            //   b9f0000000           | mov                 ecx, 0xf0
            //   be????????           |                     

        $sequence_6 = { 8b7d08 8b450c b9ff000000 33d2 f7f1 }
            // n = 5, score = 1100
            //   8b7d08               | mov                 edi, dword ptr [ebp + 8]
            //   8b450c               | mov                 eax, dword ptr [ebp + 0xc]
            //   b9ff000000           | mov                 ecx, 0xff
            //   33d2                 | xor                 edx, edx
            //   f7f1                 | div                 ecx

        $sequence_7 = { 56 57 b9f0000000 be???????? 8b4508 }
            // n = 5, score = 1100
            //   56                   | push                esi
            //   57                   | push                edi
            //   b9f0000000           | mov                 ecx, 0xf0
            //   be????????           |                     
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]

        $sequence_8 = { e8???????? 5f 5e 5a 59 5b 5d }
            // n = 7, score = 1100
            //   e8????????           |                     
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5a                   | pop                 edx
            //   59                   | pop                 ecx
            //   5b                   | pop                 ebx
            //   5d                   | pop                 ebp

        $sequence_9 = { 81ea10101010 2d10101010 81eb10101010 81ef10101010 }
            // n = 4, score = 1100
            //   81ea10101010         | sub                 edx, 0x10101010
            //   2d10101010           | sub                 eax, 0x10101010
            //   81eb10101010         | sub                 ebx, 0x10101010
            //   81ef10101010         | sub                 edi, 0x10101010

    condition:
        7 of them and filesize < 286720
}