rule win_deadwood_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.deadwood."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.deadwood"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 51 e8???????? 83c404 33db be0f000000 89b42418010000 899c2414010000 }
            // n = 7, score = 100
            //   51                   | push                ecx
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   33db                 | xor                 ebx, ebx
            //   be0f000000           | mov                 esi, 0xf
            //   89b42418010000       | mov                 dword ptr [esp + 0x118], esi
            //   899c2414010000       | mov                 dword ptr [esp + 0x114], ebx

        $sequence_1 = { 7303 8d4508 8b5518 52 50 8b4110 50 }
            // n = 7, score = 100
            //   7303                 | jae                 5
            //   8d4508               | lea                 eax, [ebp + 8]
            //   8b5518               | mov                 edx, dword ptr [ebp + 0x18]
            //   52                   | push                edx
            //   50                   | push                eax
            //   8b4110               | mov                 eax, dword ptr [ecx + 0x10]
            //   50                   | push                eax

        $sequence_2 = { 7464 8bf0 8b4814 894c2424 3bcb 7504 895c2428 }
            // n = 7, score = 100
            //   7464                 | je                  0x66
            //   8bf0                 | mov                 esi, eax
            //   8b4814               | mov                 ecx, dword ptr [eax + 0x14]
            //   894c2424             | mov                 dword ptr [esp + 0x24], ecx
            //   3bcb                 | cmp                 ecx, ebx
            //   7504                 | jne                 6
            //   895c2428             | mov                 dword ptr [esp + 0x28], ebx

        $sequence_3 = { 6a01 8d442414 50 8d4c243c 897c247c c744241878f44500 e8???????? }
            // n = 7, score = 100
            //   6a01                 | push                1
            //   8d442414             | lea                 eax, [esp + 0x14]
            //   50                   | push                eax
            //   8d4c243c             | lea                 ecx, [esp + 0x3c]
            //   897c247c             | mov                 dword ptr [esp + 0x7c], edi
            //   c744241878f44500     | mov                 dword ptr [esp + 0x18], 0x45f478
            //   e8????????           |                     

        $sequence_4 = { 8bf8 85ff 0f8484000000 53 53 53 53 }
            // n = 7, score = 100
            //   8bf8                 | mov                 edi, eax
            //   85ff                 | test                edi, edi
            //   0f8484000000         | je                  0x8a
            //   53                   | push                ebx
            //   53                   | push                ebx
            //   53                   | push                ebx
            //   53                   | push                ebx

        $sequence_5 = { ff15???????? 6804010000 8d8df4fdffff 51 50 ff15???????? 33d2 }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   6804010000           | push                0x104
            //   8d8df4fdffff         | lea                 ecx, [ebp - 0x20c]
            //   51                   | push                ecx
            //   50                   | push                eax
            //   ff15????????         |                     
            //   33d2                 | xor                 edx, edx

        $sequence_6 = { e8???????? 8b542460 c7442440e4ba4500 bb???????? 895c2454 8b4204 c7440460c8ba4500 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8b542460             | mov                 edx, dword ptr [esp + 0x60]
            //   c7442440e4ba4500     | mov                 dword ptr [esp + 0x40], 0x45bae4
            //   bb????????           |                     
            //   895c2454             | mov                 dword ptr [esp + 0x54], ebx
            //   8b4204               | mov                 eax, dword ptr [edx + 4]
            //   c7440460c8ba4500     | mov                 dword ptr [esp + eax + 0x60], 0x45bac8

        $sequence_7 = { 8b07 8b4804 837c390c00 0f94c1 884dd8 c745fc01000000 84c9 }
            // n = 7, score = 100
            //   8b07                 | mov                 eax, dword ptr [edi]
            //   8b4804               | mov                 ecx, dword ptr [eax + 4]
            //   837c390c00           | cmp                 dword ptr [ecx + edi + 0xc], 0
            //   0f94c1               | sete                cl
            //   884dd8               | mov                 byte ptr [ebp - 0x28], cl
            //   c745fc01000000       | mov                 dword ptr [ebp - 4], 1
            //   84c9                 | test                cl, cl

        $sequence_8 = { 74ed 89450c 8b13 807a1d00 7404 8b3e eb13 }
            // n = 7, score = 100
            //   74ed                 | je                  0xffffffef
            //   89450c               | mov                 dword ptr [ebp + 0xc], eax
            //   8b13                 | mov                 edx, dword ptr [ebx]
            //   807a1d00             | cmp                 byte ptr [edx + 0x1d], 0
            //   7404                 | je                  6
            //   8b3e                 | mov                 edi, dword ptr [esi]
            //   eb13                 | jmp                 0x15

        $sequence_9 = { 8bb510ffffff e9???????? c3 8d8d34ffffff e9???????? 8d8d18ffffff e9???????? }
            // n = 7, score = 100
            //   8bb510ffffff         | mov                 esi, dword ptr [ebp - 0xf0]
            //   e9????????           |                     
            //   c3                   | ret                 
            //   8d8d34ffffff         | lea                 ecx, [ebp - 0xcc]
            //   e9????????           |                     
            //   8d8d18ffffff         | lea                 ecx, [ebp - 0xe8]
            //   e9????????           |                     

    condition:
        7 of them and filesize < 1055744
}