rule win_dented_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.dented."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.dented"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8bf1 e8???????? 83c40c 89bd60ffffff 8d8560ffffff 50 ff15???????? }
            // n = 7, score = 400
            //   8bf1                 | mov                 esi, ecx
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   89bd60ffffff         | mov                 dword ptr [ebp - 0xa0], edi
            //   8d8560ffffff         | lea                 eax, [ebp - 0xa0]
            //   50                   | push                eax
            //   ff15????????         |                     

        $sequence_1 = { 50 51 ebc7 6a0f 33db 5f 897df4 }
            // n = 7, score = 400
            //   50                   | push                eax
            //   51                   | push                ecx
            //   ebc7                 | jmp                 0xffffffc9
            //   6a0f                 | push                0xf
            //   33db                 | xor                 ebx, ebx
            //   5f                   | pop                 edi
            //   897df4               | mov                 dword ptr [ebp - 0xc], edi

        $sequence_2 = { ffd6 ff75fc ffd6 6a00 6a01 8d4d08 e8???????? }
            // n = 7, score = 400
            //   ffd6                 | call                esi
            //   ff75fc               | push                dword ptr [ebp - 4]
            //   ffd6                 | call                esi
            //   6a00                 | push                0
            //   6a01                 | push                1
            //   8d4d08               | lea                 ecx, [ebp + 8]
            //   e8????????           |                     

        $sequence_3 = { ff15???????? 3d0e000780 7422 3d08000c80 741b }
            // n = 5, score = 400
            //   ff15????????         |                     
            //   3d0e000780           | cmp                 eax, 0x8007000e
            //   7422                 | je                  0x24
            //   3d08000c80           | cmp                 eax, 0x800c0008
            //   741b                 | je                  0x1d

        $sequence_4 = { 8985c4fcffff 8d85f4fdffff 6a40 8985c8fcffff 8d85b4fcffff 5e 50 }
            // n = 7, score = 400
            //   8985c4fcffff         | mov                 dword ptr [ebp - 0x33c], eax
            //   8d85f4fdffff         | lea                 eax, [ebp - 0x20c]
            //   6a40                 | push                0x40
            //   8985c8fcffff         | mov                 dword ptr [ebp - 0x338], eax
            //   8d85b4fcffff         | lea                 eax, [ebp - 0x34c]
            //   5e                   | pop                 esi
            //   50                   | push                eax

        $sequence_5 = { 8d4dc0 e8???????? 385dc4 7508 6a04 }
            // n = 5, score = 400
            //   8d4dc0               | lea                 ecx, [ebp - 0x40]
            //   e8????????           |                     
            //   385dc4               | cmp                 byte ptr [ebp - 0x3c], bl
            //   7508                 | jne                 0xa
            //   6a04                 | push                4

        $sequence_6 = { 6a40 5f 57 8d45b8 }
            // n = 4, score = 400
            //   6a40                 | push                0x40
            //   5f                   | pop                 edi
            //   57                   | push                edi
            //   8d45b8               | lea                 eax, [ebp - 0x48]

        $sequence_7 = { 8b85f8f7ffff 8a8485fcfbffff 32c1 880416 8b8decf7ffff }
            // n = 5, score = 400
            //   8b85f8f7ffff         | mov                 eax, dword ptr [ebp - 0x808]
            //   8a8485fcfbffff       | mov                 al, byte ptr [ebp + eax*4 - 0x404]
            //   32c1                 | xor                 al, cl
            //   880416               | mov                 byte ptr [esi + edx], al
            //   8b8decf7ffff         | mov                 ecx, dword ptr [ebp - 0x814]

        $sequence_8 = { 48 0d00ffffff 40 8a0a 8985f8f7ffff 8bbdf8f7ffff 0fb6c1 }
            // n = 7, score = 400
            //   48                   | dec                 eax
            //   0d00ffffff           | or                  eax, 0xffffff00
            //   40                   | inc                 eax
            //   8a0a                 | mov                 cl, byte ptr [edx]
            //   8985f8f7ffff         | mov                 dword ptr [ebp - 0x808], eax
            //   8bbdf8f7ffff         | mov                 edi, dword ptr [ebp - 0x808]
            //   0fb6c1               | movzx               eax, cl

        $sequence_9 = { 8b4a38 3b08 6a0f 0f4208 33db 8b4210 }
            // n = 6, score = 400
            //   8b4a38               | mov                 ecx, dword ptr [edx + 0x38]
            //   3b08                 | cmp                 ecx, dword ptr [eax]
            //   6a0f                 | push                0xf
            //   0f4208               | cmovb               ecx, dword ptr [eax]
            //   33db                 | xor                 ebx, ebx
            //   8b4210               | mov                 eax, dword ptr [edx + 0x10]

    condition:
        7 of them and filesize < 450560
}