rule win_deputydog_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.deputydog."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.deputydog"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 51 56 8bf1 8b461c 8d4e18 ff30 8d45fc }
            // n = 7, score = 100
            //   51                   | push                ecx
            //   56                   | push                esi
            //   8bf1                 | mov                 esi, ecx
            //   8b461c               | mov                 eax, dword ptr [esi + 0x1c]
            //   8d4e18               | lea                 ecx, [esi + 0x18]
            //   ff30                 | push                dword ptr [eax]
            //   8d45fc               | lea                 eax, [ebp - 4]

        $sequence_1 = { 85ff 7407 8b5510 8a12 8817 }
            // n = 5, score = 100
            //   85ff                 | test                edi, edi
            //   7407                 | je                  9
            //   8b5510               | mov                 edx, dword ptr [ebp + 0x10]
            //   8a12                 | mov                 dl, byte ptr [edx]
            //   8817                 | mov                 byte ptr [edi], dl

        $sequence_2 = { 53 8d4de0 ff15???????? 807df300 7509 }
            // n = 5, score = 100
            //   53                   | push                ebx
            //   8d4de0               | lea                 ecx, [ebp - 0x20]
            //   ff15????????         |                     
            //   807df300             | cmp                 byte ptr [ebp - 0xd], 0
            //   7509                 | jne                 0xb

        $sequence_3 = { 57 56 e8???????? 83c40c 8d4604 c60664 50 }
            // n = 7, score = 100
            //   57                   | push                edi
            //   56                   | push                esi
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   8d4604               | lea                 eax, [esi + 4]
            //   c60664               | mov                 byte ptr [esi], 0x64
            //   50                   | push                eax

        $sequence_4 = { 8d4580 50 e8???????? 8b4004 59 3bc3 59 }
            // n = 7, score = 100
            //   8d4580               | lea                 eax, [ebp - 0x80]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b4004               | mov                 eax, dword ptr [eax + 4]
            //   59                   | pop                 ecx
            //   3bc3                 | cmp                 eax, ebx
            //   59                   | pop                 ecx

        $sequence_5 = { 6a00 56 ff7604 50 ff15???????? 8365f000 6800200000 }
            // n = 7, score = 100
            //   6a00                 | push                0
            //   56                   | push                esi
            //   ff7604               | push                dword ptr [esi + 4]
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8365f000             | and                 dword ptr [ebp - 0x10], 0
            //   6800200000           | push                0x2000

        $sequence_6 = { 8b7e08 8d1419 397d08 7417 8bc2 2bc1 2bc3 }
            // n = 7, score = 100
            //   8b7e08               | mov                 edi, dword ptr [esi + 8]
            //   8d1419               | lea                 edx, [ecx + ebx]
            //   397d08               | cmp                 dword ptr [ebp + 8], edi
            //   7417                 | je                  0x19
            //   8bc2                 | mov                 eax, edx
            //   2bc1                 | sub                 eax, ecx
            //   2bc3                 | sub                 eax, ebx

        $sequence_7 = { 8b4d0c 57 ff30 6a00 ff15???????? 8b7d08 8b4f04 }
            // n = 7, score = 100
            //   8b4d0c               | mov                 ecx, dword ptr [ebp + 0xc]
            //   57                   | push                edi
            //   ff30                 | push                dword ptr [eax]
            //   6a00                 | push                0
            //   ff15????????         |                     
            //   8b7d08               | mov                 edi, dword ptr [ebp + 8]
            //   8b4f04               | mov                 ecx, dword ptr [edi + 4]

        $sequence_8 = { 53 51 ff75e4 50 ff7618 ff15???????? 8b3d???????? }
            // n = 7, score = 100
            //   53                   | push                ebx
            //   51                   | push                ecx
            //   ff75e4               | push                dword ptr [ebp - 0x1c]
            //   50                   | push                eax
            //   ff7618               | push                dword ptr [esi + 0x18]
            //   ff15????????         |                     
            //   8b3d????????         |                     

        $sequence_9 = { 57 50 ff15???????? 59 84c0 59 740b }
            // n = 7, score = 100
            //   57                   | push                edi
            //   50                   | push                eax
            //   ff15????????         |                     
            //   59                   | pop                 ecx
            //   84c0                 | test                al, al
            //   59                   | pop                 ecx
            //   740b                 | je                  0xd

    condition:
        7 of them and filesize < 90112
}