rule win_dircrypt_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.dircrypt."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.dircrypt"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 7531 c705????????01000000 e8???????? e8???????? 833d????????00 7514 68???????? }
            // n = 7, score = 900
            //   7531                 | jne                 0x33
            //   c705????????01000000     |     
            //   e8????????           |                     
            //   e8????????           |                     
            //   833d????????00       |                     
            //   7514                 | jne                 0x16
            //   68????????           |                     

        $sequence_1 = { e8???????? e8???????? 68???????? ff15???????? 833d????????00 751a }
            // n = 6, score = 900
            //   e8????????           |                     
            //   e8????????           |                     
            //   68????????           |                     
            //   ff15????????         |                     
            //   833d????????00       |                     
            //   751a                 | jne                 0x1c

        $sequence_2 = { 68???????? e8???????? 05d2070000 50 e8???????? a3???????? 6a13 }
            // n = 7, score = 900
            //   68????????           |                     
            //   e8????????           |                     
            //   05d2070000           | add                 eax, 0x7d2
            //   50                   | push                eax
            //   e8????????           |                     
            //   a3????????           |                     
            //   6a13                 | push                0x13

        $sequence_3 = { 8bec 51 6a00 6a00 8d45fc 50 68???????? }
            // n = 7, score = 900
            //   8bec                 | mov                 ebp, esp
            //   51                   | push                ecx
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   8d45fc               | lea                 eax, [ebp - 4]
            //   50                   | push                eax
            //   68????????           |                     

        $sequence_4 = { 68???????? 8d45dc 50 e8???????? 6a00 e8???????? }
            // n = 6, score = 900
            //   68????????           |                     
            //   8d45dc               | lea                 eax, [ebp - 0x24]
            //   50                   | push                eax
            //   e8????????           |                     
            //   6a00                 | push                0
            //   e8????????           |                     

        $sequence_5 = { 6801000080 e8???????? e8???????? e8???????? e8???????? }
            // n = 5, score = 900
            //   6801000080           | push                0x80000001
            //   e8????????           |                     
            //   e8????????           |                     
            //   e8????????           |                     
            //   e8????????           |                     

        $sequence_6 = { e8???????? 05d5070000 50 6a01 6a02 6a08 }
            // n = 6, score = 900
            //   e8????????           |                     
            //   05d5070000           | add                 eax, 0x7d5
            //   50                   | push                eax
            //   6a01                 | push                1
            //   6a02                 | push                2
            //   6a08                 | push                8

        $sequence_7 = { 68???????? 8d45dc 50 e8???????? 6a00 e8???????? 05d6070000 }
            // n = 7, score = 900
            //   68????????           |                     
            //   8d45dc               | lea                 eax, [ebp - 0x24]
            //   50                   | push                eax
            //   e8????????           |                     
            //   6a00                 | push                0
            //   e8????????           |                     
            //   05d6070000           | add                 eax, 0x7d6

        $sequence_8 = { 833d????????00 7514 68???????? 68???????? e8???????? a3???????? 833d????????00 }
            // n = 7, score = 900
            //   833d????????00       |                     
            //   7514                 | jne                 0x16
            //   68????????           |                     
            //   68????????           |                     
            //   e8????????           |                     
            //   a3????????           |                     
            //   833d????????00       |                     

        $sequence_9 = { 51 6a00 6a00 8d45fc 50 68???????? 6802000080 }
            // n = 7, score = 900
            //   51                   | push                ecx
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   8d45fc               | lea                 eax, [ebp - 4]
            //   50                   | push                eax
            //   68????????           |                     
            //   6802000080           | push                0x80000002

    condition:
        7 of them and filesize < 671744
}