rule win_disk_knight_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.disk_knight."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.disk_knight"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 897d8c 897d88 ff15???????? 8b1d???????? 8d4dc4 51 }
            // n = 6, score = 100
            //   897d8c               | mov                 dword ptr [ebp - 0x74], edi
            //   897d88               | mov                 dword ptr [ebp - 0x78], edi
            //   ff15????????         |                     
            //   8b1d????????         |                     
            //   8d4dc4               | lea                 ecx, [ebp - 0x3c]
            //   51                   | push                ecx

        $sequence_1 = { c745f0e01b4000 33c0 8945f4 8945f8 8845e0 6a01 ff15???????? }
            // n = 7, score = 100
            //   c745f0e01b4000       | mov                 dword ptr [ebp - 0x10], 0x401be0
            //   33c0                 | xor                 eax, eax
            //   8945f4               | mov                 dword ptr [ebp - 0xc], eax
            //   8945f8               | mov                 dword ptr [ebp - 8], eax
            //   8845e0               | mov                 byte ptr [ebp - 0x20], al
            //   6a01                 | push                1
            //   ff15????????         |                     

        $sequence_2 = { ff15???????? f7d8 1bc0 23f0 8d45b0 50 8d4dc0 }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   f7d8                 | neg                 eax
            //   1bc0                 | sbb                 eax, eax
            //   23f0                 | and                 esi, eax
            //   8d45b0               | lea                 eax, [ebp - 0x50]
            //   50                   | push                eax
            //   8d4dc0               | lea                 ecx, [ebp - 0x40]

        $sequence_3 = { 8d8d7cffffff 51 56 ff5220 dbe2 85c0 7d0f }
            // n = 7, score = 100
            //   8d8d7cffffff         | lea                 ecx, [ebp - 0x84]
            //   51                   | push                ecx
            //   56                   | push                esi
            //   ff5220               | call                dword ptr [edx + 0x20]
            //   dbe2                 | fnclex              
            //   85c0                 | test                eax, eax
            //   7d0f                 | jge                 0x11

        $sequence_4 = { 8b4710 8d5594 52 50 8b08 ff9138010000 85c0 }
            // n = 7, score = 100
            //   8b4710               | mov                 eax, dword ptr [edi + 0x10]
            //   8d5594               | lea                 edx, [ebp - 0x6c]
            //   52                   | push                edx
            //   50                   | push                eax
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   ff9138010000         | call                dword ptr [ecx + 0x138]
            //   85c0                 | test                eax, eax

        $sequence_5 = { 895004 8b8d48ffffff 894808 8b954cffffff 89500c 8b85e0feffff 8b08 }
            // n = 7, score = 100
            //   895004               | mov                 dword ptr [eax + 4], edx
            //   8b8d48ffffff         | mov                 ecx, dword ptr [ebp - 0xb8]
            //   894808               | mov                 dword ptr [eax + 8], ecx
            //   8b954cffffff         | mov                 edx, dword ptr [ebp - 0xb4]
            //   89500c               | mov                 dword ptr [eax + 0xc], edx
            //   8b85e0feffff         | mov                 eax, dword ptr [ebp - 0x120]
            //   8b08                 | mov                 ecx, dword ptr [eax]

        $sequence_6 = { 3bc8 7d7d 8d9574ffffff 52 6a01 56 e8???????? }
            // n = 7, score = 100
            //   3bc8                 | cmp                 ecx, eax
            //   7d7d                 | jge                 0x7f
            //   8d9574ffffff         | lea                 edx, [ebp - 0x8c]
            //   52                   | push                edx
            //   6a01                 | push                1
            //   56                   | push                esi
            //   e8????????           |                     

        $sequence_7 = { ff15???????? 8b3d???????? 83c40c 85f6 0f84d1010000 a1???????? 85c0 }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   8b3d????????         |                     
            //   83c40c               | add                 esp, 0xc
            //   85f6                 | test                esi, esi
            //   0f84d1010000         | je                  0x1d7
            //   a1????????           |                     
            //   85c0                 | test                eax, eax

        $sequence_8 = { e8???????? 8bf0 ff15???????? 8d54240c 8d8424a0000000 52 50 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax
            //   ff15????????         |                     
            //   8d54240c             | lea                 edx, [esp + 0xc]
            //   8d8424a0000000       | lea                 eax, [esp + 0xa0]
            //   52                   | push                edx
            //   50                   | push                eax

        $sequence_9 = { 8b45d0 0f80ea060000 69db00010000 99 0f80dd060000 2bc2 899d10ffffff }
            // n = 7, score = 100
            //   8b45d0               | mov                 eax, dword ptr [ebp - 0x30]
            //   0f80ea060000         | jo                  0x6f0
            //   69db00010000         | imul                ebx, ebx, 0x100
            //   99                   | cdq                 
            //   0f80dd060000         | jo                  0x6e3
            //   2bc2                 | sub                 eax, edx
            //   899d10ffffff         | mov                 dword ptr [ebp - 0xf0], ebx

    condition:
        7 of them and filesize < 868352
}