rule win_dma_locker_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.dma_locker."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.dma_locker"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 8bf0 eb02 33f6 6803010000 8d8c24a1040000 }
            // n = 6, score = 200
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax
            //   eb02                 | jmp                 4
            //   33f6                 | xor                 esi, esi
            //   6803010000           | push                0x103
            //   8d8c24a1040000       | lea                 ecx, [esp + 0x4a1]

        $sequence_1 = { 57 56 e8???????? 83c40c 84db }
            // n = 5, score = 200
            //   57                   | push                edi
            //   56                   | push                esi
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   84db                 | test                bl, bl

        $sequence_2 = { 8bc7 e8???????? 84c0 741f 8b4f10 8b13 57 }
            // n = 7, score = 200
            //   8bc7                 | mov                 eax, edi
            //   e8????????           |                     
            //   84c0                 | test                al, al
            //   741f                 | je                  0x21
            //   8b4f10               | mov                 ecx, dword ptr [edi + 0x10]
            //   8b13                 | mov                 edx, dword ptr [ebx]
            //   57                   | push                edi

        $sequence_3 = { 8a5dfd 32ca 8a55fc 32cb 8848ff 8aca }
            // n = 6, score = 200
            //   8a5dfd               | mov                 bl, byte ptr [ebp - 3]
            //   32ca                 | xor                 cl, dl
            //   8a55fc               | mov                 dl, byte ptr [ebp - 4]
            //   32cb                 | xor                 cl, bl
            //   8848ff               | mov                 byte ptr [eax - 1], cl
            //   8aca                 | mov                 cl, dl

        $sequence_4 = { 8b5e04 8b0e 8945ec 8b55ec }
            // n = 4, score = 200
            //   8b5e04               | mov                 ebx, dword ptr [esi + 4]
            //   8b0e                 | mov                 ecx, dword ptr [esi]
            //   8945ec               | mov                 dword ptr [ebp - 0x14], eax
            //   8b55ec               | mov                 edx, dword ptr [ebp - 0x14]

        $sequence_5 = { ffd7 85c0 7fe3 5f }
            // n = 4, score = 200
            //   ffd7                 | call                edi
            //   85c0                 | test                eax, eax
            //   7fe3                 | jg                  0xffffffe5
            //   5f                   | pop                 edi

        $sequence_6 = { e8???????? 8b442420 8b00 83c40c 8d4c2424 51 }
            // n = 6, score = 200
            //   e8????????           |                     
            //   8b442420             | mov                 eax, dword ptr [esp + 0x20]
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   83c40c               | add                 esp, 0xc
            //   8d4c2424             | lea                 ecx, [esp + 0x24]
            //   51                   | push                ecx

        $sequence_7 = { 52 ff15???????? a1???????? 6a00 50 ff15???????? e9???????? }
            // n = 7, score = 200
            //   52                   | push                edx
            //   ff15????????         |                     
            //   a1????????           |                     
            //   6a00                 | push                0
            //   50                   | push                eax
            //   ff15????????         |                     
            //   e9????????           |                     

        $sequence_8 = { 7545 68???????? e8???????? 8b95b0f6ffff 83c404 52 ff15???????? }
            // n = 7, score = 200
            //   7545                 | jne                 0x47
            //   68????????           |                     
            //   e8????????           |                     
            //   8b95b0f6ffff         | mov                 edx, dword ptr [ebp - 0x950]
            //   83c404               | add                 esp, 4
            //   52                   | push                edx
            //   ff15????????         |                     

        $sequence_9 = { 385e14 0f85e8000000 8b4618 83f8ff 7407 50 ff15???????? }
            // n = 7, score = 200
            //   385e14               | cmp                 byte ptr [esi + 0x14], bl
            //   0f85e8000000         | jne                 0xee
            //   8b4618               | mov                 eax, dword ptr [esi + 0x18]
            //   83f8ff               | cmp                 eax, -1
            //   7407                 | je                  9
            //   50                   | push                eax
            //   ff15????????         |                     

    condition:
        7 of them and filesize < 532480
}