rule win_dmsniff_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.dmsniff."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.dmsniff"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 83c661 89f3 881d???????? 8d04bf }
            // n = 4, score = 500
            //   83c661               | add                 esi, 0x61
            //   89f3                 | mov                 ebx, esi
            //   881d????????         |                     
            //   8d04bf               | lea                 eax, [edi + edi*4]

        $sequence_1 = { 50 d93c24 66810c240003 d92c24 83c404 6a00 6a00 }
            // n = 7, score = 500
            //   50                   | push                eax
            //   d93c24               | fnstcw              word ptr [esp]
            //   66810c240003         | or                  word ptr [esp], 0x300
            //   d92c24               | fldcw               word ptr [esp]
            //   83c404               | add                 esp, 4
            //   6a00                 | push                0
            //   6a00                 | push                0

        $sequence_2 = { 53 56 57 8b5d0c 8b7510 }
            // n = 5, score = 500
            //   53                   | push                ebx
            //   56                   | push                esi
            //   57                   | push                edi
            //   8b5d0c               | mov                 ebx, dword ptr [ebp + 0xc]
            //   8b7510               | mov                 esi, dword ptr [ebp + 0x10]

        $sequence_3 = { 89fe 46 89b5fcfeffff 899cbd00ffffff 8d85f0feffff 50 6a00 }
            // n = 7, score = 500
            //   89fe                 | mov                 esi, edi
            //   46                   | inc                 esi
            //   89b5fcfeffff         | mov                 dword ptr [ebp - 0x104], esi
            //   899cbd00ffffff       | mov                 dword ptr [ebp + edi*4 - 0x100], ebx
            //   8d85f0feffff         | lea                 eax, [ebp - 0x110]
            //   50                   | push                eax
            //   6a00                 | push                0

        $sequence_4 = { eb15 47 39f7 72d3 ff45fc 8b45f4 3945fc }
            // n = 7, score = 500
            //   eb15                 | jmp                 0x17
            //   47                   | inc                 edi
            //   39f7                 | cmp                 edi, esi
            //   72d3                 | jb                  0xffffffd5
            //   ff45fc               | inc                 dword ptr [ebp - 4]
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]
            //   3945fc               | cmp                 dword ptr [ebp - 4], eax

        $sequence_5 = { 56 57 8965e8 50 d93c24 }
            // n = 5, score = 500
            //   56                   | push                esi
            //   57                   | push                edi
            //   8965e8               | mov                 dword ptr [ebp - 0x18], esp
            //   50                   | push                eax
            //   d93c24               | fnstcw              word ptr [esp]

        $sequence_6 = { eb18 68???????? e8???????? 50 68???????? e8???????? 83c40c }
            // n = 7, score = 500
            //   eb18                 | jmp                 0x1a
            //   68????????           |                     
            //   e8????????           |                     
            //   50                   | push                eax
            //   68????????           |                     
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc

        $sequence_7 = { e8???????? 50 68???????? e8???????? 83c40c eb18 }
            // n = 6, score = 500
            //   e8????????           |                     
            //   50                   | push                eax
            //   68????????           |                     
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   eb18                 | jmp                 0x1a

        $sequence_8 = { e8???????? 83c40c eb18 68???????? e8???????? 50 }
            // n = 6, score = 500
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   eb18                 | jmp                 0x1a
            //   68????????           |                     
            //   e8????????           |                     
            //   50                   | push                eax

        $sequence_9 = { 7316 8bbdfcfeffff 89fe 46 89b5fcfeffff 899cbd00ffffff }
            // n = 6, score = 500
            //   7316                 | jae                 0x18
            //   8bbdfcfeffff         | mov                 edi, dword ptr [ebp - 0x104]
            //   89fe                 | mov                 esi, edi
            //   46                   | inc                 esi
            //   89b5fcfeffff         | mov                 dword ptr [ebp - 0x104], esi
            //   899cbd00ffffff       | mov                 dword ptr [ebp + edi*4 - 0x100], ebx

    condition:
        7 of them and filesize < 131072
}