rule win_dubrute_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.dubrute."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.dubrute"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d45dc dd5de4 50 c645fc0d ff15???????? 8d4df0 c645fc08 }
            // n = 7, score = 100
            //   8d45dc               | lea                 eax, [ebp - 0x24]
            //   dd5de4               | fstp                qword ptr [ebp - 0x1c]
            //   50                   | push                eax
            //   c645fc0d             | mov                 byte ptr [ebp - 4], 0xd
            //   ff15????????         |                     
            //   8d4df0               | lea                 ecx, [ebp - 0x10]
            //   c645fc08             | mov                 byte ptr [ebp - 4], 8

        $sequence_1 = { 83c410 83f8ff 743b 85c0 741c 03f0 56 }
            // n = 7, score = 100
            //   83c410               | add                 esp, 0x10
            //   83f8ff               | cmp                 eax, -1
            //   743b                 | je                  0x3d
            //   85c0                 | test                eax, eax
            //   741c                 | je                  0x1e
            //   03f0                 | add                 esi, eax
            //   56                   | push                esi

        $sequence_2 = { 83e906 7426 49 741a 49 740e 49 }
            // n = 7, score = 100
            //   83e906               | sub                 ecx, 6
            //   7426                 | je                  0x28
            //   49                   | dec                 ecx
            //   741a                 | je                  0x1c
            //   49                   | dec                 ecx
            //   740e                 | je                  0x10
            //   49                   | dec                 ecx

        $sequence_3 = { 7427 48 7413 48 48 7551 57 }
            // n = 7, score = 100
            //   7427                 | je                  0x29
            //   48                   | dec                 eax
            //   7413                 | je                  0x15
            //   48                   | dec                 eax
            //   48                   | dec                 eax
            //   7551                 | jne                 0x53
            //   57                   | push                edi

        $sequence_4 = { 5e 5d c3 8b4c2408 81f9ff000000 7e1b 8b442404 }
            // n = 7, score = 100
            //   5e                   | pop                 esi
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   8b4c2408             | mov                 ecx, dword ptr [esp + 8]
            //   81f9ff000000         | cmp                 ecx, 0xff
            //   7e1b                 | jle                 0x1d
            //   8b442404             | mov                 eax, dword ptr [esp + 4]

        $sequence_5 = { e8???????? 83c410 ff866c090000 5e c3 55 8bec }
            // n = 7, score = 100
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10
            //   ff866c090000         | inc                 dword ptr [esi + 0x96c]
            //   5e                   | pop                 esi
            //   c3                   | ret                 
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp

        $sequence_6 = { 7520 8b06 8b4018 8b00 ff30 e8???????? 6a06 }
            // n = 7, score = 100
            //   7520                 | jne                 0x22
            //   8b06                 | mov                 eax, dword ptr [esi]
            //   8b4018               | mov                 eax, dword ptr [eax + 0x18]
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   ff30                 | push                dword ptr [eax]
            //   e8????????           |                     
            //   6a06                 | push                6

        $sequence_7 = { 57 53 ff15???????? 8b3d???????? 8325????????00 8b37 3bf7 }
            // n = 7, score = 100
            //   57                   | push                edi
            //   53                   | push                ebx
            //   ff15????????         |                     
            //   8b3d????????         |                     
            //   8325????????00       |                     
            //   8b37                 | mov                 esi, dword ptr [edi]
            //   3bf7                 | cmp                 esi, edi

        $sequence_8 = { 56 53 68???????? e8???????? 83c40c 837d1400 }
            // n = 6, score = 100
            //   56                   | push                esi
            //   53                   | push                ebx
            //   68????????           |                     
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   837d1400             | cmp                 dword ptr [ebp + 0x14], 0

        $sequence_9 = { 8a48ff 884e01 83c603 837df000 7fd4 e9???????? f745f0f8ffffff }
            // n = 7, score = 100
            //   8a48ff               | mov                 cl, byte ptr [eax - 1]
            //   884e01               | mov                 byte ptr [esi + 1], cl
            //   83c603               | add                 esi, 3
            //   837df000             | cmp                 dword ptr [ebp - 0x10], 0
            //   7fd4                 | jg                  0xffffffd6
            //   e9????????           |                     
            //   f745f0f8ffffff       | test                dword ptr [ebp - 0x10], 0xfffffff8

    condition:
        7 of them and filesize < 598016
}