rule win_ehdevel_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.ehdevel."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.ehdevel"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 51 e8???????? e9???????? 33d2 68fe070000 52 8d85feefffff }
            // n = 7, score = 100
            //   51                   | push                ecx
            //   e8????????           |                     
            //   e9????????           |                     
            //   33d2                 | xor                 edx, edx
            //   68fe070000           | push                0x7fe
            //   52                   | push                edx
            //   8d85feefffff         | lea                 eax, [ebp - 0x1002]

        $sequence_1 = { 7545 56 c70303000000 ff15???????? 56 ff15???????? 68???????? }
            // n = 7, score = 100
            //   7545                 | jne                 0x47
            //   56                   | push                esi
            //   c70303000000         | mov                 dword ptr [ebx], 3
            //   ff15????????         |                     
            //   56                   | push                esi
            //   ff15????????         |                     
            //   68????????           |                     

        $sequence_2 = { 8d8dcce7ffff 51 6a00 6813000020 56 c785cce7ffff00000000 c785c8e7ffff04000000 }
            // n = 7, score = 100
            //   8d8dcce7ffff         | lea                 ecx, [ebp - 0x1834]
            //   51                   | push                ecx
            //   6a00                 | push                0
            //   6813000020           | push                0x20000013
            //   56                   | push                esi
            //   c785cce7ffff00000000     | mov    dword ptr [ebp - 0x1834], 0
            //   c785c8e7ffff04000000     | mov    dword ptr [ebp - 0x1838], 4

        $sequence_3 = { 8d85f0e7ffff 50 56 6a00 6a10 6a02 ff15???????? }
            // n = 7, score = 100
            //   8d85f0e7ffff         | lea                 eax, [ebp - 0x1810]
            //   50                   | push                eax
            //   56                   | push                esi
            //   6a00                 | push                0
            //   6a10                 | push                0x10
            //   6a02                 | push                2
            //   ff15????????         |                     

        $sequence_4 = { e8???????? 83c404 33c9 6a08 b8???????? }
            // n = 5, score = 100
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   33c9                 | xor                 ecx, ecx
            //   6a08                 | push                8
            //   b8????????           |                     

        $sequence_5 = { 8d8dd4e5ffff 51 8d95f8f7ffff 6800040000 52 e8???????? }
            // n = 6, score = 100
            //   8d8dd4e5ffff         | lea                 ecx, [ebp - 0x1a2c]
            //   51                   | push                ecx
            //   8d95f8f7ffff         | lea                 edx, [ebp - 0x808]
            //   6800040000           | push                0x400
            //   52                   | push                edx
            //   e8????????           |                     

        $sequence_6 = { 83c410 8b4d0c 8d442408 50 51 }
            // n = 5, score = 100
            //   83c410               | add                 esp, 0x10
            //   8b4d0c               | mov                 ecx, dword ptr [ebp + 0xc]
            //   8d442408             | lea                 eax, [esp + 8]
            //   50                   | push                eax
            //   51                   | push                ecx

        $sequence_7 = { 83d8ff 85c0 0f84cffdffff 68???????? 6800040000 57 e8???????? }
            // n = 7, score = 100
            //   83d8ff               | sbb                 eax, -1
            //   85c0                 | test                eax, eax
            //   0f84cffdffff         | je                  0xfffffdd5
            //   68????????           |                     
            //   6800040000           | push                0x400
            //   57                   | push                edi
            //   e8????????           |                     

        $sequence_8 = { 50 e8???????? 8d8c24d4190000 51 8d9424d8010000 6800040000 52 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   e8????????           |                     
            //   8d8c24d4190000       | lea                 ecx, [esp + 0x19d4]
            //   51                   | push                ecx
            //   8d9424d8010000       | lea                 edx, [esp + 0x1d8]
            //   6800040000           | push                0x400
            //   52                   | push                edx

        $sequence_9 = { 8db564f7ffff e8???????? 33d2 899de8f7ffff 89bde4f7ffff 668995d4f7ffff 33c0 }
            // n = 7, score = 100
            //   8db564f7ffff         | lea                 esi, [ebp - 0x89c]
            //   e8????????           |                     
            //   33d2                 | xor                 edx, edx
            //   899de8f7ffff         | mov                 dword ptr [ebp - 0x818], ebx
            //   89bde4f7ffff         | mov                 dword ptr [ebp - 0x81c], edi
            //   668995d4f7ffff       | mov                 word ptr [ebp - 0x82c], dx
            //   33c0                 | xor                 eax, eax

    condition:
        7 of them and filesize < 524288
}