rule win_eternal_petya_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.eternal_petya."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.eternal_petya"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 55 8bec 51 57 68000000f0 }
            // n = 5, score = 400
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   51                   | push                ecx
            //   57                   | push                edi
            //   68000000f0           | push                0xf0000000

        $sequence_1 = { 53 8d4644 50 53 }
            // n = 4, score = 400
            //   53                   | push                ebx
            //   8d4644               | lea                 eax, [esi + 0x44]
            //   50                   | push                eax
            //   53                   | push                ebx

        $sequence_2 = { 57 68000000f0 6a18 33ff }
            // n = 4, score = 400
            //   57                   | push                edi
            //   68000000f0           | push                0xf0000000
            //   6a18                 | push                0x18
            //   33ff                 | xor                 edi, edi

        $sequence_3 = { 53 6a21 8d460c 50 }
            // n = 4, score = 400
            //   53                   | push                ebx
            //   6a21                 | push                0x21
            //   8d460c               | lea                 eax, [esi + 0xc]
            //   50                   | push                eax

        $sequence_4 = { 68f0000000 6a40 ff15???????? 8bd8 }
            // n = 4, score = 400
            //   68f0000000           | push                0xf0
            //   6a40                 | push                0x40
            //   ff15????????         |                     
            //   8bd8                 | mov                 ebx, eax

        $sequence_5 = { 49 75f2 8b4364 034360 8b4b68 894dd4 }
            // n = 6, score = 300
            //   49                   | dec                 ecx
            //   75f2                 | jne                 0xfffffff4
            //   8b4364               | mov                 eax, dword ptr [ebx + 0x64]
            //   034360               | add                 eax, dword ptr [ebx + 0x60]
            //   8b4b68               | mov                 ecx, dword ptr [ebx + 0x68]
            //   894dd4               | mov                 dword ptr [ebp - 0x2c], ecx

        $sequence_6 = { 8945d0 8bc7 8b7df8 d3e8 8b4de0 03c1 8d3c87 }
            // n = 7, score = 300
            //   8945d0               | mov                 dword ptr [ebp - 0x30], eax
            //   8bc7                 | mov                 eax, edi
            //   8b7df8               | mov                 edi, dword ptr [ebp - 8]
            //   d3e8                 | shr                 eax, cl
            //   8b4de0               | mov                 ecx, dword ptr [ebp - 0x20]
            //   03c1                 | add                 eax, ecx
            //   8d3c87               | lea                 edi, [edi + eax*4]

        $sequence_7 = { 55 8bec 8b4d0c baff000000 }
            // n = 4, score = 300
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   8b4d0c               | mov                 ecx, dword ptr [ebp + 0xc]
            //   baff000000           | mov                 edx, 0xff

        $sequence_8 = { 8d4508 50 53 ff750c 897508 }
            // n = 5, score = 300
            //   8d4508               | lea                 eax, [ebp + 8]
            //   50                   | push                eax
            //   53                   | push                ebx
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   897508               | mov                 dword ptr [ebp + 8], esi

        $sequence_9 = { 68???????? e8???????? 85c0 7403 83ce02 }
            // n = 5, score = 300
            //   68????????           |                     
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   7403                 | je                  5
            //   83ce02               | or                  esi, 2

        $sequence_10 = { 68e8030000 ff15???????? 3bfe 75d3 }
            // n = 4, score = 300
            //   68e8030000           | push                0x3e8
            //   ff15????????         |                     
            //   3bfe                 | cmp                 edi, esi
            //   75d3                 | jne                 0xffffffd5

        $sequence_11 = { 55 8bec 8b5508 53 56 57 8b721c }
            // n = 7, score = 300
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]
            //   53                   | push                ebx
            //   56                   | push                esi
            //   57                   | push                edi
            //   8b721c               | mov                 esi, dword ptr [edx + 0x1c]

        $sequence_12 = { 8b07 85c0 75c3 8b75f4 }
            // n = 4, score = 300
            //   8b07                 | mov                 eax, dword ptr [edi]
            //   85c0                 | test                eax, eax
            //   75c3                 | jne                 0xffffffc5
            //   8b75f4               | mov                 esi, dword ptr [ebp - 0xc]

        $sequence_13 = { e8???????? 894610 895614 8bc6 5f 5e }
            // n = 6, score = 200
            //   e8????????           |                     
            //   894610               | mov                 dword ptr [esi + 0x10], eax
            //   895614               | mov                 dword ptr [esi + 0x14], edx
            //   8bc6                 | mov                 eax, esi
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi

        $sequence_14 = { 898502fcffff 8b85e8fbffff 99 81e2ff010000 }
            // n = 4, score = 200
            //   898502fcffff         | mov                 dword ptr [ebp - 0x3fe], eax
            //   8b85e8fbffff         | mov                 eax, dword ptr [ebp - 0x418]
            //   99                   | cdq                 
            //   81e2ff010000         | and                 edx, 0x1ff

        $sequence_15 = { 56 51 ffd3 8b15???????? 56 52 8985f0fbffff }
            // n = 7, score = 200
            //   56                   | push                esi
            //   51                   | push                ecx
            //   ffd3                 | call                ebx
            //   8b15????????         |                     
            //   56                   | push                esi
            //   52                   | push                edx
            //   8985f0fbffff         | mov                 dword ptr [ebp - 0x410], eax

    condition:
        7 of them and filesize < 851968
}