rule win_evilbunny_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.evilbunny."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.evilbunny"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b4dec 8b5104 8b45ec 8b4804 8b12 8bf4 51 }
            // n = 7, score = 200
            //   8b4dec               | mov                 ecx, dword ptr [ebp - 0x14]
            //   8b5104               | mov                 edx, dword ptr [ecx + 4]
            //   8b45ec               | mov                 eax, dword ptr [ebp - 0x14]
            //   8b4804               | mov                 ecx, dword ptr [eax + 4]
            //   8b12                 | mov                 edx, dword ptr [edx]
            //   8bf4                 | mov                 esi, esp
            //   51                   | push                ecx

        $sequence_1 = { eb09 8b450c 8b80b0d91a00 3bf0 7e44 83ee07 eb3f }
            // n = 7, score = 200
            //   eb09                 | jmp                 0xb
            //   8b450c               | mov                 eax, dword ptr [ebp + 0xc]
            //   8b80b0d91a00         | mov                 eax, dword ptr [eax + 0x1ad9b0]
            //   3bf0                 | cmp                 esi, eax
            //   7e44                 | jle                 0x46
            //   83ee07               | sub                 esi, 7
            //   eb3f                 | jmp                 0x41

        $sequence_2 = { c1e104 8b5508 8b4220 8d4c08f0 8b5508 894a1c 8b4508 }
            // n = 7, score = 200
            //   c1e104               | shl                 ecx, 4
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]
            //   8b4220               | mov                 eax, dword ptr [edx + 0x20]
            //   8d4c08f0             | lea                 ecx, [eax + ecx - 0x10]
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]
            //   894a1c               | mov                 dword ptr [edx + 0x1c], ecx
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]

        $sequence_3 = { 8b4df8 51 e8???????? 83c404 83c028 50 6a00 }
            // n = 7, score = 200
            //   8b4df8               | mov                 ecx, dword ptr [ebp - 8]
            //   51                   | push                ecx
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   83c028               | add                 eax, 0x28
            //   50                   | push                eax
            //   6a00                 | push                0

        $sequence_4 = { e8???????? 83c40c 8b55f8 8b4204 50 68???????? 8b4d08 }
            // n = 7, score = 200
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   8b55f8               | mov                 edx, dword ptr [ebp - 8]
            //   8b4204               | mov                 eax, dword ptr [edx + 4]
            //   50                   | push                eax
            //   68????????           |                     
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]

        $sequence_5 = { e8???????? 83c40c 837dd808 7308 8b45d8 89458c eb07 }
            // n = 7, score = 200
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   837dd808             | cmp                 dword ptr [ebp - 0x28], 8
            //   7308                 | jae                 0xa
            //   8b45d8               | mov                 eax, dword ptr [ebp - 0x28]
            //   89458c               | mov                 dword ptr [ebp - 0x74], eax
            //   eb07                 | jmp                 9

        $sequence_6 = { c1ea0a 33c2 038558ffffff 8b8d38ffffff c1e907 8b9538ffffff c1e219 }
            // n = 7, score = 200
            //   c1ea0a               | shr                 edx, 0xa
            //   33c2                 | xor                 eax, edx
            //   038558ffffff         | add                 eax, dword ptr [ebp - 0xa8]
            //   8b8d38ffffff         | mov                 ecx, dword ptr [ebp - 0xc8]
            //   c1e907               | shr                 ecx, 7
            //   8b9538ffffff         | mov                 edx, dword ptr [ebp - 0xc8]
            //   c1e219               | shl                 edx, 0x19

        $sequence_7 = { e8???????? 034508 50 e8???????? 83c40c 8b45f4 50 }
            // n = 7, score = 200
            //   e8????????           |                     
            //   034508               | add                 eax, dword ptr [ebp + 8]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]
            //   50                   | push                eax

        $sequence_8 = { c7000b000000 e9???????? 8b4d0c 8b5108 52 6a00 6a05 }
            // n = 7, score = 200
            //   c7000b000000         | mov                 dword ptr [eax], 0xb
            //   e9????????           |                     
            //   8b4d0c               | mov                 ecx, dword ptr [ebp + 0xc]
            //   8b5108               | mov                 edx, dword ptr [ecx + 8]
            //   52                   | push                edx
            //   6a00                 | push                0
            //   6a05                 | push                5

        $sequence_9 = { 8b5598 8b45f8 8902 8b4598 52 8bcd 50 }
            // n = 7, score = 200
            //   8b5598               | mov                 edx, dword ptr [ebp - 0x68]
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   8902                 | mov                 dword ptr [edx], eax
            //   8b4598               | mov                 eax, dword ptr [ebp - 0x68]
            //   52                   | push                edx
            //   8bcd                 | mov                 ecx, ebp
            //   50                   | push                eax

    condition:
        7 of them and filesize < 1695744
}