rule win_fakerean_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.fakerean."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.fakerean"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 752e 8945fc eb29 395dfc 7524 57 8bce }
            // n = 7, score = 300
            //   752e                 | jne                 0x30
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   eb29                 | jmp                 0x2b
            //   395dfc               | cmp                 dword ptr [ebp - 4], ebx
            //   7524                 | jne                 0x26
            //   57                   | push                edi
            //   8bce                 | mov                 ecx, esi

        $sequence_1 = { 49 6a01 ff750c 50 57 ff7514 40 }
            // n = 7, score = 300
            //   49                   | dec                 ecx
            //   6a01                 | push                1
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   50                   | push                eax
            //   57                   | push                edi
            //   ff7514               | push                dword ptr [ebp + 0x14]
            //   40                   | inc                 eax

        $sequence_2 = { ff15???????? 3d14050000 74e5 ff7508 56 57 ff15???????? }
            // n = 7, score = 300
            //   ff15????????         |                     
            //   3d14050000           | cmp                 eax, 0x514
            //   74e5                 | je                  0xffffffe7
            //   ff7508               | push                dword ptr [ebp + 8]
            //   56                   | push                esi
            //   57                   | push                edi
            //   ff15????????         |                     

        $sequence_3 = { ff7508 ff15???????? 3bc3 0f8495000000 8b400c 8b00 }
            // n = 6, score = 300
            //   ff7508               | push                dword ptr [ebp + 8]
            //   ff15????????         |                     
            //   3bc3                 | cmp                 eax, ebx
            //   0f8495000000         | je                  0x9b
            //   8b400c               | mov                 eax, dword ptr [eax + 0xc]
            //   8b00                 | mov                 eax, dword ptr [eax]

        $sequence_4 = { 59 3bc3 7419 8d5010 e8???????? 8945e0 3bc3 }
            // n = 7, score = 300
            //   59                   | pop                 ecx
            //   3bc3                 | cmp                 eax, ebx
            //   7419                 | je                  0x1b
            //   8d5010               | lea                 edx, [eax + 0x10]
            //   e8????????           |                     
            //   8945e0               | mov                 dword ptr [ebp - 0x20], eax
            //   3bc3                 | cmp                 eax, ebx

        $sequence_5 = { ff35???????? ff15???????? 6800000500 6aec ff35???????? ff15???????? 680000cf06 }
            // n = 7, score = 300
            //   ff35????????         |                     
            //   ff15????????         |                     
            //   6800000500           | push                0x50000
            //   6aec                 | push                -0x14
            //   ff35????????         |                     
            //   ff15????????         |                     
            //   680000cf06           | push                0x6cf0000

        $sequence_6 = { 741a 81fe00020000 7d12 56 8bc7 e8???????? }
            // n = 6, score = 300
            //   741a                 | je                  0x1c
            //   81fe00020000         | cmp                 esi, 0x200
            //   7d12                 | jge                 0x14
            //   56                   | push                esi
            //   8bc7                 | mov                 eax, edi
            //   e8????????           |                     

        $sequence_7 = { 8b4df0 6bc018 6bc918 8b4c190c 2b4c1804 f7df }
            // n = 6, score = 300
            //   8b4df0               | mov                 ecx, dword ptr [ebp - 0x10]
            //   6bc018               | imul                eax, eax, 0x18
            //   6bc918               | imul                ecx, ecx, 0x18
            //   8b4c190c             | mov                 ecx, dword ptr [ecx + ebx + 0xc]
            //   2b4c1804             | sub                 ecx, dword ptr [eax + ebx + 4]
            //   f7df                 | neg                 edi

        $sequence_8 = { f7d8 1bc0 25bfe0ffff 05401f0000 50 ff35???????? ff15???????? }
            // n = 7, score = 300
            //   f7d8                 | neg                 eax
            //   1bc0                 | sbb                 eax, eax
            //   25bfe0ffff           | and                 eax, 0xffffe0bf
            //   05401f0000           | add                 eax, 0x1f40
            //   50                   | push                eax
            //   ff35????????         |                     
            //   ff15????????         |                     

        $sequence_9 = { 8d45f0 50 8d450c 50 ff15???????? 85c0 7431 }
            // n = 7, score = 300
            //   8d45f0               | lea                 eax, [ebp - 0x10]
            //   50                   | push                eax
            //   8d450c               | lea                 eax, [ebp + 0xc]
            //   50                   | push                eax
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7431                 | je                  0x33

    condition:
        7 of them and filesize < 4071424
}