rule win_final1stspy_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.final1stspy."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.final1stspy"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 03d0 8b45fc 8a4803 c1e206 80f93d 7508 }
            // n = 6, score = 300
            //   03d0                 | add                 edx, eax
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   8a4803               | mov                 cl, byte ptr [eax + 3]
            //   c1e206               | shl                 edx, 6
            //   80f93d               | cmp                 cl, 0x3d
            //   7508                 | jne                 0xa

        $sequence_1 = { 51 56 8d55fc c745fc00000000 e8???????? 8bf0 }
            // n = 6, score = 300
            //   51                   | push                ecx
            //   56                   | push                esi
            //   8d55fc               | lea                 edx, [ebp - 4]
            //   c745fc00000000       | mov                 dword ptr [ebp - 4], 0
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax

        $sequence_2 = { 8a1d???????? 8b4dfc 83c104 894dfc }
            // n = 4, score = 300
            //   8a1d????????         |                     
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   83c104               | add                 ecx, 4
            //   894dfc               | mov                 dword ptr [ebp - 4], ecx

        $sequence_3 = { eb2e 85ff 7594 b8???????? 6690 3ad9 }
            // n = 6, score = 300
            //   eb2e                 | jmp                 0x30
            //   85ff                 | test                edi, edi
            //   7594                 | jne                 0xffffff96
            //   b8????????           |                     
            //   6690                 | nop                 
            //   3ad9                 | cmp                 bl, cl

        $sequence_4 = { 81e7ff070080 7908 4f 81cf00f8ffff }
            // n = 4, score = 300
            //   81e7ff070080         | and                 edi, 0x800007ff
            //   7908                 | jns                 0xa
            //   4f                   | dec                 edi
            //   81cf00f8ffff         | or                  edi, 0xfffff800

        $sequence_5 = { 0f114c0f10 83c120 3bca 7cd4 3bce }
            // n = 5, score = 300
            //   0f114c0f10           | movups              xmmword ptr [edi + ecx + 0x10], xmm1
            //   83c120               | add                 ecx, 0x20
            //   3bca                 | cmp                 ecx, edx
            //   7cd4                 | jl                  0xffffffd6
            //   3bce                 | cmp                 ecx, esi

        $sequence_6 = { 84db 7410 8a11 8acb 3aca 7425 8a4801 }
            // n = 7, score = 300
            //   84db                 | test                bl, bl
            //   7410                 | je                  0x12
            //   8a11                 | mov                 dl, byte ptr [ecx]
            //   8acb                 | mov                 cl, bl
            //   3aca                 | cmp                 cl, dl
            //   7425                 | je                  0x27
            //   8a4801               | mov                 cl, byte ptr [eax + 1]

        $sequence_7 = { 81cf00f8ffff 47 33f6 85ff 7e0a }
            // n = 5, score = 300
            //   81cf00f8ffff         | or                  edi, 0xfffff800
            //   47                   | inc                 edi
            //   33f6                 | xor                 esi, esi
            //   85ff                 | test                edi, edi
            //   7e0a                 | jle                 0xc

        $sequence_8 = { 8945fc 57 8d7e01 8a06 }
            // n = 4, score = 300
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   57                   | push                edi
            //   8d7e01               | lea                 edi, [esi + 1]
            //   8a06                 | mov                 al, byte ptr [esi]

        $sequence_9 = { 7410 8a11 8acb 3aca }
            // n = 4, score = 300
            //   7410                 | je                  0x12
            //   8a11                 | mov                 dl, byte ptr [ecx]
            //   8acb                 | mov                 cl, bl
            //   3aca                 | cmp                 cl, dl

    condition:
        7 of them and filesize < 557056
}