rule win_floxif_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.floxif."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.floxif"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 8945fc 837dfc02 7709 c745f401000000 eb09 8b45fc }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   837dfc02             | cmp                 dword ptr [ebp - 4], 2
            //   7709                 | ja                  0xb
            //   c745f401000000       | mov                 dword ptr [ebp - 0xc], 1
            //   eb09                 | jmp                 0xb
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]

        $sequence_1 = { 3955f4 0f83c9000000 68???????? e8???????? }
            // n = 4, score = 100
            //   3955f4               | cmp                 dword ptr [ebp - 0xc], edx
            //   0f83c9000000         | jae                 0xcf
            //   68????????           |                     
            //   e8????????           |                     

        $sequence_2 = { 8b55fc c70200000000 8b45fc c7401000000000 8b45fc 8be5 }
            // n = 6, score = 100
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   c70200000000         | mov                 dword ptr [edx], 0
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   c7401000000000       | mov                 dword ptr [eax + 0x10], 0
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   8be5                 | mov                 esp, ebp

        $sequence_3 = { c645e500 c645e6e1 c645e700 c645e87d c645e973 c645ea7a c645eb30 }
            // n = 7, score = 100
            //   c645e500             | mov                 byte ptr [ebp - 0x1b], 0
            //   c645e6e1             | mov                 byte ptr [ebp - 0x1a], 0xe1
            //   c645e700             | mov                 byte ptr [ebp - 0x19], 0
            //   c645e87d             | mov                 byte ptr [ebp - 0x18], 0x7d
            //   c645e973             | mov                 byte ptr [ebp - 0x17], 0x73
            //   c645ea7a             | mov                 byte ptr [ebp - 0x16], 0x7a
            //   c645eb30             | mov                 byte ptr [ebp - 0x15], 0x30

        $sequence_4 = { c645e500 c645e6bb c645e700 c645e828 c645e92b c645ea23 }
            // n = 6, score = 100
            //   c645e500             | mov                 byte ptr [ebp - 0x1b], 0
            //   c645e6bb             | mov                 byte ptr [ebp - 0x1a], 0xbb
            //   c645e700             | mov                 byte ptr [ebp - 0x19], 0
            //   c645e828             | mov                 byte ptr [ebp - 0x18], 0x28
            //   c645e92b             | mov                 byte ptr [ebp - 0x17], 0x2b
            //   c645ea23             | mov                 byte ptr [ebp - 0x16], 0x23

        $sequence_5 = { 7505 e9???????? 837dd800 7406 837dd805 7502 eb92 }
            // n = 7, score = 100
            //   7505                 | jne                 7
            //   e9????????           |                     
            //   837dd800             | cmp                 dword ptr [ebp - 0x28], 0
            //   7406                 | je                  8
            //   837dd805             | cmp                 dword ptr [ebp - 0x28], 5
            //   7502                 | jne                 4
            //   eb92                 | jmp                 0xffffff94

        $sequence_6 = { 83ec14 894df8 8b45f8 8b4808 }
            // n = 4, score = 100
            //   83ec14               | sub                 esp, 0x14
            //   894df8               | mov                 dword ptr [ebp - 8], ecx
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   8b4808               | mov                 ecx, dword ptr [eax + 8]

        $sequence_7 = { ebaa 8d4d08 e8???????? 3945fc 7526 8d4d18 e8???????? }
            // n = 7, score = 100
            //   ebaa                 | jmp                 0xffffffac
            //   8d4d08               | lea                 ecx, [ebp + 8]
            //   e8????????           |                     
            //   3945fc               | cmp                 dword ptr [ebp - 4], eax
            //   7526                 | jne                 0x28
            //   8d4d18               | lea                 ecx, [ebp + 0x18]
            //   e8????????           |                     

        $sequence_8 = { 8b55fc 837a0400 7507 e8???????? eb11 8b4dfc e8???????? }
            // n = 7, score = 100
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   837a0400             | cmp                 dword ptr [edx + 4], 0
            //   7507                 | jne                 9
            //   e8????????           |                     
            //   eb11                 | jmp                 0x13
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   e8????????           |                     

        $sequence_9 = { e8???????? e8???????? 83c410 eb44 83ec10 8bcc 8d5508 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10
            //   eb44                 | jmp                 0x46
            //   83ec10               | sub                 esp, 0x10
            //   8bcc                 | mov                 ecx, esp
            //   8d5508               | lea                 edx, [ebp + 8]

    condition:
        7 of them and filesize < 352256
}