rule win_flying_dutchman_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.flying_dutchman."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.flying_dutchman"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 66890c02 83c002 6685c9 75f1 e9???????? 8b85e8feffff 83e800 }
            // n = 7, score = 100
            //   66890c02             | mov                 word ptr [edx + eax], cx
            //   83c002               | add                 eax, 2
            //   6685c9               | test                cx, cx
            //   75f1                 | jne                 0xfffffff3
            //   e9????????           |                     
            //   8b85e8feffff         | mov                 eax, dword ptr [ebp - 0x118]
            //   83e800               | sub                 eax, 0

        $sequence_1 = { 48 0f84f8000000 48 0f853d010000 83bd44fcffff06 7553 8b35???????? }
            // n = 7, score = 100
            //   48                   | dec                 eax
            //   0f84f8000000         | je                  0xfe
            //   48                   | dec                 eax
            //   0f853d010000         | jne                 0x143
            //   83bd44fcffff06       | cmp                 dword ptr [ebp - 0x3bc], 6
            //   7553                 | jne                 0x55
            //   8b35????????         |                     

        $sequence_2 = { 8bec 51 56 6a18 e8???????? 33f6 }
            // n = 6, score = 100
            //   8bec                 | mov                 ebp, esp
            //   51                   | push                ecx
            //   56                   | push                esi
            //   6a18                 | push                0x18
            //   e8????????           |                     
            //   33f6                 | xor                 esi, esi

        $sequence_3 = { 8d442430 50 89742438 895c2434 68???????? eb40 57 }
            // n = 7, score = 100
            //   8d442430             | lea                 eax, [esp + 0x30]
            //   50                   | push                eax
            //   89742438             | mov                 dword ptr [esp + 0x38], esi
            //   895c2434             | mov                 dword ptr [esp + 0x34], ebx
            //   68????????           |                     
            //   eb40                 | jmp                 0x42
            //   57                   | push                edi

        $sequence_4 = { ff75f0 f3a5 ff75f4 ff15???????? ff75f4 8b35???????? ffd6 }
            // n = 7, score = 100
            //   ff75f0               | push                dword ptr [ebp - 0x10]
            //   f3a5                 | rep movsd           dword ptr es:[edi], dword ptr [esi]
            //   ff75f4               | push                dword ptr [ebp - 0xc]
            //   ff15????????         |                     
            //   ff75f4               | push                dword ptr [ebp - 0xc]
            //   8b35????????         |                     
            //   ffd6                 | call                esi

        $sequence_5 = { 3bfb 7531 6a14 e8???????? 8bf0 59 }
            // n = 6, score = 100
            //   3bfb                 | cmp                 edi, ebx
            //   7531                 | jne                 0x33
            //   6a14                 | push                0x14
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax
            //   59                   | pop                 ecx

        $sequence_6 = { ff15???????? 3bc7 7504 33c0 eb1f 0fbf480a }
            // n = 6, score = 100
            //   ff15????????         |                     
            //   3bc7                 | cmp                 eax, edi
            //   7504                 | jne                 6
            //   33c0                 | xor                 eax, eax
            //   eb1f                 | jmp                 0x21
            //   0fbf480a             | movsx               ecx, word ptr [eax + 0xa]

        $sequence_7 = { 0f8489000000 48 747f 2ddb030000 }
            // n = 4, score = 100
            //   0f8489000000         | je                  0x8f
            //   48                   | dec                 eax
            //   747f                 | je                  0x81
            //   2ddb030000           | sub                 eax, 0x3db

        $sequence_8 = { e8???????? 8be5 5d c20800 55 8bec 81eca8000000 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8be5                 | mov                 esp, ebp
            //   5d                   | pop                 ebp
            //   c20800               | ret                 8
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   81eca8000000         | sub                 esp, 0xa8

        $sequence_9 = { 832600 83660400 83660800 c3 8b4b04 56 57 }
            // n = 7, score = 100
            //   832600               | and                 dword ptr [esi], 0
            //   83660400             | and                 dword ptr [esi + 4], 0
            //   83660800             | and                 dword ptr [esi + 8], 0
            //   c3                   | ret                 
            //   8b4b04               | mov                 ecx, dword ptr [ebx + 4]
            //   56                   | push                esi
            //   57                   | push                edi

    condition:
        7 of them and filesize < 276480
}