rule win_friedex_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.friedex."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.friedex"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 57 8bc8 e8???????? 6a26 }
            // n = 5, score = 800
            //   e8????????           |                     
            //   57                   | push                edi
            //   8bc8                 | mov                 ecx, eax
            //   e8????????           |                     
            //   6a26                 | push                0x26

        $sequence_1 = { c20c00 51 51 53 55 8be9 c744240820090d0a }
            // n = 7, score = 800
            //   c20c00               | ret                 0xc
            //   51                   | push                ecx
            //   51                   | push                ecx
            //   53                   | push                ebx
            //   55                   | push                ebp
            //   8be9                 | mov                 ebp, ecx
            //   c744240820090d0a     | mov                 dword ptr [esp + 8], 0xa0d0920

        $sequence_2 = { 1adb e8???????? 6a20 5f }
            // n = 4, score = 800
            //   1adb                 | sbb                 bl, bl
            //   e8????????           |                     
            //   6a20                 | push                0x20
            //   5f                   | pop                 edi

        $sequence_3 = { 74f9 33c9 663908 0f94c0 5f 5e 5d }
            // n = 7, score = 800
            //   74f9                 | je                  0xfffffffb
            //   33c9                 | xor                 ecx, ecx
            //   663908               | cmp                 word ptr [eax], cx
            //   0f94c0               | sete                al
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5d                   | pop                 ebp

        $sequence_4 = { 663910 7431 8bd8 8d7102 eb1d }
            // n = 5, score = 800
            //   663910               | cmp                 word ptr [eax], dx
            //   7431                 | je                  0x33
            //   8bd8                 | mov                 ebx, eax
            //   8d7102               | lea                 esi, [ecx + 2]
            //   eb1d                 | jmp                 0x1f

        $sequence_5 = { 5f 5b 5e 5d c20c00 51 }
            // n = 6, score = 800
            //   5f                   | pop                 edi
            //   5b                   | pop                 ebx
            //   5e                   | pop                 esi
            //   5d                   | pop                 ebp
            //   c20c00               | ret                 0xc
            //   51                   | push                ecx

        $sequence_6 = { 75c1 6a2a 5f eb06 b001 eb0f 03c5 }
            // n = 7, score = 800
            //   75c1                 | jne                 0xffffffc3
            //   6a2a                 | push                0x2a
            //   5f                   | pop                 edi
            //   eb06                 | jmp                 8
            //   b001                 | mov                 al, 1
            //   eb0f                 | jmp                 0x11
            //   03c5                 | add                 eax, ebp

        $sequence_7 = { 6a00 ff760c ffd0 8b442408 5e }
            // n = 5, score = 800
            //   6a00                 | push                0
            //   ff760c               | push                dword ptr [esi + 0xc]
            //   ffd0                 | call                eax
            //   8b442408             | mov                 eax, dword ptr [esp + 8]
            //   5e                   | pop                 esi

        $sequence_8 = { 8955e0 e8???????? 8d0dd830a500 890424 894c2404 e8???????? }
            // n = 6, score = 100
            //   8955e0               | mov                 dword ptr [ebp - 0x20], edx
            //   e8????????           |                     
            //   8d0dd830a500         | lea                 ecx, [0xa530d8]
            //   890424               | mov                 dword ptr [esp], eax
            //   894c2404             | mov                 dword ptr [esp + 4], ecx
            //   e8????????           |                     

        $sequence_9 = { 8d055a23a500 31c9 8d55d8 803d????????e9 8955d4 8945d0 }
            // n = 6, score = 100
            //   8d055a23a500         | lea                 eax, [0xa5235a]
            //   31c9                 | xor                 ecx, ecx
            //   8d55d8               | lea                 edx, [ebp - 0x28]
            //   803d????????e9       |                     
            //   8955d4               | mov                 dword ptr [ebp - 0x2c], edx
            //   8945d0               | mov                 dword ptr [ebp - 0x30], eax

        $sequence_10 = { 8a2c057530a500 83c001 38e9 8945a0 8955cc 74bc }
            // n = 6, score = 100
            //   8a2c057530a500       | mov                 ch, byte ptr [eax + 0xa53075]
            //   83c001               | add                 eax, 1
            //   38e9                 | cmp                 cl, ch
            //   8945a0               | mov                 dword ptr [ebp - 0x60], eax
            //   8955cc               | mov                 dword ptr [ebp - 0x34], edx
            //   74bc                 | je                  0xffffffbe

        $sequence_11 = { 8d055a23a500 5d c3 55 }
            // n = 4, score = 100
            //   8d055a23a500         | lea                 eax, [0xa5235a]
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   55                   | push                ebp

        $sequence_12 = { c7424458270000 c7424800100100 8b7de4 c787cc00000000000000 c787c800000000000000 }
            // n = 5, score = 100
            //   c7424458270000       | mov                 dword ptr [edx + 0x44], 0x2758
            //   c7424800100100       | mov                 dword ptr [edx + 0x48], 0x11000
            //   8b7de4               | mov                 edi, dword ptr [ebp - 0x1c]
            //   c787cc00000000000000     | mov    dword ptr [edi + 0xcc], 0
            //   c787c800000000000000     | mov    dword ptr [edi + 0xc8], 0

        $sequence_13 = { 8b45a4 8a4daf 31d2 8a2c057530a500 83c001 38e9 }
            // n = 6, score = 100
            //   8b45a4               | mov                 eax, dword ptr [ebp - 0x5c]
            //   8a4daf               | mov                 cl, byte ptr [ebp - 0x51]
            //   31d2                 | xor                 edx, edx
            //   8a2c057530a500       | mov                 ch, byte ptr [eax + 0xa53075]
            //   83c001               | add                 eax, 1
            //   38e9                 | cmp                 cl, ch

        $sequence_14 = { 8d0dc930a500 890424 894c2404 e8???????? 8d0d4430a500 31d2 8b75f8 }
            // n = 7, score = 100
            //   8d0dc930a500         | lea                 ecx, [0xa530c9]
            //   890424               | mov                 dword ptr [esp], eax
            //   894c2404             | mov                 dword ptr [esp + 4], ecx
            //   e8????????           |                     
            //   8d0d4430a500         | lea                 ecx, [0xa53044]
            //   31d2                 | xor                 edx, edx
            //   8b75f8               | mov                 esi, dword ptr [ebp - 8]

        $sequence_15 = { 8d0d4430a500 31d2 890c24 c744240400000000 }
            // n = 4, score = 100
            //   8d0d4430a500         | lea                 ecx, [0xa53044]
            //   31d2                 | xor                 edx, edx
            //   890c24               | mov                 dword ptr [esp], ecx
            //   c744240400000000     | mov                 dword ptr [esp + 4], 0

    condition:
        7 of them and filesize < 204800
}