rule win_gaudox_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.gaudox."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.gaudox"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 7403 c60000 8bce e8???????? 8b45f8 85c0 7410 }
            // n = 7, score = 200
            //   7403                 | je                  5
            //   c60000               | mov                 byte ptr [eax], 0
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   85c0                 | test                eax, eax
            //   7410                 | je                  0x12

        $sequence_1 = { 837df000 0f849a000000 6a00 8d95c4feffff 52 b804000000 6bc800 }
            // n = 7, score = 200
            //   837df000             | cmp                 dword ptr [ebp - 0x10], 0
            //   0f849a000000         | je                  0xa0
            //   6a00                 | push                0
            //   8d95c4feffff         | lea                 edx, [ebp - 0x13c]
            //   52                   | push                edx
            //   b804000000           | mov                 eax, 4
            //   6bc800               | imul                ecx, eax, 0

        $sequence_2 = { 8d8c2458030000 e8???????? 8bf0 85f6 0f88df000000 a1???????? 8d8c2450030000 }
            // n = 7, score = 200
            //   8d8c2458030000       | lea                 ecx, [esp + 0x358]
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax
            //   85f6                 | test                esi, esi
            //   0f88df000000         | js                  0xe5
            //   a1????????           |                     
            //   8d8c2450030000       | lea                 ecx, [esp + 0x350]

        $sequence_3 = { a1???????? 57 ffb0b8000000 eb26 8bb8b0000000 83ff54 }
            // n = 6, score = 200
            //   a1????????           |                     
            //   57                   | push                edi
            //   ffb0b8000000         | push                dword ptr [eax + 0xb8]
            //   eb26                 | jmp                 0x28
            //   8bb8b0000000         | mov                 edi, dword ptr [eax + 0xb0]
            //   83ff54               | cmp                 edi, 0x54

        $sequence_4 = { 13c9 66f3ab 8b450c 03f0 8bc6 5f 5e }
            // n = 7, score = 200
            //   13c9                 | adc                 ecx, ecx
            //   66f3ab               | rep stosd           dword ptr es:[edi], eax
            //   8b450c               | mov                 eax, dword ptr [ebp + 0xc]
            //   03f0                 | add                 esi, eax
            //   8bc6                 | mov                 eax, esi
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi

        $sequence_5 = { 56 8b7014 81feb8000000 7729 68???????? b9???????? e8???????? }
            // n = 7, score = 200
            //   56                   | push                esi
            //   8b7014               | mov                 esi, dword ptr [eax + 0x14]
            //   81feb8000000         | cmp                 esi, 0xb8
            //   7729                 | ja                  0x2b
            //   68????????           |                     
            //   b9????????           |                     
            //   e8????????           |                     

        $sequence_6 = { ff75fc 8bf0 6a08 6a00 e8???????? 85f6 782a }
            // n = 7, score = 200
            //   ff75fc               | push                dword ptr [ebp - 4]
            //   8bf0                 | mov                 esi, eax
            //   6a08                 | push                8
            //   6a00                 | push                0
            //   e8????????           |                     
            //   85f6                 | test                esi, esi
            //   782a                 | js                  0x2c

        $sequence_7 = { 8b45f4 8b5018 85d2 74ec 6a00 6a00 68d113282e }
            // n = 7, score = 200
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]
            //   8b5018               | mov                 edx, dword ptr [eax + 0x18]
            //   85d2                 | test                edx, edx
            //   74ec                 | je                  0xffffffee
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   68d113282e           | push                0x2e2813d1

        $sequence_8 = { 57 85c0 0f84ad010000 85d2 0f84a5010000 8b7d08 85ff }
            // n = 7, score = 200
            //   57                   | push                edi
            //   85c0                 | test                eax, eax
            //   0f84ad010000         | je                  0x1b3
            //   85d2                 | test                edx, edx
            //   0f84a5010000         | je                  0x1ab
            //   8b7d08               | mov                 edi, dword ptr [ebp + 8]
            //   85ff                 | test                edi, edi

        $sequence_9 = { 8d442460 50 6a27 6a00 e8???????? 85c0 781c }
            // n = 7, score = 200
            //   8d442460             | lea                 eax, [esp + 0x60]
            //   50                   | push                eax
            //   6a27                 | push                0x27
            //   6a00                 | push                0
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   781c                 | js                  0x1e

    condition:
        7 of them and filesize < 155648
}