rule win_gcleaner_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.gcleaner."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.gcleaner"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d8d70feffff 8d45b0 0f4345b0 51 50 }
            // n = 5, score = 600
            //   8d8d70feffff         | lea                 ecx, [ebp - 0x190]
            //   8d45b0               | lea                 eax, [ebp - 0x50]
            //   0f4345b0             | cmovae              eax, dword ptr [ebp - 0x50]
            //   51                   | push                ecx
            //   50                   | push                eax

        $sequence_1 = { 8bd0 c645fc04 8d4dd8 e8???????? 83c410 }
            // n = 5, score = 600
            //   8bd0                 | mov                 edx, eax
            //   c645fc04             | mov                 byte ptr [ebp - 4], 4
            //   8d4dd8               | lea                 ecx, [ebp - 0x28]
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10

        $sequence_2 = { 660fd64010 8345e418 eb10 8d4dc8 }
            // n = 4, score = 600
            //   660fd64010           | movq                qword ptr [eax + 0x10], xmm0
            //   8345e418             | add                 dword ptr [ebp - 0x1c], 0x18
            //   eb10                 | jmp                 0x12
            //   8d4dc8               | lea                 ecx, [ebp - 0x38]

        $sequence_3 = { 660fd64610 c742e000000000 c742e40f000000 c642d000 8b42e8 894618 }
            // n = 6, score = 600
            //   660fd64610           | movq                qword ptr [esi + 0x10], xmm0
            //   c742e000000000       | mov                 dword ptr [edx - 0x20], 0
            //   c742e40f000000       | mov                 dword ptr [edx - 0x1c], 0xf
            //   c642d000             | mov                 byte ptr [edx - 0x30], 0
            //   8b42e8               | mov                 eax, dword ptr [edx - 0x18]
            //   894618               | mov                 dword ptr [esi + 0x18], eax

        $sequence_4 = { e8???????? 8d8d60ffffff e8???????? 6a00 6a00 }
            // n = 5, score = 600
            //   e8????????           |                     
            //   8d8d60ffffff         | lea                 ecx, [ebp - 0xa0]
            //   e8????????           |                     
            //   6a00                 | push                0
            //   6a00                 | push                0

        $sequence_5 = { c642d000 8b42e8 894618 8d42ec 83c61c 3bc7 }
            // n = 6, score = 600
            //   c642d000             | mov                 byte ptr [edx - 0x30], 0
            //   8b42e8               | mov                 eax, dword ptr [edx - 0x18]
            //   894618               | mov                 dword ptr [esi + 0x18], eax
            //   8d42ec               | lea                 eax, [edx - 0x14]
            //   83c61c               | add                 esi, 0x1c
            //   3bc7                 | cmp                 eax, edi

        $sequence_6 = { eb10 8d4dc8 51 50 }
            // n = 4, score = 600
            //   eb10                 | jmp                 0x12
            //   8d4dc8               | lea                 ecx, [ebp - 0x38]
            //   51                   | push                ecx
            //   50                   | push                eax

        $sequence_7 = { 7438 8035????????2e 8035????????2e 8035????????2e 8035????????2e 8035????????2e 8035????????2e }
            // n = 7, score = 600
            //   7438                 | je                  0x3a
            //   8035????????2e       |                     
            //   8035????????2e       |                     
            //   8035????????2e       |                     
            //   8035????????2e       |                     
            //   8035????????2e       |                     
            //   8035????????2e       |                     

        $sequence_8 = { 52 51 e8???????? 83c408 85ff 0f8807010000 }
            // n = 6, score = 600
            //   52                   | push                edx
            //   51                   | push                ecx
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   85ff                 | test                edi, edi
            //   0f8807010000         | js                  0x10d

        $sequence_9 = { c645fc02 83fa10 722c 8b4dc8 42 8bc1 }
            // n = 6, score = 600
            //   c645fc02             | mov                 byte ptr [ebp - 4], 2
            //   83fa10               | cmp                 edx, 0x10
            //   722c                 | jb                  0x2e
            //   8b4dc8               | mov                 ecx, dword ptr [ebp - 0x38]
            //   42                   | inc                 edx
            //   8bc1                 | mov                 eax, ecx

    condition:
        7 of them and filesize < 540672
}