rule win_glasses_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.glasses."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.glasses"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 8bf0 83c40c 3bf3 0f85e8fdffff 8d4590 50 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax
            //   83c40c               | add                 esp, 0xc
            //   3bf3                 | cmp                 esi, ebx
            //   0f85e8fdffff         | jne                 0xfffffdee
            //   8d4590               | lea                 eax, [ebp - 0x70]
            //   50                   | push                eax

        $sequence_1 = { e8???????? 8d852cfbffff 50 6a00 6a50 68???????? 8d8de4faffff }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8d852cfbffff         | lea                 eax, [ebp - 0x4d4]
            //   50                   | push                eax
            //   6a00                 | push                0
            //   6a50                 | push                0x50
            //   68????????           |                     
            //   8d8de4faffff         | lea                 ecx, [ebp - 0x51c]

        $sequence_2 = { e8???????? 83bdd8fdffff00 0f849e000000 8bcb e8???????? 85c0 740d }
            // n = 7, score = 100
            //   e8????????           |                     
            //   83bdd8fdffff00       | cmp                 dword ptr [ebp - 0x228], 0
            //   0f849e000000         | je                  0xa4
            //   8bcb                 | mov                 ecx, ebx
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   740d                 | je                  0xf

        $sequence_3 = { e9???????? 8d8d38f9ffff e9???????? 8d8dfcf8ffff e9???????? 8d8dacf8ffff e9???????? }
            // n = 7, score = 100
            //   e9????????           |                     
            //   8d8d38f9ffff         | lea                 ecx, [ebp - 0x6c8]
            //   e9????????           |                     
            //   8d8dfcf8ffff         | lea                 ecx, [ebp - 0x704]
            //   e9????????           |                     
            //   8d8dacf8ffff         | lea                 ecx, [ebp - 0x754]
            //   e9????????           |                     

        $sequence_4 = { 8bf1 8975f0 c706???????? 8d8e84000000 c745fc01000000 c7460800000000 e8???????? }
            // n = 7, score = 100
            //   8bf1                 | mov                 esi, ecx
            //   8975f0               | mov                 dword ptr [ebp - 0x10], esi
            //   c706????????         |                     
            //   8d8e84000000         | lea                 ecx, [esi + 0x84]
            //   c745fc01000000       | mov                 dword ptr [ebp - 4], 1
            //   c7460800000000       | mov                 dword ptr [esi + 8], 0
            //   e8????????           |                     

        $sequence_5 = { e8???????? 83b94814000002 0f8d54ffffff ff894c140000 8b814c140000 8b91580b0000 899481540b0000 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   83b94814000002       | cmp                 dword ptr [ecx + 0x1448], 2
            //   0f8d54ffffff         | jge                 0xffffff5a
            //   ff894c140000         | dec                 dword ptr [ecx + 0x144c]
            //   8b814c140000         | mov                 eax, dword ptr [ecx + 0x144c]
            //   8b91580b0000         | mov                 edx, dword ptr [ecx + 0xb58]
            //   899481540b0000       | mov                 dword ptr [ecx + eax*4 + 0xb54], edx

        $sequence_6 = { ff0d???????? 53 8bcf e8???????? c645ff00 5f 5e }
            // n = 7, score = 100
            //   ff0d????????         |                     
            //   53                   | push                ebx
            //   8bcf                 | mov                 ecx, edi
            //   e8????????           |                     
            //   c645ff00             | mov                 byte ptr [ebp - 1], 0
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi

        $sequence_7 = { ffd2 84c0 0f840b010000 8d4da4 e8???????? 8bf8 8b45cc }
            // n = 7, score = 100
            //   ffd2                 | call                edx
            //   84c0                 | test                al, al
            //   0f840b010000         | je                  0x111
            //   8d4da4               | lea                 ecx, [ebp - 0x5c]
            //   e8????????           |                     
            //   8bf8                 | mov                 edi, eax
            //   8b45cc               | mov                 eax, dword ptr [ebp - 0x34]

        $sequence_8 = { eb10 8bce e8???????? 8b5d18 8945e8 895dec 8b7510 }
            // n = 7, score = 100
            //   eb10                 | jmp                 0x12
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     
            //   8b5d18               | mov                 ebx, dword ptr [ebp + 0x18]
            //   8945e8               | mov                 dword ptr [ebp - 0x18], eax
            //   895dec               | mov                 dword ptr [ebp - 0x14], ebx
            //   8b7510               | mov                 esi, dword ptr [ebp + 0x10]

        $sequence_9 = { e8???????? 899e7c070000 e9???????? 83f801 7524 6a02 e8???????? }
            // n = 7, score = 100
            //   e8????????           |                     
            //   899e7c070000         | mov                 dword ptr [esi + 0x77c], ebx
            //   e9????????           |                     
            //   83f801               | cmp                 eax, 1
            //   7524                 | jne                 0x26
            //   6a02                 | push                2
            //   e8????????           |                     

    condition:
        7 of them and filesize < 4177920
}