rule win_gophe_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.gophe."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.gophe"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 833902 0f94c0 84c0 7407 }
            // n = 4, score = 300
            //   833902               | cmp                 dword ptr [ecx], 2
            //   0f94c0               | sete                al
            //   84c0                 | test                al, al
            //   7407                 | je                  9

        $sequence_1 = { b905000000 ff15???????? 8b05???????? 85c0 }
            // n = 4, score = 200
            //   b905000000           | test                ecx, ecx
            //   ff15????????         |                     
            //   8b05????????         |                     
            //   85c0                 | sete                al

        $sequence_2 = { 56 8b7510 57 68???????? c70605000000 }
            // n = 5, score = 200
            //   56                   | mov                 dword ptr [eax], 0xc150003
            //   8b7510               | dec                 eax
            //   57                   | mov                 eax, dword ptr [edx + 0x10]
            //   68????????           |                     
            //   c70605000000         | mov                 dword ptr [eax + 8], 1

        $sequence_3 = { b801000000 eb09 83c8ff eb04 }
            // n = 4, score = 200
            //   b801000000           | mov                 dword ptr [ebx + 0x1c], eax
            //   eb09                 | test                ecx, ecx
            //   83c8ff               | js                  0x3a
            //   eb04                 | dec                 eax

        $sequence_4 = { 51 a1???????? 33c5 50 8d45f4 64a300000000 68e0000000 }
            // n = 7, score = 200
            //   51                   | mov                 ecx, 5
            //   a1????????           |                     
            //   33c5                 | test                eax, eax
            //   50                   | mov                 eax, 1
            //   8d45f4               | jmp                 0xb
            //   64a300000000         | or                  eax, 0xffffffff
            //   68e0000000           | jmp                 0xb

        $sequence_5 = { 5b 8be5 5d c3 b896ffffff }
            // n = 5, score = 200
            //   5b                   | dec                 eax
            //   8be5                 | mov                 eax, dword ptr [edx + 0x10]
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   b896ffffff           | mov                 eax, 0xffffff96

        $sequence_6 = { 64a300000000 68e0000000 e8???????? 83c404 }
            // n = 4, score = 200
            //   64a300000000         | push                eax
            //   68e0000000           | call                esi
            //   e8????????           |                     
            //   83c404               | test                eax, eax

        $sequence_7 = { 6805010000 8d85e0fdffff 50 68???????? }
            // n = 4, score = 200
            //   6805010000           | lea                 eax, [ebp - 0xc]
            //   8d85e0fdffff         | mov                 dword ptr fs:[0], eax
            //   50                   | push                0xe0
            //   68????????           |                     

        $sequence_8 = { 85c9 0f94c0 89431c 85c9 }
            // n = 4, score = 200
            //   85c9                 | mov                 ecx, dword ptr [edx + 0x10]
            //   0f94c0               | cmp                 word ptr [ecx + 0x30], 0xb
            //   89431c               | jne                 0x1d
            //   85c9                 | cmp                 word ptr [ecx + 0x38], 0

        $sequence_9 = { 7838 488b4c2440 ff15???????? 8bf8 }
            // n = 4, score = 200
            //   7838                 | dec                 eax
            //   488b4c2440           | mov                 edx, dword ptr [esp + 0x40]
            //   ff15????????         |                     
            //   8bf8                 | dec                 eax

        $sequence_10 = { 2bf0 b8abaaaa2a f7ee c1fa03 8bf2 }
            // n = 5, score = 200
            //   2bf0                 | lea                 eax, [ebp - 0x220]
            //   b8abaaaa2a           | push                eax
            //   f7ee                 | call                esi
            //   c1fa03               | push                0x105
            //   8bf2                 | lea                 eax, [ebp - 0x220]

        $sequence_11 = { 8bf8 488b4c2440 488b01 ff5010 85ff }
            // n = 5, score = 200
            //   8bf8                 | mov                 edi, eax
            //   488b4c2440           | dec                 eax
            //   488b01               | mov                 ecx, dword ptr [esp + 0x40]
            //   ff5010               | dec                 eax
            //   85ff                 | mov                 eax, dword ptr [ecx]

        $sequence_12 = { e8???????? 488d942488000000 488d4c2460 e8???????? }
            // n = 4, score = 200
            //   e8????????           |                     
            //   488d942488000000     | mov                 edx, dword ptr [esp + 0x40]
            //   488d4c2460           | dec                 eax
            //   e8????????           |                     

        $sequence_13 = { c684249000000000 488b542440 488b4a10 668379300b }
            // n = 4, score = 200
            //   c684249000000000     | call                dword ptr [eax + 0x10]
            //   488b542440           | test                edi, edi
            //   488b4a10             | mov                 byte ptr [esp + 0x90], 0
            //   668379300b           | dec                 eax

        $sequence_14 = { 6a00 56 e8???????? 83c40c c706ffffffff }
            // n = 5, score = 200
            //   6a00                 | mov                 eax, 0xffffff96
            //   56                   | pop                 edi
            //   e8????????           |                     
            //   83c40c               | pop                 ebx
            //   c706ffffffff         | mov                 esp, ebp

        $sequence_15 = { 5d c3 b896ffffff 5f 5e 5b }
            // n = 6, score = 200
            //   5d                   | dec                 eax
            //   c3                   | mov                 ecx, dword ptr [esp + 0x40]
            //   b896ffffff           | mov                 edi, eax
            //   5f                   | test                eax, eax
            //   5e                   | js                  0x23
            //   5b                   | js                  0x3a

    condition:
        7 of them and filesize < 1582080
}