rule win_gpcode_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.gpcode."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.gpcode"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? a1???????? a3???????? 6800001000 68???????? ff35???????? }
            // n = 6, score = 1400
            //   e8????????           |                     
            //   a1????????           |                     
            //   a3????????           |                     
            //   6800001000           | push                0x100000
            //   68????????           |                     
            //   ff35????????         |                     

        $sequence_1 = { 68???????? e8???????? 91 6a00 }
            // n = 4, score = 1400
            //   68????????           |                     
            //   e8????????           |                     
            //   91                   | xchg                eax, ecx
            //   6a00                 | push                0

        $sequence_2 = { e8???????? e8???????? c705????????01000000 c3 55 8bec }
            // n = 6, score = 1400
            //   e8????????           |                     
            //   e8????????           |                     
            //   c705????????01000000     |     
            //   c3                   | ret                 
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp

        $sequence_3 = { 85c0 7479 33c0 50 50 6a03 50 }
            // n = 7, score = 1100
            //   85c0                 | test                eax, eax
            //   7479                 | je                  0x7b
            //   33c0                 | xor                 eax, eax
            //   50                   | push                eax
            //   50                   | push                eax
            //   6a03                 | push                3
            //   50                   | push                eax

        $sequence_4 = { ff35???????? 68???????? ff75f8 ff15???????? 8945f4 85c0 7425 }
            // n = 7, score = 1100
            //   ff35????????         |                     
            //   68????????           |                     
            //   ff75f8               | push                dword ptr [ebp - 8]
            //   ff15????????         |                     
            //   8945f4               | mov                 dword ptr [ebp - 0xc], eax
            //   85c0                 | test                eax, eax
            //   7425                 | je                  0x27

        $sequence_5 = { 8906 83c608 e2e6 59 e2dc }
            // n = 5, score = 1100
            //   8906                 | mov                 dword ptr [esi], eax
            //   83c608               | add                 esi, 8
            //   e2e6                 | loop                0xffffffe8
            //   59                   | pop                 ecx
            //   e2dc                 | loop                0xffffffde

        $sequence_6 = { 83c40c 8d45fc 50 8d450c ff30 e8???????? }
            // n = 6, score = 1100
            //   83c40c               | add                 esp, 0xc
            //   8d45fc               | lea                 eax, [ebp - 4]
            //   50                   | push                eax
            //   8d450c               | lea                 eax, [ebp + 0xc]
            //   ff30                 | push                dword ptr [eax]
            //   e8????????           |                     

        $sequence_7 = { e8???????? 0bc0 7504 33c0 c9 c3 8945f0 }
            // n = 7, score = 800
            //   e8????????           |                     
            //   0bc0                 | or                  eax, eax
            //   7504                 | jne                 6
            //   33c0                 | xor                 eax, eax
            //   c9                   | leave               
            //   c3                   | ret                 
            //   8945f0               | mov                 dword ptr [ebp - 0x10], eax

        $sequence_8 = { c60000 2d???????? 50 8d85e8feffff 50 68???????? }
            // n = 6, score = 800
            //   c60000               | mov                 byte ptr [eax], 0
            //   2d????????           |                     
            //   50                   | push                eax
            //   8d85e8feffff         | lea                 eax, [ebp - 0x118]
            //   50                   | push                eax
            //   68????????           |                     

        $sequence_9 = { 68???????? 6a00 e8???????? 6a0a 68???????? 6a00 e8???????? }
            // n = 7, score = 800
            //   68????????           |                     
            //   6a00                 | push                0
            //   e8????????           |                     
            //   6a0a                 | push                0xa
            //   68????????           |                     
            //   6a00                 | push                0
            //   e8????????           |                     

        $sequence_10 = { e8???????? 83f8ff 7505 5a }
            // n = 4, score = 800
            //   e8????????           |                     
            //   83f8ff               | cmp                 eax, -1
            //   7505                 | jne                 7
            //   5a                   | pop                 edx

        $sequence_11 = { 001438 eb06 80c107 000c38 }
            // n = 4, score = 100
            //   001438               | add                 byte ptr [eax + edi], dl
            //   eb06                 | jmp                 8
            //   80c107               | add                 cl, 7
            //   000c38               | add                 byte ptr [eax + edi], cl

        $sequence_12 = { 0005???????? 0fb605???????? 8ad3 8d80b8fee014 }
            // n = 4, score = 100
            //   0005????????         |                     
            //   0fb605????????       |                     
            //   8ad3                 | mov                 dl, bl
            //   8d80b8fee014         | lea                 eax, [eax + 0x14e0feb8]

        $sequence_13 = { 0016 40 3bc3 72de }
            // n = 4, score = 100
            //   0016                 | add                 byte ptr [esi], dl
            //   40                   | inc                 eax
            //   3bc3                 | cmp                 eax, ebx
            //   72de                 | jb                  0xffffffe0

        $sequence_14 = { 0145f0 8b4df0 3b4d14 0f8263feffff }
            // n = 4, score = 100
            //   0145f0               | add                 dword ptr [ebp - 0x10], eax
            //   8b4df0               | mov                 ecx, dword ptr [ebp - 0x10]
            //   3b4d14               | cmp                 ecx, dword ptr [ebp + 0x14]
            //   0f8263feffff         | jb                  0xfffffe69

        $sequence_15 = { 000c38 40 3b45f8 72e3 }
            // n = 4, score = 100
            //   000c38               | add                 byte ptr [eax + edi], cl
            //   40                   | inc                 eax
            //   3b45f8               | cmp                 eax, dword ptr [ebp - 8]
            //   72e3                 | jb                  0xffffffe5

        $sequence_16 = { 0144240c 85f6 7fdd 33c0 }
            // n = 4, score = 100
            //   0144240c             | add                 dword ptr [esp + 0xc], eax
            //   85f6                 | test                esi, esi
            //   7fdd                 | jg                  0xffffffdf
            //   33c0                 | xor                 eax, eax

        $sequence_17 = { 0106 eb94 55 8bec }
            // n = 4, score = 100
            //   0106                 | add                 dword ptr [esi], eax
            //   eb94                 | jmp                 0xffffff96
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp

        $sequence_18 = { 000e eb08 02c9 b2f9 }
            // n = 4, score = 100
            //   000e                 | add                 byte ptr [esi], cl
            //   eb08                 | jmp                 0xa
            //   02c9                 | add                 cl, cl
            //   b2f9                 | mov                 dl, 0xf9

    condition:
        7 of them and filesize < 761856
}