rule win_graftor_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.graftor."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.graftor"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d742434 c684245803000069 e8???????? 8b54241c 53 e8???????? 59 }
            // n = 7, score = 100
            //   8d742434             | lea                 esi, [esp + 0x34]
            //   c684245803000069     | mov                 byte ptr [esp + 0x358], 0x69
            //   e8????????           |                     
            //   8b54241c             | mov                 edx, dword ptr [esp + 0x1c]
            //   53                   | push                ebx
            //   e8????????           |                     
            //   59                   | pop                 ecx

        $sequence_1 = { 55 8bec 51 8365fc00 56 0528010000 }
            // n = 6, score = 100
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   51                   | push                ecx
            //   8365fc00             | and                 dword ptr [ebp - 4], 0
            //   56                   | push                esi
            //   0528010000           | add                 eax, 0x128

        $sequence_2 = { ff750c 8d7de0 ff7508 e8???????? 8b45e8 8945f0 8b45ec }
            // n = 7, score = 100
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   8d7de0               | lea                 edi, [ebp - 0x20]
            //   ff7508               | push                dword ptr [ebp + 8]
            //   e8????????           |                     
            //   8b45e8               | mov                 eax, dword ptr [ebp - 0x18]
            //   8945f0               | mov                 dword ptr [ebp - 0x10], eax
            //   8b45ec               | mov                 eax, dword ptr [ebp - 0x14]

        $sequence_3 = { 8d44247c 50 c684245c03000070 e8???????? 83c40c c684245003000071 8b4c241c }
            // n = 7, score = 100
            //   8d44247c             | lea                 eax, [esp + 0x7c]
            //   50                   | push                eax
            //   c684245c03000070     | mov                 byte ptr [esp + 0x35c], 0x70
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   c684245003000071     | mov                 byte ptr [esp + 0x350], 0x71
            //   8b4c241c             | mov                 ecx, dword ptr [esp + 0x1c]

        $sequence_4 = { 6a00 eb8b 8b7d0c 8b0f 8b4514 394810 7641 }
            // n = 7, score = 100
            //   6a00                 | push                0
            //   eb8b                 | jmp                 0xffffff8d
            //   8b7d0c               | mov                 edi, dword ptr [ebp + 0xc]
            //   8b0f                 | mov                 ecx, dword ptr [edi]
            //   8b4514               | mov                 eax, dword ptr [ebp + 0x14]
            //   394810               | cmp                 dword ptr [eax + 0x10], ecx
            //   7641                 | jbe                 0x43

        $sequence_5 = { 55 8bec 83e4f8 6aff 687e634c00 64a100000000 }
            // n = 6, score = 100
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   83e4f8               | and                 esp, 0xfffffff8
            //   6aff                 | push                -1
            //   687e634c00           | push                0x4c637e
            //   64a100000000         | mov                 eax, dword ptr fs:[0]

        $sequence_6 = { 8901 33c0 40 e9???????? 8365d800 c745dc34ad4800 a1???????? }
            // n = 7, score = 100
            //   8901                 | mov                 dword ptr [ecx], eax
            //   33c0                 | xor                 eax, eax
            //   40                   | inc                 eax
            //   e9????????           |                     
            //   8365d800             | and                 dword ptr [ebp - 0x28], 0
            //   c745dc34ad4800       | mov                 dword ptr [ebp - 0x24], 0x48ad34
            //   a1????????           |                     

        $sequence_7 = { ff75ec 8d45e0 53 50 8bc6 e8???????? 8b18 }
            // n = 7, score = 100
            //   ff75ec               | push                dword ptr [ebp - 0x14]
            //   8d45e0               | lea                 eax, [ebp - 0x20]
            //   53                   | push                ebx
            //   50                   | push                eax
            //   8bc6                 | mov                 eax, esi
            //   e8????????           |                     
            //   8b18                 | mov                 ebx, dword ptr [eax]

        $sequence_8 = { eb05 a1???????? 8b4dfc 33cd e8???????? c9 c3 }
            // n = 7, score = 100
            //   eb05                 | jmp                 7
            //   a1????????           |                     
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   33cd                 | xor                 ecx, ebp
            //   e8????????           |                     
            //   c9                   | leave               
            //   c3                   | ret                 

        $sequence_9 = { 3bc3 0f8686010000 8b87d0000000 6a64 99 5e f7fe }
            // n = 7, score = 100
            //   3bc3                 | cmp                 eax, ebx
            //   0f8686010000         | jbe                 0x18c
            //   8b87d0000000         | mov                 eax, dword ptr [edi + 0xd0]
            //   6a64                 | push                0x64
            //   99                   | cdq                 
            //   5e                   | pop                 esi
            //   f7fe                 | idiv                esi

    condition:
        7 of them and filesize < 294912
}