rule win_greetingghoul_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.greetingghoul."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.greetingghoul"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 56 57 8bf9 33f6 8a17 80fa20 }
            // n = 6, score = 200
            //   56                   | push                esi
            //   57                   | push                edi
            //   8bf9                 | mov                 edi, ecx
            //   33f6                 | xor                 esi, esi
            //   8a17                 | mov                 dl, byte ptr [edi]
            //   80fa20               | cmp                 dl, 0x20

        $sequence_1 = { 750d 8a5702 83c702 bb10000000 }
            // n = 4, score = 200
            //   750d                 | jne                 0xf
            //   8a5702               | mov                 dl, byte ptr [edi + 2]
            //   83c702               | add                 edi, 2
            //   bb10000000           | mov                 ebx, 0x10

        $sequence_2 = { 03f1 eb03 83ceff 8a17 84d2 75a9 }
            // n = 6, score = 200
            //   03f1                 | add                 esi, ecx
            //   eb03                 | jmp                 5
            //   83ceff               | or                  esi, 0xffffffff
            //   8a17                 | mov                 dl, byte ptr [edi]
            //   84d2                 | test                dl, dl
            //   75a9                 | jne                 0xffffffab

        $sequence_3 = { 2bc8 7409 8b7df8 4e 43 }
            // n = 5, score = 200
            //   2bc8                 | sub                 ecx, eax
            //   7409                 | je                  0xb
            //   8b7df8               | mov                 edi, dword ptr [ebp - 8]
            //   4e                   | dec                 esi
            //   43                   | inc                 ebx

        $sequence_4 = { 751f 41 84c0 7405 83ea01 75eb 8b5dfc }
            // n = 7, score = 200
            //   751f                 | jne                 0x21
            //   41                   | inc                 ecx
            //   84c0                 | test                al, al
            //   7405                 | je                  7
            //   83ea01               | sub                 edx, 1
            //   75eb                 | jne                 0xffffffed
            //   8b5dfc               | mov                 ebx, dword ptr [ebp - 4]

        $sequence_5 = { 43 895dfc 47 eba7 5f 5e 83c8ff }
            // n = 7, score = 200
            //   43                   | inc                 ebx
            //   895dfc               | mov                 dword ptr [ebp - 4], ebx
            //   47                   | inc                 edi
            //   eba7                 | jmp                 0xffffffa9
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   83c8ff               | or                  eax, 0xffffffff

        $sequence_6 = { 8a1a 8d5201 8a08 3acb 750c 40 84c9 }
            // n = 7, score = 200
            //   8a1a                 | mov                 bl, byte ptr [edx]
            //   8d5201               | lea                 edx, [edx + 1]
            //   8a08                 | mov                 cl, byte ptr [eax]
            //   3acb                 | cmp                 cl, bl
            //   750c                 | jne                 0xe
            //   40                   | inc                 eax
            //   84c9                 | test                cl, cl

        $sequence_7 = { 33db 895dfc 8945f4 3806 740b }
            // n = 5, score = 200
            //   33db                 | xor                 ebx, ebx
            //   895dfc               | mov                 dword ptr [ebp - 4], ebx
            //   8945f4               | mov                 dword ptr [ebp - 0xc], eax
            //   3806                 | cmp                 byte ptr [esi], al
            //   740b                 | je                  0xd

        $sequence_8 = { 83c404 891e 85db 746f 8b7508 0f57c0 57 }
            // n = 7, score = 200
            //   83c404               | add                 esp, 4
            //   891e                 | mov                 dword ptr [esi], ebx
            //   85db                 | test                ebx, ebx
            //   746f                 | je                  0x71
            //   8b7508               | mov                 esi, dword ptr [ebp + 8]
            //   0f57c0               | xorps               xmm0, xmm0
            //   57                   | push                edi

        $sequence_9 = { 7457 8d42d0 3c09 7708 }
            // n = 4, score = 200
            //   7457                 | je                  0x59
            //   8d42d0               | lea                 eax, [edx - 0x30]
            //   3c09                 | cmp                 al, 9
            //   7708                 | ja                  0xa

    condition:
        7 of them and filesize < 696320
}