rule win_grok_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.grok."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.grok"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 39702c 7413 56 ff702c ffd3 a1???????? 89702c }
            // n = 7, score = 400
            //   39702c               | cmp                 dword ptr [eax + 0x2c], esi
            //   7413                 | je                  0x15
            //   56                   | push                esi
            //   ff702c               | push                dword ptr [eax + 0x2c]
            //   ffd3                 | call                ebx
            //   a1????????           |                     
            //   89702c               | mov                 dword ptr [eax + 0x2c], esi

        $sequence_1 = { 7c62 a1???????? 397044 7412 56 ff7044 ff15???????? }
            // n = 7, score = 400
            //   7c62                 | jl                  0x64
            //   a1????????           |                     
            //   397044               | cmp                 dword ptr [eax + 0x44], esi
            //   7412                 | je                  0x14
            //   56                   | push                esi
            //   ff7044               | push                dword ptr [eax + 0x44]
            //   ff15????????         |                     

        $sequence_2 = { 51 57 50 e8???????? 83c40c 57 53 }
            // n = 7, score = 400
            //   51                   | push                ecx
            //   57                   | push                edi
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   57                   | push                edi
            //   53                   | push                ebx

        $sequence_3 = { 33ff 897dd8 81ff00010000 7d28 8d0c17 8b4514 03c7 }
            // n = 7, score = 400
            //   33ff                 | xor                 edi, edi
            //   897dd8               | mov                 dword ptr [ebp - 0x28], edi
            //   81ff00010000         | cmp                 edi, 0x100
            //   7d28                 | jge                 0x2a
            //   8d0c17               | lea                 ecx, [edi + edx]
            //   8b4514               | mov                 eax, dword ptr [ebp + 0x14]
            //   03c7                 | add                 eax, edi

        $sequence_4 = { a1???????? 895820 a1???????? 395824 }
            // n = 4, score = 400
            //   a1????????           |                     
            //   895820               | mov                 dword ptr [eax + 0x20], ebx
            //   a1????????           |                     
            //   395824               | cmp                 dword ptr [eax + 0x24], ebx

        $sequence_5 = { 894df4 eb09 8b55f4 83c201 8955f4 8b45f8 83c009 }
            // n = 7, score = 400
            //   894df4               | mov                 dword ptr [ebp - 0xc], ecx
            //   eb09                 | jmp                 0xb
            //   8b55f4               | mov                 edx, dword ptr [ebp - 0xc]
            //   83c201               | add                 edx, 1
            //   8955f4               | mov                 dword ptr [ebp - 0xc], edx
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   83c009               | add                 eax, 9

        $sequence_6 = { 5f 56 56 6a22 6a01 56 }
            // n = 6, score = 400
            //   5f                   | pop                 edi
            //   56                   | push                esi
            //   56                   | push                esi
            //   6a22                 | push                0x22
            //   6a01                 | push                1
            //   56                   | push                esi

        $sequence_7 = { 50 e8???????? 3bc3 7d7e 395d08 7479 3d430000c0 }
            // n = 7, score = 400
            //   50                   | push                eax
            //   e8????????           |                     
            //   3bc3                 | cmp                 eax, ebx
            //   7d7e                 | jge                 0x80
            //   395d08               | cmp                 dword ptr [ebp + 8], ebx
            //   7479                 | je                  0x7b
            //   3d430000c0           | cmp                 eax, 0xc0000043

        $sequence_8 = { 33ff 47 3bc3 8945fc 0f8c9c000000 391d???????? 7410 }
            // n = 7, score = 400
            //   33ff                 | xor                 edi, edi
            //   47                   | inc                 edi
            //   3bc3                 | cmp                 eax, ebx
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   0f8c9c000000         | jl                  0xa2
            //   391d????????         |                     
            //   7410                 | je                  0x12

        $sequence_9 = { 53 51 03c6 50 e8???????? 8b463c 8d8c3080000000 }
            // n = 7, score = 400
            //   53                   | push                ebx
            //   51                   | push                ecx
            //   03c6                 | add                 eax, esi
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b463c               | mov                 eax, dword ptr [esi + 0x3c]
            //   8d8c3080000000       | lea                 ecx, [eax + esi + 0x80]

    condition:
        7 of them and filesize < 84992
}