rule win_gsecdump_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.gsecdump."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.gsecdump"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c7060f000000 c746fc00000000 c646ec00 83c61c 8d56e8 3bd7 }
            // n = 6, score = 100
            //   c7060f000000         | mov                 dword ptr [esi], 0xf
            //   c746fc00000000       | mov                 dword ptr [esi - 4], 0
            //   c646ec00             | mov                 byte ptr [esi - 0x14], 0
            //   83c61c               | add                 esi, 0x1c
            //   8d56e8               | lea                 edx, [esi - 0x18]
            //   3bd7                 | cmp                 edx, edi

        $sequence_1 = { 8b442438 50 e8???????? 83c404 8b4c2478 64890d00000000 59 }
            // n = 7, score = 100
            //   8b442438             | mov                 eax, dword ptr [esp + 0x38]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   8b4c2478             | mov                 ecx, dword ptr [esp + 0x78]
            //   64890d00000000       | mov                 dword ptr fs:[0], ecx
            //   59                   | pop                 ecx

        $sequence_2 = { 7205 e8???????? 83460401 e9???????? 8b06 83f8fe }
            // n = 6, score = 100
            //   7205                 | jb                  7
            //   e8????????           |                     
            //   83460401             | add                 dword ptr [esi + 4], 1
            //   e9????????           |                     
            //   8b06                 | mov                 eax, dword ptr [esi]
            //   83f8fe               | cmp                 eax, -2

        $sequence_3 = { 7376 8bcf c1e105 894d14 03cb 51 50 }
            // n = 7, score = 100
            //   7376                 | jae                 0x78
            //   8bcf                 | mov                 ecx, edi
            //   c1e105               | shl                 ecx, 5
            //   894d14               | mov                 dword ptr [ebp + 0x14], ecx
            //   03cb                 | add                 ecx, ebx
            //   51                   | push                ecx
            //   50                   | push                eax

        $sequence_4 = { 8d57fe 52 53 8d442430 50 8bce e8???????? }
            // n = 7, score = 100
            //   8d57fe               | lea                 edx, [edi - 2]
            //   52                   | push                edx
            //   53                   | push                ebx
            //   8d442430             | lea                 eax, [esp + 0x30]
            //   50                   | push                eax
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     

        $sequence_5 = { 51 e8???????? 83c408 85ff 8bf7 0f869afdffff 8b4c2414 }
            // n = 7, score = 100
            //   51                   | push                ecx
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   85ff                 | test                edi, edi
            //   8bf7                 | mov                 esi, edi
            //   0f869afdffff         | jbe                 0xfffffda0
            //   8b4c2414             | mov                 ecx, dword ptr [esp + 0x14]

        $sequence_6 = { 50 8d8c24bc000000 c684244401000004 e8???????? 8d4c2428 889c2438010000 e8???????? }
            // n = 7, score = 100
            //   50                   | push                eax
            //   8d8c24bc000000       | lea                 ecx, [esp + 0xbc]
            //   c684244401000004     | mov                 byte ptr [esp + 0x144], 4
            //   e8????????           |                     
            //   8d4c2428             | lea                 ecx, [esp + 0x28]
            //   889c2438010000       | mov                 byte ptr [esp + 0x138], bl
            //   e8????????           |                     

        $sequence_7 = { 8b4604 3b442424 0f84a3000000 8b06 83f8fe 7427 85c0 }
            // n = 7, score = 100
            //   8b4604               | mov                 eax, dword ptr [esi + 4]
            //   3b442424             | cmp                 eax, dword ptr [esp + 0x24]
            //   0f84a3000000         | je                  0xa9
            //   8b06                 | mov                 eax, dword ptr [esi]
            //   83f8fe               | cmp                 eax, -2
            //   7427                 | je                  0x29
            //   85c0                 | test                eax, eax

        $sequence_8 = { 50 e8???????? 8b4538 3bc6 7409 50 e8???????? }
            // n = 7, score = 100
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b4538               | mov                 eax, dword ptr [ebp + 0x38]
            //   3bc6                 | cmp                 eax, esi
            //   7409                 | je                  0xb
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_9 = { 33d2 59 f7f1 33f6 8d2c95908c4400 8b7d00 85ff }
            // n = 7, score = 100
            //   33d2                 | xor                 edx, edx
            //   59                   | pop                 ecx
            //   f7f1                 | div                 ecx
            //   33f6                 | xor                 esi, esi
            //   8d2c95908c4400       | lea                 ebp, [edx*4 + 0x448c90]
            //   8b7d00               | mov                 edi, dword ptr [ebp]
            //   85ff                 | test                edi, edi

    condition:
        7 of them and filesize < 630784
}