rule win_gup_proxy_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.gup_proxy."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.gup_proxy"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c744244400000000 c644243400 e8???????? c784242002000000000000 8d4c2444 6a00 }
            // n = 6, score = 100
            //   c744244400000000     | mov                 dword ptr [esp + 0x44], 0
            //   c644243400           | mov                 byte ptr [esp + 0x34], 0
            //   e8????????           |                     
            //   c784242002000000000000     | mov    dword ptr [esp + 0x220], 0
            //   8d4c2444             | lea                 ecx, [esp + 0x44]
            //   6a00                 | push                0

        $sequence_1 = { c1e606 03348510974100 33db 395e08 }
            // n = 4, score = 100
            //   c1e606               | shl                 esi, 6
            //   03348510974100       | add                 esi, dword ptr [eax*4 + 0x419710]
            //   33db                 | xor                 ebx, ebx
            //   395e08               | cmp                 dword ptr [esi + 8], ebx

        $sequence_2 = { 8b04bd10974100 830c06ff 33c0 eb16 e8???????? c70009000000 }
            // n = 6, score = 100
            //   8b04bd10974100       | mov                 eax, dword ptr [edi*4 + 0x419710]
            //   830c06ff             | or                  dword ptr [esi + eax], 0xffffffff
            //   33c0                 | xor                 eax, eax
            //   eb16                 | jmp                 0x18
            //   e8????????           |                     
            //   c70009000000         | mov                 dword ptr [eax], 9

        $sequence_3 = { c1f805 c1e606 8b048510974100 80643004fd 8b45f8 8b55fc 5f }
            // n = 7, score = 100
            //   c1f805               | sar                 eax, 5
            //   c1e606               | shl                 esi, 6
            //   8b048510974100       | mov                 eax, dword ptr [eax*4 + 0x419710]
            //   80643004fd           | and                 byte ptr [eax + esi + 4], 0xfd
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   5f                   | pop                 edi

        $sequence_4 = { c78588feffffc22eab48 50 8bce e8???????? 8bc3 889d88feffff c1e818 }
            // n = 7, score = 100
            //   c78588feffffc22eab48     | mov    dword ptr [ebp - 0x178], 0x48ab2ec2
            //   50                   | push                eax
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     
            //   8bc3                 | mov                 eax, ebx
            //   889d88feffff         | mov                 byte ptr [ebp - 0x178], bl
            //   c1e818               | shr                 eax, 0x18

        $sequence_5 = { c3 b8???????? c705????????61984000 a3???????? c705????????f2984000 c705????????4c994000 c705????????d1994000 }
            // n = 7, score = 100
            //   c3                   | ret                 
            //   b8????????           |                     
            //   c705????????61984000     |     
            //   a3????????           |                     
            //   c705????????f2984000     |     
            //   c705????????4c994000     |     
            //   c705????????d1994000     |     

        $sequence_6 = { c784242002000000000000 8d4c2444 6a00 68???????? c74424600f000000 c744245c00000000 c644244c00 }
            // n = 7, score = 100
            //   c784242002000000000000     | mov    dword ptr [esp + 0x220], 0
            //   8d4c2444             | lea                 ecx, [esp + 0x44]
            //   6a00                 | push                0
            //   68????????           |                     
            //   c74424600f000000     | mov                 dword ptr [esp + 0x60], 0xf
            //   c744245c00000000     | mov                 dword ptr [esp + 0x5c], 0
            //   c644244c00           | mov                 byte ptr [esp + 0x4c], 0

        $sequence_7 = { ebb4 c745e4d8a04100 a1???????? eb1a c745e4d4a04100 a1???????? }
            // n = 6, score = 100
            //   ebb4                 | jmp                 0xffffffb6
            //   c745e4d8a04100       | mov                 dword ptr [ebp - 0x1c], 0x41a0d8
            //   a1????????           |                     
            //   eb1a                 | jmp                 0x1c
            //   c745e4d4a04100       | mov                 dword ptr [ebp - 0x1c], 0x41a0d4
            //   a1????????           |                     

        $sequence_8 = { ff15???????? 8b04bd10974100 830c06ff 33c0 }
            // n = 4, score = 100
            //   ff15????????         |                     
            //   8b04bd10974100       | mov                 eax, dword ptr [edi*4 + 0x419710]
            //   830c06ff             | or                  dword ptr [esi + eax], 0xffffffff
            //   33c0                 | xor                 eax, eax

        $sequence_9 = { 53 ff15???????? 83f8ff 752a 32c0 }
            // n = 5, score = 100
            //   53                   | push                ebx
            //   ff15????????         |                     
            //   83f8ff               | cmp                 eax, -1
            //   752a                 | jne                 0x2c
            //   32c0                 | xor                 al, al

    condition:
        7 of them and filesize < 247808
}