rule win_h1n1_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.h1n1."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.h1n1"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 49 85c9 0f8527ffffff ff75f8 }
            // n = 4, score = 400
            //   49                   | dec                 ecx
            //   85c9                 | test                ecx, ecx
            //   0f8527ffffff         | jne                 0xffffff2d
            //   ff75f8               | push                dword ptr [ebp - 8]

        $sequence_1 = { 49 75b6 8bcf 2b4d0c 83e103 }
            // n = 5, score = 400
            //   49                   | dec                 ecx
            //   75b6                 | jne                 0xffffffb8
            //   8bcf                 | mov                 ecx, edi
            //   2b4d0c               | sub                 ecx, dword ptr [ebp + 0xc]
            //   83e103               | and                 ecx, 3

        $sequence_2 = { 83bdecfeffff01 7505 bb07000000 93 5b c9 c3 }
            // n = 7, score = 400
            //   83bdecfeffff01       | cmp                 dword ptr [ebp - 0x114], 1
            //   7505                 | jne                 7
            //   bb07000000           | mov                 ebx, 7
            //   93                   | xchg                eax, ebx
            //   5b                   | pop                 ebx
            //   c9                   | leave               
            //   c3                   | ret                 

        $sequence_3 = { aa ac 0ac0 740e 3c3d 740a e8???????? }
            // n = 7, score = 400
            //   aa                   | stosb               byte ptr es:[edi], al
            //   ac                   | lodsb               al, byte ptr [esi]
            //   0ac0                 | or                  al, al
            //   740e                 | je                  0x10
            //   3c3d                 | cmp                 al, 0x3d
            //   740a                 | je                  0xc
            //   e8????????           |                     

        $sequence_4 = { 0345f4 8b8ba4000000 85c9 742b }
            // n = 4, score = 400
            //   0345f4               | add                 eax, dword ptr [ebp - 0xc]
            //   8b8ba4000000         | mov                 ecx, dword ptr [ebx + 0xa4]
            //   85c9                 | test                ecx, ecx
            //   742b                 | je                  0x2d

        $sequence_5 = { ff7508 6a00 ff35???????? 58 ffd0 }
            // n = 5, score = 400
            //   ff7508               | push                dword ptr [ebp + 8]
            //   6a00                 | push                0
            //   ff35????????         |                     
            //   58                   | pop                 eax
            //   ffd0                 | call                eax

        $sequence_6 = { 351f5b5742 ab 05f8383ad2 ab ff75fc }
            // n = 5, score = 400
            //   351f5b5742           | xor                 eax, 0x42575b1f
            //   ab                   | stosd               dword ptr es:[edi], eax
            //   05f8383ad2           | add                 eax, 0xd23a38f8
            //   ab                   | stosd               dword ptr es:[edi], eax
            //   ff75fc               | push                dword ptr [ebp - 4]

        $sequence_7 = { 59 85c0 75d1 83bb8000000000 7465 }
            // n = 5, score = 400
            //   59                   | pop                 ecx
            //   85c0                 | test                eax, eax
            //   75d1                 | jne                 0xffffffd3
            //   83bb8000000000       | cmp                 dword ptr [ebx + 0x80], 0
            //   7465                 | je                  0x67

        $sequence_8 = { 8d8614850010 50 ffb610850010 57 }
            // n = 4, score = 100
            //   8d8614850010         | lea                 eax, [esi + 0x10008514]
            //   50                   | push                eax
            //   ffb610850010         | push                dword ptr [esi + 0x10008510]
            //   57                   | push                edi

        $sequence_9 = { 59 c3 56 8b742408 6804010000 68f8820010 }
            // n = 6, score = 100
            //   59                   | pop                 ecx
            //   c3                   | ret                 
            //   56                   | push                esi
            //   8b742408             | mov                 esi, dword ptr [esp + 8]
            //   6804010000           | push                0x104
            //   68f8820010           | push                0x100082f8

        $sequence_10 = { 330c85908f0010 42 3b54240c 72e4 f7d1 8bc1 }
            // n = 6, score = 100
            //   330c85908f0010       | xor                 ecx, dword ptr [eax*4 + 0x10008f90]
            //   42                   | inc                 edx
            //   3b54240c             | cmp                 edx, dword ptr [esp + 0xc]
            //   72e4                 | jb                  0xffffffe6
            //   f7d1                 | not                 ecx
            //   8bc1                 | mov                 eax, ecx

        $sequence_11 = { 57 8d3c95c0850010 8b0f 334f04 23cb }
            // n = 5, score = 100
            //   57                   | push                edi
            //   8d3c95c0850010       | lea                 edi, [edx*4 + 0x100085c0]
            //   8b0f                 | mov                 ecx, dword ptr [edi]
            //   334f04               | xor                 ecx, dword ptr [edi + 4]
            //   23cb                 | and                 ecx, ebx

        $sequence_12 = { 330d???????? 5b 8bc1 83e001 d1e9 330c8500850010 330d???????? }
            // n = 7, score = 100
            //   330d????????         |                     
            //   5b                   | pop                 ebx
            //   8bc1                 | mov                 eax, ecx
            //   83e001               | and                 eax, 1
            //   d1e9                 | shr                 ecx, 1
            //   330c8500850010       | xor                 ecx, dword ptr [eax*4 + 0x10008500]
            //   330d????????         |                     

        $sequence_13 = { 57 50 e8???????? 68f4600010 56 }
            // n = 5, score = 100
            //   57                   | push                edi
            //   50                   | push                eax
            //   e8????????           |                     
            //   68f4600010           | push                0x100060f4
            //   56                   | push                esi

        $sequence_14 = { 33d2 a3???????? 42 b9c0850010 8b01 c1e81e 3301 }
            // n = 7, score = 100
            //   33d2                 | xor                 edx, edx
            //   a3????????           |                     
            //   42                   | inc                 edx
            //   b9c0850010           | mov                 ecx, 0x100085c0
            //   8b01                 | mov                 eax, dword ptr [ecx]
            //   c1e81e               | shr                 eax, 0x1e
            //   3301                 | xor                 eax, dword ptr [ecx]

        $sequence_15 = { 6800800010 ff742410 e8???????? 6823af2930 56 ff742410 }
            // n = 6, score = 100
            //   6800800010           | push                0x10008000
            //   ff742410             | push                dword ptr [esp + 0x10]
            //   e8????????           |                     
            //   6823af2930           | push                0x3029af23
            //   56                   | push                esi
            //   ff742410             | push                dword ptr [esp + 0x10]

    condition:
        7 of them and filesize < 172032
}