rule win_hamweq_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.hamweq."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.hamweq"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 53 51 8b4e08 8945f8 ffb148010000 ff5044 }
            // n = 6, score = 200
            //   53                   | push                ebx
            //   51                   | push                ecx
            //   8b4e08               | mov                 ecx, dword ptr [esi + 8]
            //   8945f8               | mov                 dword ptr [ebp - 8], eax
            //   ffb148010000         | push                dword ptr [ecx + 0x148]
            //   ff5044               | call                dword ptr [eax + 0x44]

        $sequence_1 = { 8d85e4f1ffff 50 ff5744 50 }
            // n = 4, score = 200
            //   8d85e4f1ffff         | lea                 eax, [ebp - 0xe1c]
            //   50                   | push                eax
            //   ff5744               | call                dword ptr [edi + 0x44]
            //   50                   | push                eax

        $sequence_2 = { 837c910800 8d449108 894514 0f8438010000 837c910c00 }
            // n = 5, score = 200
            //   837c910800           | cmp                 dword ptr [ecx + edx*4 + 8], 0
            //   8d449108             | lea                 eax, [ecx + edx*4 + 8]
            //   894514               | mov                 dword ptr [ebp + 0x14], eax
            //   0f8438010000         | je                  0x13e
            //   837c910c00           | cmp                 dword ptr [ecx + edx*4 + 0xc], 0

        $sequence_3 = { 668b4804 51 ff30 56 e8???????? 83c40c }
            // n = 6, score = 200
            //   668b4804             | mov                 cx, word ptr [eax + 4]
            //   51                   | push                ecx
            //   ff30                 | push                dword ptr [eax]
            //   56                   | push                esi
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc

        $sequence_4 = { 51 ff5040 8b0e 8d85ecfeffff 53 50 }
            // n = 6, score = 200
            //   51                   | push                ecx
            //   ff5040               | call                dword ptr [eax + 0x40]
            //   8b0e                 | mov                 ecx, dword ptr [esi]
            //   8d85ecfeffff         | lea                 eax, [ebp - 0x114]
            //   53                   | push                ebx
            //   50                   | push                eax

        $sequence_5 = { 7504 6afe ebea 8b4e08 8b06 ff7170 }
            // n = 6, score = 200
            //   7504                 | jne                 6
            //   6afe                 | push                -2
            //   ebea                 | jmp                 0xffffffec
            //   8b4e08               | mov                 ecx, dword ptr [esi + 8]
            //   8b06                 | mov                 eax, dword ptr [esi]
            //   ff7170               | push                dword ptr [ecx + 0x70]

        $sequence_6 = { 8d4580 8b0b 50 ff5154 }
            // n = 4, score = 200
            //   8d4580               | lea                 eax, [ebp - 0x80]
            //   8b0b                 | mov                 ecx, dword ptr [ebx]
            //   50                   | push                eax
            //   ff5154               | call                dword ptr [ecx + 0x54]

        $sequence_7 = { 8b06 753c ffb1d8000000 8d8d00feffff 51 }
            // n = 5, score = 200
            //   8b06                 | mov                 eax, dword ptr [esi]
            //   753c                 | jne                 0x3e
            //   ffb1d8000000         | push                dword ptr [ecx + 0xd8]
            //   8d8d00feffff         | lea                 ecx, [ebp - 0x200]
            //   51                   | push                ecx

        $sequence_8 = { 51 8d4d80 51 ff5054 eb12 8b5d08 }
            // n = 6, score = 200
            //   51                   | push                ecx
            //   8d4d80               | lea                 ecx, [ebp - 0x80]
            //   51                   | push                ecx
            //   ff5054               | call                dword ptr [eax + 0x54]
            //   eb12                 | jmp                 0x14
            //   8b5d08               | mov                 ebx, dword ptr [ebp + 8]

        $sequence_9 = { c3 8b442408 8a08 84c9 7408 }
            // n = 5, score = 200
            //   c3                   | ret                 
            //   8b442408             | mov                 eax, dword ptr [esp + 8]
            //   8a08                 | mov                 cl, byte ptr [eax]
            //   84c9                 | test                cl, cl
            //   7408                 | je                  0xa

    condition:
        7 of them and filesize < 24576
}