rule win_headertip_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.headertip."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.headertip"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 85c0 7434 8b07 ff4d08 03c3 56 }
            // n = 6, score = 100
            //   85c0                 | test                eax, eax
            //   7434                 | je                  0x36
            //   8b07                 | mov                 eax, dword ptr [edi]
            //   ff4d08               | dec                 dword ptr [ebp + 8]
            //   03c3                 | add                 eax, ebx
            //   56                   | push                esi

        $sequence_1 = { 57 ff15???????? 59 eb32 ffd6 }
            // n = 5, score = 100
            //   57                   | push                edi
            //   ff15????????         |                     
            //   59                   | pop                 ecx
            //   eb32                 | jmp                 0x34
            //   ffd6                 | call                esi

        $sequence_2 = { c645d274 c645d36f c645d472 c645d579 c645d657 885dd7 c645ac47 }
            // n = 7, score = 100
            //   c645d274             | mov                 byte ptr [ebp - 0x2e], 0x74
            //   c645d36f             | mov                 byte ptr [ebp - 0x2d], 0x6f
            //   c645d472             | mov                 byte ptr [ebp - 0x2c], 0x72
            //   c645d579             | mov                 byte ptr [ebp - 0x2b], 0x79
            //   c645d657             | mov                 byte ptr [ebp - 0x2a], 0x57
            //   885dd7               | mov                 byte ptr [ebp - 0x29], bl
            //   c645ac47             | mov                 byte ptr [ebp - 0x54], 0x47

        $sequence_3 = { c6458d75 c6458e65 c6458f72 c6459079 c645914f c6459270 c6459374 }
            // n = 7, score = 100
            //   c6458d75             | mov                 byte ptr [ebp - 0x73], 0x75
            //   c6458e65             | mov                 byte ptr [ebp - 0x72], 0x65
            //   c6458f72             | mov                 byte ptr [ebp - 0x71], 0x72
            //   c6459079             | mov                 byte ptr [ebp - 0x70], 0x79
            //   c645914f             | mov                 byte ptr [ebp - 0x6f], 0x4f
            //   c6459270             | mov                 byte ptr [ebp - 0x6e], 0x70
            //   c6459374             | mov                 byte ptr [ebp - 0x6d], 0x74

        $sequence_4 = { 56 8d45ec 50 8d45f0 50 6813000020 }
            // n = 6, score = 100
            //   56                   | push                esi
            //   8d45ec               | lea                 eax, [ebp - 0x14]
            //   50                   | push                eax
            //   8d45f0               | lea                 eax, [ebp - 0x10]
            //   50                   | push                eax
            //   6813000020           | push                0x20000013

        $sequence_5 = { 894df4 8955fc f7c60000ffff 7513 81e6ffff0000 2b7010 }
            // n = 6, score = 100
            //   894df4               | mov                 dword ptr [ebp - 0xc], ecx
            //   8955fc               | mov                 dword ptr [ebp - 4], edx
            //   f7c60000ffff         | test                esi, 0xffff0000
            //   7513                 | jne                 0x15
            //   81e6ffff0000         | and                 esi, 0xffff
            //   2b7010               | sub                 esi, dword ptr [eax + 0x10]

        $sequence_6 = { 03c6 ebea 56 8b742410 57 }
            // n = 5, score = 100
            //   03c6                 | add                 eax, esi
            //   ebea                 | jmp                 0xffffffec
            //   56                   | push                esi
            //   8b742410             | mov                 esi, dword ptr [esp + 0x10]
            //   57                   | push                edi

        $sequence_7 = { 58 668945f8 6a32 58 668945fa 33c0 668945fc }
            // n = 7, score = 100
            //   58                   | pop                 eax
            //   668945f8             | mov                 word ptr [ebp - 8], ax
            //   6a32                 | push                0x32
            //   58                   | pop                 eax
            //   668945fa             | mov                 word ptr [ebp - 6], ax
            //   33c0                 | xor                 eax, eax
            //   668945fc             | mov                 word ptr [ebp - 4], ax

        $sequence_8 = { ff15???????? a3???????? 3bc6 0f84c0000000 53 8d4df4 }
            // n = 6, score = 100
            //   ff15????????         |                     
            //   a3????????           |                     
            //   3bc6                 | cmp                 eax, esi
            //   0f84c0000000         | je                  0xc6
            //   53                   | push                ebx
            //   8d4df4               | lea                 ecx, [ebp - 0xc]

        $sequence_9 = { 50 ff15???????? 83c414 56 b80013e084 50 56 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   ff15????????         |                     
            //   83c414               | add                 esp, 0x14
            //   56                   | push                esi
            //   b80013e084           | mov                 eax, 0x84e01300
            //   50                   | push                eax
            //   56                   | push                esi

    condition:
        7 of them and filesize < 174080
}