rule win_hive_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.hive."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.hive"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 31c0 b91d000000 31d2 31db }
            // n = 4, score = 300
            //   31c0                 | inc                 eax
            //   b91d000000           | movzx               ecx, bh
            //   31d2                 | add                 ecx, eax
            //   31db                 | shl                 ecx, 6

        $sequence_1 = { b807000000 b9d4000000 31d2 31db }
            // n = 4, score = 300
            //   b807000000           | inc                 eax
            //   b9d4000000           | movzx               edx, dh
            //   31d2                 | add                 eax, ecx
            //   31db                 | shl                 eax, 6

        $sequence_2 = { 89c2 e8???????? b801000000 e8???????? }
            // n = 4, score = 200
            //   89c2                 | dec                 ebp
            //   e8????????           |                     
            //   b801000000           | test                edi, edi
            //   e8????????           |                     

        $sequence_3 = { 31c9 31d2 bb54000000 31f6 }
            // n = 4, score = 200
            //   31c9                 | xor                 ebx, ebx
            //   31d2                 | xor                 edi, edi
            //   bb54000000           | jmp                 0x37
            //   31f6                 | xor                 eax, eax

        $sequence_4 = { 89d1 e8???????? b802000000 e8???????? }
            // n = 4, score = 200
            //   89d1                 | dec                 ebp
            //   e8????????           |                     
            //   b802000000           | test                edi, edi
            //   e8????????           |                     

        $sequence_5 = { 31c9 31d2 bb08000000 becb000000 31ff }
            // n = 5, score = 200
            //   31c9                 | nop                 
            //   31d2                 | add                 esp, 0xb0
            //   bb08000000           | ret                 
            //   becb000000           | nop                 
            //   31ff                 | ret                 

        $sequence_6 = { 89d0 b90d000000 e8???????? b90d000000 }
            // n = 4, score = 200
            //   89d0                 | shl                 edx, 6
            //   b90d000000           | movzx               eax, bl
            //   e8????????           |                     
            //   b90d000000           | add                 eax, edx

        $sequence_7 = { 31db 31ff eb31 31c0 }
            // n = 4, score = 200
            //   31db                 | mov                 ecx, 0xd
            //   31ff                 | mov                 ecx, 0xd
            //   eb31                 | mov                 ecx, edx
            //   31c0                 | mov                 eax, 2

        $sequence_8 = { 31ff e8???????? 833d????????00 7511 }
            // n = 4, score = 200
            //   31ff                 | mov                 eax, edx
            //   e8????????           |                     
            //   833d????????00       |                     
            //   7511                 | mov                 ecx, 0xd

        $sequence_9 = { 89d1 e8???????? b901000000 e8???????? }
            // n = 4, score = 200
            //   89d1                 | add                 eax, edx
            //   e8????????           |                     
            //   b901000000           | dec                 ebp
            //   e8????????           |                     

        $sequence_10 = { 81c4b0000000 c3 e8???????? 90 }
            // n = 4, score = 200
            //   81c4b0000000         | movzx               eax, bl
            //   c3                   | add                 eax, edx
            //   e8????????           |                     
            //   90                   | add                 edx, ecx

        $sequence_11 = { 31c9 31d2 bb09000000 bee0000000 }
            // n = 4, score = 200
            //   31c9                 | xor                 edx, edx
            //   31d2                 | xor                 ebx, ebx
            //   bb09000000           | xor                 eax, eax
            //   bee0000000           | mov                 ecx, 0xaa

        $sequence_12 = { 31c0 eb17 0fb6940496000000 0fb674041c 31d6 }
            // n = 5, score = 200
            //   31c0                 | xor                 ebx, edx
            //   eb17                 | lea                 ebx, [eax + ebx]
            //   0fb6940496000000     | lea                 ebx, [ebx + 0xe]
            //   0fb674041c           | mov                 eax, 7
            //   31d6                 | mov                 ecx, 0xd4

        $sequence_13 = { 01c1 83c101 83f90c 0f820fffffff }
            // n = 4, score = 100
            //   01c1                 | je                  0x269
            //   83c101               | add                 eax, eax
            //   83f90c               | inc                 eax
            //   0f820fffffff         | add                 al, bh

        $sequence_14 = { 01c1 c1e106 400fb6d6 01ca }
            // n = 4, score = 100
            //   01c1                 | add                 ecx, eax
            //   c1e106               | shl                 ecx, 6
            //   400fb6d6             | movzx               eax, dl
            //   01ca                 | add                 eax, ecx

        $sequence_15 = { 01c8 c1e006 400fb6cf 01c1 }
            // n = 4, score = 100
            //   01c8                 | and                 ecx, eax
            //   c1e006               | inc                 ecx
            //   400fb6cf             | mov                 dword ptr [edi + 0x14], ecx
            //   01c1                 | add                 eax, ecx

        $sequence_16 = { 01c1 c1e106 0fb6c2 01c8 }
            // n = 4, score = 100
            //   01c1                 | jb                  0xfffffe9c
            //   c1e106               | mov                 edx, 5
            //   0fb6c2               | add                 ecx, eax
            //   01c8                 | add                 ecx, 1

        $sequence_17 = { 01c2 b8ffffff03 21c5 21c3 }
            // n = 4, score = 100
            //   01c2                 | inc                 eax
            //   b8ffffff03           | movzx               edx, dh
            //   21c5                 | add                 edx, ecx
            //   21c3                 | add                 ecx, eax

        $sequence_18 = { 01c0 4000f8 0fb6c0 48898424b0000000 }
            // n = 4, score = 100
            //   01c0                 | add                 eax, eax
            //   4000f8               | inc                 eax
            //   0fb6c0               | add                 al, bh
            //   48898424b0000000     | movzx               eax, al

        $sequence_19 = { 01ca c1e206 0fb6c3 01d0 }
            // n = 4, score = 100
            //   01ca                 | mov                 ecx, eax
            //   c1e206               | shr                 ecx, 0x1f
            //   0fb6c3               | dec                 ecx
            //   01d0                 | inc                 ecx

        $sequence_20 = { 01c8 89c1 c1e91f ffc9 }
            // n = 4, score = 100
            //   01c8                 | movzx               eax, bl
            //   89c1                 | add                 eax, edx
            //   c1e91f               | add                 edx, eax
            //   ffc9                 | mov                 eax, 0x3ffffff

    condition:
        7 of them and filesize < 7946240
}