rule win_hlux_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.hlux."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.hlux"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 81f949e2a499 750b 83f90e 7406 }
            // n = 4, score = 100
            //   81f949e2a499         | cmp                 ecx, 0x99a4e249
            //   750b                 | jne                 0xd
            //   83f90e               | cmp                 ecx, 0xe
            //   7406                 | je                  8

        $sequence_1 = { 0101 c9 c3 6a10 }
            // n = 4, score = 100
            //   0101                 | add                 dword ptr [ecx], eax
            //   c9                   | leave               
            //   c3                   | ret                 
            //   6a10                 | push                0x10

        $sequence_2 = { 0009 1b4e01 e405 9d }
            // n = 4, score = 100
            //   0009                 | add                 byte ptr [ecx], cl
            //   1b4e01               | sbb                 ecx, dword ptr [esi + 1]
            //   e405                 | in                  al, 5
            //   9d                   | popfd               

        $sequence_3 = { 0088aa4b0023 d18a0688078a 46 018847018a46 }
            // n = 4, score = 100
            //   0088aa4b0023         | add                 byte ptr [eax + 0x23004baa], cl
            //   d18a0688078a         | ror                 dword ptr [edx - 0x75f877fa], 1
            //   46                   | inc                 esi
            //   018847018a46         | add                 dword ptr [eax + 0x468a0147], ecx

        $sequence_4 = { 0130 8b13 8b08 85d2 }
            // n = 4, score = 100
            //   0130                 | add                 dword ptr [eax], esi
            //   8b13                 | mov                 edx, dword ptr [ebx]
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   85d2                 | test                edx, edx

        $sequence_5 = { b8e3062de4 09c0 7506 898550ffffff 8b8550ffffff ba205af5bb }
            // n = 6, score = 100
            //   b8e3062de4           | mov                 eax, 0xe42d06e3
            //   09c0                 | or                  eax, eax
            //   7506                 | jne                 8
            //   898550ffffff         | mov                 dword ptr [ebp - 0xb0], eax
            //   8b8550ffffff         | mov                 eax, dword ptr [ebp - 0xb0]
            //   ba205af5bb           | mov                 edx, 0xbbf55a20

        $sequence_6 = { 7545 8945fc 8b45f0 895de8 81f97a701028 7534 }
            // n = 6, score = 100
            //   7545                 | jne                 0x47
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   8b45f0               | mov                 eax, dword ptr [ebp - 0x10]
            //   895de8               | mov                 dword ptr [ebp - 0x18], ebx
            //   81f97a701028         | cmp                 ecx, 0x2810707a
            //   7534                 | jne                 0x36

        $sequence_7 = { 0104b9 33c9 83c408 85c0 }
            // n = 4, score = 100
            //   0104b9               | add                 dword ptr [ecx + edi*4], eax
            //   33c9                 | xor                 ecx, ecx
            //   83c408               | add                 esp, 8
            //   85c0                 | test                eax, eax

        $sequence_8 = { 010f 840f 0000 008365f0fe8b }
            // n = 4, score = 100
            //   010f                 | add                 dword ptr [edi], ecx
            //   840f                 | test                byte ptr [edi], cl
            //   0000                 | add                 byte ptr [eax], al
            //   008365f0fe8b         | add                 byte ptr [ebx - 0x74010f9b], al

        $sequence_9 = { 8b0d???????? 85c9 753f 83f963 753a 8945fc 83f93f }
            // n = 7, score = 100
            //   8b0d????????         |                     
            //   85c9                 | test                ecx, ecx
            //   753f                 | jne                 0x41
            //   83f963               | cmp                 ecx, 0x63
            //   753a                 | jne                 0x3c
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   83f93f               | cmp                 ecx, 0x3f

        $sequence_10 = { 0104bb 8d1447 89542418 e9???????? }
            // n = 4, score = 100
            //   0104bb               | add                 dword ptr [ebx + edi*4], eax
            //   8d1447               | lea                 edx, [edi + eax*2]
            //   89542418             | mov                 dword ptr [esp + 0x18], edx
            //   e9????????           |                     

        $sequence_11 = { 895de8 33f6 8955cc 83fe13 7503 8975fc 5e }
            // n = 7, score = 100
            //   895de8               | mov                 dword ptr [ebp - 0x18], ebx
            //   33f6                 | xor                 esi, esi
            //   8955cc               | mov                 dword ptr [ebp - 0x34], edx
            //   83fe13               | cmp                 esi, 0x13
            //   7503                 | jne                 5
            //   8975fc               | mov                 dword ptr [ebp - 4], esi
            //   5e                   | pop                 esi

        $sequence_12 = { 0000 008365f0fe8b 4d 0883c108e918 }
            // n = 4, score = 100
            //   0000                 | add                 byte ptr [eax], al
            //   008365f0fe8b         | add                 byte ptr [ebx - 0x74010f9b], al
            //   4d                   | dec                 ebp
            //   0883c108e918         | or                  byte ptr [ebx + 0x18e908c1], al

        $sequence_13 = { 8945e0 83f9f3 7507 09c9 7403 }
            // n = 5, score = 100
            //   8945e0               | mov                 dword ptr [ebp - 0x20], eax
            //   83f9f3               | cmp                 ecx, -0xd
            //   7507                 | jne                 9
            //   09c9                 | or                  ecx, ecx
            //   7403                 | je                  5

        $sequence_14 = { 81fb2e5ca766 7503 895de8 8945d4 }
            // n = 4, score = 100
            //   81fb2e5ca766         | cmp                 ebx, 0x66a75c2e
            //   7503                 | jne                 5
            //   895de8               | mov                 dword ptr [ebp - 0x18], ebx
            //   8945d4               | mov                 dword ptr [ebp - 0x2c], eax

        $sequence_15 = { 83fbd5 7413 33c0 83f827 7403 }
            // n = 5, score = 100
            //   83fbd5               | cmp                 ebx, -0x2b
            //   7413                 | je                  0x15
            //   33c0                 | xor                 eax, eax
            //   83f827               | cmp                 eax, 0x27
            //   7403                 | je                  5

    condition:
        7 of them and filesize < 3147776
}