rule win_hookinjex_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.hookinjex."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.hookinjex"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 85c0 740c b913e40000 }
            // n = 4, score = 300
            //   e8????????           |                     
            //   85c0                 | dec                 eax
            //   740c                 | mov                 ecx, dword ptr [esp + 0x58]
            //   b913e40000           | dec                 eax

        $sequence_1 = { e8???????? b964000000 ff15???????? 0fb705???????? }
            // n = 4, score = 300
            //   e8????????           |                     
            //   b964000000           | dec                 eax
            //   ff15????????         |                     
            //   0fb705????????       |                     

        $sequence_2 = { e8???????? 85c0 7507 b80e000000 }
            // n = 4, score = 300
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   7507                 | je                  0xa
            //   b80e000000           | cmp                 byte ptr [ebx], 0

        $sequence_3 = { e9???????? 488b4c2458 e8???????? 488b4c2450 }
            // n = 4, score = 300
            //   e9????????           |                     
            //   488b4c2458           | mov                 eax, dword ptr [esp + 0x38]
            //   e8????????           |                     
            //   488b4c2450           | dec                 eax

        $sequence_4 = { e8???????? b95b730100 e8???????? e9???????? }
            // n = 4, score = 300
            //   e8????????           |                     
            //   b95b730100           | and                 eax, 0x1b00
            //   e8????????           |                     
            //   e9????????           |                     

        $sequence_5 = { e8???????? 85c0 750f b9dc550100 }
            // n = 4, score = 300
            //   e8????????           |                     
            //   85c0                 | add                 eax, 0x2f
            //   750f                 | dec                 eax
            //   b9dc550100           | mov                 dword ptr [esp + 0x40], eax

        $sequence_6 = { e8???????? 833d????????00 7411 b903000000 e8???????? }
            // n = 5, score = 300
            //   e8????????           |                     
            //   833d????????00       |                     
            //   7411                 | dec                 eax
            //   b903000000           | sub                 esp, 0x128
            //   e8????????           |                     

        $sequence_7 = { e8???????? 85c0 7408 803b00 }
            // n = 4, score = 300
            //   e8????????           |                     
            //   85c0                 | mov                 dword ptr [esp + 0x40], eax
            //   7408                 | dec                 eax
            //   803b00               | mov                 eax, dword ptr [esp + 0x38]

        $sequence_8 = { 48817c243000100000 0f82dc020000 488b442460 4889442438 }
            // n = 4, score = 200
            //   48817c243000100000     | dec    eax
            //   0f82dc020000         | cmp                 dword ptr [esp + 0x30], 0x1000
            //   488b442460           | jb                  0x2e2
            //   4889442438           | dec                 eax

        $sequence_9 = { 2500180000 3d00080000 750d c78424e800000001000000 eb0b }
            // n = 5, score = 200
            //   2500180000           | and                 eax, 0x1800
            //   3d00080000           | cmp                 eax, 0x800
            //   750d                 | jne                 0xf
            //   c78424e800000001000000     | mov    dword ptr [esp + 0xe8], 1
            //   eb0b                 | jmp                 0xd

        $sequence_10 = { 25001b0000 3d00100000 750a c744244401000000 }
            // n = 4, score = 200
            //   25001b0000           | and                 eax, 0x1b00
            //   3d00100000           | cmp                 eax, 0x1000
            //   750a                 | jne                 0xc
            //   c744244401000000     | mov                 dword ptr [esp + 0x44], 1

        $sequence_11 = { 25001b0000 3d00110000 750d c784243c01000001000000 }
            // n = 4, score = 200
            //   25001b0000           | and                 eax, 0x1b00
            //   3d00110000           | cmp                 eax, 0x1100
            //   750d                 | jne                 0xf
            //   c784243c01000001000000     | mov    dword ptr [esp + 0x13c], 1

        $sequence_12 = { 25001b0000 3d00100000 750d c784242401000001000000 }
            // n = 4, score = 200
            //   25001b0000           | and                 eax, 0x1b00
            //   3d00100000           | cmp                 eax, 0x1000
            //   750d                 | jne                 0xf
            //   c784242401000001000000     | mov    dword ptr [esp + 0x124], 1

        $sequence_13 = { 2500180000 3d00180000 750a c744247c01000000 }
            // n = 4, score = 200
            //   2500180000           | and                 eax, 0x1800
            //   3d00180000           | cmp                 eax, 0x1800
            //   750a                 | jne                 0xc
            //   c744247c01000000     | mov                 dword ptr [esp + 0x7c], 1

        $sequence_14 = { 25001b0000 3d00110000 750a c744245c01000000 }
            // n = 4, score = 200
            //   25001b0000           | and                 eax, 0x1b00
            //   3d00110000           | cmp                 eax, 0x1100
            //   750a                 | jne                 0xc
            //   c744245c01000000     | mov                 dword ptr [esp + 0x5c], 1

        $sequence_15 = { 48817c243800100000 0f82f5000000 488b442438 4883c02f }
            // n = 4, score = 200
            //   48817c243800100000     | mov    dword ptr [esp + 0x38], eax
            //   0f82f5000000         | dec                 eax
            //   488b442438           | mov                 eax, dword ptr [esp + 0x38]
            //   4883c02f             | dec                 eax

    condition:
        7 of them and filesize < 6545408
}