rule win_htprat_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.htprat."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.htprat"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b8568efffff 03c6 3b8558efffff 7667 8b8394000000 898560efffff 8b8558efffff }
            // n = 7, score = 200
            //   8b8568efffff         | mov                 eax, dword ptr [ebp - 0x1098]
            //   03c6                 | add                 eax, esi
            //   3b8558efffff         | cmp                 eax, dword ptr [ebp - 0x10a8]
            //   7667                 | jbe                 0x69
            //   8b8394000000         | mov                 eax, dword ptr [ebx + 0x94]
            //   898560efffff         | mov                 dword ptr [ebp - 0x10a0], eax
            //   8b8558efffff         | mov                 eax, dword ptr [ebp - 0x10a8]

        $sequence_1 = { 8bc7 897dcc e8???????? 8b5dc8 3b5f04 740e }
            // n = 6, score = 200
            //   8bc7                 | mov                 eax, edi
            //   897dcc               | mov                 dword ptr [ebp - 0x34], edi
            //   e8????????           |                     
            //   8b5dc8               | mov                 ebx, dword ptr [ebp - 0x38]
            //   3b5f04               | cmp                 ebx, dword ptr [edi + 4]
            //   740e                 | je                  0x10

        $sequence_2 = { 8d4c2418 c68424e800000003 e8???????? 8b00 3bc3 7504 32db }
            // n = 7, score = 200
            //   8d4c2418             | lea                 ecx, [esp + 0x18]
            //   c68424e800000003     | mov                 byte ptr [esp + 0xe8], 3
            //   e8????????           |                     
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   3bc3                 | cmp                 eax, ebx
            //   7504                 | jne                 6
            //   32db                 | xor                 bl, bl

        $sequence_3 = { 33d2 f3a6 6aff 58 7404 1bd2 1bd0 }
            // n = 7, score = 200
            //   33d2                 | xor                 edx, edx
            //   f3a6                 | repe cmpsb          byte ptr [esi], byte ptr es:[edi]
            //   6aff                 | push                -1
            //   58                   | pop                 eax
            //   7404                 | je                  6
            //   1bd2                 | sbb                 edx, edx
            //   1bd0                 | sbb                 edx, eax

        $sequence_4 = { 46 56 8d8d00ffffff e8???????? 53 56 }
            // n = 6, score = 200
            //   46                   | inc                 esi
            //   56                   | push                esi
            //   8d8d00ffffff         | lea                 ecx, [ebp - 0x100]
            //   e8????????           |                     
            //   53                   | push                ebx
            //   56                   | push                esi

        $sequence_5 = { 85c0 750c e8???????? a3???????? eb13 53 }
            // n = 6, score = 200
            //   85c0                 | test                eax, eax
            //   750c                 | jne                 0xe
            //   e8????????           |                     
            //   a3????????           |                     
            //   eb13                 | jmp                 0x15
            //   53                   | push                ebx

        $sequence_6 = { 8b00 8d8d38efffff 51 8d8d08efffff 51 50 ff33 }
            // n = 7, score = 200
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   8d8d38efffff         | lea                 ecx, [ebp - 0x10c8]
            //   51                   | push                ecx
            //   8d8d08efffff         | lea                 ecx, [ebp - 0x10f8]
            //   51                   | push                ecx
            //   50                   | push                eax
            //   ff33                 | push                dword ptr [ebx]

        $sequence_7 = { 894584 99 f77d8c 8b4590 8a0402 8b5594 }
            // n = 6, score = 200
            //   894584               | mov                 dword ptr [ebp - 0x7c], eax
            //   99                   | cdq                 
            //   f77d8c               | idiv                dword ptr [ebp - 0x74]
            //   8b4590               | mov                 eax, dword ptr [ebp - 0x70]
            //   8a0402               | mov                 al, byte ptr [edx + eax]
            //   8b5594               | mov                 edx, dword ptr [ebp - 0x6c]

        $sequence_8 = { 83c604 3b7734 75ec eb31 83f805 }
            // n = 5, score = 200
            //   83c604               | add                 esi, 4
            //   3b7734               | cmp                 esi, dword ptr [edi + 0x34]
            //   75ec                 | jne                 0xffffffee
            //   eb31                 | jmp                 0x33
            //   83f805               | cmp                 eax, 5

        $sequence_9 = { 8d410c 8bcb e8???????? 84c0 0f84d2000000 8b5d0c }
            // n = 6, score = 200
            //   8d410c               | lea                 eax, [ecx + 0xc]
            //   8bcb                 | mov                 ecx, ebx
            //   e8????????           |                     
            //   84c0                 | test                al, al
            //   0f84d2000000         | je                  0xd8
            //   8b5d0c               | mov                 ebx, dword ptr [ebp + 0xc]

    condition:
        7 of them and filesize < 278528
}