rule win_http_troy_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.http_troy."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.http_troy"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { dd45f8 dae9 59 59 dfe0 f6c444 7a05 }
            // n = 7, score = 200
            //   dd45f8               | fld                 qword ptr [ebp - 8]
            //   dae9                 | fucompp             
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx
            //   dfe0                 | fnstsw              ax
            //   f6c444               | test                ah, 0x44
            //   7a05                 | jp                  7

        $sequence_1 = { c3 8b8384400000 85c0 0f84bd010000 8b54240c 52 8b542414 }
            // n = 7, score = 200
            //   c3                   | ret                 
            //   8b8384400000         | mov                 eax, dword ptr [ebx + 0x4084]
            //   85c0                 | test                eax, eax
            //   0f84bd010000         | je                  0x1c3
            //   8b54240c             | mov                 edx, dword ptr [esp + 0xc]
            //   52                   | push                edx
            //   8b542414             | mov                 edx, dword ptr [esp + 0x14]

        $sequence_2 = { ff00 85d2 744e 8d45ec 50 53 8bcf }
            // n = 7, score = 200
            //   ff00                 | inc                 dword ptr [eax]
            //   85d2                 | test                edx, edx
            //   744e                 | je                  0x50
            //   8d45ec               | lea                 eax, [ebp - 0x14]
            //   50                   | push                eax
            //   53                   | push                ebx
            //   8bcf                 | mov                 ecx, edi

        $sequence_3 = { 8b4c2420 b801000000 89410c 8b4c2418 5f 5e e8???????? }
            // n = 7, score = 200
            //   8b4c2420             | mov                 ecx, dword ptr [esp + 0x20]
            //   b801000000           | mov                 eax, 1
            //   89410c               | mov                 dword ptr [ecx + 0xc], eax
            //   8b4c2418             | mov                 ecx, dword ptr [esp + 0x18]
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   e8????????           |                     

        $sequence_4 = { 56 57 e8???????? 59 59 eb7d dd4508 }
            // n = 7, score = 200
            //   56                   | push                esi
            //   57                   | push                edi
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx
            //   eb7d                 | jmp                 0x7f
            //   dd4508               | fld                 qword ptr [ebp + 8]

        $sequence_5 = { 83c604 3b742408 72ef 5e c3 56 8bf0 }
            // n = 7, score = 200
            //   83c604               | add                 esi, 4
            //   3b742408             | cmp                 esi, dword ptr [esp + 8]
            //   72ef                 | jb                  0xfffffff1
            //   5e                   | pop                 esi
            //   c3                   | ret                 
            //   56                   | push                esi
            //   8bf0                 | mov                 esi, eax

        $sequence_6 = { 6a01 68???????? ffd3 85c0 0f857afeffff 393cb5c8540310 742e }
            // n = 7, score = 200
            //   6a01                 | push                1
            //   68????????           |                     
            //   ffd3                 | call                ebx
            //   85c0                 | test                eax, eax
            //   0f857afeffff         | jne                 0xfffffe80
            //   393cb5c8540310       | cmp                 dword ptr [esi*4 + 0x100354c8], edi
            //   742e                 | je                  0x30

        $sequence_7 = { 50 8d4c240c 51 6a00 683f000f00 6a00 }
            // n = 6, score = 200
            //   50                   | push                eax
            //   8d4c240c             | lea                 ecx, [esp + 0xc]
            //   51                   | push                ecx
            //   6a00                 | push                0
            //   683f000f00           | push                0xf003f
            //   6a00                 | push                0

        $sequence_8 = { e8???????? 8b0d???????? 83c408 3bc1 741f 83c702 }
            // n = 6, score = 200
            //   e8????????           |                     
            //   8b0d????????         |                     
            //   83c408               | add                 esp, 8
            //   3bc1                 | cmp                 eax, ecx
            //   741f                 | je                  0x21
            //   83c702               | add                 edi, 2

        $sequence_9 = { e8???????? 83c41c 8d942418010000 52 ffd3 85c0 7430 }
            // n = 7, score = 200
            //   e8????????           |                     
            //   83c41c               | add                 esp, 0x1c
            //   8d942418010000       | lea                 edx, [esp + 0x118]
            //   52                   | push                edx
            //   ffd3                 | call                ebx
            //   85c0                 | test                eax, eax
            //   7430                 | je                  0x32

    condition:
        7 of them and filesize < 475136
}