rule win_ice_ix_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.ice_ix."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.ice_ix"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 3bc3 748c 6a01 8d4584 50 6883346425 e8???????? }
            // n = 7, score = 200
            //   3bc3                 | cmp                 eax, ebx
            //   748c                 | je                  0xffffff8e
            //   6a01                 | push                1
            //   8d4584               | lea                 eax, [ebp - 0x7c]
            //   50                   | push                eax
            //   6883346425           | push                0x25643483
            //   e8????????           |                     

        $sequence_1 = { 85db 0f844b020000 81fe00020000 0f873f020000 83fe06 0f86e5000000 8b03 }
            // n = 7, score = 200
            //   85db                 | test                ebx, ebx
            //   0f844b020000         | je                  0x251
            //   81fe00020000         | cmp                 esi, 0x200
            //   0f873f020000         | ja                  0x245
            //   83fe06               | cmp                 esi, 6
            //   0f86e5000000         | jbe                 0xeb
            //   8b03                 | mov                 eax, dword ptr [ebx]

        $sequence_2 = { 50 e8???????? 50 53 8d857cfeffff 50 e8???????? }
            // n = 7, score = 200
            //   50                   | push                eax
            //   e8????????           |                     
            //   50                   | push                eax
            //   53                   | push                ebx
            //   8d857cfeffff         | lea                 eax, [ebp - 0x184]
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_3 = { 56 57 6a02 5b 53 6821634578 }
            // n = 6, score = 200
            //   56                   | push                esi
            //   57                   | push                edi
            //   6a02                 | push                2
            //   5b                   | pop                 ebx
            //   53                   | push                ebx
            //   6821634578           | push                0x78456321

        $sequence_4 = { 8d75b8 b891000000 e8???????? 8d75d0 b892000000 e8???????? 8d75dc }
            // n = 7, score = 200
            //   8d75b8               | lea                 esi, [ebp - 0x48]
            //   b891000000           | mov                 eax, 0x91
            //   e8????????           |                     
            //   8d75d0               | lea                 esi, [ebp - 0x30]
            //   b892000000           | mov                 eax, 0x92
            //   e8????????           |                     
            //   8d75dc               | lea                 esi, [ebp - 0x24]

        $sequence_5 = { 0f84dc000000 8d442420 50 ff15???????? 8db424c0000000 b8a2000000 e8???????? }
            // n = 7, score = 200
            //   0f84dc000000         | je                  0xe2
            //   8d442420             | lea                 eax, [esp + 0x20]
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8db424c0000000       | lea                 esi, [esp + 0xc0]
            //   b8a2000000           | mov                 eax, 0xa2
            //   e8????????           |                     

        $sequence_6 = { 6a73 8d74243c 58 e8???????? 8bc6 89442410 }
            // n = 6, score = 200
            //   6a73                 | push                0x73
            //   8d74243c             | lea                 esi, [esp + 0x3c]
            //   58                   | pop                 eax
            //   e8????????           |                     
            //   8bc6                 | mov                 eax, esi
            //   89442410             | mov                 dword ptr [esp + 0x10], eax

        $sequence_7 = { 6a42 8db550ffffff 58 e8???????? 8b75f4 8b55f0 3bf7 }
            // n = 7, score = 200
            //   6a42                 | push                0x42
            //   8db550ffffff         | lea                 esi, [ebp - 0xb0]
            //   58                   | pop                 eax
            //   e8????????           |                     
            //   8b75f4               | mov                 esi, dword ptr [ebp - 0xc]
            //   8b55f0               | mov                 edx, dword ptr [ebp - 0x10]
            //   3bf7                 | cmp                 esi, edi

        $sequence_8 = { 0f84a7000000 83f8ff 0f849e000000 6a3b 8d75e0 58 897dec }
            // n = 7, score = 200
            //   0f84a7000000         | je                  0xad
            //   83f8ff               | cmp                 eax, -1
            //   0f849e000000         | je                  0xa4
            //   6a3b                 | push                0x3b
            //   8d75e0               | lea                 esi, [ebp - 0x20]
            //   58                   | pop                 eax
            //   897dec               | mov                 dword ptr [ebp - 0x14], edi

        $sequence_9 = { 68cc000000 6a2d 58 e8???????? ff75d0 ff15???????? 5f }
            // n = 7, score = 200
            //   68cc000000           | push                0xcc
            //   6a2d                 | push                0x2d
            //   58                   | pop                 eax
            //   e8????????           |                     
            //   ff75d0               | push                dword ptr [ebp - 0x30]
            //   ff15????????         |                     
            //   5f                   | pop                 edi

    condition:
        7 of them and filesize < 327680
}