rule win_iisniff_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.iisniff."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.iisniff"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 85c0 7513 8b442414 8b4804 53 }
            // n = 5, score = 200
            //   85c0                 | test                eax, eax
            //   7513                 | jne                 0x15
            //   8b442414             | mov                 eax, dword ptr [esp + 0x14]
            //   8b4804               | mov                 ecx, dword ptr [eax + 4]
            //   53                   | push                ebx

        $sequence_1 = { 8b8c240c000100 56 8d842414000100 50 51 }
            // n = 5, score = 200
            //   8b8c240c000100       | mov                 ecx, dword ptr [esp + 0x1000c]
            //   56                   | push                esi
            //   8d842414000100       | lea                 eax, [esp + 0x10014]
            //   50                   | push                eax
            //   51                   | push                ecx

        $sequence_2 = { 7507 be04000000 eb69 c645fc01 8b0f }
            // n = 5, score = 200
            //   7507                 | jne                 9
            //   be04000000           | mov                 esi, 4
            //   eb69                 | jmp                 0x6b
            //   c645fc01             | mov                 byte ptr [ebp - 4], 1
            //   8b0f                 | mov                 ecx, dword ptr [edi]

        $sequence_3 = { 55 56 8bb42488000000 57 33db }
            // n = 5, score = 200
            //   55                   | push                ebp
            //   56                   | push                esi
            //   8bb42488000000       | mov                 esi, dword ptr [esp + 0x88]
            //   57                   | push                edi
            //   33db                 | xor                 ebx, ebx

        $sequence_4 = { 83d8ff 85c0 7537 8dbc24a4000000 e8???????? }
            // n = 5, score = 200
            //   83d8ff               | sbb                 eax, -1
            //   85c0                 | test                eax, eax
            //   7537                 | jne                 0x39
            //   8dbc24a4000000       | lea                 edi, [esp + 0xa4]
            //   e8????????           |                     

        $sequence_5 = { 5f 5b c20400 8b4038 8b08 890e }
            // n = 6, score = 200
            //   5f                   | pop                 edi
            //   5b                   | pop                 ebx
            //   c20400               | ret                 4
            //   8b4038               | mov                 eax, dword ptr [eax + 0x38]
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   890e                 | mov                 dword ptr [esi], ecx

        $sequence_6 = { 8b45cc ff704c e8???????? 59 83f8ff 0f852cffffff }
            // n = 6, score = 200
            //   8b45cc               | mov                 eax, dword ptr [ebp - 0x34]
            //   ff704c               | push                dword ptr [eax + 0x4c]
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   83f8ff               | cmp                 eax, -1
            //   0f852cffffff         | jne                 0xffffff32

        $sequence_7 = { 56 8d4dd4 894598 e8???????? 8365fc00 56 8d4d9c }
            // n = 7, score = 200
            //   56                   | push                esi
            //   8d4dd4               | lea                 ecx, [ebp - 0x2c]
            //   894598               | mov                 dword ptr [ebp - 0x68], eax
            //   e8????????           |                     
            //   8365fc00             | and                 dword ptr [ebp - 4], 0
            //   56                   | push                esi
            //   8d4d9c               | lea                 ecx, [ebp - 0x64]

        $sequence_8 = { 895c241c 89442420 e8???????? 8bf0 }
            // n = 4, score = 200
            //   895c241c             | mov                 dword ptr [esp + 0x1c], ebx
            //   89442420             | mov                 dword ptr [esp + 0x20], eax
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax

        $sequence_9 = { e8???????? 83c404 8d8c24fc000000 899c2448010000 89bc2444010000 }
            // n = 5, score = 200
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   8d8c24fc000000       | lea                 ecx, [esp + 0xfc]
            //   899c2448010000       | mov                 dword ptr [esp + 0x148], ebx
            //   89bc2444010000       | mov                 dword ptr [esp + 0x144], edi

        $sequence_10 = { 6a03 68000000c0 68???????? ff15???????? 6a02 }
            // n = 5, score = 200
            //   6a03                 | push                3
            //   68000000c0           | push                0xc0000000
            //   68????????           |                     
            //   ff15????????         |                     
            //   6a02                 | push                2

        $sequence_11 = { e8???????? 8b4f3c 8b11 8d75c8 56 ff75cc }
            // n = 6, score = 200
            //   e8????????           |                     
            //   8b4f3c               | mov                 ecx, dword ptr [edi + 0x3c]
            //   8b11                 | mov                 edx, dword ptr [ecx]
            //   8d75c8               | lea                 esi, [ebp - 0x38]
            //   56                   | push                esi
            //   ff75cc               | push                dword ptr [ebp - 0x34]

        $sequence_12 = { ff75e8 e8???????? 834dfcff 8b45dc }
            // n = 4, score = 200
            //   ff75e8               | push                dword ptr [ebp - 0x18]
            //   e8????????           |                     
            //   834dfcff             | or                  dword ptr [ebp - 4], 0xffffffff
            //   8b45dc               | mov                 eax, dword ptr [ebp - 0x24]

        $sequence_13 = { c3 ff7508 e8???????? 59 c3 833d????????00 7505 }
            // n = 7, score = 200
            //   c3                   | ret                 
            //   ff7508               | push                dword ptr [ebp + 8]
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   c3                   | ret                 
            //   833d????????00       |                     
            //   7505                 | jne                 7

        $sequence_14 = { 64a300000000 80bc24a400000000 7409 6a00 6a00 e8???????? 8b410c }
            // n = 7, score = 200
            //   64a300000000         | mov                 dword ptr fs:[0], eax
            //   80bc24a400000000     | cmp                 byte ptr [esp + 0xa4], 0
            //   7409                 | je                  0xb
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   e8????????           |                     
            //   8b410c               | mov                 eax, dword ptr [ecx + 0xc]

    condition:
        7 of them and filesize < 1441792
}