rule win_infy_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.infy."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.infy"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 7e24 8945d4 807de300 7409 8b45e4 66833820 }
            // n = 6, score = 200
            //   7e24                 | jle                 0x26
            //   8945d4               | mov                 dword ptr [ebp - 0x2c], eax
            //   807de300             | cmp                 byte ptr [ebp - 0x1d], 0
            //   7409                 | je                  0xb
            //   8b45e4               | mov                 eax, dword ptr [ebp - 0x1c]
            //   66833820             | cmp                 word ptr [eax], 0x20

        $sequence_1 = { 7409 8b13 8bc3 e8???????? 85c0 7405 83e804 }
            // n = 7, score = 200
            //   7409                 | je                  0xb
            //   8b13                 | mov                 edx, dword ptr [ebx]
            //   8bc3                 | mov                 eax, ebx
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   7405                 | je                  7
            //   83e804               | sub                 eax, 4

        $sequence_2 = { 57 33c9 894df8 8955f0 }
            // n = 4, score = 200
            //   57                   | push                edi
            //   33c9                 | xor                 ecx, ecx
            //   894df8               | mov                 dword ptr [ebp - 8], ecx
            //   8955f0               | mov                 dword ptr [ebp - 0x10], edx

        $sequence_3 = { 7553 837e1400 7442 837e1c00 }
            // n = 4, score = 200
            //   7553                 | jne                 0x55
            //   837e1400             | cmp                 dword ptr [esi + 0x14], 0
            //   7442                 | je                  0x44
            //   837e1c00             | cmp                 dword ptr [esi + 0x1c], 0

        $sequence_4 = { 668378f602 7412 6a00 89e0 }
            // n = 4, score = 200
            //   668378f602           | cmp                 word ptr [eax - 0xa], 2
            //   7412                 | je                  0x14
            //   6a00                 | push                0
            //   89e0                 | mov                 eax, esp

        $sequence_5 = { 68???????? 8d45c8 ba09000000 e8???????? 8d45ec }
            // n = 5, score = 200
            //   68????????           |                     
            //   8d45c8               | lea                 eax, [ebp - 0x38]
            //   ba09000000           | mov                 edx, 9
            //   e8????????           |                     
            //   8d45ec               | lea                 eax, [ebp - 0x14]

        $sequence_6 = { 807de300 7409 8b45e4 66833820 7304 33c0 eb02 }
            // n = 7, score = 200
            //   807de300             | cmp                 byte ptr [ebp - 0x1d], 0
            //   7409                 | je                  0xb
            //   8b45e4               | mov                 eax, dword ptr [ebp - 0x1c]
            //   66833820             | cmp                 word ptr [eax], 0x20
            //   7304                 | jae                 6
            //   33c0                 | xor                 eax, eax
            //   eb02                 | jmp                 4

        $sequence_7 = { c1e002 034610 f6400380 0f94c2 83e201 8955e0 85d2 }
            // n = 7, score = 200
            //   c1e002               | shl                 eax, 2
            //   034610               | add                 eax, dword ptr [esi + 0x10]
            //   f6400380             | test                byte ptr [eax + 3], 0x80
            //   0f94c2               | sete                dl
            //   83e201               | and                 edx, 1
            //   8955e0               | mov                 dword ptr [ebp - 0x20], edx
            //   85d2                 | test                edx, edx

        $sequence_8 = { e8???????? 8bd0 81e2ff000000 2500ff0000 c1e808 83fa05 7505 }
            // n = 7, score = 200
            //   e8????????           |                     
            //   8bd0                 | mov                 edx, eax
            //   81e2ff000000         | and                 edx, 0xff
            //   2500ff0000           | and                 eax, 0xff00
            //   c1e808               | shr                 eax, 8
            //   83fa05               | cmp                 edx, 5
            //   7505                 | jne                 7

        $sequence_9 = { e8???????? 83c40c 5b 5d c20800 55 8bec }
            // n = 7, score = 200
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   5b                   | pop                 ebx
            //   5d                   | pop                 ebp
            //   c20800               | ret                 8
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp

    condition:
        7 of them and filesize < 147456
}