rule win_isaacwiper_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.isaacwiper."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.isaacwiper"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 771b 52 51 e8???????? 83c408 5f c706???????? }
            // n = 7, score = 100
            //   771b                 | ja                  0x1d
            //   52                   | push                edx
            //   51                   | push                ecx
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   5f                   | pop                 edi
            //   c706????????         |                     

        $sequence_1 = { b804000000 33d2 395138 0f45c2 0b410c 0bc3 50 }
            // n = 7, score = 100
            //   b804000000           | mov                 eax, 4
            //   33d2                 | xor                 edx, edx
            //   395138               | cmp                 dword ptr [ecx + 0x38], edx
            //   0f45c2               | cmovne              eax, edx
            //   0b410c               | or                  eax, dword ptr [ecx + 0xc]
            //   0bc3                 | or                  eax, ebx
            //   50                   | push                eax

        $sequence_2 = { 8d0471 3bc8 7319 8d46ff }
            // n = 4, score = 100
            //   8d0471               | lea                 eax, [ecx + esi*2]
            //   3bc8                 | cmp                 ecx, eax
            //   7319                 | jae                 0x1b
            //   8d46ff               | lea                 eax, [esi - 1]

        $sequence_3 = { 5b 8be5 5d c3 6a34 e8???????? 8bf0 }
            // n = 7, score = 100
            //   5b                   | pop                 ebx
            //   8be5                 | mov                 esp, ebp
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   6a34                 | push                0x34
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax

        $sequence_4 = { 7576 eb56 8b0485d89e0210 6800080000 6a00 50 8945fc }
            // n = 7, score = 100
            //   7576                 | jne                 0x78
            //   eb56                 | jmp                 0x58
            //   8b0485d89e0210       | mov                 eax, dword ptr [eax*4 + 0x10029ed8]
            //   6800080000           | push                0x800
            //   6a00                 | push                0
            //   50                   | push                eax
            //   8945fc               | mov                 dword ptr [ebp - 4], eax

        $sequence_5 = { 744a 83c118 57 8b7d14 894d08 0f1f4000 }
            // n = 6, score = 100
            //   744a                 | je                  0x4c
            //   83c118               | add                 ecx, 0x18
            //   57                   | push                edi
            //   8b7d14               | mov                 edi, dword ptr [ebp + 0x14]
            //   894d08               | mov                 dword ptr [ebp + 8], ecx
            //   0f1f4000             | nop                 dword ptr [eax]

        $sequence_6 = { 81ecc8090000 56 57 8bf1 c745f800000000 ff15???????? 898538f6ffff }
            // n = 7, score = 100
            //   81ecc8090000         | sub                 esp, 0x9c8
            //   56                   | push                esi
            //   57                   | push                edi
            //   8bf1                 | mov                 esi, ecx
            //   c745f800000000       | mov                 dword ptr [ebp - 8], 0
            //   ff15????????         |                     
            //   898538f6ffff         | mov                 dword ptr [ebp - 0x9c8], eax

        $sequence_7 = { 6685f6 743e 6a00 8bd6 8bcf e8???????? 8ad0 }
            // n = 7, score = 100
            //   6685f6               | test                si, si
            //   743e                 | je                  0x40
            //   6a00                 | push                0
            //   8bd6                 | mov                 edx, esi
            //   8bcf                 | mov                 ecx, edi
            //   e8????????           |                     
            //   8ad0                 | mov                 dl, al

        $sequence_8 = { 85db 0f8454010000 8bc6 83e001 03c8 d1ee }
            // n = 6, score = 100
            //   85db                 | test                ebx, ebx
            //   0f8454010000         | je                  0x15a
            //   8bc6                 | mov                 eax, esi
            //   83e001               | and                 eax, 1
            //   03c8                 | add                 ecx, eax
            //   d1ee                 | shr                 esi, 1

        $sequence_9 = { 8bf8 83e03f c1ff06 6bd038 8b34bde8670310 8a441628 }
            // n = 6, score = 100
            //   8bf8                 | mov                 edi, eax
            //   83e03f               | and                 eax, 0x3f
            //   c1ff06               | sar                 edi, 6
            //   6bd038               | imul                edx, eax, 0x38
            //   8b34bde8670310       | mov                 esi, dword ptr [edi*4 + 0x100367e8]
            //   8a441628             | mov                 al, byte ptr [esi + edx + 0x28]

    condition:
        7 of them and filesize < 467968
}