rule win_jackpos_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.jackpos."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.jackpos"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b5604 eb03 8d5604 2bc7 03c0 50 }
            // n = 6, score = 100
            //   8b5604               | mov                 edx, dword ptr [esi + 4]
            //   eb03                 | jmp                 5
            //   8d5604               | lea                 edx, [esi + 4]
            //   2bc7                 | sub                 eax, edi
            //   03c0                 | add                 eax, eax
            //   50                   | push                eax

        $sequence_1 = { d1f8 03d0 eb0f 85c0 }
            // n = 4, score = 100
            //   d1f8                 | sar                 eax, 1
            //   03d0                 | add                 edx, eax
            //   eb0f                 | jmp                 0x11
            //   85c0                 | test                eax, eax

        $sequence_2 = { 75ed 837df408 8b4dfc 7202 }
            // n = 4, score = 100
            //   75ed                 | jne                 0xffffffef
            //   837df408             | cmp                 dword ptr [ebp - 0xc], 8
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   7202                 | jb                  4

        $sequence_3 = { 8b4508 e8???????? 8b7d08 8b550c 8b4718 3b7d10 747e }
            // n = 7, score = 100
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   e8????????           |                     
            //   8b7d08               | mov                 edi, dword ptr [ebp + 8]
            //   8b550c               | mov                 edx, dword ptr [ebp + 0xc]
            //   8b4718               | mov                 eax, dword ptr [edi + 0x18]
            //   3b7d10               | cmp                 edi, dword ptr [ebp + 0x10]
            //   747e                 | je                  0x80

        $sequence_4 = { 52 8bf0 53 897588 e8???????? }
            // n = 5, score = 100
            //   52                   | push                edx
            //   8bf0                 | mov                 esi, eax
            //   53                   | push                ebx
            //   897588               | mov                 dword ptr [ebp - 0x78], esi
            //   e8????????           |                     

        $sequence_5 = { 7303 8d45d8 8d4dac 51 50 e8???????? 8b55b4 }
            // n = 7, score = 100
            //   7303                 | jae                 5
            //   8d45d8               | lea                 eax, [ebp - 0x28]
            //   8d4dac               | lea                 ecx, [ebp - 0x54]
            //   51                   | push                ecx
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b55b4               | mov                 edx, dword ptr [ebp - 0x4c]

        $sequence_6 = { 85ff 7f87 5f 8bc6 5e 5b }
            // n = 6, score = 100
            //   85ff                 | test                edi, edi
            //   7f87                 | jg                  0xffffff89
            //   5f                   | pop                 edi
            //   8bc6                 | mov                 eax, esi
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx

        $sequence_7 = { 8b4604 33c9 66890c03 5f 8bc6 }
            // n = 5, score = 100
            //   8b4604               | mov                 eax, dword ptr [esi + 4]
            //   33c9                 | xor                 ecx, ecx
            //   66890c03             | mov                 word ptr [ebx + eax], cx
            //   5f                   | pop                 edi
            //   8bc6                 | mov                 eax, esi

        $sequence_8 = { 765a 8b4a14 57 3bc1 734e 2bc8 8bf9 }
            // n = 7, score = 100
            //   765a                 | jbe                 0x5c
            //   8b4a14               | mov                 ecx, dword ptr [edx + 0x14]
            //   57                   | push                edi
            //   3bc1                 | cmp                 eax, ecx
            //   734e                 | jae                 0x50
            //   2bc8                 | sub                 ecx, eax
            //   8bf9                 | mov                 edi, ecx

        $sequence_9 = { 037214 ebc4 5f 5e 5d }
            // n = 5, score = 100
            //   037214               | add                 esi, dword ptr [edx + 0x14]
            //   ebc4                 | jmp                 0xffffffc6
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5d                   | pop                 ebp

    condition:
        7 of them and filesize < 319488
}