rule win_jimmy_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.jimmy."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.jimmy"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8908 eb11 e8???????? 8945f4 ff75f8 e8???????? 59 }
            // n = 7, score = 400
            //   8908                 | mov                 dword ptr [eax], ecx
            //   eb11                 | jmp                 0x13
            //   e8????????           |                     
            //   8945f4               | mov                 dword ptr [ebp - 0xc], eax
            //   ff75f8               | push                dword ptr [ebp - 8]
            //   e8????????           |                     
            //   59                   | pop                 ecx

        $sequence_1 = { 8b4508 83602c00 8b45fc c9 c3 55 8bec }
            // n = 7, score = 400
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   83602c00             | and                 dword ptr [eax + 0x2c], 0
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   c9                   | leave               
            //   c3                   | ret                 
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp

        $sequence_2 = { 89814c010000 eb27 a1???????? 8b4de4 898840010000 ff75e4 }
            // n = 6, score = 400
            //   89814c010000         | mov                 dword ptr [ecx + 0x14c], eax
            //   eb27                 | jmp                 0x29
            //   a1????????           |                     
            //   8b4de4               | mov                 ecx, dword ptr [ebp - 0x1c]
            //   898840010000         | mov                 dword ptr [eax + 0x140], ecx
            //   ff75e4               | push                dword ptr [ebp - 0x1c]

        $sequence_3 = { ff7508 ff55fc 59 59 c9 c3 55 }
            // n = 7, score = 400
            //   ff7508               | push                dword ptr [ebp + 8]
            //   ff55fc               | call                dword ptr [ebp - 4]
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx
            //   c9                   | leave               
            //   c3                   | ret                 
            //   55                   | push                ebp

        $sequence_4 = { 6a73 58 668945f2 6a20 58 668945f4 6a25 }
            // n = 7, score = 400
            //   6a73                 | push                0x73
            //   58                   | pop                 eax
            //   668945f2             | mov                 word ptr [ebp - 0xe], ax
            //   6a20                 | push                0x20
            //   58                   | pop                 eax
            //   668945f4             | mov                 word ptr [ebp - 0xc], ax
            //   6a25                 | push                0x25

        $sequence_5 = { 8b4508 ff702c 8b4508 ff7024 e8???????? 59 59 }
            // n = 7, score = 400
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   ff702c               | push                dword ptr [eax + 0x2c]
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   ff7024               | push                dword ptr [eax + 0x24]
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx

        $sequence_6 = { 50 8d45c4 50 8b4508 83c008 50 6a00 }
            // n = 7, score = 400
            //   50                   | push                eax
            //   8d45c4               | lea                 eax, [ebp - 0x3c]
            //   50                   | push                eax
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   83c008               | add                 eax, 8
            //   50                   | push                eax
            //   6a00                 | push                0

        $sequence_7 = { 85c0 7419 8b45fc 0fbe00 8b4df8 0fbe09 }
            // n = 6, score = 400
            //   85c0                 | test                eax, eax
            //   7419                 | je                  0x1b
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   0fbe00               | movsx               eax, byte ptr [eax]
            //   8b4df8               | mov                 ecx, dword ptr [ebp - 8]
            //   0fbe09               | movsx               ecx, byte ptr [ecx]

        $sequence_8 = { e8???????? 59 b001 c9 c20800 }
            // n = 5, score = 400
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   b001                 | mov                 al, 1
            //   c9                   | leave               
            //   c20800               | ret                 8

        $sequence_9 = { 6a09 e8???????? 59 59 8945fc ff7510 ff750c }
            // n = 7, score = 400
            //   6a09                 | push                9
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   ff7510               | push                dword ptr [ebp + 0x10]
            //   ff750c               | push                dword ptr [ebp + 0xc]

    condition:
        7 of them and filesize < 188416
}