rule win_jripbot_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.jripbot."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.jripbot"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 48 3b442418 0f822bffffff 8b8c24fc010000 5f 5e 5b }
            // n = 7, score = 100
            //   48                   | dec                 eax
            //   3b442418             | cmp                 eax, dword ptr [esp + 0x18]
            //   0f822bffffff         | jb                  0xffffff31
            //   8b8c24fc010000       | mov                 ecx, dword ptr [esp + 0x1fc]
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx

        $sequence_1 = { c1e807 8807 02d2 885701 66c7060100 33c9 837b0401 }
            // n = 7, score = 100
            //   c1e807               | shr                 eax, 7
            //   8807                 | mov                 byte ptr [edi], al
            //   02d2                 | add                 dl, dl
            //   885701               | mov                 byte ptr [edi + 1], dl
            //   66c7060100           | mov                 word ptr [esi], 1
            //   33c9                 | xor                 ecx, ecx
            //   837b0401             | cmp                 dword ptr [ebx + 4], 1

        $sequence_2 = { 8b5d08 c1eb08 23d8 0fb69b38834200 c1e608 33f3 8b5d0c }
            // n = 7, score = 100
            //   8b5d08               | mov                 ebx, dword ptr [ebp + 8]
            //   c1eb08               | shr                 ebx, 8
            //   23d8                 | and                 ebx, eax
            //   0fb69b38834200       | movzx               ebx, byte ptr [ebx + 0x428338]
            //   c1e608               | shl                 esi, 8
            //   33f3                 | xor                 esi, ebx
            //   8b5d0c               | mov                 ebx, dword ptr [ebp + 0xc]

        $sequence_3 = { 8d742414 e8???????? 59 59 eb06 895c240c 33c0 }
            // n = 7, score = 100
            //   8d742414             | lea                 esi, [esp + 0x14]
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx
            //   eb06                 | jmp                 8
            //   895c240c             | mov                 dword ptr [esp + 0xc], ebx
            //   33c0                 | xor                 eax, eax

        $sequence_4 = { 33c0 8b8eb8000000 3bc7 0f95c0 6a02 884105 33db }
            // n = 7, score = 100
            //   33c0                 | xor                 eax, eax
            //   8b8eb8000000         | mov                 ecx, dword ptr [esi + 0xb8]
            //   3bc7                 | cmp                 eax, edi
            //   0f95c0               | setne               al
            //   6a02                 | push                2
            //   884105               | mov                 byte ptr [ecx + 5], al
            //   33db                 | xor                 ebx, ebx

        $sequence_5 = { 51 50 56 56 ff750c ff75fc ffd7 }
            // n = 7, score = 100
            //   51                   | push                ecx
            //   50                   | push                eax
            //   56                   | push                esi
            //   56                   | push                esi
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   ff75fc               | push                dword ptr [ebp - 4]
            //   ffd7                 | call                edi

        $sequence_6 = { 50 e8???????? 8b1d???????? 83c40c 8d442438 50 ff15???????? }
            // n = 7, score = 100
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b1d????????         |                     
            //   83c40c               | add                 esp, 0xc
            //   8d442438             | lea                 eax, [esp + 0x38]
            //   50                   | push                eax
            //   ff15????????         |                     

        $sequence_7 = { 8b4004 894604 33c0 8b8c242c010000 5f 5e 5b }
            // n = 7, score = 100
            //   8b4004               | mov                 eax, dword ptr [eax + 4]
            //   894604               | mov                 dword ptr [esi + 4], eax
            //   33c0                 | xor                 eax, eax
            //   8b8c242c010000       | mov                 ecx, dword ptr [esp + 0x12c]
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx

        $sequence_8 = { eb04 8b442430 8b4c241c 2b4c2418 ff742418 8b5c2438 }
            // n = 6, score = 100
            //   eb04                 | jmp                 6
            //   8b442430             | mov                 eax, dword ptr [esp + 0x30]
            //   8b4c241c             | mov                 ecx, dword ptr [esp + 0x1c]
            //   2b4c2418             | sub                 ecx, dword ptr [esp + 0x18]
            //   ff742418             | push                dword ptr [esp + 0x18]
            //   8b5c2438             | mov                 ebx, dword ptr [esp + 0x38]

        $sequence_9 = { 7443 3bf8 743f 8b4368 397008 7537 8b4df4 }
            // n = 7, score = 100
            //   7443                 | je                  0x45
            //   3bf8                 | cmp                 edi, eax
            //   743f                 | je                  0x41
            //   8b4368               | mov                 eax, dword ptr [ebx + 0x68]
            //   397008               | cmp                 dword ptr [eax + 8], esi
            //   7537                 | jne                 0x39
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]

    condition:
        7 of them and filesize < 507904
}