rule win_jupiter_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.jupiter."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.jupiter"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8a4147 884104 8a4146 884105 8b4144 c1f808 884106 }
            // n = 7, score = 400
            //   8a4147               | dec                 eax
            //   884104               | mov                 dword ptr [esp + 0x200], 0
            //   8a4146               | dec                 eax
            //   884105               | mov                 eax, dword ptr [esp + 0x20]
            //   8b4144               | dec                 eax
            //   c1f808               | mov                 dword ptr [eax + 0x30], 0
            //   884106               | dec                 eax

        $sequence_1 = { c605????????01 66c705????????0101 c605????????01 c605????????01 66c705????????0101 }
            // n = 5, score = 400
            //   c605????????01       |                     
            //   66c705????????0101     |     
            //   c605????????01       |                     
            //   c605????????01       |                     
            //   66c705????????0101     |     

        $sequence_2 = { 8b4144 c1f808 884106 8a4144 884107 }
            // n = 5, score = 400
            //   8b4144               | lea                 eax, [ebp + 0x400]
            //   c1f808               | mov                 edx, 0x8004667e
            //   884106               | mov                 dword ptr [ebp + 0x400], eax
            //   8a4144               | test                eax, eax
            //   884107               | dec                 esp

        $sequence_3 = { 884105 8b4144 c1f808 884106 8a4144 }
            // n = 5, score = 400
            //   884105               | dec                 esp
            //   8b4144               | add                 ebx, ecx
            //   c1f808               | dec                 ecx
            //   884106               | dec                 esp
            //   8a4144               | jne                 0x14a8

        $sequence_4 = { 50 6802000000 ff35???????? ff35???????? }
            // n = 4, score = 400
            //   50                   | dec                 eax
            //   6802000000           | mov                 eax, dword ptr [esp + 0xd0]
            //   ff35????????         |                     
            //   ff35????????         |                     

        $sequence_5 = { 66c705????????0101 c605????????01 c605????????01 c605????????01 }
            // n = 4, score = 400
            //   66c705????????0101     |     
            //   c605????????01       |                     
            //   c605????????01       |                     
            //   c605????????01       |                     

        $sequence_6 = { 884105 8b4144 c1f808 884106 8a4144 884107 }
            // n = 6, score = 400
            //   884105               | dec                 eax
            //   8b4144               | lea                 edx, [0xf293]
            //   c1f808               | dec                 eax
            //   884106               | mov                 ecx, ebx
            //   8a4144               | dec                 eax
            //   884107               | lea                 edx, [0xf293]

        $sequence_7 = { c1f808 884106 8a4144 884107 }
            // n = 4, score = 400
            //   c1f808               | test                eax, eax
            //   884106               | jne                 0x1a70
            //   8a4144               | inc                 esp
            //   884107               | mov                 edi, dword ptr [ebp + 0x58]

        $sequence_8 = { c605????????01 66c705????????0101 c605????????01 c605????????01 }
            // n = 4, score = 400
            //   c605????????01       |                     
            //   66c705????????0101     |     
            //   c605????????01       |                     
            //   c605????????01       |                     

        $sequence_9 = { 884104 8a4146 884105 8b4144 }
            // n = 4, score = 400
            //   884104               | jg                  0x291
            //   8a4146               | mov                 esi, eax
            //   884105               | push                edi
            //   8b4144               | test                ebp, ebp

    condition:
        7 of them and filesize < 224112
}