rule win_kardonloader_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.kardonloader."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.kardonloader"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 83e13f c1e806 03c3 8a0490 88443702 8a0419 8b4d0c }
            // n = 7, score = 200
            //   83e13f               | and                 ecx, 0x3f
            //   c1e806               | shr                 eax, 6
            //   03c3                 | add                 eax, ebx
            //   8a0490               | mov                 al, byte ptr [eax + edx*4]
            //   88443702             | mov                 byte ptr [edi + esi + 2], al
            //   8a0419               | mov                 al, byte ptr [ecx + ebx]
            //   8b4d0c               | mov                 ecx, dword ptr [ebp + 0xc]

        $sequence_1 = { 5e 8be5 5d c3 6a00 ff15???????? cc }
            // n = 7, score = 200
            //   5e                   | pop                 esi
            //   8be5                 | mov                 esp, ebp
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   6a00                 | push                0
            //   ff15????????         |                     
            //   cc                   | int3                

        $sequence_2 = { e8???????? 83c438 85c0 7405 83c004 }
            // n = 5, score = 200
            //   e8????????           |                     
            //   83c438               | add                 esp, 0x38
            //   85c0                 | test                eax, eax
            //   7405                 | je                  7
            //   83c004               | add                 eax, 4

        $sequence_3 = { 56 ff7508 68???????? e8???????? 85c0 0f8421010000 }
            // n = 6, score = 200
            //   56                   | push                esi
            //   ff7508               | push                dword ptr [ebp + 8]
            //   68????????           |                     
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   0f8421010000         | je                  0x127

        $sequence_4 = { 50 56 e8???????? 83c40c 894714 b001 5f }
            // n = 7, score = 200
            //   50                   | push                eax
            //   56                   | push                esi
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   894714               | mov                 dword ptr [edi + 0x14], eax
            //   b001                 | mov                 al, 1
            //   5f                   | pop                 edi

        $sequence_5 = { e8???????? 59 50 8d8550faffff 50 }
            // n = 5, score = 200
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   50                   | push                eax
            //   8d8550faffff         | lea                 eax, [ebp - 0x5b0]
            //   50                   | push                eax

        $sequence_6 = { 50 ff35???????? ff35???????? e8???????? 83c438 e9???????? 5f }
            // n = 7, score = 200
            //   50                   | push                eax
            //   ff35????????         |                     
            //   ff35????????         |                     
            //   e8????????           |                     
            //   83c438               | add                 esp, 0x38
            //   e9????????           |                     
            //   5f                   | pop                 edi

        $sequence_7 = { 750b c74704???????? 0fb7720a 6a05 58 663bf0 750e }
            // n = 7, score = 200
            //   750b                 | jne                 0xd
            //   c74704????????       |                     
            //   0fb7720a             | movzx               esi, word ptr [edx + 0xa]
            //   6a05                 | push                5
            //   58                   | pop                 eax
            //   663bf0               | cmp                 si, ax
            //   750e                 | jne                 0x10

        $sequence_8 = { c0e204 8b45fc 880c30 0fb6441f02 8a8018314000 c0e802 }
            // n = 6, score = 200
            //   c0e204               | shl                 dl, 4
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   880c30               | mov                 byte ptr [eax + esi], cl
            //   0fb6441f02           | movzx               eax, byte ptr [edi + ebx + 2]
            //   8a8018314000         | mov                 al, byte ptr [eax + 0x403118]
            //   c0e802               | shr                 al, 2

        $sequence_9 = { 50 8d85e4fdffff 50 8d85e8feffff 68???????? 50 }
            // n = 6, score = 200
            //   50                   | push                eax
            //   8d85e4fdffff         | lea                 eax, [ebp - 0x21c]
            //   50                   | push                eax
            //   8d85e8feffff         | lea                 eax, [ebp - 0x118]
            //   68????????           |                     
            //   50                   | push                eax

    condition:
        7 of them and filesize < 57344
}