rule win_kelihos_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.kelihos."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.kelihos"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 59 59 c644241701 84c0 7505 c644241700 }
            // n = 7, score = 300
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx
            //   c644241701           | mov                 byte ptr [esp + 0x17], 1
            //   84c0                 | test                al, al
            //   7505                 | jne                 7
            //   c644241700           | mov                 byte ptr [esp + 0x17], 0

        $sequence_1 = { ff7508 ff75fc ff7508 50 51 ff750c 56 }
            // n = 7, score = 300
            //   ff7508               | push                dword ptr [ebp + 8]
            //   ff75fc               | push                dword ptr [ebp - 4]
            //   ff7508               | push                dword ptr [ebp + 8]
            //   50                   | push                eax
            //   51                   | push                ecx
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   56                   | push                esi

        $sequence_2 = { e8???????? 6a00 6a01 8d4dc0 e8???????? 8a45ef e8???????? }
            // n = 7, score = 300
            //   e8????????           |                     
            //   6a00                 | push                0
            //   6a01                 | push                1
            //   8d4dc0               | lea                 ecx, [ebp - 0x40]
            //   e8????????           |                     
            //   8a45ef               | mov                 al, byte ptr [ebp - 0x11]
            //   e8????????           |                     

        $sequence_3 = { e8???????? b001 e8???????? c20800 6a18 b8???????? e8???????? }
            // n = 7, score = 300
            //   e8????????           |                     
            //   b001                 | mov                 al, 1
            //   e8????????           |                     
            //   c20800               | ret                 8
            //   6a18                 | push                0x18
            //   b8????????           |                     
            //   e8????????           |                     

        $sequence_4 = { e8???????? 83c40c 53 6a01 8d8ddcfdffff e8???????? 53 }
            // n = 7, score = 300
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   53                   | push                ebx
            //   6a01                 | push                1
            //   8d8ddcfdffff         | lea                 ecx, [ebp - 0x224]
            //   e8????????           |                     
            //   53                   | push                ebx

        $sequence_5 = { e8???????? c645fc02 807dd800 0f84f7000000 8b06 8b4004 03c6 }
            // n = 7, score = 300
            //   e8????????           |                     
            //   c645fc02             | mov                 byte ptr [ebp - 4], 2
            //   807dd800             | cmp                 byte ptr [ebp - 0x28], 0
            //   0f84f7000000         | je                  0xfd
            //   8b06                 | mov                 eax, dword ptr [esi]
            //   8b4004               | mov                 eax, dword ptr [eax + 4]
            //   03c6                 | add                 eax, esi

        $sequence_6 = { ff75ac 8d7db8 895da8 e8???????? 83c40c 84c0 0f840b010000 }
            // n = 7, score = 300
            //   ff75ac               | push                dword ptr [ebp - 0x54]
            //   8d7db8               | lea                 edi, [ebp - 0x48]
            //   895da8               | mov                 dword ptr [ebp - 0x58], ebx
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   84c0                 | test                al, al
            //   0f840b010000         | je                  0x111

        $sequence_7 = { 8b4d0c 8b5508 6a00 6a10 50 51 52 }
            // n = 7, score = 300
            //   8b4d0c               | mov                 ecx, dword ptr [ebp + 0xc]
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]
            //   6a00                 | push                0
            //   6a10                 | push                0x10
            //   50                   | push                eax
            //   51                   | push                ecx
            //   52                   | push                edx

        $sequence_8 = { c3 6a10 b8???????? e8???????? 8b7d08 33db 53 }
            // n = 7, score = 300
            //   c3                   | ret                 
            //   6a10                 | push                0x10
            //   b8????????           |                     
            //   e8????????           |                     
            //   8b7d08               | mov                 edi, dword ptr [ebp + 8]
            //   33db                 | xor                 ebx, ebx
            //   53                   | push                ebx

        $sequence_9 = { e8???????? eb02 33c0 e8???????? c20400 83c1f8 8b01 }
            // n = 7, score = 300
            //   e8????????           |                     
            //   eb02                 | jmp                 4
            //   33c0                 | xor                 eax, eax
            //   e8????????           |                     
            //   c20400               | ret                 4
            //   83c1f8               | add                 ecx, -8
            //   8b01                 | mov                 eax, dword ptr [ecx]

    condition:
        7 of them and filesize < 4702208
}