rule win_ketrican_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.ketrican."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.ketrican"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8965f0 33db 895dfc 33c0 }
            // n = 4, score = 700
            //   8965f0               | mov                 dword ptr [ebp - 0x10], esp
            //   33db                 | xor                 ebx, ebx
            //   895dfc               | mov                 dword ptr [ebp - 4], ebx
            //   33c0                 | xor                 eax, eax

        $sequence_1 = { 7417 6a0a 6a1f 68???????? }
            // n = 4, score = 600
            //   7417                 | je                  0x19
            //   6a0a                 | push                0xa
            //   6a1f                 | push                0x1f
            //   68????????           |                     

        $sequence_2 = { e8???????? 83c010 8906 c3 56 }
            // n = 5, score = 600
            //   e8????????           |                     
            //   83c010               | add                 eax, 0x10
            //   8906                 | mov                 dword ptr [esi], eax
            //   c3                   | ret                 
            //   56                   | push                esi

        $sequence_3 = { 8bd1 e8???????? 5f 5e c3 55 8bec }
            // n = 7, score = 600
            //   8bd1                 | mov                 edx, ecx
            //   e8????????           |                     
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   c3                   | ret                 
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp

        $sequence_4 = { 8b06 5d c20400 55 8bec 8b4508 894508 }
            // n = 7, score = 600
            //   8b06                 | mov                 eax, dword ptr [esi]
            //   5d                   | pop                 ebp
            //   c20400               | ret                 4
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   894508               | mov                 dword ptr [ebp + 8], eax

        $sequence_5 = { 8bc1 8945f0 834dfcff e8???????? }
            // n = 4, score = 600
            //   8bc1                 | mov                 eax, ecx
            //   8945f0               | mov                 dword ptr [ebp - 0x10], eax
            //   834dfcff             | or                  dword ptr [ebp - 4], 0xffffffff
            //   e8????????           |                     

        $sequence_6 = { 8901 5b 5d c20800 680e000780 e8???????? cc }
            // n = 7, score = 600
            //   8901                 | mov                 dword ptr [ecx], eax
            //   5b                   | pop                 ebx
            //   5d                   | pop                 ebp
            //   c20800               | ret                 8
            //   680e000780           | push                0x8007000e
            //   e8????????           |                     
            //   cc                   | int3                

        $sequence_7 = { 680e000780 e8???????? cc 8b06 83e810 8b08 }
            // n = 6, score = 600
            //   680e000780           | push                0x8007000e
            //   e8????????           |                     
            //   cc                   | int3                
            //   8b06                 | mov                 eax, dword ptr [esi]
            //   83e810               | sub                 eax, 0x10
            //   8b08                 | mov                 ecx, dword ptr [eax]

        $sequence_8 = { 48 7445 48 743a 48 }
            // n = 5, score = 500
            //   48                   | dec                 eax
            //   7445                 | je                  0x47
            //   48                   | dec                 eax
            //   743a                 | je                  0x3c
            //   48                   | dec                 eax

        $sequence_9 = { 884603 83c604 8345f804 8b45f8 5f }
            // n = 5, score = 500
            //   884603               | mov                 byte ptr [esi + 3], al
            //   83c604               | add                 esi, 4
            //   8345f804             | add                 dword ptr [ebp - 8], 4
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   5f                   | pop                 edi

        $sequence_10 = { 58 668945d8 6a72 58 }
            // n = 4, score = 500
            //   58                   | pop                 eax
            //   668945d8             | mov                 word ptr [ebp - 0x28], ax
            //   6a72                 | push                0x72
            //   58                   | pop                 eax

        $sequence_11 = { 6a00 8d85f1fbffff 50 e8???????? 83c40c 6800040000 }
            // n = 6, score = 500
            //   6a00                 | push                0
            //   8d85f1fbffff         | lea                 eax, [ebp - 0x40f]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   6800040000           | push                0x400

        $sequence_12 = { ff7508 53 53 ffd6 5f 5e }
            // n = 6, score = 500
            //   ff7508               | push                dword ptr [ebp + 8]
            //   53                   | push                ebx
            //   53                   | push                ebx
            //   ffd6                 | call                esi
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi

        $sequence_13 = { 740a 48 754a e8???????? }
            // n = 4, score = 500
            //   740a                 | je                  0xc
            //   48                   | dec                 eax
            //   754a                 | jne                 0x4c
            //   e8????????           |                     

        $sequence_14 = { 83c002 663bd3 75f5 2bc1 d1f8 8d7001 6800080200 }
            // n = 7, score = 500
            //   83c002               | add                 eax, 2
            //   663bd3               | cmp                 dx, bx
            //   75f5                 | jne                 0xfffffff7
            //   2bc1                 | sub                 eax, ecx
            //   d1f8                 | sar                 eax, 1
            //   8d7001               | lea                 esi, [eax + 1]
            //   6800080200           | push                0x20800

        $sequence_15 = { e8???????? 8b8a8c2f0000 33c8 e8???????? b8???????? }
            // n = 5, score = 100
            //   e8????????           |                     
            //   8b8a8c2f0000         | mov                 ecx, dword ptr [edx + 0x2f8c]
            //   33c8                 | xor                 ecx, eax
            //   e8????????           |                     
            //   b8????????           |                     

        $sequence_16 = { ff15???????? 68???????? c705????????98824100 a3???????? }
            // n = 4, score = 100
            //   ff15????????         |                     
            //   68????????           |                     
            //   c705????????98824100     |     
            //   a3????????           |                     

        $sequence_17 = { 8d420c 8b4ae8 33c8 e8???????? 8b8a4c010000 }
            // n = 5, score = 100
            //   8d420c               | lea                 eax, [edx + 0xc]
            //   8b4ae8               | mov                 ecx, dword ptr [edx - 0x18]
            //   33c8                 | xor                 ecx, eax
            //   e8????????           |                     
            //   8b8a4c010000         | mov                 ecx, dword ptr [edx + 0x14c]

        $sequence_18 = { 33c8 e8???????? 8b8ae8080000 33c8 e8???????? }
            // n = 5, score = 100
            //   33c8                 | xor                 ecx, eax
            //   e8????????           |                     
            //   8b8ae8080000         | mov                 ecx, dword ptr [edx + 0x8e8]
            //   33c8                 | xor                 ecx, eax
            //   e8????????           |                     

        $sequence_19 = { 8d4dd0 e9???????? 8d4de0 e9???????? 8d4db8 e9???????? 8d4ddc }
            // n = 7, score = 100
            //   8d4dd0               | lea                 ecx, [ebp - 0x30]
            //   e9????????           |                     
            //   8d4de0               | lea                 ecx, [ebp - 0x20]
            //   e9????????           |                     
            //   8d4db8               | lea                 ecx, [ebp - 0x48]
            //   e9????????           |                     
            //   8d4ddc               | lea                 ecx, [ebp - 0x24]

        $sequence_20 = { b8???????? e9???????? 8b542408 8d420c 8b8aa4feffff 33c8 }
            // n = 6, score = 100
            //   b8????????           |                     
            //   e9????????           |                     
            //   8b542408             | mov                 edx, dword ptr [esp + 8]
            //   8d420c               | lea                 eax, [edx + 0xc]
            //   8b8aa4feffff         | mov                 ecx, dword ptr [edx - 0x15c]
            //   33c8                 | xor                 ecx, eax

        $sequence_21 = { c705????????98824100 a3???????? c605????????00 e8???????? 59 }
            // n = 5, score = 100
            //   c705????????98824100     |     
            //   a3????????           |                     
            //   c605????????00       |                     
            //   e8????????           |                     
            //   59                   | pop                 ecx

        $sequence_22 = { 8b8a54ffffff 33c8 e8???????? 8b8adc090000 33c8 e8???????? }
            // n = 6, score = 100
            //   8b8a54ffffff         | mov                 ecx, dword ptr [edx - 0xac]
            //   33c8                 | xor                 ecx, eax
            //   e8????????           |                     
            //   8b8adc090000         | mov                 ecx, dword ptr [edx + 0x9dc]
            //   33c8                 | xor                 ecx, eax
            //   e8????????           |                     

    condition:
        7 of them and filesize < 1449984
}