rule win_kikothac_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.kikothac."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.kikothac"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 85c0 7516 8b86942f4100 b301 85c0 740a }
            // n = 6, score = 200
            //   85c0                 | test                eax, eax
            //   7516                 | jne                 0x18
            //   8b86942f4100         | mov                 eax, dword ptr [esi + 0x412f94]
            //   b301                 | mov                 bl, 1
            //   85c0                 | test                eax, eax
            //   740a                 | je                  0xc

        $sequence_1 = { 50 ff15???????? a3???????? 3bc3 7507 32c0 5b }
            // n = 7, score = 200
            //   50                   | push                eax
            //   ff15????????         |                     
            //   a3????????           |                     
            //   3bc3                 | cmp                 eax, ebx
            //   7507                 | jne                 9
            //   32c0                 | xor                 al, al
            //   5b                   | pop                 ebx

        $sequence_2 = { 56 33f6 57 8975fc ffd3 85c0 }
            // n = 6, score = 200
            //   56                   | push                esi
            //   33f6                 | xor                 esi, esi
            //   57                   | push                edi
            //   8975fc               | mov                 dword ptr [ebp - 4], esi
            //   ffd3                 | call                ebx
            //   85c0                 | test                eax, eax

        $sequence_3 = { c60424cd 8d642438 e9???????? c64424046e 895500 9c 6689742408 }
            // n = 7, score = 200
            //   c60424cd             | mov                 byte ptr [esp], 0xcd
            //   8d642438             | lea                 esp, [esp + 0x38]
            //   e9????????           |                     
            //   c64424046e           | mov                 byte ptr [esp + 4], 0x6e
            //   895500               | mov                 dword ptr [ebp], edx
            //   9c                   | pushfd              
            //   6689742408           | mov                 word ptr [esp + 8], si

        $sequence_4 = { c1c80a e9???????? 66894500 9c }
            // n = 4, score = 200
            //   c1c80a               | ror                 eax, 0xa
            //   e9????????           |                     
            //   66894500             | mov                 word ptr [ebp], ax
            //   9c                   | pushfd              

        $sequence_5 = { 8b441604 51 50 ff15???????? 85c0 7516 }
            // n = 6, score = 200
            //   8b441604             | mov                 eax, dword ptr [esi + edx + 4]
            //   51                   | push                ecx
            //   50                   | push                eax
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7516                 | jne                 0x18

        $sequence_6 = { 51 68102ba40e ff3424 9c 8f442438 }
            // n = 5, score = 200
            //   51                   | push                ecx
            //   68102ba40e           | push                0xea42b10
            //   ff3424               | push                dword ptr [esp]
            //   9c                   | pushfd              
            //   8f442438             | pop                 dword ptr [esp + 0x38]

        $sequence_7 = { 6820040000 57 57 57 }
            // n = 4, score = 200
            //   6820040000           | push                0x420
            //   57                   | push                edi
            //   57                   | push                edi
            //   57                   | push                edi

        $sequence_8 = { 60 f6c356 c6442404ab 20d0 }
            // n = 4, score = 200
            //   60                   | pushal              
            //   f6c356               | test                bl, 0x56
            //   c6442404ab           | mov                 byte ptr [esp + 4], 0xab
            //   20d0                 | and                 al, dl

        $sequence_9 = { e9???????? 8b7c242c 66c70424dc83 98 9f 8b442430 660fbeeb }
            // n = 7, score = 200
            //   e9????????           |                     
            //   8b7c242c             | mov                 edi, dword ptr [esp + 0x2c]
            //   66c70424dc83         | mov                 word ptr [esp], 0x83dc
            //   98                   | cwde                
            //   9f                   | lahf                
            //   8b442430             | mov                 eax, dword ptr [esp + 0x30]
            //   660fbeeb             | movsx               bp, bl

    condition:
        7 of them and filesize < 581632
}