rule win_kins_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.kins."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.kins"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e9???????? 8d45dc 8d75cc e8???????? 83f8ff 741f 8bc6 }
            // n = 7, score = 5000
            //   e9????????           |                     
            //   8d45dc               | lea                 eax, [ebp - 0x24]
            //   8d75cc               | lea                 esi, [ebp - 0x34]
            //   e8????????           |                     
            //   83f8ff               | cmp                 eax, -1
            //   741f                 | je                  0x21
            //   8bc6                 | mov                 eax, esi

        $sequence_1 = { 8bfe 337dfc 23f8 33fe 037df0 8d9417937198fd 8b7dfc }
            // n = 7, score = 5000
            //   8bfe                 | mov                 edi, esi
            //   337dfc               | xor                 edi, dword ptr [ebp - 4]
            //   23f8                 | and                 edi, eax
            //   33fe                 | xor                 edi, esi
            //   037df0               | add                 edi, dword ptr [ebp - 0x10]
            //   8d9417937198fd       | lea                 edx, [edi + edx - 0x2678e6d]
            //   8b7dfc               | mov                 edi, dword ptr [ebp - 4]

        $sequence_2 = { e8???????? 83f8ff 743d 47 3bfa }
            // n = 5, score = 5000
            //   e8????????           |                     
            //   83f8ff               | cmp                 eax, -1
            //   743d                 | je                  0x3f
            //   47                   | inc                 edi
            //   3bfa                 | cmp                 edi, edx

        $sequence_3 = { f7d3 0bde 33d8 035df4 8dbc3ba72394ab c1c70f 8bd8 }
            // n = 7, score = 5000
            //   f7d3                 | not                 ebx
            //   0bde                 | or                  ebx, esi
            //   33d8                 | xor                 ebx, eax
            //   035df4               | add                 ebx, dword ptr [ebp - 0xc]
            //   8dbc3ba72394ab       | lea                 edi, [ebx + edi - 0x546bdc59]
            //   c1c70f               | rol                 edi, 0xf
            //   8bd8                 | mov                 ebx, eax

        $sequence_4 = { c1e008 0bc2 0fb65116 0fb64917 c1e008 0bc2 }
            // n = 6, score = 5000
            //   c1e008               | shl                 eax, 8
            //   0bc2                 | or                  eax, edx
            //   0fb65116             | movzx               edx, byte ptr [ecx + 0x16]
            //   0fb64917             | movzx               ecx, byte ptr [ecx + 0x17]
            //   c1e008               | shl                 eax, 8
            //   0bc2                 | or                  eax, edx

        $sequence_5 = { 0fb6c0 83e07f 8bf2 746f 0fb61c39 c1e608 48 }
            // n = 7, score = 5000
            //   0fb6c0               | movzx               eax, al
            //   83e07f               | and                 eax, 0x7f
            //   8bf2                 | mov                 esi, edx
            //   746f                 | je                  0x71
            //   0fb61c39             | movzx               ebx, byte ptr [ecx + edi]
            //   c1e608               | shl                 esi, 8
            //   48                   | dec                 eax

        $sequence_6 = { 40 85f6 75d8 8b7510 3b16 7719 }
            // n = 6, score = 5000
            //   40                   | inc                 eax
            //   85f6                 | test                esi, esi
            //   75d8                 | jne                 0xffffffda
            //   8b7510               | mov                 esi, dword ptr [ebp + 0x10]
            //   3b16                 | cmp                 edx, dword ptr [esi]
            //   7719                 | ja                  0x1b

        $sequence_7 = { 33de 23df 33da 035908 8d840378a46ad7 c1c007 03c7 }
            // n = 7, score = 5000
            //   33de                 | xor                 ebx, esi
            //   23df                 | and                 ebx, edi
            //   33da                 | xor                 ebx, edx
            //   035908               | add                 ebx, dword ptr [ecx + 8]
            //   8d840378a46ad7       | lea                 eax, [ebx + eax - 0x28955b88]
            //   c1c007               | rol                 eax, 7
            //   03c7                 | add                 eax, edi

        $sequence_8 = { 8d8578fcffff 50 8d857cfdffff 50 }
            // n = 4, score = 5000
            //   8d8578fcffff         | lea                 eax, [ebp - 0x388]
            //   50                   | push                eax
            //   8d857cfdffff         | lea                 eax, [ebp - 0x284]
            //   50                   | push                eax

        $sequence_9 = { ff4118 8b4118 83f838 762b eb0b c644081c00 }
            // n = 6, score = 5000
            //   ff4118               | inc                 dword ptr [ecx + 0x18]
            //   8b4118               | mov                 eax, dword ptr [ecx + 0x18]
            //   83f838               | cmp                 eax, 0x38
            //   762b                 | jbe                 0x2d
            //   eb0b                 | jmp                 0xd
            //   c644081c00           | mov                 byte ptr [eax + ecx + 0x1c], 0

    condition:
        7 of them and filesize < 548864
}