rule win_koobface_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.koobface."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.koobface"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d850cffffff 50 c745fc26000000 e8???????? 834dfcff 53 }
            // n = 6, score = 100
            //   8d850cffffff         | lea                 eax, [ebp - 0xf4]
            //   50                   | push                eax
            //   c745fc26000000       | mov                 dword ptr [ebp - 4], 0x26
            //   e8????????           |                     
            //   834dfcff             | or                  dword ptr [ebp - 4], 0xffffffff
            //   53                   | push                ebx

        $sequence_1 = { e8???????? 33db 59 889dfaf7ffff 889dfbf7ffff 899decf7ffff 899de0f7ffff }
            // n = 7, score = 100
            //   e8????????           |                     
            //   33db                 | xor                 ebx, ebx
            //   59                   | pop                 ecx
            //   889dfaf7ffff         | mov                 byte ptr [ebp - 0x806], bl
            //   889dfbf7ffff         | mov                 byte ptr [ebp - 0x805], bl
            //   899decf7ffff         | mov                 dword ptr [ebp - 0x814], ebx
            //   899de0f7ffff         | mov                 dword ptr [ebp - 0x820], ebx

        $sequence_2 = { 83bd34c1ffff0a 754c 8d8540c1ffff 6a41 50 }
            // n = 5, score = 100
            //   83bd34c1ffff0a       | cmp                 dword ptr [ebp - 0x3ecc], 0xa
            //   754c                 | jne                 0x4e
            //   8d8540c1ffff         | lea                 eax, [ebp - 0x3ec0]
            //   6a41                 | push                0x41
            //   50                   | push                eax

        $sequence_3 = { 50 c745cc5cd74100 e8???????? 8b7508 bf63736de0 393e 0f85a5010000 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   c745cc5cd74100       | mov                 dword ptr [ebp - 0x34], 0x41d75c
            //   e8????????           |                     
            //   8b7508               | mov                 esi, dword ptr [ebp + 8]
            //   bf63736de0           | mov                 edi, 0xe06d7363
            //   393e                 | cmp                 dword ptr [esi], edi
            //   0f85a5010000         | jne                 0x1ab

        $sequence_4 = { e8???????? 50 8d8538f4ffff 50 e8???????? 8b8520f4ffff 59 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   50                   | push                eax
            //   8d8538f4ffff         | lea                 eax, [ebp - 0xbc8]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b8520f4ffff         | mov                 eax, dword ptr [ebp - 0xbe0]
            //   59                   | pop                 ecx

        $sequence_5 = { e8???????? 8b8598faffff c1e803 50 8d85a4faffff 57 50 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8b8598faffff         | mov                 eax, dword ptr [ebp - 0x568]
            //   c1e803               | shr                 eax, 3
            //   50                   | push                eax
            //   8d85a4faffff         | lea                 eax, [ebp - 0x55c]
            //   57                   | push                edi
            //   50                   | push                eax

        $sequence_6 = { 8d8528ffffff 68???????? 50 e8???????? 83c40c 8d8528ffffff 50 }
            // n = 7, score = 100
            //   8d8528ffffff         | lea                 eax, [ebp - 0xd8]
            //   68????????           |                     
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   8d8528ffffff         | lea                 eax, [ebp - 0xd8]
            //   50                   | push                eax

        $sequence_7 = { 8d8528ffffff 50 e8???????? 68???????? 8d850857ffff }
            // n = 5, score = 100
            //   8d8528ffffff         | lea                 eax, [ebp - 0xd8]
            //   50                   | push                eax
            //   e8????????           |                     
            //   68????????           |                     
            //   8d850857ffff         | lea                 eax, [ebp - 0xa8f8]

        $sequence_8 = { 8d4de4 51 53 ff90e0000000 837de404 7407 }
            // n = 6, score = 100
            //   8d4de4               | lea                 ecx, [ebp - 0x1c]
            //   51                   | push                ecx
            //   53                   | push                ebx
            //   ff90e0000000         | call                dword ptr [eax + 0xe0]
            //   837de404             | cmp                 dword ptr [ebp - 0x1c], 4
            //   7407                 | je                  9

        $sequence_9 = { 68???????? e8???????? 59 57 e8???????? 59 8b4dfc }
            // n = 7, score = 100
            //   68????????           |                     
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   57                   | push                edi
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]

    condition:
        7 of them and filesize < 368640
}