rule win_krbanker_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.krbanker."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.krbanker"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 83c404 58 8945dc 837ddc00 }
            // n = 4, score = 400
            //   83c404               | add                 esp, 4
            //   58                   | pop                 eax
            //   8945dc               | mov                 dword ptr [ebp - 0x24], eax
            //   837ddc00             | cmp                 dword ptr [ebp - 0x24], 0

        $sequence_1 = { 83c404 58 8945fc b8???????? 50 }
            // n = 5, score = 400
            //   83c404               | add                 esp, 4
            //   58                   | pop                 eax
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   b8????????           |                     
            //   50                   | push                eax

        $sequence_2 = { 6801000000 bb40010000 e8???????? 83c410 8945c8 6801010080 6a00 }
            // n = 7, score = 400
            //   6801000000           | push                1
            //   bb40010000           | mov                 ebx, 0x140
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10
            //   8945c8               | mov                 dword ptr [ebp - 0x38], eax
            //   6801010080           | push                0x80000101
            //   6a00                 | push                0

        $sequence_3 = { 0faf03 ebf5 8bc8 c3 55 8bec 83c4f4 }
            // n = 7, score = 400
            //   0faf03               | imul                eax, dword ptr [ebx]
            //   ebf5                 | jmp                 0xfffffff7
            //   8bc8                 | mov                 ecx, eax
            //   c3                   | ret                 
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   83c4f4               | add                 esp, -0xc

        $sequence_4 = { 75a4 dd442410 e8???????? 8ad8 }
            // n = 4, score = 400
            //   75a4                 | jne                 0xffffffa6
            //   dd442410             | fld                 qword ptr [esp + 0x10]
            //   e8????????           |                     
            //   8ad8                 | mov                 bl, al

        $sequence_5 = { 7762 7415 3d04000080 7417 3d01010080 }
            // n = 5, score = 400
            //   7762                 | ja                  0x64
            //   7415                 | je                  0x17
            //   3d04000080           | cmp                 eax, 0x80000004
            //   7417                 | je                  0x19
            //   3d01010080           | cmp                 eax, 0x80000101

        $sequence_6 = { bb40010000 e8???????? 83c410 8945cc ff75cc ff75d0 }
            // n = 6, score = 400
            //   bb40010000           | mov                 ebx, 0x140
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10
            //   8945cc               | mov                 dword ptr [ebp - 0x34], eax
            //   ff75cc               | push                dword ptr [ebp - 0x34]
            //   ff75d0               | push                dword ptr [ebp - 0x30]

        $sequence_7 = { 8a5c2410 8ac3 5e 5b c3 8b542410 83ec0c }
            // n = 7, score = 400
            //   8a5c2410             | mov                 bl, byte ptr [esp + 0x10]
            //   8ac3                 | mov                 al, bl
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx
            //   c3                   | ret                 
            //   8b542410             | mov                 edx, dword ptr [esp + 0x10]
            //   83ec0c               | sub                 esp, 0xc

        $sequence_8 = { 8b5dfc 83c304 895df8 8965f4 ff7514 }
            // n = 5, score = 400
            //   8b5dfc               | mov                 ebx, dword ptr [ebp - 4]
            //   83c304               | add                 ebx, 4
            //   895df8               | mov                 dword ptr [ebp - 8], ebx
            //   8965f4               | mov                 dword ptr [ebp - 0xc], esp
            //   ff7514               | push                dword ptr [ebp + 0x14]

        $sequence_9 = { 03d8 895dd4 8b5df8 e8???????? }
            // n = 4, score = 400
            //   03d8                 | add                 ebx, eax
            //   895dd4               | mov                 dword ptr [ebp - 0x2c], ebx
            //   8b5df8               | mov                 ebx, dword ptr [ebp - 8]
            //   e8????????           |                     

    condition:
        7 of them and filesize < 1826816
}