rule win_krdownloader_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.krdownloader."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.krdownloader"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c645e161 c645e22e c645e370 c645e468 c645e570 c645e63f c645e76d }
            // n = 7, score = 200
            //   c645e161             | mov                 byte ptr [ebp - 0x1f], 0x61
            //   c645e22e             | mov                 byte ptr [ebp - 0x1e], 0x2e
            //   c645e370             | mov                 byte ptr [ebp - 0x1d], 0x70
            //   c645e468             | mov                 byte ptr [ebp - 0x1c], 0x68
            //   c645e570             | mov                 byte ptr [ebp - 0x1b], 0x70
            //   c645e63f             | mov                 byte ptr [ebp - 0x1a], 0x3f
            //   c645e76d             | mov                 byte ptr [ebp - 0x19], 0x6d

        $sequence_1 = { 8b4df4 8b09 e8???????? 8945f0 }
            // n = 4, score = 200
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]
            //   8b09                 | mov                 ecx, dword ptr [ecx]
            //   e8????????           |                     
            //   8945f0               | mov                 dword ptr [ebp - 0x10], eax

        $sequence_2 = { 7528 8b45fc 0345f4 0fb6482c 51 68???????? }
            // n = 6, score = 200
            //   7528                 | jne                 0x2a
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   0345f4               | add                 eax, dword ptr [ebp - 0xc]
            //   0fb6482c             | movzx               ecx, byte ptr [eax + 0x2c]
            //   51                   | push                ecx
            //   68????????           |                     

        $sequence_3 = { e8???????? 8945d8 8b4dfc 51 8b55f8 }
            // n = 5, score = 200
            //   e8????????           |                     
            //   8945d8               | mov                 dword ptr [ebp - 0x28], eax
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   51                   | push                ecx
            //   8b55f8               | mov                 edx, dword ptr [ebp - 8]

        $sequence_4 = { 7418 8b4dec 0fbe11 0fbe45f3 3bd0 }
            // n = 5, score = 200
            //   7418                 | je                  0x1a
            //   8b4dec               | mov                 ecx, dword ptr [ebp - 0x14]
            //   0fbe11               | movsx               edx, byte ptr [ecx]
            //   0fbe45f3             | movsx               eax, byte ptr [ebp - 0xd]
            //   3bd0                 | cmp                 edx, eax

        $sequence_5 = { 8955f0 8b45f0 8945f8 c745d800000080 817d1000000080 7310 }
            // n = 6, score = 200
            //   8955f0               | mov                 dword ptr [ebp - 0x10], edx
            //   8b45f0               | mov                 eax, dword ptr [ebp - 0x10]
            //   8945f8               | mov                 dword ptr [ebp - 8], eax
            //   c745d800000080       | mov                 dword ptr [ebp - 0x28], 0x80000000
            //   817d1000000080       | cmp                 dword ptr [ebp + 0x10], 0x80000000
            //   7310                 | jae                 0x12

        $sequence_6 = { c745f001000000 eb28 837d0c00 7422 6a04 68???????? 8b4d0c }
            // n = 7, score = 200
            //   c745f001000000       | mov                 dword ptr [ebp - 0x10], 1
            //   eb28                 | jmp                 0x2a
            //   837d0c00             | cmp                 dword ptr [ebp + 0xc], 0
            //   7422                 | je                  0x24
            //   6a04                 | push                4
            //   68????????           |                     
            //   8b4d0c               | mov                 ecx, dword ptr [ebp + 0xc]

        $sequence_7 = { 89815c0d0300 8b55fc 8b82500d0300 50 ff15???????? }
            // n = 5, score = 200
            //   89815c0d0300         | mov                 dword ptr [ecx + 0x30d5c], eax
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   8b82500d0300         | mov                 eax, dword ptr [edx + 0x30d50]
            //   50                   | push                eax
            //   ff15????????         |                     

        $sequence_8 = { 735e 8b4dfc 8b5134 83ea01 3955f4 }
            // n = 5, score = 200
            //   735e                 | jae                 0x60
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   8b5134               | mov                 edx, dword ptr [ecx + 0x34]
            //   83ea01               | sub                 edx, 1
            //   3955f4               | cmp                 dword ptr [ebp - 0xc], edx

        $sequence_9 = { 83c001 8945fc 817dfc6f020000 7d63 8b4dfc 8b55f8 }
            // n = 6, score = 200
            //   83c001               | add                 eax, 1
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   817dfc6f020000       | cmp                 dword ptr [ebp - 4], 0x26f
            //   7d63                 | jge                 0x65
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   8b55f8               | mov                 edx, dword ptr [ebp - 8]

    condition:
        7 of them and filesize < 352256
}