rule win_kuluoz_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.kuluoz."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.kuluoz"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 6a00 6a00 8b45cc 50 ff55ec 8945c8 837dc800 }
            // n = 7, score = 100
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   8b45cc               | mov                 eax, dword ptr [ebp - 0x34]
            //   50                   | push                eax
            //   ff55ec               | call                dword ptr [ebp - 0x14]
            //   8945c8               | mov                 dword ptr [ebp - 0x38], eax
            //   837dc800             | cmp                 dword ptr [ebp - 0x38], 0

        $sequence_1 = { 52 8b45fc 8b4840 51 e8???????? 83c40c 8b55fc }
            // n = 7, score = 100
            //   52                   | push                edx
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   8b4840               | mov                 ecx, dword ptr [eax + 0x40]
            //   51                   | push                ecx
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]

        $sequence_2 = { 83c001 8b4d0c 898146120000 837dfc04 7552 }
            // n = 5, score = 100
            //   83c001               | add                 eax, 1
            //   8b4d0c               | mov                 ecx, dword ptr [ebp + 0xc]
            //   898146120000         | mov                 dword ptr [ecx + 0x1246], eax
            //   837dfc04             | cmp                 dword ptr [ebp - 4], 4
            //   7552                 | jne                 0x54

        $sequence_3 = { 8b4508 50 8d4dd8 51 e8???????? 8b10 }
            // n = 6, score = 100
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   50                   | push                eax
            //   8d4dd8               | lea                 ecx, [ebp - 0x28]
            //   51                   | push                ecx
            //   e8????????           |                     
            //   8b10                 | mov                 edx, dword ptr [eax]

        $sequence_4 = { 338df4feffff 8985f0feffff 898df4feffff 68ff000000 8d95f8feffff 52 e8???????? }
            // n = 7, score = 100
            //   338df4feffff         | xor                 ecx, dword ptr [ebp - 0x10c]
            //   8985f0feffff         | mov                 dword ptr [ebp - 0x110], eax
            //   898df4feffff         | mov                 dword ptr [ebp - 0x10c], ecx
            //   68ff000000           | push                0xff
            //   8d95f8feffff         | lea                 edx, [ebp - 0x108]
            //   52                   | push                edx
            //   e8????????           |                     

        $sequence_5 = { 7502 eb05 e9???????? 837dfc06 0f84a2000000 837dfc04 7552 }
            // n = 7, score = 100
            //   7502                 | jne                 4
            //   eb05                 | jmp                 7
            //   e9????????           |                     
            //   837dfc06             | cmp                 dword ptr [ebp - 4], 6
            //   0f84a2000000         | je                  0xa8
            //   837dfc04             | cmp                 dword ptr [ebp - 4], 4
            //   7552                 | jne                 0x54

        $sequence_6 = { 83fa0a 7409 0fbe4508 83f80d 7504 b001 }
            // n = 6, score = 100
            //   83fa0a               | cmp                 edx, 0xa
            //   7409                 | je                  0xb
            //   0fbe4508             | movsx               eax, byte ptr [ebp + 8]
            //   83f80d               | cmp                 eax, 0xd
            //   7504                 | jne                 6
            //   b001                 | mov                 al, 1

        $sequence_7 = { 8b45fc 0fb60c02 51 e8???????? 0fbed0 3bf2 7404 }
            // n = 7, score = 100
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   0fb60c02             | movzx               ecx, byte ptr [edx + eax]
            //   51                   | push                ecx
            //   e8????????           |                     
            //   0fbed0               | movsx               edx, al
            //   3bf2                 | cmp                 esi, edx
            //   7404                 | je                  6

        $sequence_8 = { 8bec 81ec780a0000 a1???????? 33c5 8945fc }
            // n = 5, score = 100
            //   8bec                 | mov                 ebp, esp
            //   81ec780a0000         | sub                 esp, 0xa78
            //   a1????????           |                     
            //   33c5                 | xor                 eax, ebp
            //   8945fc               | mov                 dword ptr [ebp - 4], eax

        $sequence_9 = { f7f1 0fbe9204605009 8b45f8 0345fc 0fbe08 }
            // n = 5, score = 100
            //   f7f1                 | div                 ecx
            //   0fbe9204605009       | movsx               edx, byte ptr [edx + 0x9506004]
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   0345fc               | add                 eax, dword ptr [ebp - 4]
            //   0fbe08               | movsx               ecx, byte ptr [eax]

    condition:
        7 of them and filesize < 65536
}