rule win_laturo_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.laturo."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.laturo"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 486bc038 488b0d???????? 8b440120 c1e01e c1f81f 3b442450 741a }
            // n = 7, score = 200
            //   486bc038             | and                 dword ptr [esp + 0x30], 0
            //   488b0d????????       |                     
            //   8b440120             | dec                 eax
            //   c1e01e               | lea                 ecx, [0x7bfc]
            //   c1f81f               | and                 dword ptr [esp + 0x28], 0
            //   3b442450             | inc                 ecx
            //   741a                 | mov                 eax, 3

        $sequence_1 = { e8???????? 33db 8bf8 85c0 0f8453020000 4c8d2dea040100 }
            // n = 6, score = 200
            //   e8????????           |                     
            //   33db                 | inc                 esp
            //   8bf8                 | mov                 eax, dword ptr [ecx + eax*4]
            //   85c0                 | xor                 edx, edx
            //   0f8453020000         | mov                 ecx, 0x5a
            //   4c8d2dea040100       | dec                 esp

        $sequence_2 = { 884814 0fb644243c 83f805 7511 0fb6442405 83e001 85c0 }
            // n = 7, score = 200
            //   884814               | lea                 esi, [eax + eax*8]
            //   0fb644243c           | dec                 ecx
            //   83f805               | sar                 esp, 6
            //   7511                 | dec                 edx
            //   0fb6442405           | mov                 eax, dword ptr [ecx + 0x1a5f0]
            //   83e001               | dec                 edx
            //   85c0                 | mov                 eax, dword ptr [eax + esi*8 + 0x28]

        $sequence_3 = { 48837c242000 7432 488b442430 4839442420 720c }
            // n = 5, score = 200
            //   48837c242000         | dec                 eax
            //   7432                 | mov                 dword ptr [ebp - 0x41], eax
            //   488b442430           | xor                 ebx, ebx
            //   4839442420           | mov                 edi, eax
            //   720c                 | test                eax, eax

        $sequence_4 = { 488d0d13800100 33c0 8b542420 f00fb111 85c0 742c 48837c242820 }
            // n = 7, score = 200
            //   488d0d13800100       | dec                 eax
            //   33c0                 | lea                 ecx, [0x18013]
            //   8b542420             | xor                 eax, eax
            //   f00fb111             | mov                 edx, dword ptr [esp + 0x20]
            //   85c0                 | lock cmpxchg        dword ptr [ecx], edx
            //   742c                 | test                eax, eax
            //   48837c242820         | je                  0x2e

        $sequence_5 = { 4c8d34c0 49c1fc06 4a8b84e1f0a50100 4a8b44f028 488945bf }
            // n = 5, score = 200
            //   4c8d34c0             | sar                 eax, 0x1f
            //   49c1fc06             | cmp                 eax, dword ptr [esp + 0x50]
            //   4a8b84e1f0a50100     | je                  0x1c
            //   4a8b44f028           | dec                 eax
            //   488945bf             | mov                 ecx, dword ptr [ecx]

        $sequence_6 = { 488b09 448b0481 33d2 b95a000000 ff15???????? }
            // n = 5, score = 200
            //   488b09               | dec                 eax
            //   448b0481             | imul                eax, eax, 0x38
            //   33d2                 | mov                 eax, dword ptr [ecx + eax + 0x20]
            //   b95a000000           | shl                 eax, 0x1e
            //   ff15????????         |                     

        $sequence_7 = { 4883f9fd 7706 ff15???????? 488364243000 488d0dfc7b0000 8364242800 41b803000000 }
            // n = 7, score = 200
            //   4883f9fd             | dec                 eax
            //   7706                 | cmp                 dword ptr [esp + 0x28], 0x20
            //   ff15????????         |                     
            //   488364243000         | dec                 eax
            //   488d0dfc7b0000       | cmp                 ecx, -3
            //   8364242800           | ja                  8
            //   41b803000000         | dec                 eax

        $sequence_8 = { 8bc2 8955e4 c1e802 8bf2 8b55f0 83e603 }
            // n = 6, score = 100
            //   8bc2                 | mov                 eax, edx
            //   8955e4               | mov                 dword ptr [ebp - 0x1c], edx
            //   c1e802               | shr                 eax, 2
            //   8bf2                 | mov                 esi, edx
            //   8b55f0               | mov                 edx, dword ptr [ebp - 0x10]
            //   83e603               | and                 esi, 3

        $sequence_9 = { b803000000 50 68???????? ff763c e8???????? 83c40c 85c0 }
            // n = 7, score = 100
            //   b803000000           | mov                 eax, 3
            //   50                   | push                eax
            //   68????????           |                     
            //   ff763c               | push                dword ptr [esi + 0x3c]
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   85c0                 | test                eax, eax

        $sequence_10 = { 7510 46 83c028 3bf2 }
            // n = 4, score = 100
            //   7510                 | jne                 0x12
            //   46                   | inc                 esi
            //   83c028               | add                 eax, 0x28
            //   3bf2                 | cmp                 esi, edx

        $sequence_11 = { 8a4dfe 84c0 8a45ff 7909 }
            // n = 4, score = 100
            //   8a4dfe               | mov                 cl, byte ptr [ebp - 2]
            //   84c0                 | test                al, al
            //   8a45ff               | mov                 al, byte ptr [ebp - 1]
            //   7909                 | jns                 0xb

        $sequence_12 = { 53 ff15???????? 50 ff15???????? 834f1406 8b15???????? 8b4df4 }
            // n = 7, score = 100
            //   53                   | push                ebx
            //   ff15????????         |                     
            //   50                   | push                eax
            //   ff15????????         |                     
            //   834f1406             | or                  dword ptr [edi + 0x14], 6
            //   8b15????????         |                     
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]

        $sequence_13 = { 6bd730 8b0c8d30430110 c644112800 85f6 740c 56 e8???????? }
            // n = 7, score = 100
            //   6bd730               | imul                edx, edi, 0x30
            //   8b0c8d30430110       | mov                 ecx, dword ptr [ecx*4 + 0x10014330]
            //   c644112800           | mov                 byte ptr [ecx + edx + 0x28], 0
            //   85f6                 | test                esi, esi
            //   740c                 | je                  0xe
            //   56                   | push                esi
            //   e8????????           |                     

        $sequence_14 = { 8945fc ff15???????? 85c0 7460 c603e9 8b4704 2bc3 }
            // n = 7, score = 100
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7460                 | je                  0x62
            //   c603e9               | mov                 byte ptr [ebx], 0xe9
            //   8b4704               | mov                 eax, dword ptr [edi + 4]
            //   2bc3                 | sub                 eax, ebx

        $sequence_15 = { 83feff 0f8432010000 57 6a01 83caff 8d4de8 }
            // n = 6, score = 100
            //   83feff               | cmp                 esi, -1
            //   0f8432010000         | je                  0x138
            //   57                   | push                edi
            //   6a01                 | push                1
            //   83caff               | or                  edx, 0xffffffff
            //   8d4de8               | lea                 ecx, [ebp - 0x18]

    condition:
        7 of them and filesize < 253952
}