rule win_ldr4_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.ldr4."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.ldr4"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ff750c 0fb745f0 ff7508 50 0fb745ee 50 0fb745ec }
            // n = 7, score = 100
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   0fb745f0             | movzx               eax, word ptr [ebp - 0x10]
            //   ff7508               | push                dword ptr [ebp + 8]
            //   50                   | push                eax
            //   0fb745ee             | movzx               eax, word ptr [ebp - 0x12]
            //   50                   | push                eax
            //   0fb745ec             | movzx               eax, word ptr [ebp - 0x14]

        $sequence_1 = { c9 c20c00 56 6a2f ff74240c e8???????? 6a3f }
            // n = 7, score = 100
            //   c9                   | leave               
            //   c20c00               | ret                 0xc
            //   56                   | push                esi
            //   6a2f                 | push                0x2f
            //   ff74240c             | push                dword ptr [esp + 0xc]
            //   e8????????           |                     
            //   6a3f                 | push                0x3f

        $sequence_2 = { 6a00 53 ff15???????? 837df800 0f8528010000 8d45f4 }
            // n = 6, score = 100
            //   6a00                 | push                0
            //   53                   | push                ebx
            //   ff15????????         |                     
            //   837df800             | cmp                 dword ptr [ebp - 8], 0
            //   0f8528010000         | jne                 0x12e
            //   8d45f4               | lea                 eax, [ebp - 0xc]

        $sequence_3 = { 53 56 57 8945f8 33c0 33db 6a3e }
            // n = 7, score = 100
            //   53                   | push                ebx
            //   56                   | push                esi
            //   57                   | push                edi
            //   8945f8               | mov                 dword ptr [ebp - 8], eax
            //   33c0                 | xor                 eax, eax
            //   33db                 | xor                 ebx, ebx
            //   6a3e                 | push                0x3e

        $sequence_4 = { 7506 6683f901 7723 83c720 66893b eb04 8365fc00 }
            // n = 7, score = 100
            //   7506                 | jne                 8
            //   6683f901             | cmp                 cx, 1
            //   7723                 | ja                  0x25
            //   83c720               | add                 edi, 0x20
            //   66893b               | mov                 word ptr [ebx], di
            //   eb04                 | jmp                 6
            //   8365fc00             | and                 dword ptr [ebp - 4], 0

        $sequence_5 = { 8d442410 50 8b442420 358555f261 50 8bc3 e8???????? }
            // n = 7, score = 100
            //   8d442410             | lea                 eax, [esp + 0x10]
            //   50                   | push                eax
            //   8b442420             | mov                 eax, dword ptr [esp + 0x20]
            //   358555f261           | xor                 eax, 0x61f25585
            //   50                   | push                eax
            //   8bc3                 | mov                 eax, ebx
            //   e8????????           |                     

        $sequence_6 = { ff15???????? 8bf0 85f6 742c 33c9 85db 7622 }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   8bf0                 | mov                 esi, eax
            //   85f6                 | test                esi, esi
            //   742c                 | je                  0x2e
            //   33c9                 | xor                 ecx, ecx
            //   85db                 | test                ebx, ebx
            //   7622                 | jbe                 0x24

        $sequence_7 = { 8d8d00feffff 51 e8???????? 85c0 757e }
            // n = 5, score = 100
            //   8d8d00feffff         | lea                 ecx, [ebp - 0x200]
            //   51                   | push                ecx
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   757e                 | jne                 0x80

        $sequence_8 = { 8d42f8 d1e8 3955fc 7c3e 85c0 }
            // n = 5, score = 100
            //   8d42f8               | lea                 eax, [edx - 8]
            //   d1e8                 | shr                 eax, 1
            //   3955fc               | cmp                 dword ptr [ebp - 4], edx
            //   7c3e                 | jl                  0x40
            //   85c0                 | test                eax, eax

        $sequence_9 = { 0f84f1010000 8b3d???????? 50 ffd7 ff750c 8945e8 ffd7 }
            // n = 7, score = 100
            //   0f84f1010000         | je                  0x1f7
            //   8b3d????????         |                     
            //   50                   | push                eax
            //   ffd7                 | call                edi
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   8945e8               | mov                 dword ptr [ebp - 0x18], eax
            //   ffd7                 | call                edi

    condition:
        7 of them and filesize < 117760
}