rule win_lethic_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.lethic."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.lethic"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 837df400 7507 33c0 e9???????? 8b55f4 8b4218 }
            // n = 6, score = 1200
            //   837df400             | cmp                 dword ptr [ebp - 0xc], 0
            //   7507                 | jne                 9
            //   33c0                 | xor                 eax, eax
            //   e9????????           |                     
            //   8b55f4               | mov                 edx, dword ptr [ebp - 0xc]
            //   8b4218               | mov                 eax, dword ptr [edx + 0x18]

        $sequence_1 = { 33c0 e9???????? 8b45fc 8b4d10 894804 }
            // n = 5, score = 1200
            //   33c0                 | xor                 eax, eax
            //   e9????????           |                     
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   8b4d10               | mov                 ecx, dword ptr [ebp + 0x10]
            //   894804               | mov                 dword ptr [eax + 4], ecx

        $sequence_2 = { 50 8b4dfc 83c108 51 8b55f4 }
            // n = 5, score = 1200
            //   50                   | push                eax
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   83c108               | add                 ecx, 8
            //   51                   | push                ecx
            //   8b55f4               | mov                 edx, dword ptr [ebp - 0xc]

        $sequence_3 = { 8b45fc 8b08 894dfc ebec 8b55fc }
            // n = 5, score = 1200
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   894dfc               | mov                 dword ptr [ebp - 4], ecx
            //   ebec                 | jmp                 0xffffffee
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]

        $sequence_4 = { eb42 6a10 8b55fc 83c208 52 }
            // n = 5, score = 1200
            //   eb42                 | jmp                 0x44
            //   6a10                 | push                0x10
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   83c208               | add                 edx, 8
            //   52                   | push                edx

        $sequence_5 = { ebec 8b55fc 8b45f4 8b08 890a 8b55fc }
            // n = 6, score = 1200
            //   ebec                 | jmp                 0xffffffee
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   890a                 | mov                 dword ptr [edx], ecx
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]

        $sequence_6 = { 8945fc c745f801000000 837dfc00 7507 33c0 e9???????? 8b45fc }
            // n = 7, score = 1200
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   c745f801000000       | mov                 dword ptr [ebp - 8], 1
            //   837dfc00             | cmp                 dword ptr [ebp - 4], 0
            //   7507                 | jne                 9
            //   33c0                 | xor                 eax, eax
            //   e9????????           |                     
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]

        $sequence_7 = { 3b55f8 7411 8b45fc c60000 }
            // n = 4, score = 1200
            //   3b55f8               | cmp                 edx, dword ptr [ebp - 8]
            //   7411                 | je                  0x13
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   c60000               | mov                 byte ptr [eax], 0

        $sequence_8 = { 8b08 890a 8b55fc 8b02 8945fc 8b4df4 51 }
            // n = 7, score = 1200
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   890a                 | mov                 dword ptr [edx], ecx
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   8b02                 | mov                 eax, dword ptr [edx]
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]
            //   51                   | push                ecx

        $sequence_9 = { eb42 6a10 8b55fc 83c208 52 8b45fc 8b4818 }
            // n = 7, score = 1200
            //   eb42                 | jmp                 0x44
            //   6a10                 | push                0x10
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   83c208               | add                 edx, 8
            //   52                   | push                edx
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   8b4818               | mov                 ecx, dword ptr [eax + 0x18]

    condition:
        7 of them and filesize < 81920
}