rule win_lockbit_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.lockbit."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.lockbit"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 0f28c8 660f73f904 660fefc8 0f28c1 660f73f804 }
            // n = 5, score = 300
            //   0f28c8               | movaps              xmm1, xmm0
            //   660f73f904           | pslldq              xmm1, 4
            //   660fefc8             | pxor                xmm1, xmm0
            //   0f28c1               | movaps              xmm0, xmm1
            //   660f73f804           | pslldq              xmm0, 4

        $sequence_1 = { 50 e8???????? 8d858cfeffff 50 8d45c0 50 8d45a0 }
            // n = 7, score = 300
            //   50                   | push                eax
            //   e8????????           |                     
            //   8d858cfeffff         | lea                 eax, [ebp - 0x174]
            //   50                   | push                eax
            //   8d45c0               | lea                 eax, [ebp - 0x40]
            //   50                   | push                eax
            //   8d45a0               | lea                 eax, [ebp - 0x60]

        $sequence_2 = { fec1 47 4e 85f6 75d2 5d }
            // n = 6, score = 300
            //   fec1                 | inc                 cl
            //   47                   | inc                 edi
            //   4e                   | dec                 esi
            //   85f6                 | test                esi, esi
            //   75d2                 | jne                 0xffffffd4
            //   5d                   | pop                 ebp

        $sequence_3 = { 56 57 8d9d84fcffff b900c2eb0b e2fe e8???????? 53 }
            // n = 7, score = 300
            //   56                   | push                esi
            //   57                   | push                edi
            //   8d9d84fcffff         | lea                 ebx, [ebp - 0x37c]
            //   b900c2eb0b           | mov                 ecx, 0xbebc200
            //   e2fe                 | loop                0
            //   e8????????           |                     
            //   53                   | push                ebx

        $sequence_4 = { 6683f866 7706 6683e857 eb17 6683f830 720c 6683f839 }
            // n = 7, score = 300
            //   6683f866             | cmp                 ax, 0x66
            //   7706                 | ja                  8
            //   6683e857             | sub                 ax, 0x57
            //   eb17                 | jmp                 0x19
            //   6683f830             | cmp                 ax, 0x30
            //   720c                 | jb                  0xe
            //   6683f839             | cmp                 ax, 0x39

        $sequence_5 = { 33db 55 8b6d10 8bc1 }
            // n = 4, score = 300
            //   33db                 | xor                 ebx, ebx
            //   55                   | push                ebp
            //   8b6d10               | mov                 ebp, dword ptr [ebp + 0x10]
            //   8bc1                 | mov                 eax, ecx

        $sequence_6 = { 8d8550fdffff 50 6a00 ff15???????? }
            // n = 4, score = 300
            //   8d8550fdffff         | lea                 eax, [ebp - 0x2b0]
            //   50                   | push                eax
            //   6a00                 | push                0
            //   ff15????????         |                     

        $sequence_7 = { 33c0 8d7df0 33c9 53 0fa2 }
            // n = 5, score = 300
            //   33c0                 | xor                 eax, eax
            //   8d7df0               | lea                 edi, [ebp - 0x10]
            //   33c9                 | xor                 ecx, ecx
            //   53                   | push                ebx
            //   0fa2                 | cpuid               

        $sequence_8 = { f745f800000002 740c 5f 5e }
            // n = 4, score = 300
            //   f745f800000002       | test                dword ptr [ebp - 8], 0x2000000
            //   740c                 | je                  0xe
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi

        $sequence_9 = { 02d3 8a5c1500 8a541d00 8a541500 fec2 8a441500 }
            // n = 6, score = 300
            //   02d3                 | add                 dl, bl
            //   8a5c1500             | mov                 bl, byte ptr [ebp + edx]
            //   8a541d00             | mov                 dl, byte ptr [ebp + ebx]
            //   8a541500             | mov                 dl, byte ptr [ebp + edx]
            //   fec2                 | inc                 dl
            //   8a441500             | mov                 al, byte ptr [ebp + edx]

        $sequence_10 = { 33d0 8bc1 c1e810 0fb6c0 c1e208 }
            // n = 5, score = 300
            //   33d0                 | xor                 edx, eax
            //   8bc1                 | mov                 eax, ecx
            //   c1e810               | shr                 eax, 0x10
            //   0fb6c0               | movzx               eax, al
            //   c1e208               | shl                 edx, 8

        $sequence_11 = { 53 56 57 33c0 8b5d14 33c9 33d2 }
            // n = 7, score = 300
            //   53                   | push                ebx
            //   56                   | push                esi
            //   57                   | push                edi
            //   33c0                 | xor                 eax, eax
            //   8b5d14               | mov                 ebx, dword ptr [ebp + 0x14]
            //   33c9                 | xor                 ecx, ecx
            //   33d2                 | xor                 edx, edx

        $sequence_12 = { 8d45f8 50 8d45fc 50 ff75fc ff75f4 }
            // n = 6, score = 300
            //   8d45f8               | lea                 eax, [ebp - 8]
            //   50                   | push                eax
            //   8d45fc               | lea                 eax, [ebp - 4]
            //   50                   | push                eax
            //   ff75fc               | push                dword ptr [ebp - 4]
            //   ff75f4               | push                dword ptr [ebp - 0xc]

        $sequence_13 = { e9???????? 6683f841 720c 6683f846 7706 6683e837 }
            // n = 6, score = 300
            //   e9????????           |                     
            //   6683f841             | cmp                 ax, 0x41
            //   720c                 | jb                  0xe
            //   6683f846             | cmp                 ax, 0x46
            //   7706                 | ja                  8
            //   6683e837             | sub                 ax, 0x37

        $sequence_14 = { 6a00 6a00 6800000040 ff75d4 }
            // n = 4, score = 300
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   6800000040           | push                0x40000000
            //   ff75d4               | push                dword ptr [ebp - 0x2c]

        $sequence_15 = { 5b 8907 897704 894f08 89570c f745f800000002 740c }
            // n = 7, score = 300
            //   5b                   | pop                 ebx
            //   8907                 | mov                 dword ptr [edi], eax
            //   897704               | mov                 dword ptr [edi + 4], esi
            //   894f08               | mov                 dword ptr [edi + 8], ecx
            //   89570c               | mov                 dword ptr [edi + 0xc], edx
            //   f745f800000002       | test                dword ptr [ebp - 8], 0x2000000
            //   740c                 | je                  0xe

        $sequence_16 = { 214493fc 8b5df8 8bc3 43 }
            // n = 4, score = 200
            //   214493fc             | and                 dword ptr [ebx + edx*4 - 4], eax
            //   8b5df8               | mov                 ebx, dword ptr [ebp - 8]
            //   8bc3                 | mov                 eax, ebx
            //   43                   | inc                 ebx

        $sequence_17 = { 7407 8bce e8???????? 837b0402 }
            // n = 4, score = 200
            //   7407                 | je                  9
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     
            //   837b0402             | cmp                 dword ptr [ebx + 4], 2

        $sequence_18 = { 7414 663901 740f 0f1f440000 }
            // n = 4, score = 200
            //   7414                 | je                  0x16
            //   663901               | cmp                 word ptr [ecx], ax
            //   740f                 | je                  0x11
            //   0f1f440000           | nop                 dword ptr [eax + eax]

        $sequence_19 = { 1bdb 83e30b 83c328 ff7518 8b7d08 8d049500000000 ff7514 }
            // n = 7, score = 200
            //   1bdb                 | sbb                 ebx, ebx
            //   83e30b               | and                 ebx, 0xb
            //   83c328               | add                 ebx, 0x28
            //   ff7518               | push                dword ptr [ebp + 0x18]
            //   8b7d08               | mov                 edi, dword ptr [ebp + 8]
            //   8d049500000000       | lea                 eax, [edx*4]
            //   ff7514               | push                dword ptr [ebp + 0x14]

    condition:
        7 of them and filesize < 2049024
}