rule win_lockergoga_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.lockergoga."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.lockergoga"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e9???????? 33c0 897dd4 8b560c 33c9 894514 3bc3 }
            // n = 7, score = 400
            //   e9????????           |                     
            //   33c0                 | xor                 eax, eax
            //   897dd4               | mov                 dword ptr [ebp - 0x2c], edi
            //   8b560c               | mov                 edx, dword ptr [esi + 0xc]
            //   33c9                 | xor                 ecx, ecx
            //   894514               | mov                 dword ptr [ebp + 0x14], eax
            //   3bc3                 | cmp                 eax, ebx

        $sequence_1 = { 725e 8b06 8b7e38 8b80e4000000 89459c 3bd7 722c }
            // n = 7, score = 400
            //   725e                 | jb                  0x60
            //   8b06                 | mov                 eax, dword ptr [esi]
            //   8b7e38               | mov                 edi, dword ptr [esi + 0x38]
            //   8b80e4000000         | mov                 eax, dword ptr [eax + 0xe4]
            //   89459c               | mov                 dword ptr [ebp - 0x64], eax
            //   3bd7                 | cmp                 edx, edi
            //   722c                 | jb                  0x2e

        $sequence_2 = { e8???????? 50 ffb5f0feffff 8d85c0feffff c645fc0c 50 8bcf }
            // n = 7, score = 400
            //   e8????????           |                     
            //   50                   | push                eax
            //   ffb5f0feffff         | push                dword ptr [ebp - 0x110]
            //   8d85c0feffff         | lea                 eax, [ebp - 0x140]
            //   c645fc0c             | mov                 byte ptr [ebp - 4], 0xc
            //   50                   | push                eax
            //   8bcf                 | mov                 ecx, edi

        $sequence_3 = { ff10 8d4b10 e8???????? 6a38 53 e8???????? 83c408 }
            // n = 7, score = 400
            //   ff10                 | call                dword ptr [eax]
            //   8d4b10               | lea                 ecx, [ebx + 0x10]
            //   e8????????           |                     
            //   6a38                 | push                0x38
            //   53                   | push                ebx
            //   e8????????           |                     
            //   83c408               | add                 esp, 8

        $sequence_4 = { e8???????? 8d45d8 c645fc04 50 8bcb e8???????? 8b1b }
            // n = 7, score = 400
            //   e8????????           |                     
            //   8d45d8               | lea                 eax, [ebp - 0x28]
            //   c645fc04             | mov                 byte ptr [ebp - 4], 4
            //   50                   | push                eax
            //   8bcb                 | mov                 ecx, ebx
            //   e8????????           |                     
            //   8b1b                 | mov                 ebx, dword ptr [ebx]

        $sequence_5 = { e8???????? 8d45c0 c645fc01 50 8bce e8???????? 8bf0 }
            // n = 7, score = 400
            //   e8????????           |                     
            //   8d45c0               | lea                 eax, [ebp - 0x40]
            //   c645fc01             | mov                 byte ptr [ebp - 4], 1
            //   50                   | push                eax
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax

        $sequence_6 = { 8b4df0 33cd e8???????? 8be5 5d c3 ff7594 }
            // n = 7, score = 400
            //   8b4df0               | mov                 ecx, dword ptr [ebp - 0x10]
            //   33cd                 | xor                 ecx, ebp
            //   e8????????           |                     
            //   8be5                 | mov                 esp, ebp
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   ff7594               | push                dword ptr [ebp - 0x6c]

        $sequence_7 = { 8b5904 8b7d0c 8975e8 8975ec 8945f0 c745fc00000000 85ff }
            // n = 7, score = 400
            //   8b5904               | mov                 ebx, dword ptr [ecx + 4]
            //   8b7d0c               | mov                 edi, dword ptr [ebp + 0xc]
            //   8975e8               | mov                 dword ptr [ebp - 0x18], esi
            //   8975ec               | mov                 dword ptr [ebp - 0x14], esi
            //   8945f0               | mov                 dword ptr [ebp - 0x10], eax
            //   c745fc00000000       | mov                 dword ptr [ebp - 4], 0
            //   85ff                 | test                edi, edi

        $sequence_8 = { f30f7e4710 660fd64610 c7471000000000 c747140f000000 c60700 83c718 c745fcffffffff }
            // n = 7, score = 400
            //   f30f7e4710           | movq                xmm0, qword ptr [edi + 0x10]
            //   660fd64610           | movq                qword ptr [esi + 0x10], xmm0
            //   c7471000000000       | mov                 dword ptr [edi + 0x10], 0
            //   c747140f000000       | mov                 dword ptr [edi + 0x14], 0xf
            //   c60700               | mov                 byte ptr [edi], 0
            //   83c718               | add                 edi, 0x18
            //   c745fcffffffff       | mov                 dword ptr [ebp - 4], 0xffffffff

        $sequence_9 = { e8???????? 8bc8 3bcf 7413 837f1410 8bc7 7202 }
            // n = 7, score = 400
            //   e8????????           |                     
            //   8bc8                 | mov                 ecx, eax
            //   3bcf                 | cmp                 ecx, edi
            //   7413                 | je                  0x15
            //   837f1410             | cmp                 dword ptr [edi + 0x14], 0x10
            //   8bc7                 | mov                 eax, edi
            //   7202                 | jb                  4

    condition:
        7 of them and filesize < 2588672
}