rule win_locky_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.locky."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.locky"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 89b560ffffff 898568ffffff ffd7 8bf8 897de0 3bfb }
            // n = 6, score = 2100
            //   89b560ffffff         | mov                 dword ptr [ebp - 0xa0], esi
            //   898568ffffff         | mov                 dword ptr [ebp - 0x98], eax
            //   ffd7                 | call                edi
            //   8bf8                 | mov                 edi, eax
            //   897de0               | mov                 dword ptr [ebp - 0x20], edi
            //   3bfb                 | cmp                 edi, ebx

        $sequence_1 = { 8b4db8 3975cc 7303 8d4db8 8b45d4 3975e8 }
            // n = 6, score = 2100
            //   8b4db8               | mov                 ecx, dword ptr [ebp - 0x48]
            //   3975cc               | cmp                 dword ptr [ebp - 0x34], esi
            //   7303                 | jae                 5
            //   8d4db8               | lea                 ecx, [ebp - 0x48]
            //   8b45d4               | mov                 eax, dword ptr [ebp - 0x2c]
            //   3975e8               | cmp                 dword ptr [ebp - 0x18], esi

        $sequence_2 = { 50 50 50 894de8 8b4d08 }
            // n = 5, score = 2100
            //   50                   | push                eax
            //   50                   | push                eax
            //   50                   | push                eax
            //   894de8               | mov                 dword ptr [ebp - 0x18], ecx
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]

        $sequence_3 = { 8d459c 50 8d45b8 50 e8???????? 59 59 }
            // n = 7, score = 2100
            //   8d459c               | lea                 eax, [ebp - 0x64]
            //   50                   | push                eax
            //   8d45b8               | lea                 eax, [ebp - 0x48]
            //   50                   | push                eax
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx

        $sequence_4 = { 46 3bf0 7621 8bc8 d1e9 ba49922409 }
            // n = 6, score = 2100
            //   46                   | inc                 esi
            //   3bf0                 | cmp                 esi, eax
            //   7621                 | jbe                 0x23
            //   8bc8                 | mov                 ecx, eax
            //   d1e9                 | shr                 ecx, 1
            //   ba49922409           | mov                 edx, 0x9249249

        $sequence_5 = { 8bc6 03c1 3810 7412 83ff10 7204 }
            // n = 6, score = 2100
            //   8bc6                 | mov                 eax, esi
            //   03c1                 | add                 eax, ecx
            //   3810                 | cmp                 byte ptr [eax], dl
            //   7412                 | je                  0x14
            //   83ff10               | cmp                 edi, 0x10
            //   7204                 | jb                  6

        $sequence_6 = { 837e1410 8b4610 7202 8b36 50 56 8d45f0 }
            // n = 7, score = 2100
            //   837e1410             | cmp                 dword ptr [esi + 0x14], 0x10
            //   8b4610               | mov                 eax, dword ptr [esi + 0x10]
            //   7202                 | jb                  4
            //   8b36                 | mov                 esi, dword ptr [esi]
            //   50                   | push                eax
            //   56                   | push                esi
            //   8d45f0               | lea                 eax, [ebp - 0x10]

        $sequence_7 = { 83c9ff 8bf0 51 e8???????? 40 50 }
            // n = 6, score = 2100
            //   83c9ff               | or                  ecx, 0xffffffff
            //   8bf0                 | mov                 esi, eax
            //   51                   | push                ecx
            //   e8????????           |                     
            //   40                   | inc                 eax
            //   50                   | push                eax

        $sequence_8 = { 03d3 5b c21000 e9???????? 8bff 55 8bec }
            // n = 7, score = 1400
            //   03d3                 | add                 edx, ebx
            //   5b                   | pop                 ebx
            //   c21000               | ret                 0x10
            //   e9????????           |                     
            //   8bff                 | mov                 edi, edi
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp

        $sequence_9 = { 6a44 90 e9???????? 90 }
            // n = 4, score = 700
            //   6a44                 | push                0x44
            //   90                   | nop                 
            //   e9????????           |                     
            //   90                   | nop                 

        $sequence_10 = { 5d 90 ebf6 90 }
            // n = 4, score = 700
            //   5d                   | pop                 ebp
            //   90                   | nop                 
            //   ebf6                 | jmp                 0xfffffff8
            //   90                   | nop                 

        $sequence_11 = { 83c40c e9???????? 90 8d00 }
            // n = 4, score = 700
            //   83c40c               | add                 esp, 0xc
            //   e9????????           |                     
            //   90                   | nop                 
            //   8d00                 | lea                 eax, [eax]

        $sequence_12 = { 66ab e9???????? 90 8d36 }
            // n = 4, score = 700
            //   66ab                 | stosw               word ptr es:[edi], ax
            //   e9????????           |                     
            //   90                   | nop                 
            //   8d36                 | lea                 esi, [esi]

        $sequence_13 = { ff15???????? e9???????? 90 50 90 }
            // n = 5, score = 700
            //   ff15????????         |                     
            //   e9????????           |                     
            //   90                   | nop                 
            //   50                   | push                eax
            //   90                   | nop                 

        $sequence_14 = { 66ab 90 e9???????? 8d36 }
            // n = 4, score = 700
            //   66ab                 | stosw               word ptr es:[edi], ax
            //   90                   | nop                 
            //   e9????????           |                     
            //   8d36                 | lea                 esi, [esi]

        $sequence_15 = { 5e c21000 8bff 55 8bec 33c0 8b4d08 }
            // n = 7, score = 700
            //   5e                   | pop                 esi
            //   c21000               | ret                 0x10
            //   8bff                 | mov                 edi, edi
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   33c0                 | xor                 eax, eax
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]

    condition:
        7 of them and filesize < 1122304
}