rule win_locky_decryptor_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.locky_decryptor."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.locky_decryptor"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d7c2420 c684249000000001 e8???????? 6a01 33ff }
            // n = 5, score = 100
            //   8d7c2420             | lea                 edi, [esp + 0x20]
            //   c684249000000001     | mov                 byte ptr [esp + 0x90], 1
            //   e8????????           |                     
            //   6a01                 | push                1
            //   33ff                 | xor                 edi, edi

        $sequence_1 = { 56 6a5c 8bf0 e8???????? }
            // n = 4, score = 100
            //   56                   | push                esi
            //   6a5c                 | push                0x5c
            //   8bf0                 | mov                 esi, eax
            //   e8????????           |                     

        $sequence_2 = { 58 33db 33c9 8945e0 }
            // n = 4, score = 100
            //   58                   | pop                 eax
            //   33db                 | xor                 ebx, ebx
            //   33c9                 | xor                 ecx, ecx
            //   8945e0               | mov                 dword ptr [ebp - 0x20], eax

        $sequence_3 = { 8d45e0 50 33ff 6880000000 897dc0 ff15???????? 50 }
            // n = 7, score = 100
            //   8d45e0               | lea                 eax, [ebp - 0x20]
            //   50                   | push                eax
            //   33ff                 | xor                 edi, edi
            //   6880000000           | push                0x80
            //   897dc0               | mov                 dword ptr [ebp - 0x40], edi
            //   ff15????????         |                     
            //   50                   | push                eax

        $sequence_4 = { 66890e 56 8d8ddcfbffff e8???????? 8bc6 }
            // n = 5, score = 100
            //   66890e               | mov                 word ptr [esi], cx
            //   56                   | push                esi
            //   8d8ddcfbffff         | lea                 ecx, [ebp - 0x424]
            //   e8????????           |                     
            //   8bc6                 | mov                 eax, esi

        $sequence_5 = { 50 e8???????? 8364247800 56 50 8d442420 }
            // n = 6, score = 100
            //   50                   | push                eax
            //   e8????????           |                     
            //   8364247800           | and                 dword ptr [esp + 0x78], 0
            //   56                   | push                esi
            //   50                   | push                eax
            //   8d442420             | lea                 eax, [esp + 0x20]

        $sequence_6 = { 68???????? 8d8504ffffff e9???????? 015ddc 6a00 5b }
            // n = 6, score = 100
            //   68????????           |                     
            //   8d8504ffffff         | lea                 eax, [ebp - 0xfc]
            //   e9????????           |                     
            //   015ddc               | add                 dword ptr [ebp - 0x24], ebx
            //   6a00                 | push                0
            //   5b                   | pop                 ebx

        $sequence_7 = { 56 e8???????? 8b4df4 83c40c 5f 5e 8bc3 }
            // n = 7, score = 100
            //   56                   | push                esi
            //   e8????????           |                     
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]
            //   83c40c               | add                 esp, 0xc
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   8bc3                 | mov                 eax, ebx

        $sequence_8 = { 894c2410 3bda 7e6c 33d2 c7442418f0ffffff }
            // n = 5, score = 100
            //   894c2410             | mov                 dword ptr [esp + 0x10], ecx
            //   3bda                 | cmp                 ebx, edx
            //   7e6c                 | jle                 0x6e
            //   33d2                 | xor                 edx, edx
            //   c7442418f0ffffff     | mov                 dword ptr [esp + 0x18], 0xfffffff0

        $sequence_9 = { ff15???????? c745fc0a000000 395de4 740f }
            // n = 4, score = 100
            //   ff15????????         |                     
            //   c745fc0a000000       | mov                 dword ptr [ebp - 4], 0xa
            //   395de4               | cmp                 dword ptr [ebp - 0x1c], ebx
            //   740f                 | je                  0x11

    condition:
        7 of them and filesize < 278528
}