rule win_logtu_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.logtu."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.logtu"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8bf0 8d85a4fdffff 68???????? 50 ff15???????? }
            // n = 5, score = 300
            //   8bf0                 | mov                 esi, eax
            //   8d85a4fdffff         | lea                 eax, [ebp - 0x25c]
            //   68????????           |                     
            //   50                   | push                eax
            //   ff15????????         |                     

        $sequence_1 = { ff15???????? 8d8534ffffff 50 ff15???????? 6a01 }
            // n = 5, score = 300
            //   ff15????????         |                     
            //   8d8534ffffff         | lea                 eax, [ebp - 0xcc]
            //   50                   | push                eax
            //   ff15????????         |                     
            //   6a01                 | push                1

        $sequence_2 = { 50 6a64 6a00 ff15???????? 85c0 7509 8b45bc }
            // n = 7, score = 300
            //   50                   | push                eax
            //   6a64                 | push                0x64
            //   6a00                 | push                0
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7509                 | jne                 0xb
            //   8b45bc               | mov                 eax, dword ptr [ebp - 0x44]

        $sequence_3 = { 8bec 81ec98050000 a1???????? 33c5 8945fc 53 }
            // n = 6, score = 300
            //   8bec                 | mov                 ebp, esp
            //   81ec98050000         | sub                 esp, 0x598
            //   a1????????           |                     
            //   33c5                 | xor                 eax, ebp
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   53                   | push                ebx

        $sequence_4 = { 55 8bec 81ec98050000 a1???????? 33c5 8945fc 53 }
            // n = 7, score = 300
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   81ec98050000         | sub                 esp, 0x598
            //   a1????????           |                     
            //   33c5                 | xor                 eax, ebp
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   53                   | push                ebx

        $sequence_5 = { 8d8574faffff 50 8d8534ffffff 50 }
            // n = 4, score = 300
            //   8d8574faffff         | lea                 eax, [ebp - 0x58c]
            //   50                   | push                eax
            //   8d8534ffffff         | lea                 eax, [ebp - 0xcc]
            //   50                   | push                eax

        $sequence_6 = { 50 8d85fcf7ffff 68???????? 50 e8???????? 8d85fcf7ffff 6800040000 }
            // n = 7, score = 300
            //   50                   | push                eax
            //   8d85fcf7ffff         | lea                 eax, [ebp - 0x804]
            //   68????????           |                     
            //   50                   | push                eax
            //   e8????????           |                     
            //   8d85fcf7ffff         | lea                 eax, [ebp - 0x804]
            //   6800040000           | push                0x400

        $sequence_7 = { 6a01 8bf0 8d85a4fdffff 68???????? }
            // n = 4, score = 300
            //   6a01                 | push                1
            //   8bf0                 | mov                 esi, eax
            //   8d85a4fdffff         | lea                 eax, [ebp - 0x25c]
            //   68????????           |                     

        $sequence_8 = { 8d8584faffff 50 8d8574faffff 50 8d8534ffffff }
            // n = 5, score = 300
            //   8d8584faffff         | lea                 eax, [ebp - 0x57c]
            //   50                   | push                eax
            //   8d8574faffff         | lea                 eax, [ebp - 0x58c]
            //   50                   | push                eax
            //   8d8534ffffff         | lea                 eax, [ebp - 0xcc]

        $sequence_9 = { 8d8578faffff 50 8d8584faffff 50 }
            // n = 4, score = 300
            //   8d8578faffff         | lea                 eax, [ebp - 0x588]
            //   50                   | push                eax
            //   8d8584faffff         | lea                 eax, [ebp - 0x57c]
            //   50                   | push                eax

    condition:
        7 of them and filesize < 924672
}