rule win_lokipws_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.lokipws."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.lokipws"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 55 8bec 83ec1c 6a2a 58 6a4d 668945e4 }
            // n = 7, score = 300
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   83ec1c               | sub                 esp, 0x1c
            //   6a2a                 | push                0x2a
            //   58                   | pop                 eax
            //   6a4d                 | push                0x4d
            //   668945e4             | mov                 word ptr [ebp - 0x1c], ax

        $sequence_1 = { 53 57 a3???????? e8???????? 68???????? 56 }
            // n = 6, score = 300
            //   53                   | push                ebx
            //   57                   | push                edi
            //   a3????????           |                     
            //   e8????????           |                     
            //   68????????           |                     
            //   56                   | push                esi

        $sequence_2 = { 50 688b778dfe 50 e8???????? 8d4df8 }
            // n = 5, score = 300
            //   50                   | push                eax
            //   688b778dfe           | push                0xfe8d778b
            //   50                   | push                eax
            //   e8????????           |                     
            //   8d4df8               | lea                 ecx, [ebp - 8]

        $sequence_3 = { 6a00 ff75fc ff35???????? e8???????? 6a00 6a00 }
            // n = 6, score = 300
            //   6a00                 | push                0
            //   ff75fc               | push                dword ptr [ebp - 4]
            //   ff35????????         |                     
            //   e8????????           |                     
            //   6a00                 | push                0
            //   6a00                 | push                0

        $sequence_4 = { 56 ff750c e8???????? 83c40c 85c0 7420 90 }
            // n = 7, score = 300
            //   56                   | push                esi
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   85c0                 | test                eax, eax
            //   7420                 | je                  0x22
            //   90                   | nop                 

        $sequence_5 = { 50 ff7508 8975fc e8???????? 8bf8 59 59 }
            // n = 7, score = 300
            //   50                   | push                eax
            //   ff7508               | push                dword ptr [ebp + 8]
            //   8975fc               | mov                 dword ptr [ebp - 4], esi
            //   e8????????           |                     
            //   8bf8                 | mov                 edi, eax
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx

        $sequence_6 = { 58 66895dc4 668975ca 66897dcc 66895dce 668955d0 66895dd2 }
            // n = 7, score = 300
            //   58                   | pop                 eax
            //   66895dc4             | mov                 word ptr [ebp - 0x3c], bx
            //   668975ca             | mov                 word ptr [ebp - 0x36], si
            //   66897dcc             | mov                 word ptr [ebp - 0x34], di
            //   66895dce             | mov                 word ptr [ebp - 0x32], bx
            //   668955d0             | mov                 word ptr [ebp - 0x30], dx
            //   66895dd2             | mov                 word ptr [ebp - 0x2e], bx

        $sequence_7 = { 6a02 e8???????? ff750c ff7508 ffd0 5d c3 }
            // n = 7, score = 300
            //   6a02                 | push                2
            //   e8????????           |                     
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   ff7508               | push                dword ptr [ebp + 8]
            //   ffd0                 | call                eax
            //   5d                   | pop                 ebp
            //   c3                   | ret                 

        $sequence_8 = { 668945f2 58 6a6e 668945f6 58 668945fa 33c0 }
            // n = 7, score = 300
            //   668945f2             | mov                 word ptr [ebp - 0xe], ax
            //   58                   | pop                 eax
            //   6a6e                 | push                0x6e
            //   668945f6             | mov                 word ptr [ebp - 0xa], ax
            //   58                   | pop                 eax
            //   668945fa             | mov                 word ptr [ebp - 6], ax
            //   33c0                 | xor                 eax, eax

        $sequence_9 = { 83fe05 6a02 58 0f47f0 33db 43 3bf3 }
            // n = 7, score = 300
            //   83fe05               | cmp                 esi, 5
            //   6a02                 | push                2
            //   58                   | pop                 eax
            //   0f47f0               | cmova               esi, eax
            //   33db                 | xor                 ebx, ebx
            //   43                   | inc                 ebx
            //   3bf3                 | cmp                 esi, ebx

    condition:
        7 of them and filesize < 1327104
}