rule win_lunchmoney_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.lunchmoney."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.lunchmoney"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b4304 8d4b0c 83791408 8945dc 8b4308 8945e0 7202 }
            // n = 7, score = 100
            //   8b4304               | mov                 eax, dword ptr [ebx + 4]
            //   8d4b0c               | lea                 ecx, [ebx + 0xc]
            //   83791408             | cmp                 dword ptr [ecx + 0x14], 8
            //   8945dc               | mov                 dword ptr [ebp - 0x24], eax
            //   8b4308               | mov                 eax, dword ptr [ebx + 8]
            //   8945e0               | mov                 dword ptr [ebp - 0x20], eax
            //   7202                 | jb                  4

        $sequence_1 = { 7405 e8???????? a900000080 751f d9fa 833d????????00 0f85f38b0000 }
            // n = 7, score = 100
            //   7405                 | je                  7
            //   e8????????           |                     
            //   a900000080           | test                eax, 0x80000000
            //   751f                 | jne                 0x21
            //   d9fa                 | fsqrt               
            //   833d????????00       |                     
            //   0f85f38b0000         | jne                 0x8bf9

        $sequence_2 = { c1e60a 56 e8???????? 56 8bf8 6a00 57 }
            // n = 7, score = 100
            //   c1e60a               | shl                 esi, 0xa
            //   56                   | push                esi
            //   e8????????           |                     
            //   56                   | push                esi
            //   8bf8                 | mov                 edi, eax
            //   6a00                 | push                0
            //   57                   | push                edi

        $sequence_3 = { 53 8d4d08 e8???????? 83f8ff 750e 68???????? }
            // n = 6, score = 100
            //   53                   | push                ebx
            //   8d4d08               | lea                 ecx, [ebp + 8]
            //   e8????????           |                     
            //   83f8ff               | cmp                 eax, -1
            //   750e                 | jne                 0x10
            //   68????????           |                     

        $sequence_4 = { 8d4dd4 e8???????? 83f8ff 742d 6aff 40 }
            // n = 6, score = 100
            //   8d4dd4               | lea                 ecx, [ebp - 0x2c]
            //   e8????????           |                     
            //   83f8ff               | cmp                 eax, -1
            //   742d                 | je                  0x2f
            //   6aff                 | push                -1
            //   40                   | inc                 eax

        $sequence_5 = { 7420 53 8d85dcfeffff 50 }
            // n = 4, score = 100
            //   7420                 | je                  0x22
            //   53                   | push                ebx
            //   8d85dcfeffff         | lea                 eax, [ebp - 0x124]
            //   50                   | push                eax

        $sequence_6 = { ff7580 e8???????? 8b8568ffffff 014588 59 83957cffffff00 837d0800 }
            // n = 7, score = 100
            //   ff7580               | push                dword ptr [ebp - 0x80]
            //   e8????????           |                     
            //   8b8568ffffff         | mov                 eax, dword ptr [ebp - 0x98]
            //   014588               | add                 dword ptr [ebp - 0x78], eax
            //   59                   | pop                 ecx
            //   83957cffffff00       | adc                 dword ptr [ebp - 0x84], 0
            //   837d0800             | cmp                 dword ptr [ebp + 8], 0

        $sequence_7 = { 8bcf e8???????? 837f1408 8bc8 }
            // n = 4, score = 100
            //   8bcf                 | mov                 ecx, edi
            //   e8????????           |                     
            //   837f1408             | cmp                 dword ptr [edi + 0x14], 8
            //   8bc8                 | mov                 ecx, eax

        $sequence_8 = { 8bc3 e8???????? c3 53 56 8bf1 57 }
            // n = 7, score = 100
            //   8bc3                 | mov                 eax, ebx
            //   e8????????           |                     
            //   c3                   | ret                 
            //   53                   | push                ebx
            //   56                   | push                esi
            //   8bf1                 | mov                 esi, ecx
            //   57                   | push                edi

        $sequence_9 = { 8d86f8000000 83c124 3bc8 740a 6aff 6a00 50 }
            // n = 7, score = 100
            //   8d86f8000000         | lea                 eax, [esi + 0xf8]
            //   83c124               | add                 ecx, 0x24
            //   3bc8                 | cmp                 ecx, eax
            //   740a                 | je                  0xc
            //   6aff                 | push                -1
            //   6a00                 | push                0
            //   50                   | push                eax

    condition:
        7 of them and filesize < 373760
}