rule win_lurk_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.lurk."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.lurk"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ff7508 ff15???????? 8b35???????? 50 ff7508 }
            // n = 5, score = 1100
            //   ff7508               | push                dword ptr [ebp + 8]
            //   ff15????????         |                     
            //   8b35????????         |                     
            //   50                   | push                eax
            //   ff7508               | push                dword ptr [ebp + 8]

        $sequence_1 = { 8b4508 5b 5f 5e c9 c3 55 }
            // n = 7, score = 900
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   5b                   | pop                 ebx
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   c9                   | leave               
            //   c3                   | ret                 
            //   55                   | push                ebp

        $sequence_2 = { 8b4d08 8b5110 83c201 8b4508 895010 8b4dac 51 }
            // n = 7, score = 800
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   8b5110               | mov                 edx, dword ptr [ecx + 0x10]
            //   83c201               | add                 edx, 1
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   895010               | mov                 dword ptr [eax + 0x10], edx
            //   8b4dac               | mov                 ecx, dword ptr [ebp - 0x54]
            //   51                   | push                ecx

        $sequence_3 = { f3a5 66a5 33db 395d08 }
            // n = 4, score = 800
            //   f3a5                 | rep movsd           dword ptr es:[edi], dword ptr [esi]
            //   66a5                 | movsw               word ptr es:[edi], word ptr [esi]
            //   33db                 | xor                 ebx, ebx
            //   395d08               | cmp                 dword ptr [ebp + 8], ebx

        $sequence_4 = { 72cc 33c9 8bc1 99 6a0b 5f f7ff }
            // n = 7, score = 800
            //   72cc                 | jb                  0xffffffce
            //   33c9                 | xor                 ecx, ecx
            //   8bc1                 | mov                 eax, ecx
            //   99                   | cdq                 
            //   6a0b                 | push                0xb
            //   5f                   | pop                 edi
            //   f7ff                 | idiv                edi

        $sequence_5 = { c1ee03 33ce eb0e c1e60b 33ce 8bf0 c1ee05 }
            // n = 7, score = 800
            //   c1ee03               | shr                 esi, 3
            //   33ce                 | xor                 ecx, esi
            //   eb0e                 | jmp                 0x10
            //   c1e60b               | shl                 esi, 0xb
            //   33ce                 | xor                 ecx, esi
            //   8bf0                 | mov                 esi, eax
            //   c1ee05               | shr                 esi, 5

        $sequence_6 = { 59 3bc7 7534 0fbe4203 }
            // n = 4, score = 800
            //   59                   | pop                 ecx
            //   3bc7                 | cmp                 eax, edi
            //   7534                 | jne                 0x36
            //   0fbe4203             | movsx               eax, byte ptr [edx + 3]

        $sequence_7 = { 8b3d???????? 33f6 bb24080000 53 6a40 8975ec }
            // n = 6, score = 800
            //   8b3d????????         |                     
            //   33f6                 | xor                 esi, esi
            //   bb24080000           | mov                 ebx, 0x824
            //   53                   | push                ebx
            //   6a40                 | push                0x40
            //   8975ec               | mov                 dword ptr [ebp - 0x14], esi

        $sequence_8 = { ff750c 83ceff ff7508 ff7510 e8???????? 83c418 85c0 }
            // n = 7, score = 800
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   83ceff               | or                  esi, 0xffffffff
            //   ff7508               | push                dword ptr [ebp + 8]
            //   ff7510               | push                dword ptr [ebp + 0x10]
            //   e8????????           |                     
            //   83c418               | add                 esp, 0x18
            //   85c0                 | test                eax, eax

        $sequence_9 = { ff750c 57 ff15???????? 85c0 7411 395dfc 750c }
            // n = 7, score = 800
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   57                   | push                edi
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7411                 | je                  0x13
            //   395dfc               | cmp                 dword ptr [ebp - 4], ebx
            //   750c                 | jne                 0xe

        $sequence_10 = { 68???????? 8d85ecfeffff 50 ff15???????? 8d85ecfeffff 50 }
            // n = 6, score = 800
            //   68????????           |                     
            //   8d85ecfeffff         | lea                 eax, [ebp - 0x114]
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8d85ecfeffff         | lea                 eax, [ebp - 0x114]
            //   50                   | push                eax

        $sequence_11 = { ebf8 56 8bf0 33c0 85d2 8bca 740c }
            // n = 7, score = 800
            //   ebf8                 | jmp                 0xfffffffa
            //   56                   | push                esi
            //   8bf0                 | mov                 esi, eax
            //   33c0                 | xor                 eax, eax
            //   85d2                 | test                edx, edx
            //   8bca                 | mov                 ecx, edx
            //   740c                 | je                  0xe

        $sequence_12 = { 8945fc 8b4d10 8b91a4000000 8955f8 837df800 7661 }
            // n = 6, score = 800
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   8b4d10               | mov                 ecx, dword ptr [ebp + 0x10]
            //   8b91a4000000         | mov                 edx, dword ptr [ecx + 0xa4]
            //   8955f8               | mov                 dword ptr [ebp - 8], edx
            //   837df800             | cmp                 dword ptr [ebp - 8], 0
            //   7661                 | jbe                 0x63

        $sequence_13 = { c9 c3 55 8bec 81ec08010000 6a35 6a40 }
            // n = 7, score = 800
            //   c9                   | leave               
            //   c3                   | ret                 
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   81ec08010000         | sub                 esp, 0x108
            //   6a35                 | push                0x35
            //   6a40                 | push                0x40

        $sequence_14 = { 744d 56 8d4508 50 }
            // n = 4, score = 800
            //   744d                 | je                  0x4f
            //   56                   | push                esi
            //   8d4508               | lea                 eax, [ebp + 8]
            //   50                   | push                eax

        $sequence_15 = { 83f866 7567 3bf0 7563 0fbe4205 50 e8???????? }
            // n = 7, score = 800
            //   83f866               | cmp                 eax, 0x66
            //   7567                 | jne                 0x69
            //   3bf0                 | cmp                 esi, eax
            //   7563                 | jne                 0x65
            //   0fbe4205             | movsx               eax, byte ptr [edx + 5]
            //   50                   | push                eax
            //   e8????????           |                     

    condition:
        7 of them and filesize < 5316608
}