rule win_magala_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.magala."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.magala"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b4004 838c054cffffff04 8b8538ffffff 8b4004 c6840578ffffff30 2b17 744e }
            // n = 7, score = 200
            //   8b4004               | mov                 eax, dword ptr [eax + 4]
            //   838c054cffffff04     | or                  dword ptr [ebp + eax - 0xb4], 4
            //   8b8538ffffff         | mov                 eax, dword ptr [ebp - 0xc8]
            //   8b4004               | mov                 eax, dword ptr [eax + 4]
            //   c6840578ffffff30     | mov                 byte ptr [ebp + eax - 0x88], 0x30
            //   2b17                 | sub                 edx, dword ptr [edi]
            //   744e                 | je                  0x50

        $sequence_1 = { 8b7dd0 3bdf 0f849d000000 33c0 c745e800000000 6aff 50 }
            // n = 7, score = 200
            //   8b7dd0               | mov                 edi, dword ptr [ebp - 0x30]
            //   3bdf                 | cmp                 ebx, edi
            //   0f849d000000         | je                  0xa3
            //   33c0                 | xor                 eax, eax
            //   c745e800000000       | mov                 dword ptr [ebp - 0x18], 0
            //   6aff                 | push                -1
            //   50                   | push                eax

        $sequence_2 = { 8bcf e8???????? 56 8bd0 c645fc0c 8d4da8 e8???????? }
            // n = 7, score = 200
            //   8bcf                 | mov                 ecx, edi
            //   e8????????           |                     
            //   56                   | push                esi
            //   8bd0                 | mov                 edx, eax
            //   c645fc0c             | mov                 byte ptr [ebp - 4], 0xc
            //   8d4da8               | lea                 ecx, [ebp - 0x58]
            //   e8????????           |                     

        $sequence_3 = { 8a55d8 c645fc00 83f810 7242 }
            // n = 4, score = 200
            //   8a55d8               | mov                 dl, byte ptr [ebp - 0x28]
            //   c645fc00             | mov                 byte ptr [ebp - 4], 0
            //   83f810               | cmp                 eax, 0x10
            //   7242                 | jb                  0x44

        $sequence_4 = { e8???????? 8b4df8 83c40c 837e1410 894e10 7211 }
            // n = 6, score = 200
            //   e8????????           |                     
            //   8b4df8               | mov                 ecx, dword ptr [ebp - 8]
            //   83c40c               | add                 esp, 0xc
            //   837e1410             | cmp                 dword ptr [esi + 0x14], 0x10
            //   894e10               | mov                 dword ptr [esi + 0x10], ecx
            //   7211                 | jb                  0x13

        $sequence_5 = { 6685c0 75f4 a1???????? 8b550c }
            // n = 4, score = 200
            //   6685c0               | test                ax, ax
            //   75f4                 | jne                 0xfffffff6
            //   a1????????           |                     
            //   8b550c               | mov                 edx, dword ptr [ebp + 0xc]

        $sequence_6 = { 6a01 50 8b08 ff513c 85c0 75b8 50 }
            // n = 7, score = 200
            //   6a01                 | push                1
            //   50                   | push                eax
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   ff513c               | call                dword ptr [ecx + 0x3c]
            //   85c0                 | test                eax, eax
            //   75b8                 | jne                 0xffffffba
            //   50                   | push                eax

        $sequence_7 = { 8995e0fdffff 8955fc 8b1d???????? 0f1f8000000000 }
            // n = 4, score = 200
            //   8995e0fdffff         | mov                 dword ptr [ebp - 0x220], edx
            //   8955fc               | mov                 dword ptr [ebp - 4], edx
            //   8b1d????????         |                     
            //   0f1f8000000000       | nop                 dword ptr [eax]

        $sequence_8 = { c745e800000000 c745ec0f000000 c645d800 e8???????? c745fc00000000 8d4e04 }
            // n = 6, score = 200
            //   c745e800000000       | mov                 dword ptr [ebp - 0x18], 0
            //   c745ec0f000000       | mov                 dword ptr [ebp - 0x14], 0xf
            //   c645d800             | mov                 byte ptr [ebp - 0x28], 0
            //   e8????????           |                     
            //   c745fc00000000       | mov                 dword ptr [ebp - 4], 0
            //   8d4e04               | lea                 ecx, [esi + 4]

        $sequence_9 = { e8???????? 8b4df8 b853d9de75 8b75f4 33db 2bce f7e9 }
            // n = 7, score = 200
            //   e8????????           |                     
            //   8b4df8               | mov                 ecx, dword ptr [ebp - 8]
            //   b853d9de75           | mov                 eax, 0x75ded953
            //   8b75f4               | mov                 esi, dword ptr [ebp - 0xc]
            //   33db                 | xor                 ebx, ebx
            //   2bce                 | sub                 ecx, esi
            //   f7e9                 | imul                ecx

    condition:
        7 of them and filesize < 589824
}