rule win_makloader_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.makloader."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.makloader"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8a11 88955ce6ffff 838530e6ffff01 80bd5ce6ffff00 }
            // n = 4, score = 200
            //   8a11                 | mov                 dl, byte ptr [ecx]
            //   88955ce6ffff         | mov                 byte ptr [ebp - 0x19a4], dl
            //   838530e6ffff01       | add                 dword ptr [ebp - 0x19d0], 1
            //   80bd5ce6ffff00       | cmp                 byte ptr [ebp - 0x19a4], 0

        $sequence_1 = { 8d45f0 64a300000000 f2c3 8b4de4 33cd f2e8a8e9feff }
            // n = 6, score = 200
            //   8d45f0               | lea                 eax, [ebp - 0x10]
            //   64a300000000         | mov                 dword ptr fs:[0], eax
            //   f2c3                 | bnd ret             
            //   8b4de4               | mov                 ecx, dword ptr [ebp - 0x1c]
            //   33cd                 | xor                 ecx, ebp
            //   f2e8a8e9feff         | bnd call            0xfffee9ae

        $sequence_2 = { 8d8de4fcffff 898d30e5ffff 8d95d8e5ffff 899534e5ffff 8d8530e5ffff 50 }
            // n = 6, score = 200
            //   8d8de4fcffff         | lea                 ecx, [ebp - 0x31c]
            //   898d30e5ffff         | mov                 dword ptr [ebp - 0x1ad0], ecx
            //   8d95d8e5ffff         | lea                 edx, [ebp - 0x1a28]
            //   899534e5ffff         | mov                 dword ptr [ebp - 0x1acc], edx
            //   8d8530e5ffff         | lea                 eax, [ebp - 0x1ad0]
            //   50                   | push                eax

        $sequence_3 = { 8b45d4 50 e8???????? 83c408 8945d4 837dd000 }
            // n = 6, score = 200
            //   8b45d4               | mov                 eax, dword ptr [ebp - 0x2c]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   8945d4               | mov                 dword ptr [ebp - 0x2c], eax
            //   837dd000             | cmp                 dword ptr [ebp - 0x30], 0

        $sequence_4 = { 8b9540e5ffff 8bca c1e902 f3a5 8bca }
            // n = 5, score = 200
            //   8b9540e5ffff         | mov                 edx, dword ptr [ebp - 0x1ac0]
            //   8bca                 | mov                 ecx, edx
            //   c1e902               | shr                 ecx, 2
            //   f3a5                 | rep movsd           dword ptr es:[edi], dword ptr [esi]
            //   8bca                 | mov                 ecx, edx

        $sequence_5 = { 68???????? e8???????? 83c404 83f0ff 50 0fb695e5e5ffff }
            // n = 6, score = 200
            //   68????????           |                     
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   83f0ff               | xor                 eax, 0xffffffff
            //   50                   | push                eax
            //   0fb695e5e5ffff       | movzx               edx, byte ptr [ebp - 0x1a1b]

        $sequence_6 = { 3bf3 72e9 5f 5e 5b c3 56 }
            // n = 7, score = 200
            //   3bf3                 | cmp                 esi, ebx
            //   72e9                 | jb                  0xffffffeb
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx
            //   c3                   | ret                 
            //   56                   | push                esi

        $sequence_7 = { 51 e8???????? 83c404 ba01000000 6bca05 8b5508 }
            // n = 6, score = 200
            //   51                   | push                ecx
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   ba01000000           | mov                 edx, 1
            //   6bca05               | imul                ecx, edx, 5
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]

        $sequence_8 = { 8d95e0f3ffff 52 8d8d70e6ffff e8???????? 8d8570ffffff }
            // n = 5, score = 200
            //   8d95e0f3ffff         | lea                 edx, [ebp - 0xc20]
            //   52                   | push                edx
            //   8d8d70e6ffff         | lea                 ecx, [ebp - 0x1990]
            //   e8????????           |                     
            //   8d8570ffffff         | lea                 eax, [ebp - 0x90]

        $sequence_9 = { 89856ce6ffff 6a4b 6a00 8d55b0 52 e8???????? 83c40c }
            // n = 7, score = 200
            //   89856ce6ffff         | mov                 dword ptr [ebp - 0x1994], eax
            //   6a4b                 | push                0x4b
            //   6a00                 | push                0
            //   8d55b0               | lea                 edx, [ebp - 0x50]
            //   52                   | push                edx
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc

    condition:
        7 of them and filesize < 335872
}