rule win_malumpos_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.malumpos."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.malumpos"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 85f6 7907 0d80000000 eb27 }
            // n = 4, score = 100
            //   85f6                 | test                esi, esi
            //   7907                 | jns                 9
            //   0d80000000           | or                  eax, 0x80
            //   eb27                 | jmp                 0x29

        $sequence_1 = { 53 50 c78500fdffff07000100 895d4c 895dcc e8???????? }
            // n = 6, score = 100
            //   53                   | push                ebx
            //   50                   | push                eax
            //   c78500fdffff07000100     | mov    dword ptr [ebp - 0x300], 0x10007
            //   895d4c               | mov                 dword ptr [ebp + 0x4c], ebx
            //   895dcc               | mov                 dword ptr [ebp - 0x34], ebx
            //   e8????????           |                     

        $sequence_2 = { 59 8d45cc 50 ff15???????? 6a44 }
            // n = 5, score = 100
            //   59                   | pop                 ecx
            //   8d45cc               | lea                 eax, [ebp - 0x34]
            //   50                   | push                eax
            //   ff15????????         |                     
            //   6a44                 | push                0x44

        $sequence_3 = { 0f1f00 0f1f00 0f1f00 0f1f00 6a72 }
            // n = 5, score = 100
            //   0f1f00               | nop                 dword ptr [eax]
            //   0f1f00               | nop                 dword ptr [eax]
            //   0f1f00               | nop                 dword ptr [eax]
            //   0f1f00               | nop                 dword ptr [eax]
            //   6a72                 | push                0x72

        $sequence_4 = { 3bc8 0f86f1feffff ff770c 50 e8???????? }
            // n = 5, score = 100
            //   3bc8                 | cmp                 ecx, eax
            //   0f86f1feffff         | jbe                 0xfffffef7
            //   ff770c               | push                dword ptr [edi + 0xc]
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_5 = { 7805 0500000000 57 3500000000 }
            // n = 4, score = 100
            //   7805                 | js                  7
            //   0500000000           | add                 eax, 0
            //   57                   | push                edi
            //   3500000000           | xor                 eax, 0

        $sequence_6 = { 8a0432 3c3d 7506 8365fc00 eb0d }
            // n = 5, score = 100
            //   8a0432               | mov                 al, byte ptr [edx + esi]
            //   3c3d                 | cmp                 al, 0x3d
            //   7506                 | jne                 8
            //   8365fc00             | and                 dword ptr [ebp - 4], 0
            //   eb0d                 | jmp                 0xf

        $sequence_7 = { e8???????? 68???????? a3???????? ffd0 810d????????00200000 be???????? c745f468e50300 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   68????????           |                     
            //   a3????????           |                     
            //   ffd0                 | call                eax
            //   810d????????00200000     |     
            //   be????????           |                     
            //   c745f468e50300       | mov                 dword ptr [ebp - 0xc], 0x3e568

        $sequence_8 = { 6683f300 55 51 7204 }
            // n = 4, score = 100
            //   6683f300             | xor                 bx, 0
            //   55                   | push                ebp
            //   51                   | push                ecx
            //   7204                 | jb                  6

        $sequence_9 = { 8d4520 50 ff15???????? 8d4520 }
            // n = 4, score = 100
            //   8d4520               | lea                 eax, [ebp + 0x20]
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8d4520               | lea                 eax, [ebp + 0x20]

    condition:
        7 of them and filesize < 542720
}