rule win_mangzamel_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.mangzamel."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.mangzamel"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b7508 837e1410 7404 32c0 eb6e 8b06 53 }
            // n = 7, score = 400
            //   8b7508               | mov                 esi, dword ptr [ebp + 8]
            //   837e1410             | cmp                 dword ptr [esi + 0x14], 0x10
            //   7404                 | je                  6
            //   32c0                 | xor                 al, al
            //   eb6e                 | jmp                 0x70
            //   8b06                 | mov                 eax, dword ptr [esi]
            //   53                   | push                ebx

        $sequence_1 = { 8d8dd4feffff e8???????? 33db 8d8dc0fdffff 895dfc e8???????? 8d85d4feffff }
            // n = 7, score = 400
            //   8d8dd4feffff         | lea                 ecx, [ebp - 0x12c]
            //   e8????????           |                     
            //   33db                 | xor                 ebx, ebx
            //   8d8dc0fdffff         | lea                 ecx, [ebp - 0x240]
            //   895dfc               | mov                 dword ptr [ebp - 4], ebx
            //   e8????????           |                     
            //   8d85d4feffff         | lea                 eax, [ebp - 0x12c]

        $sequence_2 = { 6a00 8bce ff7674 e8???????? 6a01 6804000102 8bce }
            // n = 7, score = 400
            //   6a00                 | push                0
            //   8bce                 | mov                 ecx, esi
            //   ff7674               | push                dword ptr [esi + 0x74]
            //   e8????????           |                     
            //   6a01                 | push                1
            //   6804000102           | push                0x2010004
            //   8bce                 | mov                 ecx, esi

        $sequence_3 = { ff7508 e8???????? 84c0 7404 c645f301 8b4df4 }
            // n = 6, score = 400
            //   ff7508               | push                dword ptr [ebp + 8]
            //   e8????????           |                     
            //   84c0                 | test                al, al
            //   7404                 | je                  6
            //   c645f301             | mov                 byte ptr [ebp - 0xd], 1
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]

        $sequence_4 = { 8bd0 8b00 8b5208 3932 7506 837a0400 }
            // n = 6, score = 400
            //   8bd0                 | mov                 edx, eax
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   8b5208               | mov                 edx, dword ptr [edx + 8]
            //   3932                 | cmp                 dword ptr [edx], esi
            //   7506                 | jne                 8
            //   837a0400             | cmp                 dword ptr [edx + 4], 0

        $sequence_5 = { e8???????? 33c0 8bce 50 50 50 ff742414 }
            // n = 7, score = 400
            //   e8????????           |                     
            //   33c0                 | xor                 eax, eax
            //   8bce                 | mov                 ecx, esi
            //   50                   | push                eax
            //   50                   | push                eax
            //   50                   | push                eax
            //   ff742414             | push                dword ptr [esp + 0x14]

        $sequence_6 = { 8bce ff7508 ff5040 8ac3 5e 5b 5d }
            // n = 7, score = 400
            //   8bce                 | mov                 ecx, esi
            //   ff7508               | push                dword ptr [ebp + 8]
            //   ff5040               | call                dword ptr [eax + 0x40]
            //   8ac3                 | mov                 al, bl
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx
            //   5d                   | pop                 ebp

        $sequence_7 = { 57 8b7c2414 33c0 8907 8b0d???????? 3bc8 }
            // n = 6, score = 400
            //   57                   | push                edi
            //   8b7c2414             | mov                 edi, dword ptr [esp + 0x14]
            //   33c0                 | xor                 eax, eax
            //   8907                 | mov                 dword ptr [edi], eax
            //   8b0d????????         |                     
            //   3bc8                 | cmp                 ecx, eax

        $sequence_8 = { 8d4b6c e8???????? 5e 5b c3 56 8bf1 }
            // n = 7, score = 400
            //   8d4b6c               | lea                 ecx, [ebx + 0x6c]
            //   e8????????           |                     
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx
            //   c3                   | ret                 
            //   56                   | push                esi
            //   8bf1                 | mov                 esi, ecx

        $sequence_9 = { 8b74240c 57 8b7c240c 8d4602 50 57 e8???????? }
            // n = 7, score = 400
            //   8b74240c             | mov                 esi, dword ptr [esp + 0xc]
            //   57                   | push                edi
            //   8b7c240c             | mov                 edi, dword ptr [esp + 0xc]
            //   8d4602               | lea                 eax, [esi + 2]
            //   50                   | push                eax
            //   57                   | push                edi
            //   e8????????           |                     

    condition:
        7 of them and filesize < 360448
}