rule win_maoloa_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.maoloa."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.maoloa"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b55fc 8bcb 85c0 7817 8d45f0 50 e8???????? }
            // n = 7, score = 100
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   8bcb                 | mov                 ecx, ebx
            //   85c0                 | test                eax, eax
            //   7817                 | js                  0x19
            //   8d45f0               | lea                 eax, [ebp - 0x10]
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_1 = { 50 ffb5f0e4ffff 8b35???????? ffd6 8b85c0e4ffff c1e015 03858ce5ffff }
            // n = 7, score = 100
            //   50                   | push                eax
            //   ffb5f0e4ffff         | push                dword ptr [ebp - 0x1b10]
            //   8b35????????         |                     
            //   ffd6                 | call                esi
            //   8b85c0e4ffff         | mov                 eax, dword ptr [ebp - 0x1b40]
            //   c1e015               | shl                 eax, 0x15
            //   03858ce5ffff         | add                 eax, dword ptr [ebp - 0x1a74]

        $sequence_2 = { 8b4df8 33cd e8???????? 8be5 5d c3 befcffffff }
            // n = 7, score = 100
            //   8b4df8               | mov                 ecx, dword ptr [ebp - 8]
            //   33cd                 | xor                 ecx, ebp
            //   e8????????           |                     
            //   8be5                 | mov                 esp, ebp
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   befcffffff           | mov                 esi, 0xfffffffc

        $sequence_3 = { 83c404 85f6 0f8590000000 6a01 8bd7 8bcf e8???????? }
            // n = 7, score = 100
            //   83c404               | add                 esp, 4
            //   85f6                 | test                esi, esi
            //   0f8590000000         | jne                 0x96
            //   6a01                 | push                1
            //   8bd7                 | mov                 edx, edi
            //   8bcf                 | mov                 ecx, edi
            //   e8????????           |                     

        $sequence_4 = { 85c0 8d8d00e0ffff 0f45ce 8bf1 89b5f8dfffff 8d85f8efffff 50 }
            // n = 7, score = 100
            //   85c0                 | test                eax, eax
            //   8d8d00e0ffff         | lea                 ecx, [ebp - 0x2000]
            //   0f45ce               | cmovne              ecx, esi
            //   8bf1                 | mov                 esi, ecx
            //   89b5f8dfffff         | mov                 dword ptr [ebp - 0x2008], esi
            //   8d85f8efffff         | lea                 eax, [ebp - 0x1008]
            //   50                   | push                eax

        $sequence_5 = { b910000000 0f43c1 8d4c2418 2bf8 }
            // n = 4, score = 100
            //   b910000000           | mov                 ecx, 0x10
            //   0f43c1               | cmovae              eax, ecx
            //   8d4c2418             | lea                 ecx, [esp + 0x18]
            //   2bf8                 | sub                 edi, eax

        $sequence_6 = { 8d97a9cfde4b 33c1 894db4 0345d0 03d0 8b7db4 c1c20b }
            // n = 7, score = 100
            //   8d97a9cfde4b         | lea                 edx, [edi + 0x4bdecfa9]
            //   33c1                 | xor                 eax, ecx
            //   894db4               | mov                 dword ptr [ebp - 0x4c], ecx
            //   0345d0               | add                 eax, dword ptr [ebp - 0x30]
            //   03d0                 | add                 edx, eax
            //   8b7db4               | mov                 edi, dword ptr [ebp - 0x4c]
            //   c1c20b               | rol                 edx, 0xb

        $sequence_7 = { 8bd3 c707ffffffff 8bcf e8???????? 83c404 8bf0 8b85e0f9ffff }
            // n = 7, score = 100
            //   8bd3                 | mov                 edx, ebx
            //   c707ffffffff         | mov                 dword ptr [edi], 0xffffffff
            //   8bcf                 | mov                 ecx, edi
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   8bf0                 | mov                 esi, eax
            //   8b85e0f9ffff         | mov                 eax, dword ptr [ebp - 0x620]

        $sequence_8 = { 0f1f00 0fb601 8d4901 30440eff 0fb641ff 30440aff 83ef01 }
            // n = 7, score = 100
            //   0f1f00               | nop                 dword ptr [eax]
            //   0fb601               | movzx               eax, byte ptr [ecx]
            //   8d4901               | lea                 ecx, [ecx + 1]
            //   30440eff             | xor                 byte ptr [esi + ecx - 1], al
            //   0fb641ff             | movzx               eax, byte ptr [ecx - 1]
            //   30440aff             | xor                 byte ptr [edx + ecx - 1], al
            //   83ef01               | sub                 edi, 1

        $sequence_9 = { 5e 5b 8be5 5d c3 8d45f0 8bd1 }
            // n = 7, score = 100
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx
            //   8be5                 | mov                 esp, ebp
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   8d45f0               | lea                 eax, [ebp - 0x10]
            //   8bd1                 | mov                 edx, ecx

    condition:
        7 of them and filesize < 586752
}