rule win_matrix_banker_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.matrix_banker."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.matrix_banker"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { eb0b 8d4abf 80f905 7703 }
            // n = 4, score = 900
            //   eb0b                 | mov                 esi, eax
            //   8d4abf               | movzx               eax, byte ptr [edi + 2]
            //   80f905               | shld                edx, esi, 8
            //   7703                 | cdq                 

        $sequence_1 = { 8d489f 80f905 7704 04a9 eb0a 8d48bf }
            // n = 6, score = 900
            //   8d489f               | mov                 eax, dword ptr [eax*8 + 0x4b3dacc]
            //   80f905               | pop                 ebp
            //   7704                 | ret                 
            //   04a9                 | push                ebp
            //   eb0a                 | pop                 ebp
            //   8d48bf               | ret                 

        $sequence_2 = { 8d4a9f 80f905 7705 80c2a9 eb0b }
            // n = 5, score = 900
            //   8d4a9f               | lea                 eax, [ebp + 1]
            //   80f905               | dec                 eax
            //   7705                 | arpl                ax, cx
            //   80c2a9               | dec                 eax
            //   eb0b                 | shl                 ecx, 5

        $sequence_3 = { 7705 80c2a9 eb0b 8d4abf 80f905 7703 80c2c9 }
            // n = 7, score = 900
            //   7705                 | mov                 dword ptr [esp + 0x28], eax
            //   80c2a9               | dec                 eax
            //   eb0b                 | xor                 eax, esp
            //   8d4abf               | dec                 eax
            //   80f905               | mov                 dword ptr [esp + 0x48], eax
            //   7703                 | dec                 eax
            //   80c2c9               | lea                 eax, [0x24df7]

        $sequence_4 = { 80f905 7702 04c9 8d4ad0 }
            // n = 4, score = 900
            //   80f905               | dec                 eax
            //   7702                 | lea                 ecx, [esp + 0x40]
            //   04c9                 | mov                 edx, 1
            //   8d4ad0               | dec                 esp

        $sequence_5 = { 80c2a9 eb0b 8d4abf 80f905 7703 80c2c9 }
            // n = 6, score = 900
            //   80c2a9               | dec                 eax
            //   eb0b                 | mov                 ecx, dword ptr [esp + 0x58]
            //   8d4abf               | dec                 eax
            //   80f905               | test                ecx, ecx
            //   7703                 | je                  0xcd6
            //   80c2c9               | inc                 ecx

        $sequence_6 = { ff15???????? e8???????? 85c0 740a e8???????? 83f8ff }
            // n = 6, score = 900
            //   ff15????????         |                     
            //   e8????????           |                     
            //   85c0                 | push                -1
            //   740a                 | inc                 eax
            //   e8????????           |                     
            //   83f8ff               | lea                 ecx, [esp + 0x28]

        $sequence_7 = { eb18 8d4a9f 80f905 7705 80c2a9 }
            // n = 5, score = 900
            //   eb18                 | mov                 byte ptr [eax + esi], bl
            //   8d4a9f               | dec                 eax
            //   80f905               | mov                 ecx, dword ptr [edi + 8]
            //   7705                 | dec                 esp
            //   80c2a9               | lea                 ecx, [esp + 0x20]

        $sequence_8 = { eb18 8d4a9f 80f905 7705 }
            // n = 4, score = 900
            //   eb18                 | jne                 0x208
            //   8d4a9f               | mov                 esi, eax
            //   80f905               | mov                 dword ptr [ebp - 0xc4], eax
            //   7705                 | add                 esi, dword ptr [ebp - 0xb8]

        $sequence_9 = { 8d489f 80f905 7704 04a9 eb0a 8d48bf 80f905 }
            // n = 7, score = 900
            //   8d489f               | mov                 ebp, dword ptr [esp + 0x58]
            //   80f905               | dec                 ecx
            //   7704                 | mov                 eax, edi
            //   04a9                 | dec                 eax
            //   eb0a                 | test                ecx, ecx
            //   8d48bf               | je                  0x12bf
            //   80f905               | dec                 eax

    condition:
        7 of them and filesize < 422912
}