rule win_mebromi_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.mebromi."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.mebromi"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 743a 837d0800 742e 85f6 7419 0fb6da f68301a0290004 }
            // n = 7, score = 100
            //   743a                 | je                  0x3c
            //   837d0800             | cmp                 dword ptr [ebp + 8], 0
            //   742e                 | je                  0x30
            //   85f6                 | test                esi, esi
            //   7419                 | je                  0x1b
            //   0fb6da               | movzx               ebx, dl
            //   f68301a0290004       | test                byte ptr [ebx + 0x29a001], 4

        $sequence_1 = { 68ff010f00 68???????? ff742410 ff15???????? 8bf0 85f6 7416 }
            // n = 7, score = 100
            //   68ff010f00           | push                0xf01ff
            //   68????????           |                     
            //   ff742410             | push                dword ptr [esp + 0x10]
            //   ff15????????         |                     
            //   8bf0                 | mov                 esi, eax
            //   85f6                 | test                esi, esi
            //   7416                 | je                  0x18

        $sequence_2 = { 7714 8b55fc 8a9270722900 089001a02900 }
            // n = 4, score = 100
            //   7714                 | ja                  0x16
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   8a9270722900         | mov                 dl, byte ptr [edx + 0x297270]
            //   089001a02900         | or                  byte ptr [eax + 0x29a001], dl

        $sequence_3 = { 683f000f00 55 55 ff15???????? 8bf0 e8???????? 56 }
            // n = 7, score = 100
            //   683f000f00           | push                0xf003f
            //   55                   | push                ebp
            //   55                   | push                ebp
            //   ff15????????         |                     
            //   8bf0                 | mov                 esi, eax
            //   e8????????           |                     
            //   56                   | push                esi

        $sequence_4 = { 48 750c e8???????? eb05 e8???????? 6a01 }
            // n = 6, score = 100
            //   48                   | dec                 eax
            //   750c                 | jne                 0xe
            //   e8????????           |                     
            //   eb05                 | jmp                 7
            //   e8????????           |                     
            //   6a01                 | push                1

        $sequence_5 = { 0fb6fa 3bc7 7714 8b55fc 8a9270722900 089001a02900 }
            // n = 6, score = 100
            //   0fb6fa               | movzx               edi, dl
            //   3bc7                 | cmp                 eax, edi
            //   7714                 | ja                  0x16
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   8a9270722900         | mov                 dl, byte ptr [edx + 0x297270]
            //   089001a02900         | or                  byte ptr [eax + 0x29a001], dl

        $sequence_6 = { 2c29 0000 2d29008a46 0323 d18847034ec1 e9???????? }
            // n = 6, score = 100
            //   2c29                 | sub                 al, 0x29
            //   0000                 | add                 byte ptr [eax], al
            //   2d29008a46           | sub                 eax, 0x468a0029
            //   0323                 | add                 esp, dword ptr [ebx]
            //   d18847034ec1         | ror                 dword ptr [eax - 0x3eb1fcb9], 1
            //   e9????????           |                     

        $sequence_7 = { 0fb6d2 f68201a0290004 740c ff01 }
            // n = 4, score = 100
            //   0fb6d2               | movzx               edx, dl
            //   f68201a0290004       | test                byte ptr [edx + 0x29a001], 4
            //   740c                 | je                  0xe
            //   ff01                 | inc                 dword ptr [ecx]

        $sequence_8 = { aa 8d9e88722900 803b00 8bcb 742c 8a5101 84d2 }
            // n = 7, score = 100
            //   aa                   | stosb               byte ptr es:[edi], al
            //   8d9e88722900         | lea                 ebx, [esi + 0x297288]
            //   803b00               | cmp                 byte ptr [ebx], 0
            //   8bcb                 | mov                 ecx, ebx
            //   742c                 | je                  0x2e
            //   8a5101               | mov                 dl, byte ptr [ecx + 1]
            //   84d2                 | test                dl, dl

        $sequence_9 = { 50 6a01 56 ff15???????? 56 8bf8 ff15???????? }
            // n = 7, score = 100
            //   50                   | push                eax
            //   6a01                 | push                1
            //   56                   | push                esi
            //   ff15????????         |                     
            //   56                   | push                esi
            //   8bf8                 | mov                 edi, eax
            //   ff15????????         |                     

    condition:
        7 of them and filesize < 106496
}