rule win_medusalocker_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.medusalocker."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.medusalocker"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 8945e8 eb07 c745e800000000 8b4de8 894de4 c645fc02 }
            // n = 7, score = 400
            //   e8????????           |                     
            //   8945e8               | mov                 dword ptr [ebp - 0x18], eax
            //   eb07                 | jmp                 9
            //   c745e800000000       | mov                 dword ptr [ebp - 0x18], 0
            //   8b4de8               | mov                 ecx, dword ptr [ebp - 0x18]
            //   894de4               | mov                 dword ptr [ebp - 0x1c], ecx
            //   c645fc02             | mov                 byte ptr [ebp - 4], 2

        $sequence_1 = { 8b4dd4 e8???????? 83c048 50 8d55d8 }
            // n = 5, score = 400
            //   8b4dd4               | mov                 ecx, dword ptr [ebp - 0x2c]
            //   e8????????           |                     
            //   83c048               | add                 eax, 0x48
            //   50                   | push                eax
            //   8d55d8               | lea                 edx, [ebp - 0x28]

        $sequence_2 = { e8???????? 33c0 8845bb c745c488020000 6888020000 e8???????? 83c404 }
            // n = 7, score = 400
            //   e8????????           |                     
            //   33c0                 | xor                 eax, eax
            //   8845bb               | mov                 byte ptr [ebp - 0x45], al
            //   c745c488020000       | mov                 dword ptr [ebp - 0x3c], 0x288
            //   6888020000           | push                0x288
            //   e8????????           |                     
            //   83c404               | add                 esp, 4

        $sequence_3 = { 83c404 8b08 51 e8???????? 83c410 }
            // n = 5, score = 400
            //   83c404               | add                 esp, 4
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   51                   | push                ecx
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10

        $sequence_4 = { 8845d7 8b4d08 e8???????? 0fb6c8 85c9 0f85f6000000 8b5508 }
            // n = 7, score = 400
            //   8845d7               | mov                 byte ptr [ebp - 0x29], al
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   e8????????           |                     
            //   0fb6c8               | movzx               ecx, al
            //   85c9                 | test                ecx, ecx
            //   0f85f6000000         | jne                 0xfc
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]

        $sequence_5 = { 8d45e8 50 8b4d0c 51 e8???????? 83c404 50 }
            // n = 7, score = 400
            //   8d45e8               | lea                 eax, [ebp - 0x18]
            //   50                   | push                eax
            //   8b4d0c               | mov                 ecx, dword ptr [ebp + 0xc]
            //   51                   | push                ecx
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   50                   | push                eax

        $sequence_6 = { 33c0 8945e8 668945ec b902000000 6bd100 668b450c }
            // n = 6, score = 400
            //   33c0                 | xor                 eax, eax
            //   8945e8               | mov                 dword ptr [ebp - 0x18], eax
            //   668945ec             | mov                 word ptr [ebp - 0x14], ax
            //   b902000000           | mov                 ecx, 2
            //   6bd100               | imul                edx, ecx, 0
            //   668b450c             | mov                 ax, word ptr [ebp + 0xc]

        $sequence_7 = { 894508 8b4d08 3b4d0c 7427 8b5508 }
            // n = 5, score = 400
            //   894508               | mov                 dword ptr [ebp + 8], eax
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   3b4d0c               | cmp                 ecx, dword ptr [ebp + 0xc]
            //   7427                 | je                  0x29
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]

        $sequence_8 = { 8965d8 8b45e4 83c00c 50 e8???????? e8???????? 8b4de4 }
            // n = 7, score = 400
            //   8965d8               | mov                 dword ptr [ebp - 0x28], esp
            //   8b45e4               | mov                 eax, dword ptr [ebp - 0x1c]
            //   83c00c               | add                 eax, 0xc
            //   50                   | push                eax
            //   e8????????           |                     
            //   e8????????           |                     
            //   8b4de4               | mov                 ecx, dword ptr [ebp - 0x1c]

        $sequence_9 = { 8b55e0 52 6a01 8b4df0 e8???????? c645fc03 8d8d38ffffff }
            // n = 7, score = 400
            //   8b55e0               | mov                 edx, dword ptr [ebp - 0x20]
            //   52                   | push                edx
            //   6a01                 | push                1
            //   8b4df0               | mov                 ecx, dword ptr [ebp - 0x10]
            //   e8????????           |                     
            //   c645fc03             | mov                 byte ptr [ebp - 4], 3
            //   8d8d38ffffff         | lea                 ecx, [ebp - 0xc8]

    condition:
        7 of them and filesize < 1433600
}