rule win_meow_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.meow."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.meow"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c685cefaffff53 c685cffaffff63 c685d0faffff53 c685d1faffff53 c685d2faffff53 8a85c9faffff e8???????? }
            // n = 7, score = 100
            //   c685cefaffff53       | mov                 byte ptr [ebp - 0x532], 0x53
            //   c685cffaffff63       | mov                 byte ptr [ebp - 0x531], 0x63
            //   c685d0faffff53       | mov                 byte ptr [ebp - 0x530], 0x53
            //   c685d1faffff53       | mov                 byte ptr [ebp - 0x52f], 0x53
            //   c685d2faffff53       | mov                 byte ptr [ebp - 0x52e], 0x53
            //   8a85c9faffff         | mov                 al, byte ptr [ebp - 0x537]
            //   e8????????           |                     

        $sequence_1 = { 72dc ff75ec 8d4599 50 e8???????? 8b33 ba0f000000 }
            // n = 7, score = 100
            //   72dc                 | jb                  0xffffffde
            //   ff75ec               | push                dword ptr [ebp - 0x14]
            //   8d4599               | lea                 eax, [ebp - 0x67]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b33                 | mov                 esi, dword ptr [ebx]
            //   ba0f000000           | mov                 edx, 0xf

        $sequence_2 = { 0f8441070000 c745f4bb195c00 be03000000 8b45f4 99 f7fe 85d2 }
            // n = 7, score = 100
            //   0f8441070000         | je                  0x747
            //   c745f4bb195c00       | mov                 dword ptr [ebp - 0xc], 0x5c19bb
            //   be03000000           | mov                 esi, 3
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]
            //   99                   | cdq                 
            //   f7fe                 | idiv                esi
            //   85d2                 | test                edx, edx

        $sequence_3 = { 99 f7f9 8b45f4 85d2 7403 48 eb01 }
            // n = 7, score = 100
            //   99                   | cdq                 
            //   f7f9                 | idiv                ecx
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]
            //   85d2                 | test                edx, edx
            //   7403                 | je                  5
            //   48                   | dec                 eax
            //   eb01                 | jmp                 3

        $sequence_4 = { 743b 8b45f0 83c117 83c00b 99 f7f9 8945f0 }
            // n = 7, score = 100
            //   743b                 | je                  0x3d
            //   8b45f0               | mov                 eax, dword ptr [ebp - 0x10]
            //   83c117               | add                 ecx, 0x17
            //   83c00b               | add                 eax, 0xb
            //   99                   | cdq                 
            //   f7f9                 | idiv                ecx
            //   8945f0               | mov                 dword ptr [ebp - 0x10], eax

        $sequence_5 = { c685dbfdffff5f c685dcfdffff7d c685ddfdffff7d c685defdffff7d 8a85d5fdffff e8???????? 898564f5ffff }
            // n = 7, score = 100
            //   c685dbfdffff5f       | mov                 byte ptr [ebp - 0x225], 0x5f
            //   c685dcfdffff7d       | mov                 byte ptr [ebp - 0x224], 0x7d
            //   c685ddfdffff7d       | mov                 byte ptr [ebp - 0x223], 0x7d
            //   c685defdffff7d       | mov                 byte ptr [ebp - 0x222], 0x7d
            //   8a85d5fdffff         | mov                 al, byte ptr [ebp - 0x22b]
            //   e8????????           |                     
            //   898564f5ffff         | mov                 dword ptr [ebp - 0xa9c], eax

        $sequence_6 = { 7907 48 83c8fc 83c001 7463 8b4c2410 8d4303 }
            // n = 7, score = 100
            //   7907                 | jns                 9
            //   48                   | dec                 eax
            //   83c8fc               | or                  eax, 0xfffffffc
            //   83c001               | add                 eax, 1
            //   7463                 | je                  0x65
            //   8b4c2410             | mov                 ecx, dword ptr [esp + 0x10]
            //   8d4303               | lea                 eax, [ebx + 3]

        $sequence_7 = { 8a01 8d4901 0fb6c0 83e871 6bc037 99 f7fb }
            // n = 7, score = 100
            //   8a01                 | mov                 al, byte ptr [ecx]
            //   8d4901               | lea                 ecx, [ecx + 1]
            //   0fb6c0               | movzx               eax, al
            //   83e871               | sub                 eax, 0x71
            //   6bc037               | imul                eax, eax, 0x37
            //   99                   | cdq                 
            //   f7fb                 | idiv                ebx

        $sequence_8 = { c6854dfeffff4c c6854efeffff3b c6854ffeffff6b c68550feffff3b c68551feffff26 c68552feffff3b c68553feffff18 }
            // n = 7, score = 100
            //   c6854dfeffff4c       | mov                 byte ptr [ebp - 0x1b3], 0x4c
            //   c6854efeffff3b       | mov                 byte ptr [ebp - 0x1b2], 0x3b
            //   c6854ffeffff6b       | mov                 byte ptr [ebp - 0x1b1], 0x6b
            //   c68550feffff3b       | mov                 byte ptr [ebp - 0x1b0], 0x3b
            //   c68551feffff26       | mov                 byte ptr [ebp - 0x1af], 0x26
            //   c68552feffff3b       | mov                 byte ptr [ebp - 0x1ae], 0x3b
            //   c68553feffff18       | mov                 byte ptr [ebp - 0x1ad], 0x18

        $sequence_9 = { 99 f7f9 85d2 7445 8b442410 8d4f17 83c00b }
            // n = 7, score = 100
            //   99                   | cdq                 
            //   f7f9                 | idiv                ecx
            //   85d2                 | test                edx, edx
            //   7445                 | je                  0x47
            //   8b442410             | mov                 eax, dword ptr [esp + 0x10]
            //   8d4f17               | lea                 ecx, [edi + 0x17]
            //   83c00b               | add                 eax, 0xb

    condition:
        7 of them and filesize < 492544
}