rule win_mewsei_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.mewsei."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.mewsei"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 337df8 8b5dfc 237df4 337df0 037dc0 8dbc1faf0f7cf5 }
            // n = 6, score = 400
            //   337df8               | xor                 edi, dword ptr [ebp - 8]
            //   8b5dfc               | mov                 ebx, dword ptr [ebp - 4]
            //   237df4               | and                 edi, dword ptr [ebp - 0xc]
            //   337df0               | xor                 edi, dword ptr [ebp - 0x10]
            //   037dc0               | add                 edi, dword ptr [ebp - 0x40]
            //   8dbc1faf0f7cf5       | lea                 edi, [edi + ebx - 0xa83f051]

        $sequence_1 = { e8???????? 50 8bc7 e8???????? 83c404 e8???????? 50 }
            // n = 7, score = 400
            //   e8????????           |                     
            //   50                   | push                eax
            //   8bc7                 | mov                 eax, edi
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   e8????????           |                     
            //   50                   | push                eax

        $sequence_2 = { 0fbe7c0602 57 e8???????? 83c404 85c0 7405 8d47d0 }
            // n = 7, score = 400
            //   0fbe7c0602           | movsx               edi, byte ptr [esi + eax + 2]
            //   57                   | push                edi
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   85c0                 | test                eax, eax
            //   7405                 | je                  7
            //   8d47d0               | lea                 eax, [edi - 0x30]

        $sequence_3 = { 8b4610 8b0cb8 8911 8b55f8 }
            // n = 4, score = 400
            //   8b4610               | mov                 eax, dword ptr [esi + 0x10]
            //   8b0cb8               | mov                 ecx, dword ptr [eax + edi*4]
            //   8911                 | mov                 dword ptr [ecx], edx
            //   8b55f8               | mov                 edx, dword ptr [ebp - 8]

        $sequence_4 = { 57 e8???????? 8b1d???????? 83c410 6a00 }
            // n = 5, score = 400
            //   57                   | push                edi
            //   e8????????           |                     
            //   8b1d????????         |                     
            //   83c410               | add                 esp, 0x10
            //   6a00                 | push                0

        $sequence_5 = { 83c404 895df8 85db 750c 6a01 e8???????? 83c404 }
            // n = 7, score = 400
            //   83c404               | add                 esp, 4
            //   895df8               | mov                 dword ptr [ebp - 8], ebx
            //   85db                 | test                ebx, ebx
            //   750c                 | jne                 0xe
            //   6a01                 | push                1
            //   e8????????           |                     
            //   83c404               | add                 esp, 4

        $sequence_6 = { 6a01 6a0e 56 ff15???????? }
            // n = 4, score = 400
            //   6a01                 | push                1
            //   6a0e                 | push                0xe
            //   56                   | push                esi
            //   ff15????????         |                     

        $sequence_7 = { 6a04 8d4df8 51 6a04 6a00 56 }
            // n = 6, score = 400
            //   6a04                 | push                4
            //   8d4df8               | lea                 ecx, [ebp - 8]
            //   51                   | push                ecx
            //   6a04                 | push                4
            //   6a00                 | push                0
            //   56                   | push                esi

        $sequence_8 = { ff15???????? 57 8bf0 53 56 ff15???????? 50 }
            // n = 7, score = 400
            //   ff15????????         |                     
            //   57                   | push                edi
            //   8bf0                 | mov                 esi, eax
            //   53                   | push                ebx
            //   56                   | push                esi
            //   ff15????????         |                     
            //   50                   | push                eax

        $sequence_9 = { 337df4 337dfc 037dcc 8dbc1ff87ca21f 8b5df0 c1c710 }
            // n = 6, score = 400
            //   337df4               | xor                 edi, dword ptr [ebp - 0xc]
            //   337dfc               | xor                 edi, dword ptr [ebp - 4]
            //   037dcc               | add                 edi, dword ptr [ebp - 0x34]
            //   8dbc1ff87ca21f       | lea                 edi, [edi + ebx + 0x1fa27cf8]
            //   8b5df0               | mov                 ebx, dword ptr [ebp - 0x10]
            //   c1c710               | rol                 edi, 0x10

    condition:
        7 of them and filesize < 504832
}