rule win_micrass_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.micrass."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.micrass"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 59 89442424 8d442408 6a50 }
            // n = 4, score = 100
            //   59                   | pop                 ecx
            //   89442424             | mov                 dword ptr [esp + 0x24], eax
            //   8d442408             | lea                 eax, [esp + 8]
            //   6a50                 | push                0x50

        $sequence_1 = { 66890c45c4cc4000 40 ebe8 33c0 8945e4 3d01010000 7d0d }
            // n = 7, score = 100
            //   66890c45c4cc4000     | mov                 word ptr [eax*2 + 0x40ccc4], cx
            //   40                   | inc                 eax
            //   ebe8                 | jmp                 0xffffffea
            //   33c0                 | xor                 eax, eax
            //   8945e4               | mov                 dword ptr [ebp - 0x1c], eax
            //   3d01010000           | cmp                 eax, 0x101
            //   7d0d                 | jge                 0xf

        $sequence_2 = { 8dbdccfdffff a5 a5 a5 a5 }
            // n = 5, score = 100
            //   8dbdccfdffff         | lea                 edi, [ebp - 0x234]
            //   a5                   | movsd               dword ptr es:[edi], dword ptr [esi]
            //   a5                   | movsd               dword ptr es:[edi], dword ptr [esi]
            //   a5                   | movsd               dword ptr es:[edi], dword ptr [esi]
            //   a5                   | movsd               dword ptr es:[edi], dword ptr [esi]

        $sequence_3 = { 6a06 89430c 8d4310 8d8984194000 5a 668b31 }
            // n = 6, score = 100
            //   6a06                 | push                6
            //   89430c               | mov                 dword ptr [ebx + 0xc], eax
            //   8d4310               | lea                 eax, [ebx + 0x10]
            //   8d8984194000         | lea                 ecx, [ecx + 0x401984]
            //   5a                   | pop                 edx
            //   668b31               | mov                 si, word ptr [ecx]

        $sequence_4 = { 8d85f8afffff 6a00 50 e8???????? 68???????? 57 e8???????? }
            // n = 7, score = 100
            //   8d85f8afffff         | lea                 eax, [ebp - 0x5008]
            //   6a00                 | push                0
            //   50                   | push                eax
            //   e8????????           |                     
            //   68????????           |                     
            //   57                   | push                edi
            //   e8????????           |                     

        $sequence_5 = { 53 8985b83fffff 8d85c03fffff 57 50 89bddc9fffff }
            // n = 6, score = 100
            //   53                   | push                ebx
            //   8985b83fffff         | mov                 dword ptr [ebp - 0xc048], eax
            //   8d85c03fffff         | lea                 eax, [ebp - 0xc040]
            //   57                   | push                edi
            //   50                   | push                eax
            //   89bddc9fffff         | mov                 dword ptr [ebp - 0x6024], edi

        $sequence_6 = { 56 b9???????? 8bf2 2bc8 2bf0 8a1401 }
            // n = 6, score = 100
            //   56                   | push                esi
            //   b9????????           |                     
            //   8bf2                 | mov                 esi, edx
            //   2bc8                 | sub                 ecx, eax
            //   2bf0                 | sub                 esi, eax
            //   8a1401               | mov                 dl, byte ptr [ecx + eax]

        $sequence_7 = { 8985e4fbffff 6a05 59 be???????? }
            // n = 4, score = 100
            //   8985e4fbffff         | mov                 dword ptr [ebp - 0x41c], eax
            //   6a05                 | push                5
            //   59                   | pop                 ecx
            //   be????????           |                     

        $sequence_8 = { 50 c744244801010000 e8???????? 59 50 89442414 }
            // n = 6, score = 100
            //   50                   | push                eax
            //   c744244801010000     | mov                 dword ptr [esp + 0x48], 0x101
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   50                   | push                eax
            //   89442414             | mov                 dword ptr [esp + 0x14], eax

        $sequence_9 = { 8bcb e8???????? 59 837e4400 57 bf???????? }
            // n = 6, score = 100
            //   8bcb                 | mov                 ecx, ebx
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   837e4400             | cmp                 dword ptr [esi + 0x44], 0
            //   57                   | push                edi
            //   bf????????           |                     

    condition:
        7 of them and filesize < 163840
}