rule win_miragefox_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.miragefox."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.miragefox"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 53 50 c6450805 e8???????? be1c810000 8d4508 56 }
            // n = 7, score = 100
            //   53                   | push                ebx
            //   50                   | push                eax
            //   c6450805             | mov                 byte ptr [ebp + 8], 5
            //   e8????????           |                     
            //   be1c810000           | mov                 esi, 0x811c
            //   8d4508               | lea                 eax, [ebp + 8]
            //   56                   | push                esi

        $sequence_1 = { 7509 0fb68340f62a00 eb02 8bc3 5b c9 c3 }
            // n = 7, score = 100
            //   7509                 | jne                 0xb
            //   0fb68340f62a00       | movzx               eax, byte ptr [ebx + 0x2af640]
            //   eb02                 | jmp                 4
            //   8bc3                 | mov                 eax, ebx
            //   5b                   | pop                 ebx
            //   c9                   | leave               
            //   c3                   | ret                 

        $sequence_2 = { 8985f07fffff 6a00 0f94c0 83c023 8885ec7fffff 8d85e0f7feff }
            // n = 6, score = 100
            //   8985f07fffff         | mov                 dword ptr [ebp - 0x8010], eax
            //   6a00                 | push                0
            //   0f94c0               | sete                al
            //   83c023               | add                 eax, 0x23
            //   8885ec7fffff         | mov                 byte ptr [ebp - 0x8014], al
            //   8d85e0f7feff         | lea                 eax, [ebp - 0x10820]

        $sequence_3 = { 7417 8bf9 c1ff05 83e11f 8b3cbd20f52a00 }
            // n = 5, score = 100
            //   7417                 | je                  0x19
            //   8bf9                 | mov                 edi, ecx
            //   c1ff05               | sar                 edi, 5
            //   83e11f               | and                 ecx, 0x1f
            //   8b3cbd20f52a00       | mov                 edi, dword ptr [edi*4 + 0x2af520]

        $sequence_4 = { 57 e8???????? 8d4604 6a19 }
            // n = 4, score = 100
            //   57                   | push                edi
            //   e8????????           |                     
            //   8d4604               | lea                 eax, [esi + 4]
            //   6a19                 | push                0x19

        $sequence_5 = { 6a00 50 e8???????? 8b4510 83c40c 8985147cffff }
            // n = 6, score = 100
            //   6a00                 | push                0
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b4510               | mov                 eax, dword ptr [ebp + 0x10]
            //   83c40c               | add                 esp, 0xc
            //   8985147cffff         | mov                 dword ptr [ebp - 0x83ec], eax

        $sequence_6 = { 6802800000 8d8520010000 53 50 e8???????? 8b4510 83c418 }
            // n = 7, score = 100
            //   6802800000           | push                0x8002
            //   8d8520010000         | lea                 eax, [ebp + 0x120]
            //   53                   | push                ebx
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b4510               | mov                 eax, dword ptr [ebp + 0x10]
            //   83c418               | add                 esp, 0x18

        $sequence_7 = { 6800400000 50 ff75fc ff15???????? 8b8514010000 2b75f4 }
            // n = 6, score = 100
            //   6800400000           | push                0x4000
            //   50                   | push                eax
            //   ff75fc               | push                dword ptr [ebp - 4]
            //   ff15????????         |                     
            //   8b8514010000         | mov                 eax, dword ptr [ebp + 0x114]
            //   2b75f4               | sub                 esi, dword ptr [ebp - 0xc]

        $sequence_8 = { b820080100 e8???????? 53 56 ff7518 6a00 6a01 }
            // n = 7, score = 100
            //   b820080100           | mov                 eax, 0x10820
            //   e8????????           |                     
            //   53                   | push                ebx
            //   56                   | push                esi
            //   ff7518               | push                dword ptr [ebp + 0x18]
            //   6a00                 | push                0
            //   6a01                 | push                1

        $sequence_9 = { e8???????? 834dfcff 8d4dec e8???????? e9???????? bf18800000 }
            // n = 6, score = 100
            //   e8????????           |                     
            //   834dfcff             | or                  dword ptr [ebp - 4], 0xffffffff
            //   8d4dec               | lea                 ecx, [ebp - 0x14]
            //   e8????????           |                     
            //   e9????????           |                     
            //   bf18800000           | mov                 edi, 0x8018

    condition:
        7 of them and filesize < 286720
}