rule win_miuref_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.miuref."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.miuref"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 59 59 8945fc 85f6 760e 803c072e 7418 }
            // n = 7, score = 200
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   85f6                 | test                esi, esi
            //   760e                 | jbe                 0x10
            //   803c072e             | cmp                 byte ptr [edi + eax], 0x2e
            //   7418                 | je                  0x1a

        $sequence_1 = { ff15???????? 50 e8???????? ff750c 8906 50 e8???????? }
            // n = 7, score = 200
            //   ff15????????         |                     
            //   50                   | push                eax
            //   e8????????           |                     
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   8906                 | mov                 dword ptr [esi], eax
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_2 = { 8bf0 8d7df0 a5 a5 a5 83c418 a5 }
            // n = 7, score = 200
            //   8bf0                 | mov                 esi, eax
            //   8d7df0               | lea                 edi, [ebp - 0x10]
            //   a5                   | movsd               dword ptr es:[edi], dword ptr [esi]
            //   a5                   | movsd               dword ptr es:[edi], dword ptr [esi]
            //   a5                   | movsd               dword ptr es:[edi], dword ptr [esi]
            //   83c418               | add                 esp, 0x18
            //   a5                   | movsd               dword ptr es:[edi], dword ptr [esi]

        $sequence_3 = { 6a02 ff35???????? e8???????? 8bf0 83c40c 85f6 7412 }
            // n = 7, score = 200
            //   6a02                 | push                2
            //   ff35????????         |                     
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax
            //   83c40c               | add                 esp, 0xc
            //   85f6                 | test                esi, esi
            //   7412                 | je                  0x14

        $sequence_4 = { 8d8300010000 ff75fc 50 e8???????? 68???????? 8d45f8 50 }
            // n = 7, score = 200
            //   8d8300010000         | lea                 eax, [ebx + 0x100]
            //   ff75fc               | push                dword ptr [ebp - 4]
            //   50                   | push                eax
            //   e8????????           |                     
            //   68????????           |                     
            //   8d45f8               | lea                 eax, [ebp - 8]
            //   50                   | push                eax

        $sequence_5 = { 8b4124 83f801 7514 ff7514 ff7510 ff750c }
            // n = 6, score = 200
            //   8b4124               | mov                 eax, dword ptr [ecx + 0x24]
            //   83f801               | cmp                 eax, 1
            //   7514                 | jne                 0x16
            //   ff7514               | push                dword ptr [ebp + 0x14]
            //   ff7510               | push                dword ptr [ebp + 0x10]
            //   ff750c               | push                dword ptr [ebp + 0xc]

        $sequence_6 = { 7509 0fb74e06 663bcf 7507 33c0 e9???????? }
            // n = 6, score = 200
            //   7509                 | jne                 0xb
            //   0fb74e06             | movzx               ecx, word ptr [esi + 6]
            //   663bcf               | cmp                 cx, di
            //   7507                 | jne                 9
            //   33c0                 | xor                 eax, eax
            //   e9????????           |                     

        $sequence_7 = { e8???????? 50 ff35???????? e8???????? 83c43c e9???????? 55 }
            // n = 7, score = 200
            //   e8????????           |                     
            //   50                   | push                eax
            //   ff35????????         |                     
            //   e8????????           |                     
            //   83c43c               | add                 esp, 0x3c
            //   e9????????           |                     
            //   55                   | push                ebp

        $sequence_8 = { 8d45d8 50 a5 e8???????? 83c408 8bf0 8bfc }
            // n = 7, score = 200
            //   8d45d8               | lea                 eax, [ebp - 0x28]
            //   50                   | push                eax
            //   a5                   | movsd               dword ptr es:[edi], dword ptr [esi]
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   8bf0                 | mov                 esi, eax
            //   8bfc                 | mov                 edi, esp

        $sequence_9 = { 53 53 ff15???????? 50 a3???????? e8???????? 59 }
            // n = 7, score = 200
            //   53                   | push                ebx
            //   53                   | push                ebx
            //   ff15????????         |                     
            //   50                   | push                eax
            //   a3????????           |                     
            //   e8????????           |                     
            //   59                   | pop                 ecx

    condition:
        7 of them and filesize < 180224
}