rule win_mofksys_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.mofksys."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.mofksys"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 50 e8???????? 8bd0 8d4de8 ffd6 8d8d60ffffff }
            // n = 6, score = 100
            //   50                   | push                eax
            //   e8????????           |                     
            //   8bd0                 | mov                 edx, eax
            //   8d4de8               | lea                 ecx, [ebp - 0x18]
            //   ffd6                 | call                esi
            //   8d8d60ffffff         | lea                 ecx, [ebp - 0xa0]

        $sequence_1 = { 894dd4 c745fc07000000 8b55d8 52 e8???????? ff15???????? 8b45d4 }
            // n = 7, score = 100
            //   894dd4               | mov                 dword ptr [ebp - 0x2c], ecx
            //   c745fc07000000       | mov                 dword ptr [ebp - 4], 7
            //   8b55d8               | mov                 edx, dword ptr [ebp - 0x28]
            //   52                   | push                edx
            //   e8????????           |                     
            //   ff15????????         |                     
            //   8b45d4               | mov                 eax, dword ptr [ebp - 0x2c]

        $sequence_2 = { 83c40c c745fca1000000 ba???????? 8d4dc0 ff15???????? 8d4dc0 51 }
            // n = 7, score = 100
            //   83c40c               | add                 esp, 0xc
            //   c745fca1000000       | mov                 dword ptr [ebp - 4], 0xa1
            //   ba????????           |                     
            //   8d4dc0               | lea                 ecx, [ebp - 0x40]
            //   ff15????????         |                     
            //   8d4dc0               | lea                 ecx, [ebp - 0x40]
            //   51                   | push                ecx

        $sequence_3 = { f7de 3bf0 7209 ff15???????? 8b4dc0 8b4118 0fafc6 }
            // n = 7, score = 100
            //   f7de                 | neg                 esi
            //   3bf0                 | cmp                 esi, eax
            //   7209                 | jb                  0xb
            //   ff15????????         |                     
            //   8b4dc0               | mov                 ecx, dword ptr [ebp - 0x40]
            //   8b4118               | mov                 eax, dword ptr [ecx + 0x18]
            //   0fafc6               | imul                eax, esi

        $sequence_4 = { ff15???????? 83c410 c745fc65000000 ba???????? 8d4dcc ff15???????? a1???????? }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   83c410               | add                 esp, 0x10
            //   c745fc65000000       | mov                 dword ptr [ebp - 4], 0x65
            //   ba????????           |                     
            //   8d4dcc               | lea                 ecx, [ebp - 0x34]
            //   ff15????????         |                     
            //   a1????????           |                     

        $sequence_5 = { ff15???????? 8bd0 8d8d7cfcffff ffd6 50 ffd7 }
            // n = 6, score = 100
            //   ff15????????         |                     
            //   8bd0                 | mov                 edx, eax
            //   8d8d7cfcffff         | lea                 ecx, [ebp - 0x384]
            //   ffd6                 | call                esi
            //   50                   | push                eax
            //   ffd7                 | call                edi

        $sequence_6 = { a1???????? 8b4de4 50 51 ffd7 8bd0 8d4da8 }
            // n = 7, score = 100
            //   a1????????           |                     
            //   8b4de4               | mov                 ecx, dword ptr [ebp - 0x1c]
            //   50                   | push                eax
            //   51                   | push                ecx
            //   ffd7                 | call                edi
            //   8bd0                 | mov                 edx, eax
            //   8d4da8               | lea                 ecx, [ebp - 0x58]

        $sequence_7 = { 3bc3 7d12 68e0000000 68???????? 56 50 }
            // n = 6, score = 100
            //   3bc3                 | cmp                 eax, ebx
            //   7d12                 | jge                 0x14
            //   68e0000000           | push                0xe0
            //   68????????           |                     
            //   56                   | push                esi
            //   50                   | push                eax

        $sequence_8 = { 83c201 0f80b2080000 52 8b45d0 50 68???????? }
            // n = 6, score = 100
            //   83c201               | add                 edx, 1
            //   0f80b2080000         | jo                  0x8b8
            //   52                   | push                edx
            //   8b45d0               | mov                 eax, dword ptr [ebp - 0x30]
            //   50                   | push                eax
            //   68????????           |                     

        $sequence_9 = { e8???????? 8d4ddc ff15???????? c745fc0f000000 68???????? 6a00 ff15???????? }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8d4ddc               | lea                 ecx, [ebp - 0x24]
            //   ff15????????         |                     
            //   c745fc0f000000       | mov                 dword ptr [ebp - 4], 0xf
            //   68????????           |                     
            //   6a00                 | push                0
            //   ff15????????         |                     

    condition:
        7 of them and filesize < 401408
}