rule win_moker_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.moker."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.moker"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 0302 8945d4 8b4dd4 83c102 }
            // n = 4, score = 200
            //   0302                 | add                 eax, dword ptr [edx]
            //   8945d4               | mov                 dword ptr [ebp - 0x2c], eax
            //   8b4dd4               | mov                 ecx, dword ptr [ebp - 0x2c]
            //   83c102               | add                 ecx, 2

        $sequence_1 = { 0302 8945e8 eb09 8b45e8 }
            // n = 4, score = 200
            //   0302                 | add                 eax, dword ptr [edx]
            //   8945e8               | mov                 dword ptr [ebp - 0x18], eax
            //   eb09                 | jmp                 0xb
            //   8b45e8               | mov                 eax, dword ptr [ebp - 0x18]

        $sequence_2 = { 0302 8945e8 8b4df8 8b55fc }
            // n = 4, score = 200
            //   0302                 | add                 eax, dword ptr [edx]
            //   8945e8               | mov                 dword ptr [ebp - 0x18], eax
            //   8b4df8               | mov                 ecx, dword ptr [ebp - 8]
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]

        $sequence_3 = { 0302 50 e8???????? 83c404 3b450c 750b 8b4df0 }
            // n = 7, score = 200
            //   0302                 | add                 eax, dword ptr [edx]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   3b450c               | cmp                 eax, dword ptr [ebp + 0xc]
            //   750b                 | jne                 0xd
            //   8b4df0               | mov                 ecx, dword ptr [ebp - 0x10]

        $sequence_4 = { 0301 8945e0 e8???????? 8b55e8 }
            // n = 4, score = 200
            //   0301                 | add                 eax, dword ptr [ecx]
            //   8945e0               | mov                 dword ptr [ebp - 0x20], eax
            //   e8????????           |                     
            //   8b55e8               | mov                 edx, dword ptr [ebp - 0x18]

        $sequence_5 = { 0302 8945dc 8b45dc 83c002 }
            // n = 4, score = 200
            //   0302                 | add                 eax, dword ptr [edx]
            //   8945dc               | mov                 dword ptr [ebp - 0x24], eax
            //   8b45dc               | mov                 eax, dword ptr [ebp - 0x24]
            //   83c002               | add                 eax, 2

        $sequence_6 = { 6a00 6a04 6a01 68000000c0 }
            // n = 4, score = 200
            //   6a00                 | push                0
            //   6a04                 | push                4
            //   6a01                 | push                1
            //   68000000c0           | push                0xc0000000

        $sequence_7 = { 0100 83c414 85c0 7502 eb0a }
            // n = 5, score = 200
            //   0100                 | add                 dword ptr [eax], eax
            //   83c414               | add                 esp, 0x14
            //   85c0                 | test                eax, eax
            //   7502                 | jne                 4
            //   eb0a                 | jmp                 0xc

        $sequence_8 = { 89e5 ff7508 ed 2e5c 034508 }
            // n = 5, score = 100
            //   89e5                 | mov                 ebp, esp
            //   ff7508               | push                dword ptr [ebp + 8]
            //   ed                   | in                  eax, dx
            //   2e5c                 | pop                 esp
            //   034508               | add                 eax, dword ptr [ebp + 8]

        $sequence_9 = { 48 8b7c2428 48 39f7 7413 fc }
            // n = 6, score = 100
            //   48                   | dec                 eax
            //   8b7c2428             | mov                 edi, dword ptr [esp + 0x28]
            //   48                   | dec                 eax
            //   39f7                 | cmp                 edi, esi
            //   7413                 | je                  0x15
            //   fc                   | cld                 

        $sequence_10 = { 49 8b4c2408 ffd0 48 }
            // n = 4, score = 100
            //   49                   | dec                 ecx
            //   8b4c2408             | mov                 ecx, dword ptr [esp + 8]
            //   ffd0                 | call                eax
            //   48                   | dec                 eax

        $sequence_11 = { d16000 d0806200a501 40 00b070e000e0 31e0 00d5 31c0 }
            // n = 7, score = 100
            //   d16000               | shl                 dword ptr [eax], 1
            //   d0806200a501         | rol                 byte ptr [eax + 0x1a50062], 1
            //   40                   | inc                 eax
            //   00b070e000e0         | add                 byte ptr [eax - 0x1fff1f90], dh
            //   31e0                 | xor                 eax, esp
            //   00d5                 | add                 ch, dl
            //   31c0                 | xor                 eax, eax

        $sequence_12 = { 880424 49 89442430 49 89742458 66813e4d5a }
            // n = 6, score = 100
            //   880424               | mov                 byte ptr [esp], al
            //   49                   | dec                 ecx
            //   89442430             | mov                 dword ptr [esp + 0x30], eax
            //   49                   | dec                 ecx
            //   89742458             | mov                 dword ptr [esp + 0x58], esi
            //   66813e4d5a           | cmp                 word ptr [esi], 0x5a4d

        $sequence_13 = { 50 51 52 48 }
            // n = 4, score = 100
            //   50                   | push                eax
            //   51                   | push                ecx
            //   52                   | push                edx
            //   48                   | dec                 eax

        $sequence_14 = { c20800 55 89e5 ff750c ed }
            // n = 5, score = 100
            //   c20800               | ret                 8
            //   55                   | push                ebp
            //   89e5                 | mov                 ebp, esp
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   ed                   | in                  eax, dx

        $sequence_15 = { 89e5 60 8b7d08 6887000000 ed }
            // n = 5, score = 100
            //   89e5                 | mov                 ebp, esp
            //   60                   | pushal              
            //   8b7d08               | mov                 edi, dword ptr [ebp + 8]
            //   6887000000           | push                0x87
            //   ed                   | in                  eax, dx

    condition:
        7 of them and filesize < 1761280
}