rule win_mokes_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.mokes."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.mokes"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { f6c101 0f85b0000000 8b442424 8b00 3d???????? 0f849f000000 8b4804 }
            // n = 7, score = 400
            //   f6c101               | test                cl, 1
            //   0f85b0000000         | jne                 0xb6
            //   8b442424             | mov                 eax, dword ptr [esp + 0x24]
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   3d????????           |                     
            //   0f849f000000         | je                  0xa5
            //   8b4804               | mov                 ecx, dword ptr [eax + 4]

        $sequence_1 = { f20f1001 660f2fc1 0f28c3 f20f5cc7 0f47c1 f20f1008 f20f59c2 }
            // n = 7, score = 400
            //   f20f1001             | movsd               xmm0, qword ptr [ecx]
            //   660f2fc1             | comisd              xmm0, xmm1
            //   0f28c3               | movaps              xmm0, xmm3
            //   f20f5cc7             | subsd               xmm0, xmm7
            //   0f47c1               | cmova               eax, ecx
            //   f20f1008             | movsd               xmm1, qword ptr [eax]
            //   f20f59c2             | mulsd               xmm0, xmm2

        $sequence_2 = { ff9050010000 8b8bac010000 8d83ac010000 89442424 85c9 740b 83790400 }
            // n = 7, score = 400
            //   ff9050010000         | call                dword ptr [eax + 0x150]
            //   8b8bac010000         | mov                 ecx, dword ptr [ebx + 0x1ac]
            //   8d83ac010000         | lea                 eax, [ebx + 0x1ac]
            //   89442424             | mov                 dword ptr [esp + 0x24], eax
            //   85c9                 | test                ecx, ecx
            //   740b                 | je                  0xd
            //   83790400             | cmp                 dword ptr [ecx + 4], 0

        $sequence_3 = { ff5030 89442410 83f8ff 7512 8b4508 c700???????? 5f }
            // n = 7, score = 400
            //   ff5030               | call                dword ptr [eax + 0x30]
            //   89442410             | mov                 dword ptr [esp + 0x10], eax
            //   83f8ff               | cmp                 eax, -1
            //   7512                 | jne                 0x14
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   c700????????         |                     
            //   5f                   | pop                 edi

        $sequence_4 = { f20f1025???????? f30fe6db f30fe6d2 f30fe6c9 f30fe6c0 f20f59dc f20f59d4 }
            // n = 7, score = 400
            //   f20f1025????????     |                     
            //   f30fe6db             | cvtdq2pd            xmm3, xmm3
            //   f30fe6d2             | cvtdq2pd            xmm2, xmm2
            //   f30fe6c9             | cvtdq2pd            xmm1, xmm1
            //   f30fe6c0             | cvtdq2pd            xmm0, xmm0
            //   f20f59dc             | mulsd               xmm3, xmm4
            //   f20f59d4             | mulsd               xmm2, xmm4

        $sequence_5 = { ffd0 8d4900 3d???????? 0f84cb000000 8b00 85c0 75ef }
            // n = 7, score = 400
            //   ffd0                 | call                eax
            //   8d4900               | lea                 ecx, [ecx]
            //   3d????????           |                     
            //   0f84cb000000         | je                  0xd1
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   85c0                 | test                eax, eax
            //   75ef                 | jne                 0xfffffff1

        $sequence_6 = { e8???????? 8d4e14 e8???????? 8d4e34 e8???????? 5f 5e }
            // n = 7, score = 400
            //   e8????????           |                     
            //   8d4e14               | lea                 ecx, [esi + 0x14]
            //   e8????????           |                     
            //   8d4e34               | lea                 ecx, [esi + 0x34]
            //   e8????????           |                     
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi

        $sequence_7 = { ff750c c70000000000 e8???????? 8b4508 8bce c706???????? c74608???????? }
            // n = 7, score = 400
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   c70000000000         | mov                 dword ptr [eax], 0
            //   e8????????           |                     
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   8bce                 | mov                 ecx, esi
            //   c706????????         |                     
            //   c74608????????       |                     

        $sequence_8 = { e8???????? 8b75e4 8b4e0c 03ce 8b4604 8d0445feffffff 50 }
            // n = 7, score = 400
            //   e8????????           |                     
            //   8b75e4               | mov                 esi, dword ptr [ebp - 0x1c]
            //   8b4e0c               | mov                 ecx, dword ptr [esi + 0xc]
            //   03ce                 | add                 ecx, esi
            //   8b4604               | mov                 eax, dword ptr [esi + 4]
            //   8d0445feffffff       | lea                 eax, [eax*2 - 2]
            //   50                   | push                eax

        $sequence_9 = { f20f1005???????? 660f2fc1 0f82ac010000 f20f108e88000000 f20f109690000000 f20f5c9680000000 f20f5c4e78 }
            // n = 7, score = 400
            //   f20f1005????????     |                     
            //   660f2fc1             | comisd              xmm0, xmm1
            //   0f82ac010000         | jb                  0x1b2
            //   f20f108e88000000     | movsd               xmm1, qword ptr [esi + 0x88]
            //   f20f109690000000     | movsd               xmm2, qword ptr [esi + 0x90]
            //   f20f5c9680000000     | subsd               xmm2, qword ptr [esi + 0x80]
            //   f20f5c4e78           | subsd               xmm1, qword ptr [esi + 0x78]

    condition:
        7 of them and filesize < 18505728
}