rule win_mongall_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.mongall."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.mongall"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ff15???????? 8b400c 8b08 8b11 52 ff15???????? ba???????? }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   8b400c               | mov                 eax, dword ptr [eax + 0xc]
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   8b11                 | mov                 edx, dword ptr [ecx]
            //   52                   | push                edx
            //   ff15????????         |                     
            //   ba????????           |                     

        $sequence_1 = { 85ff 747c 56 57 68???????? e8???????? 68???????? }
            // n = 7, score = 100
            //   85ff                 | test                edi, edi
            //   747c                 | je                  0x7e
            //   56                   | push                esi
            //   57                   | push                edi
            //   68????????           |                     
            //   e8????????           |                     
            //   68????????           |                     

        $sequence_2 = { f3a5 8bc8 8b8500d9ffff 83e103 43 }
            // n = 5, score = 100
            //   f3a5                 | rep movsd           dword ptr es:[edi], dword ptr [esi]
            //   8bc8                 | mov                 ecx, eax
            //   8b8500d9ffff         | mov                 eax, dword ptr [ebp - 0x2700]
            //   83e103               | and                 ecx, 3
            //   43                   | inc                 ebx

        $sequence_3 = { 59 8985a0fdffff 3bc1 0f87cb090000 ff2485e6574000 838de8fdffffff 89b594fdffff }
            // n = 7, score = 100
            //   59                   | pop                 ecx
            //   8985a0fdffff         | mov                 dword ptr [ebp - 0x260], eax
            //   3bc1                 | cmp                 eax, ecx
            //   0f87cb090000         | ja                  0x9d1
            //   ff2485e6574000       | jmp                 dword ptr [eax*4 + 0x4057e6]
            //   838de8fdffffff       | or                  dword ptr [ebp - 0x218], 0xffffffff
            //   89b594fdffff         | mov                 dword ptr [ebp - 0x26c], esi

        $sequence_4 = { 8bd8 83fbff 7448 68???????? e8???????? }
            // n = 5, score = 100
            //   8bd8                 | mov                 ebx, eax
            //   83fbff               | cmp                 ebx, -1
            //   7448                 | je                  0x4a
            //   68????????           |                     
            //   e8????????           |                     

        $sequence_5 = { e8???????? 8bfc 85ff 741d 8b8df4fdffff 56 }
            // n = 6, score = 100
            //   e8????????           |                     
            //   8bfc                 | mov                 edi, esp
            //   85ff                 | test                edi, edi
            //   741d                 | je                  0x1f
            //   8b8df4fdffff         | mov                 ecx, dword ptr [ebp - 0x20c]
            //   56                   | push                esi

        $sequence_6 = { 56 8d45f0 33f6 50 8935???????? 8935???????? ff15???????? }
            // n = 7, score = 100
            //   56                   | push                esi
            //   8d45f0               | lea                 eax, [ebp - 0x10]
            //   33f6                 | xor                 esi, esi
            //   50                   | push                eax
            //   8935????????         |                     
            //   8935????????         |                     
            //   ff15????????         |                     

        $sequence_7 = { 8b7df0 8bc7 5f 5e c60300 }
            // n = 5, score = 100
            //   8b7df0               | mov                 edi, dword ptr [ebp - 0x10]
            //   8bc7                 | mov                 eax, edi
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   c60300               | mov                 byte ptr [ebx], 0

        $sequence_8 = { 89b5e4fdffff 89b5e0fdffff 89b5c0fdffff 888deffdffff }
            // n = 4, score = 100
            //   89b5e4fdffff         | mov                 dword ptr [ebp - 0x21c], esi
            //   89b5e0fdffff         | mov                 dword ptr [ebp - 0x220], esi
            //   89b5c0fdffff         | mov                 dword ptr [ebp - 0x240], esi
            //   888deffdffff         | mov                 byte ptr [ebp - 0x211], cl

        $sequence_9 = { 85f6 5e 741d 8d85f8feffff }
            // n = 4, score = 100
            //   85f6                 | test                esi, esi
            //   5e                   | pop                 esi
            //   741d                 | je                  0x1f
            //   8d85f8feffff         | lea                 eax, [ebp - 0x108]

    condition:
        7 of them and filesize < 199680
}