rule win_mortalkombat_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.mortalkombat."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.mortalkombat"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 33d2 ad 3382b96d4000 ab 83c204 }
            // n = 5, score = 100
            //   33d2                 | xor                 edx, edx
            //   ad                   | lodsd               eax, dword ptr [esi]
            //   3382b96d4000         | xor                 eax, dword ptr [edx + 0x406db9]
            //   ab                   | stosd               dword ptr es:[edi], eax
            //   83c204               | add                 edx, 4

        $sequence_1 = { 6a00 6803800000 ff75fc e8???????? 83f800 7e35 6a00 }
            // n = 7, score = 100
            //   6a00                 | push                0
            //   6803800000           | push                0x8003
            //   ff75fc               | push                dword ptr [ebp - 4]
            //   e8????????           |                     
            //   83f800               | cmp                 eax, 0
            //   7e35                 | jle                 0x37
            //   6a00                 | push                0

        $sequence_2 = { 2bc1 81ebb979379e 8bc8 c1e104 }
            // n = 4, score = 100
            //   2bc1                 | sub                 eax, ecx
            //   81ebb979379e         | sub                 ebx, 0x9e3779b9
            //   8bc8                 | mov                 ecx, eax
            //   c1e104               | shl                 ecx, 4

        $sequence_3 = { 83f8ff 7402 eb67 6a00 6a00 6a02 }
            // n = 6, score = 100
            //   83f8ff               | cmp                 eax, -1
            //   7402                 | je                  4
            //   eb67                 | jmp                 0x69
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   6a02                 | push                2

        $sequence_4 = { e8???????? 50 ff75ac e8???????? 8945a4 33c0 50 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   50                   | push                eax
            //   ff75ac               | push                dword ptr [ebp - 0x54]
            //   e8????????           |                     
            //   8945a4               | mov                 dword ptr [ebp - 0x5c], eax
            //   33c0                 | xor                 eax, eax
            //   50                   | push                eax

        $sequence_5 = { 803d????????01 7519 68???????? 68???????? 68???????? }
            // n = 5, score = 100
            //   803d????????01       |                     
            //   7519                 | jne                 0x1b
            //   68????????           |                     
            //   68????????           |                     
            //   68????????           |                     

        $sequence_6 = { c705????????f4010000 68???????? e8???????? a3???????? a0???????? }
            // n = 5, score = 100
            //   c705????????f4010000     |     
            //   68????????           |                     
            //   e8????????           |                     
            //   a3????????           |                     
            //   a0????????           |                     

        $sequence_7 = { ff7514 6a01 6a00 ff7510 ff75f8 }
            // n = 5, score = 100
            //   ff7514               | push                dword ptr [ebp + 0x14]
            //   6a01                 | push                1
            //   6a00                 | push                0
            //   ff7510               | push                dword ptr [ebp + 0x10]
            //   ff75f8               | push                dword ptr [ebp - 8]

        $sequence_8 = { 68???????? e8???????? 83c710 6a10 }
            // n = 4, score = 100
            //   68????????           |                     
            //   e8????????           |                     
            //   83c710               | add                 edi, 0x10
            //   6a10                 | push                0x10

        $sequence_9 = { 50 e8???????? ebd8 8b45bc }
            // n = 4, score = 100
            //   50                   | push                eax
            //   e8????????           |                     
            //   ebd8                 | jmp                 0xffffffda
            //   8b45bc               | mov                 eax, dword ptr [ebp - 0x44]

    condition:
        7 of them and filesize < 1224704
}