rule win_mosquito_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.mosquito."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.mosquito"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { f3a5 ff942464020000 81c450020000 85c0 }
            // n = 4, score = 400
            //   f3a5                 | rep movsd           dword ptr es:[edi], dword ptr [esi]
            //   ff942464020000       | call                dword ptr [esp + 0x264]
            //   81c450020000         | add                 esp, 0x250
            //   85c0                 | test                eax, eax

        $sequence_1 = { 52 50 6a00 6801c1fd7d }
            // n = 4, score = 400
            //   52                   | push                edx
            //   50                   | push                eax
            //   6a00                 | push                0
            //   6801c1fd7d           | push                0x7dfdc101

        $sequence_2 = { f7d8 1bc0 83e0b4 83c04c }
            // n = 4, score = 400
            //   f7d8                 | neg                 eax
            //   1bc0                 | sbb                 eax, eax
            //   83e0b4               | and                 eax, 0xffffffb4
            //   83c04c               | add                 eax, 0x4c

        $sequence_3 = { 8b10 8bc8 57 6842730000 ff5204 56 }
            // n = 6, score = 300
            //   8b10                 | mov                 edx, dword ptr [eax]
            //   8bc8                 | mov                 ecx, eax
            //   57                   | push                edi
            //   6842730000           | push                0x7342
            //   ff5204               | call                dword ptr [edx + 4]
            //   56                   | push                esi

        $sequence_4 = { b994000000 8bfc f3a5 ff942464020000 }
            // n = 4, score = 300
            //   b994000000           | mov                 ecx, 0x94
            //   8bfc                 | mov                 edi, esp
            //   f3a5                 | rep movsd           dword ptr es:[edi], dword ptr [esi]
            //   ff942464020000       | call                dword ptr [esp + 0x264]

        $sequence_5 = { 8b10 8bc8 ff5204 56 }
            // n = 4, score = 300
            //   8b10                 | mov                 edx, dword ptr [eax]
            //   8bc8                 | mov                 ecx, eax
            //   ff5204               | call                dword ptr [edx + 4]
            //   56                   | push                esi

        $sequence_6 = { e8???????? 85c0 7517 8bcb e8???????? 8b7328 }
            // n = 6, score = 300
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   7517                 | jne                 0x19
            //   8bcb                 | mov                 ecx, ebx
            //   e8????????           |                     
            //   8b7328               | mov                 esi, dword ptr [ebx + 0x28]

        $sequence_7 = { e8???????? 6a20 e8???????? 83c40c }
            // n = 4, score = 300
            //   e8????????           |                     
            //   6a20                 | push                0x20
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc

        $sequence_8 = { 8b00 33ff 57 6880000000 6a03 57 }
            // n = 6, score = 300
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   33ff                 | xor                 edi, edi
            //   57                   | push                edi
            //   6880000000           | push                0x80
            //   6a03                 | push                3
            //   57                   | push                edi

        $sequence_9 = { e8???????? 6a20 8bf0 e8???????? 8bc8 }
            // n = 5, score = 300
            //   e8????????           |                     
            //   6a20                 | push                0x20
            //   8bf0                 | mov                 esi, eax
            //   e8????????           |                     
            //   8bc8                 | mov                 ecx, eax

        $sequence_10 = { 8bfc f3a5 ff942460020000 81c450020000 }
            // n = 4, score = 300
            //   8bfc                 | mov                 edi, esp
            //   f3a5                 | rep movsd           dword ptr es:[edi], dword ptr [esi]
            //   ff942460020000       | call                dword ptr [esp + 0x260]
            //   81c450020000         | add                 esp, 0x250

        $sequence_11 = { 6824080000 50 e8???????? 83c410 }
            // n = 4, score = 200
            //   6824080000           | push                0x824
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10

        $sequence_12 = { 0000 006301 1000 7500 }
            // n = 4, score = 200
            //   0000                 | add                 byte ptr [eax], al
            //   006301               | add                 byte ptr [ebx + 1], ah
            //   1000                 | adc                 byte ptr [eax], al
            //   7500                 | jne                 2

        $sequence_13 = { 0000 0018 a0???????? 57 }
            // n = 4, score = 200
            //   0000                 | add                 byte ptr [eax], al
            //   0018                 | add                 byte ptr [eax], bl
            //   a0????????           |                     
            //   57                   | push                edi

        $sequence_14 = { 0000 0001 1001 c550f0 8b8078005900 }
            // n = 5, score = 200
            //   0000                 | add                 byte ptr [eax], al
            //   0001                 | add                 byte ptr [ecx], al
            //   1001                 | adc                 byte ptr [ecx], al
            //   c550f0               | lds                 edx, ptr [eax - 0x10]
            //   8b8078005900         | mov                 eax, dword ptr [eax + 0x590078]

        $sequence_15 = { 0000 0032 08804d086440 5e }
            // n = 4, score = 200
            //   0000                 | add                 byte ptr [eax], al
            //   0032                 | add                 byte ptr [edx], dh
            //   08804d086440         | or                  byte ptr [eax + 0x4064084d], al
            //   5e                   | pop                 esi

        $sequence_16 = { 0000 00645657 8b7dc2 0400 }
            // n = 4, score = 200
            //   0000                 | add                 byte ptr [eax], al
            //   00645657             | add                 byte ptr [esi + edx*2 + 0x57], ah
            //   8b7dc2               | mov                 edi, dword ptr [ebp - 0x3e]
            //   0400                 | add                 al, 0

        $sequence_17 = { 0000 006500 676c 0010 }
            // n = 4, score = 200
            //   0000                 | add                 byte ptr [eax], al
            //   006500               | add                 byte ptr [ebp], ah
            //   676c                 | insb                byte ptr es:[di], dx
            //   0010                 | add                 byte ptr [eax], dl

        $sequence_18 = { ff15???????? 6a00 56 ff15???????? 8903 83f8ff }
            // n = 6, score = 200
            //   ff15????????         |                     
            //   6a00                 | push                0
            //   56                   | push                esi
            //   ff15????????         |                     
            //   8903                 | mov                 dword ptr [ebx], eax
            //   83f8ff               | cmp                 eax, -1

        $sequence_19 = { 0000 00748078 3001 40 }
            // n = 4, score = 200
            //   0000                 | add                 byte ptr [eax], al
            //   00748078             | add                 byte ptr [eax + eax*4 + 0x78], dh
            //   3001                 | xor                 byte ptr [ecx], al
            //   40                   | inc                 eax

        $sequence_20 = { 6aff 5d c28bcf 7300 6a01 }
            // n = 5, score = 200
            //   6aff                 | push                -1
            //   5d                   | pop                 ebp
            //   c28bcf               | ret                 0xcf8b
            //   7300                 | jae                 2
            //   6a01                 | push                1

    condition:
        7 of them and filesize < 1015808
}