rule win_mount_locker_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.mount_locker."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.mount_locker"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 81f900000780 7503 0fb7c0 3d2e050000 }
            // n = 4, score = 500
            //   81f900000780         | mov                 ecx, 2
            //   7503                 | inc                 ebp
            //   0fb7c0               | xor                 eax, eax
            //   3d2e050000           | xor                 edx, edx

        $sequence_1 = { f30f5905???????? 0f5ad0 66490f7ed0 e8???????? }
            // n = 4, score = 500
            //   f30f5905????????     |                     
            //   0f5ad0               | dec                 ebp
            //   66490f7ed0           | mov                 ecx, eax
            //   e8????????           |                     

        $sequence_2 = { 4d8bc8 4c8bc2 4c8bf2 8bf1 }
            // n = 4, score = 500
            //   4d8bc8               | dec                 eax
            //   4c8bc2               | mov                 ecx, ebx
            //   4c8bf2               | dec                 ecx
            //   8bf1                 | mov                 ebp, eax

        $sequence_3 = { 8bc8 81e10000ffff 81f900000780 7503 }
            // n = 4, score = 500
            //   8bc8                 | dec                 ebp
            //   81e10000ffff         | mov                 ecx, eax
            //   81f900000780         | dec                 esp
            //   7503                 | mov                 eax, edx

        $sequence_4 = { 488b0b 41b902000000 4533c0 33d2 }
            // n = 4, score = 500
            //   488b0b               | dec                 ebp
            //   41b902000000         | mov                 ecx, eax
            //   4533c0               | dec                 esp
            //   33d2                 | mov                 eax, edx

        $sequence_5 = { 488d4df0 4889442428 4533c9 4533c0 }
            // n = 4, score = 500
            //   488d4df0             | inc                 ebp
            //   4889442428           | xor                 eax, eax
            //   4533c9               | xor                 edx, edx
            //   4533c0               | dec                 ecx

        $sequence_6 = { 488bcb 488b15???????? e8???????? 85c0 }
            // n = 4, score = 500
            //   488bcb               | dec                 eax
            //   488b15????????       |                     
            //   e8????????           |                     
            //   85c0                 | mov                 ecx, ebx

        $sequence_7 = { 488364242000 4533c9 488b4c2458 33d2 c744243001000000 c744243c02000000 }
            // n = 6, score = 500
            //   488364242000         | test                eax, eax
            //   4533c9               | dec                 eax
            //   488b4c2458           | and                 dword ptr [esp + 0x20], 0
            //   33d2                 | inc                 ebp
            //   c744243001000000     | xor                 ecx, ecx
            //   c744243c02000000     | dec                 eax

        $sequence_8 = { 4c8bf2 8bf1 33d2 33c9 }
            // n = 4, score = 500
            //   4c8bf2               | mov                 ecx, dword ptr [esp + 0x58]
            //   8bf1                 | xor                 edx, edx
            //   33d2                 | mov                 dword ptr [esp + 0x30], 1
            //   33c9                 | mov                 dword ptr [esp + 0x3c], 2

        $sequence_9 = { ff15???????? 85c0 7509 f0ff05???????? }
            // n = 4, score = 300
            //   ff15????????         |                     
            //   85c0                 | mov                 eax, edx
            //   7509                 | dec                 esp
            //   f0ff05????????       |                     

        $sequence_10 = { b905000000 ff15???????? 3d040000c0 7494 85c0 }
            // n = 5, score = 300
            //   b905000000           | xor                 edx, edx
            //   ff15????????         |                     
            //   3d040000c0           | mov                 dword ptr [esp + 0x30], 1
            //   7494                 | dec                 ecx
            //   85c0                 | mov                 ebp, eax

        $sequence_11 = { 7505 e8???????? 833d????????00 7409 833d????????00 }
            // n = 5, score = 300
            //   7505                 | mov                 dword ptr [esp + 0x30], 1
            //   e8????????           |                     
            //   833d????????00       |                     
            //   7409                 | mov                 dword ptr [esp + 0x3c], 2
            //   833d????????00       |                     

        $sequence_12 = { 8d442430 68???????? 50 ffd7 }
            // n = 4, score = 100
            //   8d442430             | xor                 ecx, ecx
            //   68????????           |                     
            //   50                   | dec                 eax
            //   ffd7                 | and                 dword ptr [esp + 0x20], 0

        $sequence_13 = { a1???????? 83f804 7515 68???????? }
            // n = 4, score = 100
            //   a1????????           |                     
            //   83f804               | inc                 ebp
            //   7515                 | xor                 ecx, ecx
            //   68????????           |                     

        $sequence_14 = { 8bf0 85f6 7424 6800010000 }
            // n = 4, score = 100
            //   8bf0                 | dec                 eax
            //   85f6                 | mov                 ecx, dword ptr [esp + 0x58]
            //   7424                 | xor                 edx, edx
            //   6800010000           | mov                 dword ptr [esp + 0x30], 1

        $sequence_15 = { ff15???????? 85c0 7409 f0ff05???????? eb1e 56 }
            // n = 6, score = 100
            //   ff15????????         |                     
            //   85c0                 | dec                 esp
            //   7409                 | mov                 esi, edx
            //   f0ff05????????       |                     
            //   eb1e                 | mov                 esi, ecx
            //   56                   | xor                 edx, edx

    condition:
        7 of them and filesize < 368640
}