rule win_multigrain_pos_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.multigrain_pos."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.multigrain_pos"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c745fc00000000 8b7518 b8cdcccccc 8d0cf504000000 }
            // n = 4, score = 200
            //   c745fc00000000       | mov                 dword ptr [ebp - 4], 0
            //   8b7518               | mov                 esi, dword ptr [ebp + 0x18]
            //   b8cdcccccc           | mov                 eax, 0xcccccccd
            //   8d0cf504000000       | lea                 ecx, [esi*8 + 4]

        $sequence_1 = { 57 e8???????? 83c404 6a00 c746140f000000 }
            // n = 5, score = 200
            //   57                   | push                edi
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   6a00                 | push                0
            //   c746140f000000       | mov                 dword ptr [esi + 0x14], 0xf

        $sequence_2 = { c645fc01 e8???????? 83c408 83bdb4fdffff08 720e ffb5a0fdffff }
            // n = 6, score = 200
            //   c645fc01             | mov                 byte ptr [ebp - 4], 1
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   83bdb4fdffff08       | cmp                 dword ptr [ebp - 0x24c], 8
            //   720e                 | jb                  0x10
            //   ffb5a0fdffff         | push                dword ptr [ebp - 0x260]

        $sequence_3 = { 0f8530020000 68c8000000 50 8d85c4feffff 50 e8???????? 83c40c }
            // n = 7, score = 200
            //   0f8530020000         | jne                 0x236
            //   68c8000000           | push                0xc8
            //   50                   | push                eax
            //   8d85c4feffff         | lea                 eax, [ebp - 0x13c]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc

        $sequence_4 = { 0fb64c1e01 c1e905 894df4 eb07 c745f400000000 0fb60c1e 8b55f8 }
            // n = 7, score = 200
            //   0fb64c1e01           | movzx               ecx, byte ptr [esi + ebx + 1]
            //   c1e905               | shr                 ecx, 5
            //   894df4               | mov                 dword ptr [ebp - 0xc], ecx
            //   eb07                 | jmp                 9
            //   c745f400000000       | mov                 dword ptr [ebp - 0xc], 0
            //   0fb60c1e             | movzx               ecx, byte ptr [esi + ebx]
            //   8b55f8               | mov                 edx, dword ptr [ebp - 8]

        $sequence_5 = { 8bd0 8d4dd8 c645fc03 e8???????? }
            // n = 4, score = 200
            //   8bd0                 | mov                 edx, eax
            //   8d4dd8               | lea                 ecx, [ebp - 0x28]
            //   c645fc03             | mov                 byte ptr [ebp - 4], 3
            //   e8????????           |                     

        $sequence_6 = { c745e0ffffffff c745e800000000 c745e400000000 c745ec01000000 c745f401000000 }
            // n = 5, score = 200
            //   c745e0ffffffff       | mov                 dword ptr [ebp - 0x20], 0xffffffff
            //   c745e800000000       | mov                 dword ptr [ebp - 0x18], 0
            //   c745e400000000       | mov                 dword ptr [ebp - 0x1c], 0
            //   c745ec01000000       | mov                 dword ptr [ebp - 0x14], 1
            //   c745f401000000       | mov                 dword ptr [ebp - 0xc], 1

        $sequence_7 = { e8???????? 83c404 56 ffd3 33db 395f10 56 }
            // n = 7, score = 200
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   56                   | push                esi
            //   ffd3                 | call                ebx
            //   33db                 | xor                 ebx, ebx
            //   395f10               | cmp                 dword ptr [edi + 0x10], ebx
            //   56                   | push                esi

        $sequence_8 = { 81eca8040000 a1???????? 33c4 898424a4040000 56 57 }
            // n = 6, score = 200
            //   81eca8040000         | sub                 esp, 0x4a8
            //   a1????????           |                     
            //   33c4                 | xor                 eax, esp
            //   898424a4040000       | mov                 dword ptr [esp + 0x4a4], eax
            //   56                   | push                esi
            //   57                   | push                edi

        $sequence_9 = { c745f400000000 8b4df0 8b5df8 0fb609 83e101 }
            // n = 5, score = 200
            //   c745f400000000       | mov                 dword ptr [ebp - 0xc], 0
            //   8b4df0               | mov                 ecx, dword ptr [ebp - 0x10]
            //   8b5df8               | mov                 ebx, dword ptr [ebp - 8]
            //   0fb609               | movzx               ecx, byte ptr [ecx]
            //   83e101               | and                 ecx, 1

    condition:
        7 of them and filesize < 286720
}