rule win_mutabaha_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.mutabaha."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.mutabaha"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 50 8d9518ffffff 8d8d68feffff e8???????? 8d8d48ffffff c645fc09 }
            // n = 6, score = 100
            //   50                   | push                eax
            //   8d9518ffffff         | lea                 edx, [ebp - 0xe8]
            //   8d8d68feffff         | lea                 ecx, [ebp - 0x198]
            //   e8????????           |                     
            //   8d8d48ffffff         | lea                 ecx, [ebp - 0xb8]
            //   c645fc09             | mov                 byte ptr [ebp - 4], 9

        $sequence_1 = { 8b85dcfdffff 83f808 7213 40 8d8dc8fdffff 50 ffb5c8fdffff }
            // n = 7, score = 100
            //   8b85dcfdffff         | mov                 eax, dword ptr [ebp - 0x224]
            //   83f808               | cmp                 eax, 8
            //   7213                 | jb                  0x15
            //   40                   | inc                 eax
            //   8d8dc8fdffff         | lea                 ecx, [ebp - 0x238]
            //   50                   | push                eax
            //   ffb5c8fdffff         | push                dword ptr [ebp - 0x238]

        $sequence_2 = { c745b800000000 c645a800 c745c06cac4700 85c0 7409 50 e8???????? }
            // n = 7, score = 100
            //   c745b800000000       | mov                 dword ptr [ebp - 0x48], 0
            //   c645a800             | mov                 byte ptr [ebp - 0x58], 0
            //   c745c06cac4700       | mov                 dword ptr [ebp - 0x40], 0x47ac6c
            //   85c0                 | test                eax, eax
            //   7409                 | je                  0xb
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_3 = { 85d2 7424 8b7c2424 8d4f08 833900 740a 40 }
            // n = 7, score = 100
            //   85d2                 | test                edx, edx
            //   7424                 | je                  0x26
            //   8b7c2424             | mov                 edi, dword ptr [esp + 0x24]
            //   8d4f08               | lea                 ecx, [edi + 8]
            //   833900               | cmp                 dword ptr [ecx], 0
            //   740a                 | je                  0xc
            //   40                   | inc                 eax

        $sequence_4 = { 0fb7f8 eb43 83f803 7536 ff734c ff75d4 e8???????? }
            // n = 7, score = 100
            //   0fb7f8               | movzx               edi, ax
            //   eb43                 | jmp                 0x45
            //   83f803               | cmp                 eax, 3
            //   7536                 | jne                 0x38
            //   ff734c               | push                dword ptr [ebx + 0x4c]
            //   ff75d4               | push                dword ptr [ebp - 0x2c]
            //   e8????????           |                     

        $sequence_5 = { c745ec00000000 668945dc e8???????? 8d45dc c745fc05000000 50 8bce }
            // n = 7, score = 100
            //   c745ec00000000       | mov                 dword ptr [ebp - 0x14], 0
            //   668945dc             | mov                 word ptr [ebp - 0x24], ax
            //   e8????????           |                     
            //   8d45dc               | lea                 eax, [ebp - 0x24]
            //   c745fc05000000       | mov                 dword ptr [ebp - 4], 5
            //   50                   | push                eax
            //   8bce                 | mov                 ecx, esi

        $sequence_6 = { e8???????? c7465400000000 8bc6 8b4df4 64890d00000000 59 5e }
            // n = 7, score = 100
            //   e8????????           |                     
            //   c7465400000000       | mov                 dword ptr [esi + 0x54], 0
            //   8bc6                 | mov                 eax, esi
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]
            //   64890d00000000       | mov                 dword ptr fs:[0], ecx
            //   59                   | pop                 ecx
            //   5e                   | pop                 esi

        $sequence_7 = { 8d8d84fdffff c78598fdffff07000000 c78594fdffff00000000 66898584fdffff e8???????? 57 ba???????? }
            // n = 7, score = 100
            //   8d8d84fdffff         | lea                 ecx, [ebp - 0x27c]
            //   c78598fdffff07000000     | mov    dword ptr [ebp - 0x268], 7
            //   c78594fdffff00000000     | mov    dword ptr [ebp - 0x26c], 0
            //   66898584fdffff       | mov                 word ptr [ebp - 0x27c], ax
            //   e8????????           |                     
            //   57                   | push                edi
            //   ba????????           |                     

        $sequence_8 = { 0103 115304 33c0 5f 5e 5b 8be5 }
            // n = 7, score = 100
            //   0103                 | add                 dword ptr [ebx], eax
            //   115304               | adc                 dword ptr [ebx + 4], edx
            //   33c0                 | xor                 eax, eax
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx
            //   8be5                 | mov                 esp, ebp

        $sequence_9 = { e9???????? 8d8d5cffffff e9???????? 8d4dbc e9???????? 8d4dd4 e9???????? }
            // n = 7, score = 100
            //   e9????????           |                     
            //   8d8d5cffffff         | lea                 ecx, [ebp - 0xa4]
            //   e9????????           |                     
            //   8d4dbc               | lea                 ecx, [ebp - 0x44]
            //   e9????????           |                     
            //   8d4dd4               | lea                 ecx, [ebp - 0x2c]
            //   e9????????           |                     

    condition:
        7 of them and filesize < 1220608
}