rule win_nefilim_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.nefilim."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.nefilim"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { be00010000 56 e8???????? 56 8944244c }
            // n = 5, score = 200
            //   be00010000           | mov                 esi, 0x100
            //   56                   | push                esi
            //   e8????????           |                     
            //   56                   | push                esi
            //   8944244c             | mov                 dword ptr [esp + 0x4c], eax

        $sequence_1 = { 8945e4 3d00010000 7d10 8a8c181d010000 8888c0e64000 40 }
            // n = 6, score = 200
            //   8945e4               | mov                 dword ptr [ebp - 0x1c], eax
            //   3d00010000           | cmp                 eax, 0x100
            //   7d10                 | jge                 0x12
            //   8a8c181d010000       | mov                 cl, byte ptr [eax + ebx + 0x11d]
            //   8888c0e64000         | mov                 byte ptr [eax + 0x40e6c0], cl
            //   40                   | inc                 eax

        $sequence_2 = { c1f802 6bc003 50 6a00 ff15???????? 50 }
            // n = 6, score = 200
            //   c1f802               | sar                 eax, 2
            //   6bc003               | imul                eax, eax, 3
            //   50                   | push                eax
            //   6a00                 | push                0
            //   ff15????????         |                     
            //   50                   | push                eax

        $sequence_3 = { 85c0 7506 ff15???????? 8d45d4 50 57 ffd3 }
            // n = 7, score = 200
            //   85c0                 | test                eax, eax
            //   7506                 | jne                 8
            //   ff15????????         |                     
            //   8d45d4               | lea                 eax, [ebp - 0x2c]
            //   50                   | push                eax
            //   57                   | push                edi
            //   ffd3                 | call                ebx

        $sequence_4 = { 397c2428 7304 8d442414 68???????? 50 ffd6 85c0 }
            // n = 7, score = 200
            //   397c2428             | cmp                 dword ptr [esp + 0x28], edi
            //   7304                 | jae                 6
            //   8d442414             | lea                 eax, [esp + 0x14]
            //   68????????           |                     
            //   50                   | push                eax
            //   ffd6                 | call                esi
            //   85c0                 | test                eax, eax

        $sequence_5 = { 50 ffd6 85c0 0f84cf020000 f68424a000000010 8d8424cc000000 }
            // n = 6, score = 200
            //   50                   | push                eax
            //   ffd6                 | call                esi
            //   85c0                 | test                eax, eax
            //   0f84cf020000         | je                  0x2d5
            //   f68424a000000010     | test                byte ptr [esp + 0xa0], 0x10
            //   8d8424cc000000       | lea                 eax, [esp + 0xcc]

        $sequence_6 = { 7421 68???????? 8d442444 e8???????? }
            // n = 4, score = 200
            //   7421                 | je                  0x23
            //   68????????           |                     
            //   8d442444             | lea                 eax, [esp + 0x44]
            //   e8????????           |                     

        $sequence_7 = { 8b3d???????? 8b1d???????? 33c9 8945e4 894de8 8b45e4 d3e8 }
            // n = 7, score = 200
            //   8b3d????????         |                     
            //   8b1d????????         |                     
            //   33c9                 | xor                 ecx, ecx
            //   8945e4               | mov                 dword ptr [ebp - 0x1c], eax
            //   894de8               | mov                 dword ptr [ebp - 0x18], ecx
            //   8b45e4               | mov                 eax, dword ptr [ebp - 0x1c]
            //   d3e8                 | shr                 eax, cl

        $sequence_8 = { 8944244c e8???????? ff74244c 8b542440 89442454 e8???????? }
            // n = 6, score = 200
            //   8944244c             | mov                 dword ptr [esp + 0x4c], eax
            //   e8????????           |                     
            //   ff74244c             | push                dword ptr [esp + 0x4c]
            //   8b542440             | mov                 edx, dword ptr [esp + 0x40]
            //   89442454             | mov                 dword ptr [esp + 0x54], eax
            //   e8????????           |                     

        $sequence_9 = { c745eceb7f4000 894df8 8945fc 64a100000000 8945e8 }
            // n = 5, score = 200
            //   c745eceb7f4000       | mov                 dword ptr [ebp - 0x14], 0x407feb
            //   894df8               | mov                 dword ptr [ebp - 8], ecx
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   64a100000000         | mov                 eax, dword ptr fs:[0]
            //   8945e8               | mov                 dword ptr [ebp - 0x18], eax

    condition:
        7 of them and filesize < 142336
}