rule win_nemim_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.nemim."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.nemim"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { a1???????? c1e002 89b48050744300 8b0d???????? 893d???????? 890d???????? }
            // n = 6, score = 200
            //   a1????????           |                     
            //   c1e002               | shl                 eax, 2
            //   89b48050744300       | mov                 dword ptr [eax + eax*4 + 0x437450], esi
            //   8b0d????????         |                     
            //   893d????????         |                     
            //   890d????????         |                     

        $sequence_1 = { eb3b a1???????? 68???????? 50 e8???????? 83c408 }
            // n = 6, score = 200
            //   eb3b                 | jmp                 0x3d
            //   a1????????           |                     
            //   68????????           |                     
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c408               | add                 esp, 8

        $sequence_2 = { 5e 5b c9 c20400 8bc1 c700???????? c3 }
            // n = 7, score = 200
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx
            //   c9                   | leave               
            //   c20400               | ret                 4
            //   8bc1                 | mov                 eax, ecx
            //   c700????????         |                     
            //   c3                   | ret                 

        $sequence_3 = { 5e 5d b801000000 5b 81c4bc000000 c3 }
            // n = 6, score = 200
            //   5e                   | pop                 esi
            //   5d                   | pop                 ebp
            //   b801000000           | mov                 eax, 1
            //   5b                   | pop                 ebx
            //   81c4bc000000         | add                 esp, 0xbc
            //   c3                   | ret                 

        $sequence_4 = { 8d44240c 55 50 56 c744241828010000 e8???????? 85c0 }
            // n = 7, score = 200
            //   8d44240c             | lea                 eax, [esp + 0xc]
            //   55                   | push                ebp
            //   50                   | push                eax
            //   56                   | push                esi
            //   c744241828010000     | mov                 dword ptr [esp + 0x18], 0x128
            //   e8????????           |                     
            //   85c0                 | test                eax, eax

        $sequence_5 = { 51 e8???????? 8dbc24600a0000 83c9ff 33c0 }
            // n = 5, score = 200
            //   51                   | push                ecx
            //   e8????????           |                     
            //   8dbc24600a0000       | lea                 edi, [esp + 0xa60]
            //   83c9ff               | or                  ecx, 0xffffffff
            //   33c0                 | xor                 eax, eax

        $sequence_6 = { 8b16 c1ea08 885001 8b0e c1e910 }
            // n = 5, score = 200
            //   8b16                 | mov                 edx, dword ptr [esi]
            //   c1ea08               | shr                 edx, 8
            //   885001               | mov                 byte ptr [eax + 1], dl
            //   8b0e                 | mov                 ecx, dword ptr [esi]
            //   c1e910               | shr                 ecx, 0x10

        $sequence_7 = { 52 e8???????? 8b4c2440 8944244c b801000000 }
            // n = 5, score = 200
            //   52                   | push                edx
            //   e8????????           |                     
            //   8b4c2440             | mov                 ecx, dword ptr [esp + 0x40]
            //   8944244c             | mov                 dword ptr [esp + 0x4c], eax
            //   b801000000           | mov                 eax, 1

        $sequence_8 = { 83fe10 7cde c605????????00 b90b000000 be???????? 8dbc2410010000 }
            // n = 6, score = 200
            //   83fe10               | cmp                 esi, 0x10
            //   7cde                 | jl                  0xffffffe0
            //   c605????????00       |                     
            //   b90b000000           | mov                 ecx, 0xb
            //   be????????           |                     
            //   8dbc2410010000       | lea                 edi, [esp + 0x110]

        $sequence_9 = { 8844244c e8???????? 68???????? e8???????? 68???????? 8bf0 }
            // n = 6, score = 200
            //   8844244c             | mov                 byte ptr [esp + 0x4c], al
            //   e8????????           |                     
            //   68????????           |                     
            //   e8????????           |                     
            //   68????????           |                     
            //   8bf0                 | mov                 esi, eax

    condition:
        7 of them and filesize < 499712
}