rule win_nemty_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.nemty."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.nemty"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 51 e8???????? 59 e8???????? 83c438 85c0 }
            // n = 6, score = 300
            //   51                   | push                ecx
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   e8????????           |                     
            //   83c438               | add                 esp, 0x38
            //   85c0                 | test                eax, eax

        $sequence_1 = { 8945a4 a1???????? 59 bf???????? 8bca 83f810 7302 }
            // n = 7, score = 300
            //   8945a4               | mov                 dword ptr [ebp - 0x5c], eax
            //   a1????????           |                     
            //   59                   | pop                 ecx
            //   bf????????           |                     
            //   8bca                 | mov                 ecx, edx
            //   83f810               | cmp                 eax, 0x10
            //   7302                 | jae                 4

        $sequence_2 = { 81ec18040000 a1???????? 33c5 8945fc 837d2010 8b4508 }
            // n = 6, score = 300
            //   81ec18040000         | sub                 esp, 0x418
            //   a1????????           |                     
            //   33c5                 | xor                 eax, ebp
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   837d2010             | cmp                 dword ptr [ebp + 0x20], 0x10
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]

        $sequence_3 = { 83781408 8b4810 57 7202 8b00 8b3d???????? 33db }
            // n = 7, score = 300
            //   83781408             | cmp                 dword ptr [eax + 0x14], 8
            //   8b4810               | mov                 ecx, dword ptr [eax + 0x10]
            //   57                   | push                edi
            //   7202                 | jb                  4
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   8b3d????????         |                     
            //   33db                 | xor                 ebx, ebx

        $sequence_4 = { 6a1c 99 5e f7fe 33db 895dd8 }
            // n = 6, score = 300
            //   6a1c                 | push                0x1c
            //   99                   | cdq                 
            //   5e                   | pop                 esi
            //   f7fe                 | idiv                esi
            //   33db                 | xor                 ebx, ebx
            //   895dd8               | mov                 dword ptr [ebp - 0x28], ebx

        $sequence_5 = { 33ff e8???????? 83c61c 3b7510 75ef 6a00 }
            // n = 6, score = 300
            //   33ff                 | xor                 edi, edi
            //   e8????????           |                     
            //   83c61c               | add                 esi, 0x1c
            //   3b7510               | cmp                 esi, dword ptr [ebp + 0x10]
            //   75ef                 | jne                 0xfffffff1
            //   6a00                 | push                0

        $sequence_6 = { 83ec1c 8bd8 8bc4 68???????? e8???????? }
            // n = 5, score = 300
            //   83ec1c               | sub                 esp, 0x1c
            //   8bd8                 | mov                 ebx, eax
            //   8bc4                 | mov                 eax, esp
            //   68????????           |                     
            //   e8????????           |                     

        $sequence_7 = { 8db4248c000000 e8???????? 53 8d742454 }
            // n = 4, score = 300
            //   8db4248c000000       | lea                 esi, [esp + 0x8c]
            //   e8????????           |                     
            //   53                   | push                ebx
            //   8d742454             | lea                 esi, [esp + 0x54]

        $sequence_8 = { 7509 be???????? 85c0 7405 }
            // n = 4, score = 300
            //   7509                 | jne                 0xb
            //   be????????           |                     
            //   85c0                 | test                eax, eax
            //   7405                 | je                  7

        $sequence_9 = { 837d3810 8bf8 8b4524 59 7303 8d4524 837d3810 }
            // n = 7, score = 300
            //   837d3810             | cmp                 dword ptr [ebp + 0x38], 0x10
            //   8bf8                 | mov                 edi, eax
            //   8b4524               | mov                 eax, dword ptr [ebp + 0x24]
            //   59                   | pop                 ecx
            //   7303                 | jae                 5
            //   8d4524               | lea                 eax, [ebp + 0x24]
            //   837d3810             | cmp                 dword ptr [ebp + 0x38], 0x10

    condition:
        7 of them and filesize < 204800
}