rule win_netspy_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.netspy."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.netspy"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 0f45c8 488b85e8330000 8908 8b15???????? 833d????????0a 0f9cc1 }
            // n = 6, score = 100
            //   0f45c8               | cmovne              ecx, eax
            //   488b85e8330000       | dec                 eax
            //   8908                 | mov                 eax, dword ptr [ebp + 0x33e8]
            //   8b15????????         |                     
            //   833d????????0a       |                     
            //   0f9cc1               | mov                 dword ptr [eax], ecx

        $sequence_1 = { 4989e1 4c898d905b0000 e8???????? 4829c4 488b85f81e0000 4989e1 }
            // n = 6, score = 100
            //   4989e1               | mov                 ecx, dword ptr [ebp - 0x10]
            //   4c898d905b0000       | mov                 eax, 0x10
            //   e8????????           |                     
            //   4829c4               | dec                 eax
            //   488b85f81e0000       | sub                 esp, eax
            //   4989e1               | dec                 ecx

        $sequence_2 = { e9???????? 488b85003a0000 8b10 89d1 }
            // n = 4, score = 100
            //   e9????????           |                     
            //   488b85003a0000       | mov                 ecx, esp
            //   8b10                 | dec                 esp
            //   89d1                 | mov                 dword ptr [ebp + 0x5b90], ecx

        $sequence_3 = { c3 488b4df0 b810000000 e8???????? 4829c4 }
            // n = 5, score = 100
            //   c3                   | mov                 dword ptr [ebp + 0x4380], eax
            //   488b4df0             | setl                cl
            //   b810000000           | ret                 
            //   e8????????           |                     
            //   4829c4               | dec                 eax

        $sequence_4 = { 488b8578430000 8b00 898580430000 8b15???????? 833d????????0a 0f9cc1 }
            // n = 6, score = 100
            //   488b8578430000       | setl                cl
            //   8b00                 | dec                 eax
            //   898580430000         | mov                 eax, dword ptr [ebp + 0x4378]
            //   8b15????????         |                     
            //   833d????????0a       |                     
            //   0f9cc1               | mov                 eax, dword ptr [eax]

        $sequence_5 = { 4889e1 e8???????? 4829c4 488b85d8310000 4889e2 458910 }
            // n = 6, score = 100
            //   4889e1               | dec                 eax
            //   e8????????           |                     
            //   4829c4               | mov                 dword ptr [ebp + 0x6b40], eax
            //   488b85d8310000       | dec                 eax
            //   4889e2               | mov                 eax, dword ptr [ebp + 0x6b40]
            //   458910               | dec                 eax

        $sequence_6 = { e8???????? 4829c4 488b8540150000 4989e1 4c898d00600000 e8???????? }
            // n = 6, score = 100
            //   e8????????           |                     
            //   4829c4               | test                al, 1
            //   488b8540150000       | jne                 0x1b
            //   4989e1               | dec                 eax
            //   4c898d00600000       | mov                 eax, dword ptr [0x60]
            //   e8????????           |                     

        $sequence_7 = { a801 0f8515000000 65488b042560000000 488985406b0000 e9???????? 488b85406b0000 488b4018 }
            // n = 7, score = 100
            //   a801                 | dec                 eax
            //   0f8515000000         | sub                 esp, eax
            //   65488b042560000000     | dec    eax
            //   488985406b0000       | mov                 eax, dword ptr [ebp + 0x1ef8]
            //   e9????????           |                     
            //   488b85406b0000       | dec                 ecx
            //   488b4018             | mov                 ecx, esp

    condition:
        7 of them and filesize < 12033024
}