rule win_neutrino_pos_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.neutrino_pos."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.neutrino_pos"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 68fbd5fba3 43 53 897dfc e8???????? 83c40c 56 }
            // n = 7, score = 200
            //   68fbd5fba3           | push                0xa3fbd5fb
            //   43                   | inc                 ebx
            //   53                   | push                ebx
            //   897dfc               | mov                 dword ptr [ebp - 4], edi
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   56                   | push                esi

        $sequence_1 = { 5a 6a71 6689955affffff 5a 6a61 6689955cffffff }
            // n = 6, score = 200
            //   5a                   | pop                 edx
            //   6a71                 | push                0x71
            //   6689955affffff       | mov                 word ptr [ebp - 0xa6], dx
            //   5a                   | pop                 edx
            //   6a61                 | push                0x61
            //   6689955cffffff       | mov                 word ptr [ebp - 0xa4], dx

        $sequence_2 = { 6863ad115b 6a04 c745e801000000 8945f4 e8???????? 59 }
            // n = 6, score = 200
            //   6863ad115b           | push                0x5b11ad63
            //   6a04                 | push                4
            //   c745e801000000       | mov                 dword ptr [ebp - 0x18], 1
            //   8945f4               | mov                 dword ptr [ebp - 0xc], eax
            //   e8????????           |                     
            //   59                   | pop                 ecx

        $sequence_3 = { e8???????? 59 59 6a00 56 e9???????? }
            // n = 6, score = 200
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx
            //   6a00                 | push                0
            //   56                   | push                esi
            //   e9????????           |                     

        $sequence_4 = { 6a62 66898556ffffff 58 6a53 66898558ffffff }
            // n = 5, score = 200
            //   6a62                 | push                0x62
            //   66898556ffffff       | mov                 word ptr [ebp - 0xaa], ax
            //   58                   | pop                 eax
            //   6a53                 | push                0x53
            //   66898558ffffff       | mov                 word ptr [ebp - 0xa8], ax

        $sequence_5 = { 59 6a64 66898d6cffffff 59 6a68 66898d6effffff 59 }
            // n = 7, score = 200
            //   59                   | pop                 ecx
            //   6a64                 | push                0x64
            //   66898d6cffffff       | mov                 word ptr [ebp - 0x94], cx
            //   59                   | pop                 ecx
            //   6a68                 | push                0x68
            //   66898d6effffff       | mov                 word ptr [ebp - 0x92], cx
            //   59                   | pop                 ecx

        $sequence_6 = { 6a63 6689854cffffff 58 6a62 6689854effffff 58 6a69 }
            // n = 7, score = 200
            //   6a63                 | push                0x63
            //   6689854cffffff       | mov                 word ptr [ebp - 0xb4], ax
            //   58                   | pop                 eax
            //   6a62                 | push                0x62
            //   6689854effffff       | mov                 word ptr [ebp - 0xb2], ax
            //   58                   | pop                 eax
            //   6a69                 | push                0x69

        $sequence_7 = { 66895db2 6a64 8bd9 66895db4 8bd8 66895db6 5b }
            // n = 7, score = 200
            //   66895db2             | mov                 word ptr [ebp - 0x4e], bx
            //   6a64                 | push                0x64
            //   8bd9                 | mov                 ebx, ecx
            //   66895db4             | mov                 word ptr [ebp - 0x4c], bx
            //   8bd8                 | mov                 ebx, eax
            //   66895db6             | mov                 word ptr [ebp - 0x4a], bx
            //   5b                   | pop                 ebx

        $sequence_8 = { 8b45e0 8b08 6a03 50 ff5138 }
            // n = 5, score = 200
            //   8b45e0               | mov                 eax, dword ptr [ebp - 0x20]
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   6a03                 | push                3
            //   50                   | push                eax
            //   ff5138               | call                dword ptr [ecx + 0x38]

        $sequence_9 = { 66894dd6 66894dd8 66894dda 66894ddc 66894dde 66894de0 66894de2 }
            // n = 7, score = 200
            //   66894dd6             | mov                 word ptr [ebp - 0x2a], cx
            //   66894dd8             | mov                 word ptr [ebp - 0x28], cx
            //   66894dda             | mov                 word ptr [ebp - 0x26], cx
            //   66894ddc             | mov                 word ptr [ebp - 0x24], cx
            //   66894dde             | mov                 word ptr [ebp - 0x22], cx
            //   66894de0             | mov                 word ptr [ebp - 0x20], cx
            //   66894de2             | mov                 word ptr [ebp - 0x1e], cx

    condition:
        7 of them and filesize < 188416
}