rule win_nimrev_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.nimrev."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.nimrev"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ffd0 90 e9???????? 90 b9d0070000 e8???????? }
            // n = 6, score = 200
            //   ffd0                 | dec                 eax
            //   90                   | mov                 dword ptr [ebp - 0x40], 0x1c8
            //   e9????????           |                     
            //   90                   | dec                 eax
            //   b9d0070000           | lea                 eax, [0x75d9]
            //   e8????????           |                     

        $sequence_1 = { c1e002 01d0 01c0 29c1 89c8 83c030 89c1 }
            // n = 7, score = 200
            //   c1e002               | dec                 eax
            //   01d0                 | mov                 eax, dword ptr [ebp - 8]
            //   01c0                 | dec                 eax
            //   29c1                 | mov                 eax, dword ptr [eax + 8]
            //   89c8                 | dec                 eax
            //   83c030               | mov                 dword ptr [ebp - 0x50], 0x355
            //   89c1                 | dec                 eax

        $sequence_2 = { b801000000 eb05 b800000000 8845f7 eb01 90 }
            // n = 6, score = 200
            //   b801000000           | dec                 eax
            //   eb05                 | lea                 eax, [0x1c016]
            //   b800000000           | dec                 eax
            //   8845f7               | mov                 dword ptr [ebp - 0x58], eax
            //   eb01                 | dec                 eax
            //   90                   | mov                 eax, dword ptr [ebp - 8]

        $sequence_3 = { b801000000 eb05 b800000000 8845f7 eb01 90 0fb645f7 }
            // n = 7, score = 200
            //   b801000000           | dec                 eax
            //   eb05                 | lea                 eax, [0x23d18]
            //   b800000000           | mov                 byte ptr [eax + 9], 3
            //   8845f7               | dec                 eax
            //   eb01                 | lea                 eax, [0x23cfb]
            //   90                   | dec                 eax
            //   0fb645f7             | mov                 dword ptr [eax + 0x10], 0

        $sequence_4 = { eb05 b800000000 8845f7 eb01 90 }
            // n = 5, score = 200
            //   eb05                 | mov                 eax, dword ptr [ebp + 0x18]
            //   b800000000           | mov                 dword ptr [ebp - 0x70], eax
            //   8845f7               | mov                 eax, dword ptr [ebp + 0x1c]
            //   eb01                 | mov                 dword ptr [ebp - 0x6c], eax
            //   90                   | mov                 eax, dword ptr [ebp + 0x20]

        $sequence_5 = { 83f001 84c0 7408 90 }
            // n = 4, score = 200
            //   83f001               | dec                 eax
            //   84c0                 | lea                 eax, [0x29f43]
            //   7408                 | dec                 eax
            //   90                   | lea                 eax, [0x17079]

        $sequence_6 = { 0fb600 3c7d 7407 b801000000 eb05 }
            // n = 5, score = 200
            //   0fb600               | mov                 dword ptr [ebp - 0x1c], 0x422b17
            //   3c7d                 | mov                 dword ptr [ebp - 0x20], 0
            //   7407                 | mov                 word ptr [ebp - 0x18], 0
            //   b801000000           | mov                 dword ptr [ebp - 0x24], 0xe0
            //   eb05                 | mov                 dword ptr [ebp - 0x20], 0x422a4f

        $sequence_7 = { 89c1 e8???????? eb04 90 eb01 90 }
            // n = 6, score = 200
            //   89c1                 | dec                 eax
            //   e8????????           |                     
            //   eb04                 | mov                 eax, dword ptr [ebp + 0x30]
            //   90                   | dec                 eax
            //   eb01                 | mov                 ecx, eax
            //   90                   | dec                 eax

        $sequence_8 = { 3c7d 7407 b801000000 eb05 }
            // n = 4, score = 200
            //   3c7d                 | cmp                 eax, edx
            //   7407                 | cmovg               eax, edx
            //   b801000000           | mov                 edx, dword ptr [ebp - 0x14]
            //   eb05                 | mov                 dword ptr [esp + 4], edx

        $sequence_9 = { eb01 90 0fb645f6 8845f7 }
            // n = 4, score = 200
            //   eb01                 | lea                 eax, [0x29bbf]
            //   90                   | dec                 eax
            //   0fb645f6             | mov                 dword ptr [eax], 1
            //   8845f7               | dec                 eax

    condition:
        7 of them and filesize < 1141760
}