rule win_oddjob_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.oddjob."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.oddjob"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 59 8d9530ffffff 6a01 8bcb 8bc2 }
            // n = 6, score = 100
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   8d9530ffffff         | lea                 edx, [ebp - 0xd0]
            //   6a01                 | push                1
            //   8bcb                 | mov                 ecx, ebx
            //   8bc2                 | mov                 eax, edx

        $sequence_1 = { c68552fbffff43 c68553fbffff5e c68554fbffff5b c68555fbffff8b c68556fbffff4b }
            // n = 5, score = 100
            //   c68552fbffff43       | mov                 byte ptr [ebp - 0x4ae], 0x43
            //   c68553fbffff5e       | mov                 byte ptr [ebp - 0x4ad], 0x5e
            //   c68554fbffff5b       | mov                 byte ptr [ebp - 0x4ac], 0x5b
            //   c68555fbffff8b       | mov                 byte ptr [ebp - 0x4ab], 0x8b
            //   c68556fbffff4b       | mov                 byte ptr [ebp - 0x4aa], 0x4b

        $sequence_2 = { 663d3600 751f 66837f0234 7518 }
            // n = 4, score = 100
            //   663d3600             | cmp                 ax, 0x36
            //   751f                 | jne                 0x21
            //   66837f0234           | cmp                 word ptr [edi + 2], 0x34
            //   7518                 | jne                 0x1a

        $sequence_3 = { 50 bf???????? 57 6a04 53 68???????? ffd6 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   bf????????           |                     
            //   57                   | push                edi
            //   6a04                 | push                4
            //   53                   | push                ebx
            //   68????????           |                     
            //   ffd6                 | call                esi

        $sequence_4 = { 8bc3 4b 85c0 0f8498000000 0fb7c1 83f841 7c05 }
            // n = 7, score = 100
            //   8bc3                 | mov                 eax, ebx
            //   4b                   | dec                 ebx
            //   85c0                 | test                eax, eax
            //   0f8498000000         | je                  0x9e
            //   0fb7c1               | movzx               eax, cx
            //   83f841               | cmp                 eax, 0x41
            //   7c05                 | jl                  7

        $sequence_5 = { c68596faffff24 c68597faffff08 c68598faffff8b c68599faffff43 }
            // n = 4, score = 100
            //   c68596faffff24       | mov                 byte ptr [ebp - 0x56a], 0x24
            //   c68597faffff08       | mov                 byte ptr [ebp - 0x569], 8
            //   c68598faffff8b       | mov                 byte ptr [ebp - 0x568], 0x8b
            //   c68599faffff43       | mov                 byte ptr [ebp - 0x567], 0x43

        $sequence_6 = { c685f8f9ffff40 c685f9f9ffff68 889dfaf9ffff c685fbf9ffff10 889dfcf9ffff 889dfdf9ffff c685fef9ffff51 }
            // n = 7, score = 100
            //   c685f8f9ffff40       | mov                 byte ptr [ebp - 0x608], 0x40
            //   c685f9f9ffff68       | mov                 byte ptr [ebp - 0x607], 0x68
            //   889dfaf9ffff         | mov                 byte ptr [ebp - 0x606], bl
            //   c685fbf9ffff10       | mov                 byte ptr [ebp - 0x605], 0x10
            //   889dfcf9ffff         | mov                 byte ptr [ebp - 0x604], bl
            //   889dfdf9ffff         | mov                 byte ptr [ebp - 0x603], bl
            //   c685fef9ffff51       | mov                 byte ptr [ebp - 0x602], 0x51

        $sequence_7 = { 889d12f8ffff 889d13f8ffff 889d14f8ffff 889d15f8ffff 889d16f8ffff 889d17f8ffff 889d18f8ffff }
            // n = 7, score = 100
            //   889d12f8ffff         | mov                 byte ptr [ebp - 0x7ee], bl
            //   889d13f8ffff         | mov                 byte ptr [ebp - 0x7ed], bl
            //   889d14f8ffff         | mov                 byte ptr [ebp - 0x7ec], bl
            //   889d15f8ffff         | mov                 byte ptr [ebp - 0x7eb], bl
            //   889d16f8ffff         | mov                 byte ptr [ebp - 0x7ea], bl
            //   889d17f8ffff         | mov                 byte ptr [ebp - 0x7e9], bl
            //   889d18f8ffff         | mov                 byte ptr [ebp - 0x7e8], bl

        $sequence_8 = { 85c0 7503 897dfc 397de8 7409 ff75e8 ff15???????? }
            // n = 7, score = 100
            //   85c0                 | test                eax, eax
            //   7503                 | jne                 5
            //   897dfc               | mov                 dword ptr [ebp - 4], edi
            //   397de8               | cmp                 dword ptr [ebp - 0x18], edi
            //   7409                 | je                  0xb
            //   ff75e8               | push                dword ptr [ebp - 0x18]
            //   ff15????????         |                     

        $sequence_9 = { 53 68???????? ffd6 85c0 741c 8d85a094ffff }
            // n = 6, score = 100
            //   53                   | push                ebx
            //   68????????           |                     
            //   ffd6                 | call                esi
            //   85c0                 | test                eax, eax
            //   741c                 | je                  0x1e
            //   8d85a094ffff         | lea                 eax, [ebp - 0x6b60]

    condition:
        7 of them and filesize < 221184
}