rule win_oni_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.oni."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.oni"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 50 8d4db0 c645b000 e8???????? 8b0d???????? b8abaaaa2a 8b3d???????? }
            // n = 7, score = 200
            //   50                   | push                eax
            //   8d4db0               | lea                 ecx, [ebp - 0x50]
            //   c645b000             | mov                 byte ptr [ebp - 0x50], 0
            //   e8????????           |                     
            //   8b0d????????         |                     
            //   b8abaaaa2a           | mov                 eax, 0x2aaaaaab
            //   8b3d????????         |                     

        $sequence_1 = { 83f904 0f828d000000 83f923 0f8789000000 8bc8 }
            // n = 5, score = 200
            //   83f904               | cmp                 ecx, 4
            //   0f828d000000         | jb                  0x93
            //   83f923               | cmp                 ecx, 0x23
            //   0f8789000000         | ja                  0x8f
            //   8bc8                 | mov                 ecx, eax

        $sequence_2 = { ff75ec 51 ff36 8b55e8 8bcb e8???????? 83c410 }
            // n = 7, score = 200
            //   ff75ec               | push                dword ptr [ebp - 0x14]
            //   51                   | push                ecx
            //   ff36                 | push                dword ptr [esi]
            //   8b55e8               | mov                 edx, dword ptr [ebp - 0x18]
            //   8bcb                 | mov                 ecx, ebx
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10

        $sequence_3 = { 7f07 3bc7 0f4fd8 8bfb 6aff 8d4701 }
            // n = 6, score = 200
            //   7f07                 | jg                  9
            //   3bc7                 | cmp                 eax, edi
            //   0f4fd8               | cmovg               ebx, eax
            //   8bfb                 | mov                 edi, ebx
            //   6aff                 | push                -1
            //   8d4701               | lea                 eax, [edi + 1]

        $sequence_4 = { 3a45ec 753e 8b45f0 8b048590884300 }
            // n = 4, score = 200
            //   3a45ec               | cmp                 al, byte ptr [ebp - 0x14]
            //   753e                 | jne                 0x40
            //   8b45f0               | mov                 eax, dword ptr [ebp - 0x10]
            //   8b048590884300       | mov                 eax, dword ptr [eax*4 + 0x438890]

        $sequence_5 = { 8d0dc0254300 ba1b000000 e9???????? a900000080 }
            // n = 4, score = 200
            //   8d0dc0254300         | lea                 ecx, [0x4325c0]
            //   ba1b000000           | mov                 edx, 0x1b
            //   e9????????           |                     
            //   a900000080           | test                eax, 0x80000000

        $sequence_6 = { 660fd685c8feffff 33ff 6800010000 899dc8feffff 89bdccfeffff 899dd0feffff ff15???????? }
            // n = 7, score = 200
            //   660fd685c8feffff     | movq                qword ptr [ebp - 0x138], xmm0
            //   33ff                 | xor                 edi, edi
            //   6800010000           | push                0x100
            //   899dc8feffff         | mov                 dword ptr [ebp - 0x138], ebx
            //   89bdccfeffff         | mov                 dword ptr [ebp - 0x134], edi
            //   899dd0feffff         | mov                 dword ptr [ebp - 0x130], ebx
            //   ff15????????         |                     

        $sequence_7 = { 8901 0fb602 5f 5e 5b 8b4c2430 33cc }
            // n = 7, score = 200
            //   8901                 | mov                 dword ptr [ecx], eax
            //   0fb602               | movzx               eax, byte ptr [edx]
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx
            //   8b4c2430             | mov                 ecx, dword ptr [esp + 0x30]
            //   33cc                 | xor                 ecx, esp

        $sequence_8 = { 8b542428 8b442414 85f6 0f8422ffffff }
            // n = 4, score = 200
            //   8b542428             | mov                 edx, dword ptr [esp + 0x28]
            //   8b442414             | mov                 eax, dword ptr [esp + 0x14]
            //   85f6                 | test                esi, esi
            //   0f8422ffffff         | je                  0xffffff28

        $sequence_9 = { f6c104 7519 f6c102 8d4df8 7540 eb6a }
            // n = 6, score = 200
            //   f6c104               | test                cl, 4
            //   7519                 | jne                 0x1b
            //   f6c102               | test                cl, 2
            //   8d4df8               | lea                 ecx, [ebp - 8]
            //   7540                 | jne                 0x42
            //   eb6a                 | jmp                 0x6c

    condition:
        7 of them and filesize < 499712
}