rule win_opachki_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.opachki."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.opachki"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c3 55 8bec 81ec00010000 ff7508 }
            // n = 5, score = 300
            //   c3                   | ret                 
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   81ec00010000         | sub                 esp, 0x100
            //   ff7508               | push                dword ptr [ebp + 8]

        $sequence_1 = { 83c40c 8b4f04 8d0433 894708 c6040800 }
            // n = 5, score = 300
            //   83c40c               | add                 esp, 0xc
            //   8b4f04               | mov                 ecx, dword ptr [edi + 4]
            //   8d0433               | lea                 eax, [ebx + esi]
            //   894708               | mov                 dword ptr [edi + 8], eax
            //   c6040800             | mov                 byte ptr [eax + ecx], 0

        $sequence_2 = { 83c8ff 5f 5b 5e c9 c20800 8bc3 }
            // n = 7, score = 300
            //   83c8ff               | or                  eax, 0xffffffff
            //   5f                   | pop                 edi
            //   5b                   | pop                 ebx
            //   5e                   | pop                 esi
            //   c9                   | leave               
            //   c20800               | ret                 8
            //   8bc3                 | mov                 eax, ebx

        $sequence_3 = { 741c 8d4dd4 51 8d4df4 51 8d4dec }
            // n = 6, score = 300
            //   741c                 | je                  0x1e
            //   8d4dd4               | lea                 ecx, [ebp - 0x2c]
            //   51                   | push                ecx
            //   8d4df4               | lea                 ecx, [ebp - 0xc]
            //   51                   | push                ecx
            //   8d4dec               | lea                 ecx, [ebp - 0x14]

        $sequence_4 = { 885dfc e8???????? ff75e8 8d45f4 }
            // n = 4, score = 300
            //   885dfc               | mov                 byte ptr [ebp - 4], bl
            //   e8????????           |                     
            //   ff75e8               | push                dword ptr [ebp - 0x18]
            //   8d45f4               | lea                 eax, [ebp - 0xc]

        $sequence_5 = { ff7510 ff75fc ff15???????? 85c0 75e2 }
            // n = 5, score = 300
            //   ff7510               | push                dword ptr [ebp + 0x10]
            //   ff75fc               | push                dword ptr [ebp - 4]
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   75e2                 | jne                 0xffffffe4

        $sequence_6 = { 8b4608 8b4e04 c6040800 5f 8bc6 5e }
            // n = 6, score = 300
            //   8b4608               | mov                 eax, dword ptr [esi + 8]
            //   8b4e04               | mov                 ecx, dword ptr [esi + 4]
            //   c6040800             | mov                 byte ptr [eax + ecx], 0
            //   5f                   | pop                 edi
            //   8bc6                 | mov                 eax, esi
            //   5e                   | pop                 esi

        $sequence_7 = { 8bd8 7413 8b4704 03c8 53 }
            // n = 5, score = 300
            //   8bd8                 | mov                 ebx, eax
            //   7413                 | je                  0x15
            //   8b4704               | mov                 eax, dword ptr [edi + 4]
            //   03c8                 | add                 ecx, eax
            //   53                   | push                ebx

        $sequence_8 = { 8a0f 894508 84c9 744d 8a10 53 56 }
            // n = 7, score = 300
            //   8a0f                 | mov                 cl, byte ptr [edi]
            //   894508               | mov                 dword ptr [ebp + 8], eax
            //   84c9                 | test                cl, cl
            //   744d                 | je                  0x4f
            //   8a10                 | mov                 dl, byte ptr [eax]
            //   53                   | push                ebx
            //   56                   | push                esi

        $sequence_9 = { c0e805 88470a 3c01 ac 7710 80fff6 7503 }
            // n = 7, score = 200
            //   c0e805               | shr                 al, 5
            //   88470a               | mov                 byte ptr [edi + 0xa], al
            //   3c01                 | cmp                 al, 1
            //   ac                   | lodsb               al, byte ptr [esi]
            //   7710                 | ja                  0x12
            //   80fff6               | cmp                 bh, 0xf6
            //   7503                 | jne                 5

        $sequence_10 = { aa 8944241c 61 c3 898389838983 898389838983 }
            // n = 6, score = 200
            //   aa                   | stosb               byte ptr es:[edi], al
            //   8944241c             | mov                 dword ptr [esp + 0x1c], eax
            //   61                   | popal               
            //   c3                   | ret                 
            //   898389838983         | mov                 dword ptr [ebx - 0x7c767c77], eax
            //   898389838983         | mov                 dword ptr [ebx - 0x7c767c77], eax

        $sequence_11 = { f6c140 7412 08d2 7408 }
            // n = 4, score = 200
            //   f6c140               | test                cl, 0x40
            //   7412                 | je                  0x14
            //   08d2                 | or                  dl, dl
            //   7408                 | je                  0xa

        $sequence_12 = { 884707 83c140 eb0a 3ca0 7206 3ca3 }
            // n = 6, score = 200
            //   884707               | mov                 byte ptr [edi + 7], al
            //   83c140               | add                 ecx, 0x40
            //   eb0a                 | jmp                 0xc
            //   3ca0                 | cmp                 al, 0xa0
            //   7206                 | jb                  8
            //   3ca3                 | cmp                 al, 0xa3

        $sequence_13 = { 7404 3c65 7505 884703 ebcc }
            // n = 5, score = 200
            //   7404                 | je                  6
            //   3c65                 | cmp                 al, 0x65
            //   7505                 | jne                 7
            //   884703               | mov                 byte ptr [edi + 3], al
            //   ebcc                 | jmp                 0xffffffce

        $sequence_14 = { f3aa 83ef25 8b742424 ac }
            // n = 4, score = 200
            //   f3aa                 | rep stosb           byte ptr es:[edi], al
            //   83ef25               | sub                 edi, 0x25
            //   8b742424             | mov                 esi, dword ptr [esp + 0x24]
            //   ac                   | lodsb               al, byte ptr [esi]

        $sequence_15 = { 898389838983 898389838585 858585858585 878593859a9a }
            // n = 4, score = 200
            //   898389838983         | mov                 dword ptr [ebx - 0x7c767c77], eax
            //   898389838585         | mov                 dword ptr [ebx - 0x7a7a7c77], eax
            //   858585858585         | test                dword ptr [ebp - 0x7a7a7a7b], eax
            //   878593859a9a         | xchg                dword ptr [ebp - 0x65657a6d], eax

    condition:
        7 of them and filesize < 122880
}