rule win_orcarat_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.orcarat."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.orcarat"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { f2ae 8d84242c110000 f7d1 50 894c2414 51 }
            // n = 6, score = 200
            //   f2ae                 | repne scasb         al, byte ptr es:[edi]
            //   8d84242c110000       | lea                 eax, [esp + 0x112c]
            //   f7d1                 | not                 ecx
            //   50                   | push                eax
            //   894c2414             | mov                 dword ptr [esp + 0x14], ecx
            //   51                   | push                ecx

        $sequence_1 = { 8d8c2418010000 50 51 8d842430110000 52 50 }
            // n = 6, score = 200
            //   8d8c2418010000       | lea                 ecx, [esp + 0x118]
            //   50                   | push                eax
            //   51                   | push                ecx
            //   8d842430110000       | lea                 eax, [esp + 0x1130]
            //   52                   | push                edx
            //   50                   | push                eax

        $sequence_2 = { 56 6a00 8d5708 6a10 }
            // n = 4, score = 200
            //   56                   | push                esi
            //   6a00                 | push                0
            //   8d5708               | lea                 edx, [edi + 8]
            //   6a10                 | push                0x10

        $sequence_3 = { 53 8dbef4020000 51 50 }
            // n = 4, score = 200
            //   53                   | push                ebx
            //   8dbef4020000         | lea                 edi, [esi + 0x2f4]
            //   51                   | push                ecx
            //   50                   | push                eax

        $sequence_4 = { 8bf0 85f6 7451 8b442414 85c0 7421 }
            // n = 6, score = 200
            //   8bf0                 | mov                 esi, eax
            //   85f6                 | test                esi, esi
            //   7451                 | je                  0x53
            //   8b442414             | mov                 eax, dword ptr [esp + 0x14]
            //   85c0                 | test                eax, eax
            //   7421                 | je                  0x23

        $sequence_5 = { f2ae 8d442420 f7d1 50 894c2418 ff15???????? 50 }
            // n = 7, score = 200
            //   f2ae                 | repne scasb         al, byte ptr es:[edi]
            //   8d442420             | lea                 eax, [esp + 0x20]
            //   f7d1                 | not                 ecx
            //   50                   | push                eax
            //   894c2418             | mov                 dword ptr [esp + 0x18], ecx
            //   ff15????????         |                     
            //   50                   | push                eax

        $sequence_6 = { 303d???????? 40 00803d400023 d18a0688078a 46 018847018a46 }
            // n = 6, score = 200
            //   303d????????         |                     
            //   40                   | inc                 eax
            //   00803d400023         | add                 byte ptr [eax + 0x2300403d], al
            //   d18a0688078a         | ror                 dword ptr [edx - 0x75f877fa], 1
            //   46                   | inc                 esi
            //   018847018a46         | add                 dword ptr [eax + 0x468a0147], ecx

        $sequence_7 = { 5d 5b 81c418020000 c20400 6a01 8d142e }
            // n = 6, score = 200
            //   5d                   | pop                 ebp
            //   5b                   | pop                 ebx
            //   81c418020000         | add                 esp, 0x218
            //   c20400               | ret                 4
            //   6a01                 | push                1
            //   8d142e               | lea                 edx, [esi + ebp]

        $sequence_8 = { ff15???????? 85c0 0f849e010000 8b0f 53 6a01 51 }
            // n = 7, score = 200
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   0f849e010000         | je                  0x1a4
            //   8b0f                 | mov                 ecx, dword ptr [edi]
            //   53                   | push                ebx
            //   6a01                 | push                1
            //   51                   | push                ecx

        $sequence_9 = { 33db 837d0000 762f 8d542410 c744241000000000 52 6800080000 }
            // n = 7, score = 200
            //   33db                 | xor                 ebx, ebx
            //   837d0000             | cmp                 dword ptr [ebp], 0
            //   762f                 | jbe                 0x31
            //   8d542410             | lea                 edx, [esp + 0x10]
            //   c744241000000000     | mov                 dword ptr [esp + 0x10], 0
            //   52                   | push                edx
            //   6800080000           | push                0x800

    condition:
        7 of them and filesize < 114688
}