rule win_penco_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.penco."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.penco"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 53 6a01 6800000080 8d9500010000 52 8b1d???????? }
            // n = 6, score = 100
            //   53                   | push                ebx
            //   6a01                 | push                1
            //   6800000080           | push                0x80000000
            //   8d9500010000         | lea                 edx, [ebp + 0x100]
            //   52                   | push                edx
            //   8b1d????????         |                     

        $sequence_1 = { 3334bd00d83400 0fb67c2414 3334bd00d43400 8b4c241c 33700c 83c010 8bde }
            // n = 7, score = 100
            //   3334bd00d83400       | xor                 esi, dword ptr [edi*4 + 0x34d800]
            //   0fb67c2414           | movzx               edi, byte ptr [esp + 0x14]
            //   3334bd00d43400       | xor                 esi, dword ptr [edi*4 + 0x34d400]
            //   8b4c241c             | mov                 ecx, dword ptr [esp + 0x1c]
            //   33700c               | xor                 esi, dword ptr [eax + 0xc]
            //   83c010               | add                 eax, 0x10
            //   8bde                 | mov                 ebx, esi

        $sequence_2 = { 40 89442418 3b442414 0f82fffeffff eb13 8d042e 68???????? }
            // n = 7, score = 100
            //   40                   | inc                 eax
            //   89442418             | mov                 dword ptr [esp + 0x18], eax
            //   3b442414             | cmp                 eax, dword ptr [esp + 0x14]
            //   0f82fffeffff         | jb                  0xffffff05
            //   eb13                 | jmp                 0x15
            //   8d042e               | lea                 eax, [esi + ebp]
            //   68????????           |                     

        $sequence_3 = { 741c 68???????? 68ff010f00 56 ff15???????? 56 85c0 }
            // n = 7, score = 100
            //   741c                 | je                  0x1e
            //   68????????           |                     
            //   68ff010f00           | push                0xf01ff
            //   56                   | push                esi
            //   ff15????????         |                     
            //   56                   | push                esi
            //   85c0                 | test                eax, eax

        $sequence_4 = { 0fbe80e8983400 83e00f 33f6 eb04 33f6 33c0 }
            // n = 6, score = 100
            //   0fbe80e8983400       | movsx               eax, byte ptr [eax + 0x3498e8]
            //   83e00f               | and                 eax, 0xf
            //   33f6                 | xor                 esi, esi
            //   eb04                 | jmp                 6
            //   33f6                 | xor                 esi, esi
            //   33c0                 | xor                 eax, eax

        $sequence_5 = { 8d4598 50 6a00 6a00 8d4db8 51 8b55a4 }
            // n = 7, score = 100
            //   8d4598               | lea                 eax, [ebp - 0x68]
            //   50                   | push                eax
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   8d4db8               | lea                 ecx, [ebp - 0x48]
            //   51                   | push                ecx
            //   8b55a4               | mov                 edx, dword ptr [ebp - 0x5c]

        $sequence_6 = { 33c0 84c9 7428 8d642400 80f930 7c1c 80f939 }
            // n = 7, score = 100
            //   33c0                 | xor                 eax, eax
            //   84c9                 | test                cl, cl
            //   7428                 | je                  0x2a
            //   8d642400             | lea                 esp, [esp]
            //   80f930               | cmp                 cl, 0x30
            //   7c1c                 | jl                  0x1e
            //   80f939               | cmp                 cl, 0x39

        $sequence_7 = { 894c2418 8b4c2444 f7f1 33d2 c744242001000000 03442410 89442414 }
            // n = 7, score = 100
            //   894c2418             | mov                 dword ptr [esp + 0x18], ecx
            //   8b4c2444             | mov                 ecx, dword ptr [esp + 0x44]
            //   f7f1                 | div                 ecx
            //   33d2                 | xor                 edx, edx
            //   c744242001000000     | mov                 dword ptr [esp + 0x20], 1
            //   03442410             | add                 eax, dword ptr [esp + 0x10]
            //   89442414             | mov                 dword ptr [esp + 0x14], eax

        $sequence_8 = { 7504 8bf0 eb3e 6a0a }
            // n = 4, score = 100
            //   7504                 | jne                 6
            //   8bf0                 | mov                 esi, eax
            //   eb3e                 | jmp                 0x40
            //   6a0a                 | push                0xa

        $sequence_9 = { 8b349528e83400 8b542428 0fb6f9 3334bd00d83400 8b4c241c c1ea18 33349528ec3400 }
            // n = 7, score = 100
            //   8b349528e83400       | mov                 esi, dword ptr [edx*4 + 0x34e828]
            //   8b542428             | mov                 edx, dword ptr [esp + 0x28]
            //   0fb6f9               | movzx               edi, cl
            //   3334bd00d83400       | xor                 esi, dword ptr [edi*4 + 0x34d800]
            //   8b4c241c             | mov                 ecx, dword ptr [esp + 0x1c]
            //   c1ea18               | shr                 edx, 0x18
            //   33349528ec3400       | xor                 esi, dword ptr [edx*4 + 0x34ec28]

    condition:
        7 of them and filesize < 319488
}