rule win_pgift_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.pgift."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.pgift"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 53 ff7508 e8???????? 83450804 83c304 }
            // n = 5, score = 100
            //   53                   | push                ebx
            //   ff7508               | push                dword ptr [ebp + 8]
            //   e8????????           |                     
            //   83450804             | add                 dword ptr [ebp + 8], 4
            //   83c304               | add                 ebx, 4

        $sequence_1 = { 2bc8 c1f902 7454 50 8d4de8 }
            // n = 5, score = 100
            //   2bc8                 | sub                 ecx, eax
            //   c1f902               | sar                 ecx, 2
            //   7454                 | je                  0x56
            //   50                   | push                eax
            //   8d4de8               | lea                 ecx, [ebp - 0x18]

        $sequence_2 = { 50 0fb745d4 50 8d45ec ff760c }
            // n = 5, score = 100
            //   50                   | push                eax
            //   0fb745d4             | movzx               eax, word ptr [ebp - 0x2c]
            //   50                   | push                eax
            //   8d45ec               | lea                 eax, [ebp - 0x14]
            //   ff760c               | push                dword ptr [esi + 0xc]

        $sequence_3 = { 8d4df0 c645fc02 e8???????? ff750c }
            // n = 4, score = 100
            //   8d4df0               | lea                 ecx, [ebp - 0x10]
            //   c645fc02             | mov                 byte ptr [ebp - 4], 2
            //   e8????????           |                     
            //   ff750c               | push                dword ptr [ebp + 0xc]

        $sequence_4 = { 83f8ff 741e 53 50 8d4de8 e8???????? ff75e8 }
            // n = 7, score = 100
            //   83f8ff               | cmp                 eax, -1
            //   741e                 | je                  0x20
            //   53                   | push                ebx
            //   50                   | push                eax
            //   8d4de8               | lea                 ecx, [ebp - 0x18]
            //   e8????????           |                     
            //   ff75e8               | push                dword ptr [ebp - 0x18]

        $sequence_5 = { 8d4df0 ff3498 e8???????? 83f8ff }
            // n = 4, score = 100
            //   8d4df0               | lea                 ecx, [ebp - 0x10]
            //   ff3498               | push                dword ptr [eax + ebx*4]
            //   e8????????           |                     
            //   83f8ff               | cmp                 eax, -1

        $sequence_6 = { 33db 8d4dec 895dfc e8???????? 8d8dd0feffff 895de8 e8???????? }
            // n = 7, score = 100
            //   33db                 | xor                 ebx, ebx
            //   8d4dec               | lea                 ecx, [ebp - 0x14]
            //   895dfc               | mov                 dword ptr [ebp - 4], ebx
            //   e8????????           |                     
            //   8d8dd0feffff         | lea                 ecx, [ebp - 0x130]
            //   895de8               | mov                 dword ptr [ebp - 0x18], ebx
            //   e8????????           |                     

        $sequence_7 = { c645fc03 897e38 897e34 897e30 e8???????? 3bc7 }
            // n = 6, score = 100
            //   c645fc03             | mov                 byte ptr [ebp - 4], 3
            //   897e38               | mov                 dword ptr [esi + 0x38], edi
            //   897e34               | mov                 dword ptr [esi + 0x34], edi
            //   897e30               | mov                 dword ptr [esi + 0x30], edi
            //   e8????????           |                     
            //   3bc7                 | cmp                 eax, edi

        $sequence_8 = { ff7634 53 50 e8???????? 83c40c 8d4638 }
            // n = 6, score = 100
            //   ff7634               | push                dword ptr [esi + 0x34]
            //   53                   | push                ebx
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   8d4638               | lea                 eax, [esi + 0x38]

        $sequence_9 = { 8d4de8 e8???????? 6a5c 8d4de8 c645fc01 }
            // n = 5, score = 100
            //   8d4de8               | lea                 ecx, [ebp - 0x18]
            //   e8????????           |                     
            //   6a5c                 | push                0x5c
            //   8d4de8               | lea                 ecx, [ebp - 0x18]
            //   c645fc01             | mov                 byte ptr [ebp - 4], 1

    condition:
        7 of them and filesize < 98304
}