rule win_phandoor_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.phandoor."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.phandoor"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 0f8482000000 833d????????00 7479 833d????????00 7470 833d????????00 }
            // n = 6, score = 800
            //   0f8482000000         | je                  0x88
            //   833d????????00       |                     
            //   7479                 | je                  0x7b
            //   833d????????00       |                     
            //   7470                 | je                  0x72
            //   833d????????00       |                     

        $sequence_1 = { 833d????????00 0f8452010000 833d????????00 0f8445010000 833d????????00 }
            // n = 5, score = 800
            //   833d????????00       |                     
            //   0f8452010000         | je                  0x158
            //   833d????????00       |                     
            //   0f8445010000         | je                  0x14b
            //   833d????????00       |                     

        $sequence_2 = { 83c40c 83c302 3bbe90010000 72d7 }
            // n = 4, score = 800
            //   83c40c               | add                 esp, 0xc
            //   83c302               | add                 ebx, 2
            //   3bbe90010000         | cmp                 edi, dword ptr [esi + 0x190]
            //   72d7                 | jb                  0xffffffd9

        $sequence_3 = { 83c404 8d55fc 8bf0 52 56 }
            // n = 5, score = 800
            //   83c404               | add                 esp, 4
            //   8d55fc               | lea                 edx, [ebp - 4]
            //   8bf0                 | mov                 esi, eax
            //   52                   | push                edx
            //   56                   | push                esi

        $sequence_4 = { 0f84c7010000 833d????????00 0f84ba010000 833d????????00 0f84ad010000 833d????????00 }
            // n = 6, score = 800
            //   0f84c7010000         | je                  0x1cd
            //   833d????????00       |                     
            //   0f84ba010000         | je                  0x1c0
            //   833d????????00       |                     
            //   0f84ad010000         | je                  0x1b3
            //   833d????????00       |                     

        $sequence_5 = { 50 8bf9 c645f400 c745f500000000 e8???????? }
            // n = 5, score = 800
            //   50                   | push                eax
            //   8bf9                 | mov                 edi, ecx
            //   c645f400             | mov                 byte ptr [ebp - 0xc], 0
            //   c745f500000000       | mov                 dword ptr [ebp - 0xb], 0
            //   e8????????           |                     

        $sequence_6 = { 32d3 32d0 8b45f4 81e1fe010000 c1e018 0b45f8 }
            // n = 6, score = 800
            //   32d3                 | xor                 dl, bl
            //   32d0                 | xor                 dl, al
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]
            //   81e1fe010000         | and                 ecx, 0x1fe
            //   c1e018               | shl                 eax, 0x18
            //   0b45f8               | or                  eax, dword ptr [ebp - 8]

        $sequence_7 = { a3???????? a3???????? a3???????? a3???????? 898de8feffff }
            // n = 5, score = 800
            //   a3????????           |                     
            //   a3????????           |                     
            //   a3????????           |                     
            //   a3????????           |                     
            //   898de8feffff         | mov                 dword ptr [ebp - 0x118], ecx

        $sequence_8 = { 83c404 893e 8b4604 3bc7 740c }
            // n = 5, score = 500
            //   83c404               | add                 esp, 4
            //   893e                 | mov                 dword ptr [esi], edi
            //   8b4604               | mov                 eax, dword ptr [esi + 4]
            //   3bc7                 | cmp                 eax, edi
            //   740c                 | je                  0xe

        $sequence_9 = { 6a01 51 52 8b5508 }
            // n = 4, score = 500
            //   6a01                 | push                1
            //   51                   | push                ecx
            //   52                   | push                edx
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]

        $sequence_10 = { 668901 5e c3 33d2 }
            // n = 4, score = 500
            //   668901               | mov                 word ptr [ecx], ax
            //   5e                   | pop                 esi
            //   c3                   | ret                 
            //   33d2                 | xor                 edx, edx

        $sequence_11 = { 33c0 3b35???????? 7327 57 }
            // n = 4, score = 500
            //   33c0                 | xor                 eax, eax
            //   3b35????????         |                     
            //   7327                 | jae                 0x29
            //   57                   | push                edi

        $sequence_12 = { 56 8b35???????? 57 68???????? 50 c705????????03000000 }
            // n = 6, score = 500
            //   56                   | push                esi
            //   8b35????????         |                     
            //   57                   | push                edi
            //   68????????           |                     
            //   50                   | push                eax
            //   c705????????03000000     |     

        $sequence_13 = { 6a01 53 51 8bc8 }
            // n = 4, score = 500
            //   6a01                 | push                1
            //   53                   | push                ebx
            //   51                   | push                ecx
            //   8bc8                 | mov                 ecx, eax

        $sequence_14 = { 56 8b7308 85f6 7420 }
            // n = 4, score = 500
            //   56                   | push                esi
            //   8b7308               | mov                 esi, dword ptr [ebx + 8]
            //   85f6                 | test                esi, esi
            //   7420                 | je                  0x22

    condition:
        7 of them and filesize < 2124800
}