rule win_phoreal_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.phoreal."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.phoreal"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d4c2414 51 8b4b04 8d542410 52 8d442418 50 }
            // n = 7, score = 200
            //   8d4c2414             | lea                 ecx, [esp + 0x14]
            //   51                   | push                ecx
            //   8b4b04               | mov                 ecx, dword ptr [ebx + 4]
            //   8d542410             | lea                 edx, [esp + 0x10]
            //   52                   | push                edx
            //   8d442418             | lea                 eax, [esp + 0x18]
            //   50                   | push                eax

        $sequence_1 = { 8b570c 8d442440 6a00 50 895350 }
            // n = 5, score = 200
            //   8b570c               | mov                 edx, dword ptr [edi + 0xc]
            //   8d442440             | lea                 eax, [esp + 0x40]
            //   6a00                 | push                0
            //   50                   | push                eax
            //   895350               | mov                 dword ptr [ebx + 0x50], edx

        $sequence_2 = { 56 57 33ff 8bf0 8d4701 }
            // n = 5, score = 200
            //   56                   | push                esi
            //   57                   | push                edi
            //   33ff                 | xor                 edi, edi
            //   8bf0                 | mov                 esi, eax
            //   8d4701               | lea                 eax, [edi + 1]

        $sequence_3 = { 75c4 8d8de4fdffff c645fc02 e8???????? bf10000000 397de4 720c }
            // n = 7, score = 200
            //   75c4                 | jne                 0xffffffc6
            //   8d8de4fdffff         | lea                 ecx, [ebp - 0x21c]
            //   c645fc02             | mov                 byte ptr [ebp - 4], 2
            //   e8????????           |                     
            //   bf10000000           | mov                 edi, 0x10
            //   397de4               | cmp                 dword ptr [ebp - 0x1c], edi
            //   720c                 | jb                  0xe

        $sequence_4 = { 8b54245c 51 8b4c245c 52 8b542458 51 48 }
            // n = 7, score = 200
            //   8b54245c             | mov                 edx, dword ptr [esp + 0x5c]
            //   51                   | push                ecx
            //   8b4c245c             | mov                 ecx, dword ptr [esp + 0x5c]
            //   52                   | push                edx
            //   8b542458             | mov                 edx, dword ptr [esp + 0x58]
            //   51                   | push                ecx
            //   48                   | dec                 eax

        $sequence_5 = { 03c3 83c9ff 2bc8 3bca }
            // n = 4, score = 200
            //   03c3                 | add                 eax, ebx
            //   83c9ff               | or                  ecx, 0xffffffff
            //   2bc8                 | sub                 ecx, eax
            //   3bca                 | cmp                 ecx, edx

        $sequence_6 = { 8b7510 b90e000000 f3a5 5e 5f 8be5 5d }
            // n = 7, score = 200
            //   8b7510               | mov                 esi, dword ptr [ebp + 0x10]
            //   b90e000000           | mov                 ecx, 0xe
            //   f3a5                 | rep movsd           dword ptr es:[edi], dword ptr [esi]
            //   5e                   | pop                 esi
            //   5f                   | pop                 edi
            //   8be5                 | mov                 esp, ebp
            //   5d                   | pop                 ebp

        $sequence_7 = { 6a01 6a00 6a00 51 50 ff15???????? 85c0 }
            // n = 7, score = 200
            //   6a01                 | push                1
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   51                   | push                ecx
            //   50                   | push                eax
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax

        $sequence_8 = { 52 8d434e 50 8d434b 8d534d 8d4b4c 50 }
            // n = 7, score = 200
            //   52                   | push                edx
            //   8d434e               | lea                 eax, [ebx + 0x4e]
            //   50                   | push                eax
            //   8d434b               | lea                 eax, [ebx + 0x4b]
            //   8d534d               | lea                 edx, [ebx + 0x4d]
            //   8d4b4c               | lea                 ecx, [ebx + 0x4c]
            //   50                   | push                eax

        $sequence_9 = { 894de0 894de4 8b8d78fdffff 8d1447 51 52 }
            // n = 6, score = 200
            //   894de0               | mov                 dword ptr [ebp - 0x20], ecx
            //   894de4               | mov                 dword ptr [ebp - 0x1c], ecx
            //   8b8d78fdffff         | mov                 ecx, dword ptr [ebp - 0x288]
            //   8d1447               | lea                 edx, [edi + eax*2]
            //   51                   | push                ecx
            //   52                   | push                edx

    condition:
        7 of them and filesize < 622592
}