rule win_pickpocket_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.pickpocket."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.pickpocket"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 85c0 750f b962890100 e8???????? }
            // n = 4, score = 400
            //   85c0                 | mov                 dword ptr [esi], 0x54
            //   750f                 | mov                 dword ptr [esi], 0x5c
            //   b962890100           | je                  0xd
            //   e8????????           |                     

        $sequence_1 = { 7e1e b9dccc0000 e9???????? b9cecc0000 e9???????? b9c7cc0000 }
            // n = 6, score = 400
            //   7e1e                 | mov                 ecx, 0xfffb
            //   b9dccc0000           | and                 word ptr [eax + 0x26], cx
            //   e9????????           |                     
            //   b9cecc0000           | test                ebx, ebx
            //   e9????????           |                     
            //   b9c7cc0000           | je                  0x1e0e

        $sequence_2 = { 7404 8b01 eb03 83c8ff 83f804 }
            // n = 5, score = 400
            //   7404                 | dec                 eax
            //   8b01                 | mov                 eax, dword ptr [edi + 0x10]
            //   eb03                 | cmp                 byte ptr [ecx], 0x1b
            //   83c8ff               | jne                 0x26f
            //   83f804               | dec                 esp

        $sequence_3 = { d3e0 a846 750f b99be00100 e8???????? e9???????? }
            // n = 6, score = 400
            //   d3e0                 | lea                 ebx, [esi + 1]
            //   a846                 | inc                 ebp
            //   750f                 | mov                 ecx, esi
            //   b99be00100           | jbe                 0xa84
            //   e8????????           |                     
            //   e9????????           |                     

        $sequence_4 = { e8???????? 85c0 750e b958de0100 }
            // n = 4, score = 400
            //   e8????????           |                     
            //   85c0                 | mov                 eax, dword ptr [esi + 0x44]
            //   750e                 | movlpd              qword ptr [ebp - 0xe8], xmm0
            //   b958de0100           | mov                 ecx, dword ptr [ebx + 4]

        $sequence_5 = { 85c0 750e b958de0100 e8???????? 8bc8 }
            // n = 5, score = 400
            //   85c0                 | mov                 dword ptr [edi + 0x10], eax
            //   750e                 | dec                 esp
            //   b958de0100           | lea                 eax, [0x88fe0]
            //   e8????????           |                     
            //   8bc8                 | mov                 edx, eax

        $sequence_6 = { 85c0 740f b989000100 e8???????? }
            // n = 4, score = 400
            //   85c0                 | inc                 esi
            //   740f                 | je                  0x187
            //   b989000100           | mov                 eax, dword ptr [ebp + 0x14]
            //   e8????????           |                     

        $sequence_7 = { 7e16 b91bcc0000 eb05 b916cc0000 }
            // n = 4, score = 400
            //   7e16                 | inc                 ecx
            //   b91bcc0000           | mov                 dh, cl
            //   eb05                 | push                edi
            //   b916cc0000           | dec                 eax

        $sequence_8 = { eb0c b96ccb0000 eb05 b960cb0000 }
            // n = 4, score = 400
            //   eb0c                 | inc                 ebx
            //   b96ccb0000           | mov                 edx, dword ptr [ebp - 8]
            //   eb05                 | mov                 dword ptr [ebp - 0x28], ebx
            //   b960cb0000           | mov                 ebx, dword ptr [ebp - 0x48]

        $sequence_9 = { eb09 8bc7 eb0a b9a9d60000 e8???????? }
            // n = 5, score = 400
            //   eb09                 | imul                eax, edx, 0x48
            //   8bc7                 | mov                 edx, ebx
            //   eb0a                 | mov                 dword ptr [ebp - 4], ebx
            //   b9a9d60000           | cmp                 ebx, esi
            //   e8????????           |                     

    condition:
        7 of them and filesize < 1458176
}