rule win_pittytiger_rat_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.pittytiger_rat."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.pittytiger_rat"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8175ec90b48f19 8175f0596f62d6 885df4 50 8d85d4ffffff }
            // n = 5, score = 100
            //   8175ec90b48f19       | xor                 dword ptr [ebp - 0x14], 0x198fb490
            //   8175f0596f62d6       | xor                 dword ptr [ebp - 0x10], 0xd6626f59
            //   885df4               | mov                 byte ptr [ebp - 0xc], bl
            //   50                   | push                eax
            //   8d85d4ffffff         | lea                 eax, [ebp - 0x2c]

        $sequence_1 = { a3???????? 0f8451feffff 8d45b8 c745b84f70656e 50 57 }
            // n = 6, score = 100
            //   a3????????           |                     
            //   0f8451feffff         | je                  0xfffffe57
            //   8d45b8               | lea                 eax, [ebp - 0x48]
            //   c745b84f70656e       | mov                 dword ptr [ebp - 0x48], 0x6e65704f
            //   50                   | push                eax
            //   57                   | push                edi

        $sequence_2 = { ab ab aa 8d7dc8 33c0 a5 }
            // n = 6, score = 100
            //   ab                   | stosd               dword ptr es:[edi], eax
            //   ab                   | stosd               dword ptr es:[edi], eax
            //   aa                   | stosb               byte ptr es:[edi], al
            //   8d7dc8               | lea                 edi, [ebp - 0x38]
            //   33c0                 | xor                 eax, eax
            //   a5                   | movsd               dword ptr es:[edi], dword ptr [esi]

        $sequence_3 = { 397df8 7678 3bf7 7474 }
            // n = 4, score = 100
            //   397df8               | cmp                 dword ptr [ebp - 8], edi
            //   7678                 | jbe                 0x7a
            //   3bf7                 | cmp                 esi, edi
            //   7474                 | je                  0x76

        $sequence_4 = { 8bf8 83ffff 7512 ff15???????? }
            // n = 4, score = 100
            //   8bf8                 | mov                 edi, eax
            //   83ffff               | cmp                 edi, -1
            //   7512                 | jne                 0x14
            //   ff15????????         |                     

        $sequence_5 = { 3bc3 a3???????? 0f8476ffffff 8d459c c745ac65416500 50 }
            // n = 6, score = 100
            //   3bc3                 | cmp                 eax, ebx
            //   a3????????           |                     
            //   0f8476ffffff         | je                  0xffffff7c
            //   8d459c               | lea                 eax, [ebp - 0x64]
            //   c745ac65416500       | mov                 dword ptr [ebp - 0x54], 0x654165
            //   50                   | push                eax

        $sequence_6 = { 7512 ff15???????? 50 53 }
            // n = 4, score = 100
            //   7512                 | jne                 0x14
            //   ff15????????         |                     
            //   50                   | push                eax
            //   53                   | push                ebx

        $sequence_7 = { 50 895df8 ff7510 ff750c ff75fc }
            // n = 5, score = 100
            //   50                   | push                eax
            //   895df8               | mov                 dword ptr [ebp - 8], ebx
            //   ff7510               | push                dword ptr [ebp + 0x10]
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   ff75fc               | push                dword ptr [ebp - 4]

        $sequence_8 = { ff15???????? 85c0 741c 6a40 ff75f0 ffd7 6af1 }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   741c                 | je                  0x1e
            //   6a40                 | push                0x40
            //   ff75f0               | push                dword ptr [ebp - 0x10]
            //   ffd7                 | call                edi
            //   6af1                 | push                -0xf

        $sequence_9 = { 8d85dcfdffff 50 8d85e0feffff 50 7407 68???????? eb05 }
            // n = 7, score = 100
            //   8d85dcfdffff         | lea                 eax, [ebp - 0x224]
            //   50                   | push                eax
            //   8d85e0feffff         | lea                 eax, [ebp - 0x120]
            //   50                   | push                eax
            //   7407                 | je                  9
            //   68????????           |                     
            //   eb05                 | jmp                 7

    condition:
        7 of them and filesize < 2162688
}