rule win_ployx_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.ployx."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.ployx"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8bc3 25ff000000 59 3bf0 59 7443 }
            // n = 6, score = 100
            //   8bc3                 | mov                 eax, ebx
            //   25ff000000           | and                 eax, 0xff
            //   59                   | pop                 ecx
            //   3bf0                 | cmp                 esi, eax
            //   59                   | pop                 ecx
            //   7443                 | je                  0x45

        $sequence_1 = { 33db 897df8 e8???????? 397dfc 59 59 }
            // n = 6, score = 100
            //   33db                 | xor                 ebx, ebx
            //   897df8               | mov                 dword ptr [ebp - 8], edi
            //   e8????????           |                     
            //   397dfc               | cmp                 dword ptr [ebp - 4], edi
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx

        $sequence_2 = { 33ff 59 85c0 7e19 8bf0 8bfe 6a20 }
            // n = 7, score = 100
            //   33ff                 | xor                 edi, edi
            //   59                   | pop                 ecx
            //   85c0                 | test                eax, eax
            //   7e19                 | jle                 0x1b
            //   8bf0                 | mov                 esi, eax
            //   8bfe                 | mov                 edi, esi
            //   6a20                 | push                0x20

        $sequence_3 = { 66ab ff35???????? aa 8d8588faffff 68???????? 50 }
            // n = 6, score = 100
            //   66ab                 | stosw               word ptr es:[edi], ax
            //   ff35????????         |                     
            //   aa                   | stosb               byte ptr es:[edi], al
            //   8d8588faffff         | lea                 eax, [ebp - 0x578]
            //   68????????           |                     
            //   50                   | push                eax

        $sequence_4 = { 8d3c78 8d0437 50 e8???????? 8b4d08 8d3c78 8d0437 }
            // n = 7, score = 100
            //   8d3c78               | lea                 edi, [eax + edi*2]
            //   8d0437               | lea                 eax, [edi + esi]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   8d3c78               | lea                 edi, [eax + edi*2]
            //   8d0437               | lea                 eax, [edi + esi]

        $sequence_5 = { b9???????? b800020000 8d5f02 99 f7fb 47 8901 }
            // n = 7, score = 100
            //   b9????????           |                     
            //   b800020000           | mov                 eax, 0x200
            //   8d5f02               | lea                 ebx, [edi + 2]
            //   99                   | cdq                 
            //   f7fb                 | idiv                ebx
            //   47                   | inc                 edi
            //   8901                 | mov                 dword ptr [ecx], eax

        $sequence_6 = { 33ff 99 59 f7f9 8bc2 03c1 99 }
            // n = 7, score = 100
            //   33ff                 | xor                 edi, edi
            //   99                   | cdq                 
            //   59                   | pop                 ecx
            //   f7f9                 | idiv                ecx
            //   8bc2                 | mov                 eax, edx
            //   03c1                 | add                 eax, ecx
            //   99                   | cdq                 

        $sequence_7 = { 59 8945f4 0f848f000000 8d45e8 50 }
            // n = 5, score = 100
            //   59                   | pop                 ecx
            //   8945f4               | mov                 dword ptr [ebp - 0xc], eax
            //   0f848f000000         | je                  0x95
            //   8d45e8               | lea                 eax, [ebp - 0x18]
            //   50                   | push                eax

        $sequence_8 = { e8???????? 83c40c 8d85a4fcffff 6a00 50 ff15???????? 8945e8 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   8d85a4fcffff         | lea                 eax, [ebp - 0x35c]
            //   6a00                 | push                0
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8945e8               | mov                 dword ptr [ebp - 0x18], eax

        $sequence_9 = { 740f 3b7df8 7503 8975f8 57 }
            // n = 5, score = 100
            //   740f                 | je                  0x11
            //   3b7df8               | cmp                 edi, dword ptr [ebp - 8]
            //   7503                 | jne                 5
            //   8975f8               | mov                 dword ptr [ebp - 8], esi
            //   57                   | push                edi

    condition:
        7 of them and filesize < 229376
}