rule win_polpo_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.polpo."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.polpo"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 6800040000 8d8decfbffff 51 50 ffd7 6a00 }
            // n = 6, score = 100
            //   6800040000           | push                0x400
            //   8d8decfbffff         | lea                 ecx, [ebp - 0x414]
            //   51                   | push                ecx
            //   50                   | push                eax
            //   ffd7                 | call                edi
            //   6a00                 | push                0

        $sequence_1 = { 50 8d85ecf7ffff 50 8d8decfbffff 51 ff15???????? 40 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   8d85ecf7ffff         | lea                 eax, [ebp - 0x814]
            //   50                   | push                eax
            //   8d8decfbffff         | lea                 ecx, [ebp - 0x414]
            //   51                   | push                ecx
            //   ff15????????         |                     
            //   40                   | inc                 eax

        $sequence_2 = { 6a02 52 ff15???????? 8b03 50 ff15???????? }
            // n = 6, score = 100
            //   6a02                 | push                2
            //   52                   | push                edx
            //   ff15????????         |                     
            //   8b03                 | mov                 eax, dword ptr [ebx]
            //   50                   | push                eax
            //   ff15????????         |                     

        $sequence_3 = { c1e606 03348540b30120 8b45f8 8b00 8906 }
            // n = 5, score = 100
            //   c1e606               | shl                 esi, 6
            //   03348540b30120       | add                 esi, dword ptr [eax*4 + 0x2001b340]
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   8906                 | mov                 dword ptr [esi], eax

        $sequence_4 = { 57 33c0 6806020000 898d98f9ffff 50 8d8df6fdffff 51 }
            // n = 7, score = 100
            //   57                   | push                edi
            //   33c0                 | xor                 eax, eax
            //   6806020000           | push                0x206
            //   898d98f9ffff         | mov                 dword ptr [ebp - 0x668], ecx
            //   50                   | push                eax
            //   8d8df6fdffff         | lea                 ecx, [ebp - 0x20a]
            //   51                   | push                ecx

        $sequence_5 = { 8d854cffffff 8bd0 8d642400 8a08 40 3acb 75f9 }
            // n = 7, score = 100
            //   8d854cffffff         | lea                 eax, [ebp - 0xb4]
            //   8bd0                 | mov                 edx, eax
            //   8d642400             | lea                 esp, [esp]
            //   8a08                 | mov                 cl, byte ptr [eax]
            //   40                   | inc                 eax
            //   3acb                 | cmp                 cl, bl
            //   75f9                 | jne                 0xfffffffb

        $sequence_6 = { 52 50 ff15???????? 6a00 6800040000 8d8dfcfaffff 68???????? }
            // n = 7, score = 100
            //   52                   | push                edx
            //   50                   | push                eax
            //   ff15????????         |                     
            //   6a00                 | push                0
            //   6800040000           | push                0x400
            //   8d8dfcfaffff         | lea                 ecx, [ebp - 0x504]
            //   68????????           |                     

        $sequence_7 = { 8a08 40 3acb 75f9 2bc6 8dbd4cf7ffff }
            // n = 6, score = 100
            //   8a08                 | mov                 cl, byte ptr [eax]
            //   40                   | inc                 eax
            //   3acb                 | cmp                 cl, bl
            //   75f9                 | jne                 0xfffffffb
            //   2bc6                 | sub                 eax, esi
            //   8dbd4cf7ffff         | lea                 edi, [ebp - 0x8b4]

        $sequence_8 = { 51 8985d0dfffff 8985d4dfffff 8885dcdfffff e8???????? }
            // n = 5, score = 100
            //   51                   | push                ecx
            //   8985d0dfffff         | mov                 dword ptr [ebp - 0x2030], eax
            //   8985d4dfffff         | mov                 dword ptr [ebp - 0x202c], eax
            //   8885dcdfffff         | mov                 byte ptr [ebp - 0x2024], al
            //   e8????????           |                     

        $sequence_9 = { ffd6 85c0 8b859cfdffff 50 0f8516020000 ff15???????? 8d45a4 }
            // n = 7, score = 100
            //   ffd6                 | call                esi
            //   85c0                 | test                eax, eax
            //   8b859cfdffff         | mov                 eax, dword ptr [ebp - 0x264]
            //   50                   | push                eax
            //   0f8516020000         | jne                 0x21c
            //   ff15????????         |                     
            //   8d45a4               | lea                 eax, [ebp - 0x5c]

    condition:
        7 of them and filesize < 250880
}