rule win_pony_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.pony."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.pony"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c20400 55 89e5 83ec18 53 }
            // n = 5, score = 800
            //   c20400               | ret                 4
            //   55                   | push                ebp
            //   89e5                 | mov                 ebp, esp
            //   83ec18               | sub                 esp, 0x18
            //   53                   | push                ebx

        $sequence_1 = { c745f400000000 8d45f8 50 ff7508 6a00 ff15???????? }
            // n = 6, score = 800
            //   c745f400000000       | mov                 dword ptr [ebp - 0xc], 0
            //   8d45f8               | lea                 eax, [ebp - 8]
            //   50                   | push                eax
            //   ff7508               | push                dword ptr [ebp + 8]
            //   6a00                 | push                0
            //   ff15????????         |                     

        $sequence_2 = { bfffffffff 33f9 0bf8 33fb 8d941792cc0c8f 03560c }
            // n = 6, score = 800
            //   bfffffffff           | mov                 edi, 0xffffffff
            //   33f9                 | xor                 edi, ecx
            //   0bf8                 | or                  edi, eax
            //   33fb                 | xor                 edi, ebx
            //   8d941792cc0c8f       | lea                 edx, [edi + edx - 0x70f3336e]
            //   03560c               | add                 edx, dword ptr [esi + 0xc]

        $sequence_3 = { ff75e8 ff7508 e8???????? 23d8 ff75ec e8???????? }
            // n = 6, score = 800
            //   ff75e8               | push                dword ptr [ebp - 0x18]
            //   ff7508               | push                dword ptr [ebp + 8]
            //   e8????????           |                     
            //   23d8                 | and                 ebx, eax
            //   ff75ec               | push                dword ptr [ebp - 0x14]
            //   e8????????           |                     

        $sequence_4 = { f7d0 50 ff7508 e8???????? c9 c20400 }
            // n = 6, score = 800
            //   f7d0                 | not                 eax
            //   50                   | push                eax
            //   ff7508               | push                dword ptr [ebp + 8]
            //   e8????????           |                     
            //   c9                   | leave               
            //   c20400               | ret                 4

        $sequence_5 = { ff7514 e8???????? eb0d 68???????? }
            // n = 4, score = 800
            //   ff7514               | push                dword ptr [ebp + 0x14]
            //   e8????????           |                     
            //   eb0d                 | jmp                 0xf
            //   68????????           |                     

        $sequence_6 = { c9 c20400 55 8bec 83c4fc ff7514 ff7510 }
            // n = 7, score = 800
            //   c9                   | leave               
            //   c20400               | ret                 4
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   83c4fc               | add                 esp, -4
            //   ff7514               | push                dword ptr [ebp + 0x14]
            //   ff7510               | push                dword ptr [ebp + 0x10]

        $sequence_7 = { ff75c8 e8???????? ff75c4 e8???????? ff75bc }
            // n = 5, score = 800
            //   ff75c8               | push                dword ptr [ebp - 0x38]
            //   e8????????           |                     
            //   ff75c4               | push                dword ptr [ebp - 0x3c]
            //   e8????????           |                     
            //   ff75bc               | push                dword ptr [ebp - 0x44]

        $sequence_8 = { b9ffffffff f2ae 3807 75c5 6a1a ff7508 }
            // n = 6, score = 800
            //   b9ffffffff           | mov                 ecx, 0xffffffff
            //   f2ae                 | repne scasb         al, byte ptr es:[edi]
            //   3807                 | cmp                 byte ptr [edi], al
            //   75c5                 | jne                 0xffffffc7
            //   6a1a                 | push                0x1a
            //   ff7508               | push                dword ptr [ebp + 8]

        $sequence_9 = { e8???????? ff7510 6a18 ff7508 e8???????? ff7510 }
            // n = 6, score = 800
            //   e8????????           |                     
            //   ff7510               | push                dword ptr [ebp + 0x10]
            //   6a18                 | push                0x18
            //   ff7508               | push                dword ptr [ebp + 8]
            //   e8????????           |                     
            //   ff7510               | push                dword ptr [ebp + 0x10]

    condition:
        7 of them and filesize < 262144
}