rule win_poortry_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.poortry."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.poortry"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 41f7d2 f9 4181f80255e860 4181f225619d1f 41f7da f8 4181c2174c0279 }
            // n = 7, score = 100
            //   41f7d2               | inc                 sp
            //   f9                   | test                edx, ebp
            //   4181f80255e860       | dec                 eax
            //   4181f225619d1f       | stc                 
            //   41f7da               | inc                 ecx
            //   f8                   | push                edx
            //   4181c2174c0279       | xor                 dword ptr [esp], eax

        $sequence_1 = { 66f7c4e120 310424 5e 41f6c105 443af4 4863c0 f5 }
            // n = 7, score = 100
            //   66f7c4e120           | inc                 ecx
            //   310424               | cmp                 dh, 0xc7
            //   5e                   | cmc                 
            //   41f6c105             | inc                 ecx
            //   443af4               | push                ecx
            //   4863c0               | inc                 ecx
            //   f5                   | rcr                 ecx, 0x39

        $sequence_2 = { 66443bf0 56 0fbae697 c1e61f 311424 f9 660fbafec8 }
            // n = 7, score = 100
            //   66443bf0             | stc                 
            //   56                   | inc                 ecx
            //   0fbae697             | add                 ecx, 0x4b920dbb
            //   c1e61f               | inc                 ecx
            //   311424               | ror                 ecx, 3
            //   f9                   | inc                 ecx
            //   660fbafec8           | bswap               ecx

        $sequence_3 = { 41f7d3 4151 450aca 6641d3e1 44311c24 4180d1a2 }
            // n = 6, score = 100
            //   41f7d3               | cmp                 ah, 0x17
            //   4151                 | add                 ebx, 0x1ca11f20
            //   450aca               | clc                 
            //   6641d3e1             | rol                 ebx, 2
            //   44311c24             | not                 ebx
            //   4180d1a2             | xor                 ebx, esi

        $sequence_4 = { f8 81f79e0d521c f8 d1cf 81c71d19891d f8 f5 }
            // n = 7, score = 100
            //   f8                   | dec                 eax
            //   81f79e0d521c         | arpl                cx, cx
            //   f8                   | inc                 ecx
            //   d1cf                 | test                eax, 0x29734a8a
            //   81c71d19891d         | push                ebx
            //   f8                   | btc                 bx, 0x96
            //   f5                   | xor                 dword ptr [esp], ebp

        $sequence_5 = { 4151 41c0e937 4d0fb7c9 313424 450fc0c9 66450fabf1 66410fbae1d7 }
            // n = 7, score = 100
            //   4151                 | clc                 
            //   41c0e937             | stc                 
            //   4d0fb7c9             | inc                 ecx
            //   313424               | rol                 ecx, 1
            //   450fc0c9             | cmp                 bx, 0x27fc
            //   66450fabf1           | inc                 ecx
            //   66410fbae1d7         | sub                 ecx, 0x1356673e

        $sequence_6 = { 4484c7 81c33f50eb3f 664181f8ec0e f7db 4153 311c24 6641c1c318 }
            // n = 7, score = 100
            //   4484c7               | pushfd              
            //   81c33f50eb3f         | sar                 ah, cl
            //   664181f8ec0e         | btr                 eax, ebx
            //   f7db                 | movsx               eax, dx
            //   4153                 | bt                  ax, di
            //   311c24               | inc                 ebp
            //   6641c1c318           | sub                 eax, eax

        $sequence_7 = { 56 401af3 40d2e6 66f7c4e120 310424 5e 41f6c105 }
            // n = 7, score = 100
            //   56                   | pop                 ecx
            //   401af3               | stc                 
            //   40d2e6               | inc                 eax
            //   66f7c4e120           | cmp                 bh, 8
            //   310424               | inc                 ecx
            //   5e                   | push                edx
            //   41f6c105             | xor                 dword ptr [esp], eax

        $sequence_8 = { 4123ea 48c1d5cd 5d f9 4d63c9 4881f98925786f 664185d3 }
            // n = 7, score = 100
            //   4123ea               | dec                 ebp
            //   48c1d5cd             | test                ecx, ecx
            //   5d                   | je                  0xfff5b85e
            //   f9                   | dec                 eax
            //   4d63c9               | lea                 ebx, [0xffff2295]
            //   4881f98925786f       | inc                 ecx
            //   664185d3             | test                bh, bl

        $sequence_9 = { f6dd 4159 4084ee 40b5c4 9d 66400fbecd 59 }
            // n = 7, score = 100
            //   f6dd                 | inc                 ecx
            //   4159                 | xor                 edx, edx
            //   4084ee               | clc                 
            //   40b5c4               | neg                 edx
            //   9d                   | inc                 ecx
            //   66400fbecd           | test                bh, 0x59
            //   59                   | clc                 

    condition:
        7 of them and filesize < 8078336
}