rule win_portdoor_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.portdoor."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.portdoor"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 50 e8???????? 83f8ff 8906 0f95c0 eb2f 807e5100 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   e8????????           |                     
            //   83f8ff               | cmp                 eax, -1
            //   8906                 | mov                 dword ptr [esi], eax
            //   0f95c0               | setne               al
            //   eb2f                 | jmp                 0x31
            //   807e5100             | cmp                 byte ptr [esi + 0x51], 0

        $sequence_1 = { 50 8d85fcf3ffff 50 e8???????? 8bf0 }
            // n = 5, score = 100
            //   50                   | push                eax
            //   8d85fcf3ffff         | lea                 eax, [ebp - 0xc04]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax

        $sequence_2 = { ff5718 8903 6a04 59 8d4102 33d2 }
            // n = 6, score = 100
            //   ff5718               | call                dword ptr [edi + 0x18]
            //   8903                 | mov                 dword ptr [ebx], eax
            //   6a04                 | push                4
            //   59                   | pop                 ecx
            //   8d4102               | lea                 eax, [ecx + 2]
            //   33d2                 | xor                 edx, edx

        $sequence_3 = { 8945a8 eb04 8365a800 8b45a8 894590 834dfcff 8b4590 }
            // n = 7, score = 100
            //   8945a8               | mov                 dword ptr [ebp - 0x58], eax
            //   eb04                 | jmp                 6
            //   8365a800             | and                 dword ptr [ebp - 0x58], 0
            //   8b45a8               | mov                 eax, dword ptr [ebp - 0x58]
            //   894590               | mov                 dword ptr [ebp - 0x70], eax
            //   834dfcff             | or                  dword ptr [ebp - 4], 0xffffffff
            //   8b4590               | mov                 eax, dword ptr [ebp - 0x70]

        $sequence_4 = { 50 8b8528e5ffff 0f94c1 898d3ce5ffff 8b8d24e5ffff 8b0485b80f0210 ff3401 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   8b8528e5ffff         | mov                 eax, dword ptr [ebp - 0x1ad8]
            //   0f94c1               | sete                cl
            //   898d3ce5ffff         | mov                 dword ptr [ebp - 0x1ac4], ecx
            //   8b8d24e5ffff         | mov                 ecx, dword ptr [ebp - 0x1adc]
            //   8b0485b80f0210       | mov                 eax, dword ptr [eax*4 + 0x10020fb8]
            //   ff3401               | push                dword ptr [ecx + eax]

        $sequence_5 = { 894224 6689424c 894248 88424e 8a01 88040b }
            // n = 6, score = 100
            //   894224               | mov                 dword ptr [edx + 0x24], eax
            //   6689424c             | mov                 word ptr [edx + 0x4c], ax
            //   894248               | mov                 dword ptr [edx + 0x48], eax
            //   88424e               | mov                 byte ptr [edx + 0x4e], al
            //   8a01                 | mov                 al, byte ptr [ecx]
            //   88040b               | mov                 byte ptr [ebx + ecx], al

        $sequence_6 = { 7e21 8b450c 6a00 2bc6 }
            // n = 4, score = 100
            //   7e21                 | jle                 0x23
            //   8b450c               | mov                 eax, dword ptr [ebp + 0xc]
            //   6a00                 | push                0
            //   2bc6                 | sub                 eax, esi

        $sequence_7 = { 51 51 8d45f8 895df8 }
            // n = 4, score = 100
            //   51                   | push                ecx
            //   51                   | push                ecx
            //   8d45f8               | lea                 eax, [ebp - 8]
            //   895df8               | mov                 dword ptr [ebp - 8], ebx

        $sequence_8 = { e8???????? 8bf8 b8eeff0000 59 668907 8b450c 885f02 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8bf8                 | mov                 edi, eax
            //   b8eeff0000           | mov                 eax, 0xffee
            //   59                   | pop                 ecx
            //   668907               | mov                 word ptr [edi], ax
            //   8b450c               | mov                 eax, dword ptr [ebp + 0xc]
            //   885f02               | mov                 byte ptr [edi + 2], bl

        $sequence_9 = { e8???????? a1???????? 33c5 8945fc 53 8b5d08 8d85fdfbffff }
            // n = 7, score = 100
            //   e8????????           |                     
            //   a1????????           |                     
            //   33c5                 | xor                 eax, ebp
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   53                   | push                ebx
            //   8b5d08               | mov                 ebx, dword ptr [ebp + 8]
            //   8d85fdfbffff         | lea                 eax, [ebp - 0x403]

    condition:
        7 of them and filesize < 297984
}