rule win_poweliks_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.poweliks."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.poweliks"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { eb0b 8b5118 ebc9 8b5dec 8b75e8 8b45f8 8b0c87 }
            // n = 7, score = 200
            //   eb0b                 | jmp                 0xd
            //   8b5118               | mov                 edx, dword ptr [ecx + 0x18]
            //   ebc9                 | jmp                 0xffffffcb
            //   8b5dec               | mov                 ebx, dword ptr [ebp - 0x14]
            //   8b75e8               | mov                 esi, dword ptr [ebp - 0x18]
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   8b0c87               | mov                 ecx, dword ptr [edi + eax*4]

        $sequence_1 = { c745b4726f6341 c745b864647265 66c745bc7373 c645be00 8bc8 57 }
            // n = 6, score = 200
            //   c745b4726f6341       | mov                 dword ptr [ebp - 0x4c], 0x41636f72
            //   c745b864647265       | mov                 dword ptr [ebp - 0x48], 0x65726464
            //   66c745bc7373         | mov                 word ptr [ebp - 0x44], 0x7373
            //   c645be00             | mov                 byte ptr [ebp - 0x42], 0
            //   8bc8                 | mov                 ecx, eax
            //   57                   | push                edi

        $sequence_2 = { 83ff0c 7439 3bc8 75ce 8b5508 }
            // n = 5, score = 200
            //   83ff0c               | cmp                 edi, 0xc
            //   7439                 | je                  0x3b
            //   3bc8                 | cmp                 ecx, eax
            //   75ce                 | jne                 0xffffffd0
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]

        $sequence_3 = { 8d5598 33ff 2bf2 8d147e 8a541598 32547d98 }
            // n = 6, score = 200
            //   8d5598               | lea                 edx, [ebp - 0x68]
            //   33ff                 | xor                 edi, edi
            //   2bf2                 | sub                 esi, edx
            //   8d147e               | lea                 edx, [esi + edi*2]
            //   8a541598             | mov                 dl, byte ptr [ebp + edx - 0x68]
            //   32547d98             | xor                 dl, byte ptr [ebp + edi*2 - 0x68]

        $sequence_4 = { 7415 8b7d08 8b720c 81c704110000 03f7 8b7a04 }
            // n = 6, score = 200
            //   7415                 | je                  0x17
            //   8b7d08               | mov                 edi, dword ptr [ebp + 8]
            //   8b720c               | mov                 esi, dword ptr [edx + 0xc]
            //   81c704110000         | add                 edi, 0x1104
            //   03f7                 | add                 esi, edi
            //   8b7a04               | mov                 edi, dword ptr [edx + 4]

        $sequence_5 = { 663b4b06 7333 8b4a08 8b32 3bce 7602 8bce }
            // n = 7, score = 200
            //   663b4b06             | cmp                 cx, word ptr [ebx + 6]
            //   7333                 | jae                 0x35
            //   8b4a08               | mov                 ecx, dword ptr [edx + 8]
            //   8b32                 | mov                 esi, dword ptr [edx]
            //   3bce                 | cmp                 ecx, esi
            //   7602                 | jbe                 4
            //   8bce                 | mov                 ecx, esi

        $sequence_6 = { 33c9 663b4b06 7333 8b4a08 8b32 3bce 7602 }
            // n = 7, score = 200
            //   33c9                 | xor                 ecx, ecx
            //   663b4b06             | cmp                 cx, word ptr [ebx + 6]
            //   7333                 | jae                 0x35
            //   8b4a08               | mov                 ecx, dword ptr [edx + 8]
            //   8b32                 | mov                 esi, dword ptr [edx]
            //   3bce                 | cmp                 ecx, esi
            //   7602                 | jbe                 4

        $sequence_7 = { 57 0fb65dfe 81e307000080 7905 4b }
            // n = 5, score = 200
            //   57                   | push                edi
            //   0fb65dfe             | movzx               ebx, byte ptr [ebp - 2]
            //   81e307000080         | and                 ebx, 0x80000007
            //   7905                 | jns                 7
            //   4b                   | dec                 ebx

        $sequence_8 = { 8b3486 8365fc00 03ca 894df4 8d45d0 03f2 2945f4 }
            // n = 7, score = 200
            //   8b3486               | mov                 esi, dword ptr [esi + eax*4]
            //   8365fc00             | and                 dword ptr [ebp - 4], 0
            //   03ca                 | add                 ecx, edx
            //   894df4               | mov                 dword ptr [ebp - 0xc], ecx
            //   8d45d0               | lea                 eax, [ebp - 0x30]
            //   03f2                 | add                 esi, edx
            //   2945f4               | sub                 dword ptr [ebp - 0xc], eax

        $sequence_9 = { 3a5c0db0 7506 40 83f80f }
            // n = 4, score = 200
            //   3a5c0db0             | cmp                 bl, byte ptr [ebp + ecx - 0x50]
            //   7506                 | jne                 8
            //   40                   | inc                 eax
            //   83f80f               | cmp                 eax, 0xf

    condition:
        7 of them and filesize < 115712
}