rule win_powerduke_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.powerduke."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.powerduke"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c705????????00000000 6a04 6800300000 ff7518 }
            // n = 4, score = 500
            //   c705????????00000000     |     
            //   6a04                 | push                4
            //   6800300000           | push                0x3000
            //   ff7518               | push                dword ptr [ebp + 0x18]

        $sequence_1 = { ff75e4 ff75bc ff15???????? 09c0 7473 }
            // n = 5, score = 500
            //   ff75e4               | push                dword ptr [ebp - 0x1c]
            //   ff75bc               | push                dword ptr [ebp - 0x44]
            //   ff15????????         |                     
            //   09c0                 | or                  eax, eax
            //   7473                 | je                  0x75

        $sequence_2 = { 6a00 ff15???????? 09c0 0f8412010000 8945e4 53 50 }
            // n = 7, score = 500
            //   6a00                 | push                0
            //   ff15????????         |                     
            //   09c0                 | or                  eax, eax
            //   0f8412010000         | je                  0x118
            //   8945e4               | mov                 dword ptr [ebp - 0x1c], eax
            //   53                   | push                ebx
            //   50                   | push                eax

        $sequence_3 = { b801000000 c9 c20c00 55 89e5 81ec080c0000 }
            // n = 6, score = 500
            //   b801000000           | mov                 eax, 1
            //   c9                   | leave               
            //   c20c00               | ret                 0xc
            //   55                   | push                ebp
            //   89e5                 | mov                 ebp, esp
            //   81ec080c0000         | sub                 esp, 0xc08

        $sequence_4 = { 89f7 31c9 803c0f3a 7409 }
            // n = 4, score = 500
            //   89f7                 | mov                 edi, esi
            //   31c9                 | xor                 ecx, ecx
            //   803c0f3a             | cmp                 byte ptr [edi + ecx], 0x3a
            //   7409                 | je                  0xb

        $sequence_5 = { 09c0 7505 b850000000 8945ec c6040e00 }
            // n = 5, score = 500
            //   09c0                 | or                  eax, eax
            //   7505                 | jne                 7
            //   b850000000           | mov                 eax, 0x50
            //   8945ec               | mov                 dword ptr [ebp - 0x14], eax
            //   c6040e00             | mov                 byte ptr [esi + ecx], 0

        $sequence_6 = { c70000000000 837d2000 740f 8b4520 }
            // n = 4, score = 500
            //   c70000000000         | mov                 dword ptr [eax], 0
            //   837d2000             | cmp                 dword ptr [ebp + 0x20], 0
            //   740f                 | je                  0x11
            //   8b4520               | mov                 eax, dword ptr [ebp + 0x20]

        $sequence_7 = { c20400 55 89e5 56 57 8b750c }
            // n = 6, score = 500
            //   c20400               | ret                 4
            //   55                   | push                ebp
            //   89e5                 | mov                 ebp, esp
            //   56                   | push                esi
            //   57                   | push                edi
            //   8b750c               | mov                 esi, dword ptr [ebp + 0xc]

        $sequence_8 = { 0f8493000000 c745f901000000 89c3 be???????? }
            // n = 4, score = 500
            //   0f8493000000         | je                  0x99
            //   c745f901000000       | mov                 dword ptr [ebp - 7], 1
            //   89c3                 | mov                 ebx, eax
            //   be????????           |                     

        $sequence_9 = { 6a00 57 ff15???????? 09c0 }
            // n = 4, score = 500
            //   6a00                 | push                0
            //   57                   | push                edi
            //   ff15????????         |                     
            //   09c0                 | or                  eax, eax

    condition:
        7 of them and filesize < 57344
}