rule win_powersniff_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.powersniff."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.powersniff"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 53 ff35???????? 8945f8 895dfc }
            // n = 4, score = 100
            //   53                   | push                ebx
            //   ff35????????         |                     
            //   8945f8               | mov                 dword ptr [ebp - 8], eax
            //   895dfc               | mov                 dword ptr [ebp - 4], ebx

        $sequence_1 = { 8b45f4 b94d5a0000 663908 7405 6a0b 5b eb0f }
            // n = 7, score = 100
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]
            //   b94d5a0000           | mov                 ecx, 0x5a4d
            //   663908               | cmp                 word ptr [eax], cx
            //   7405                 | je                  7
            //   6a0b                 | push                0xb
            //   5b                   | pop                 ebx
            //   eb0f                 | jmp                 0x11

        $sequence_2 = { 53 56 8b35???????? 57 8d85d8fdffff 50 33db }
            // n = 7, score = 100
            //   53                   | push                ebx
            //   56                   | push                esi
            //   8b35????????         |                     
            //   57                   | push                edi
            //   8d85d8fdffff         | lea                 eax, [ebp - 0x228]
            //   50                   | push                eax
            //   33db                 | xor                 ebx, ebx

        $sequence_3 = { c1eb10 8975fc 8b75f8 c1ee18 8b34b590780010 0fb6db }
            // n = 6, score = 100
            //   c1eb10               | shr                 ebx, 0x10
            //   8975fc               | mov                 dword ptr [ebp - 4], esi
            //   8b75f8               | mov                 esi, dword ptr [ebp - 8]
            //   c1ee18               | shr                 esi, 0x18
            //   8b34b590780010       | mov                 esi, dword ptr [esi*4 + 0x10007890]
            //   0fb6db               | movzx               ebx, bl

        $sequence_4 = { 50 8d45f8 50 ff75fc e8???????? 8bd8 3bde }
            // n = 7, score = 100
            //   50                   | push                eax
            //   8d45f8               | lea                 eax, [ebp - 8]
            //   50                   | push                eax
            //   ff75fc               | push                dword ptr [ebp - 4]
            //   e8????????           |                     
            //   8bd8                 | mov                 ebx, eax
            //   3bde                 | cmp                 ebx, esi

        $sequence_5 = { c745fc08000000 eb09 ff15???????? 8945fc 8b45fc 5f 5e }
            // n = 7, score = 100
            //   c745fc08000000       | mov                 dword ptr [ebp - 4], 8
            //   eb09                 | jmp                 0xb
            //   ff15????????         |                     
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi

        $sequence_6 = { ff15???????? 8bf8 897df0 3bfb 7435 8d4508 50 }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   8bf8                 | mov                 edi, eax
            //   897df0               | mov                 dword ptr [ebp - 0x10], edi
            //   3bfb                 | cmp                 edi, ebx
            //   7435                 | je                  0x37
            //   8d4508               | lea                 eax, [ebp + 8]
            //   50                   | push                eax

        $sequence_7 = { 55 8bec 83ec0c 8b473c 03c7 53 8b9880000000 }
            // n = 7, score = 100
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   83ec0c               | sub                 esp, 0xc
            //   8b473c               | mov                 eax, dword ptr [edi + 0x3c]
            //   03c7                 | add                 eax, edi
            //   53                   | push                ebx
            //   8b9880000000         | mov                 ebx, dword ptr [eax + 0x80]

        $sequence_8 = { ff15???????? 85c0 0f84b4000000 8d8590feffff 50 ffd3 034574 }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   0f84b4000000         | je                  0xba
            //   8d8590feffff         | lea                 eax, [ebp - 0x170]
            //   50                   | push                eax
            //   ffd3                 | call                ebx
            //   034574               | add                 eax, dword ptr [ebp + 0x74]

        $sequence_9 = { a1???????? 53 68???????? ff750c 8945f8 ff7508 }
            // n = 6, score = 100
            //   a1????????           |                     
            //   53                   | push                ebx
            //   68????????           |                     
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   8945f8               | mov                 dword ptr [ebp - 8], eax
            //   ff7508               | push                dword ptr [ebp + 8]

    condition:
        7 of them and filesize < 90112
}