rule win_predator_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.predator."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.predator"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 55 8bec 83ec18 8bc2 56 8bf1 8d4dfd }
            // n = 7, score = 800
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   83ec18               | sub                 esp, 0x18
            //   8bc2                 | mov                 eax, edx
            //   56                   | push                esi
            //   8bf1                 | mov                 esi, ecx
            //   8d4dfd               | lea                 ecx, [ebp - 3]

        $sequence_1 = { 80c230 8811 85c0 75f2 51 8d45fd }
            // n = 6, score = 800
            //   80c230               | add                 dl, 0x30
            //   8811                 | mov                 byte ptr [ecx], dl
            //   85c0                 | test                eax, eax
            //   75f2                 | jne                 0xfffffff4
            //   51                   | push                ecx
            //   8d45fd               | lea                 eax, [ebp - 3]

        $sequence_2 = { 8d4dfd 57 6a0a 5f 85c0 7916 }
            // n = 6, score = 800
            //   8d4dfd               | lea                 ecx, [ebp - 3]
            //   57                   | push                edi
            //   6a0a                 | push                0xa
            //   5f                   | pop                 edi
            //   85c0                 | test                eax, eax
            //   7916                 | jns                 0x18

        $sequence_3 = { 03c2 8bce 50 e8???????? 5f 8bc6 5e }
            // n = 7, score = 800
            //   03c2                 | add                 eax, edx
            //   8bce                 | mov                 ecx, esi
            //   50                   | push                eax
            //   e8????????           |                     
            //   5f                   | pop                 edi
            //   8bc6                 | mov                 eax, esi
            //   5e                   | pop                 esi

        $sequence_4 = { 7508 83c8ff e9???????? ff75ec e8???????? }
            // n = 5, score = 800
            //   7508                 | jne                 0xa
            //   83c8ff               | or                  eax, 0xffffffff
            //   e9????????           |                     
            //   ff75ec               | push                dword ptr [ebp - 0x14]
            //   e8????????           |                     

        $sequence_5 = { 83ec18 8bc2 56 8bf1 8d4dfd }
            // n = 5, score = 800
            //   83ec18               | sub                 esp, 0x18
            //   8bc2                 | mov                 eax, edx
            //   56                   | push                esi
            //   8bf1                 | mov                 esi, ecx
            //   8d4dfd               | lea                 ecx, [ebp - 3]

        $sequence_6 = { ff75ec e8???????? 59 8bf0 }
            // n = 4, score = 800
            //   ff75ec               | push                dword ptr [ebp - 0x14]
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   8bf0                 | mov                 esi, eax

        $sequence_7 = { 7508 83c8ff e9???????? ff75ec e8???????? 59 8bf0 }
            // n = 7, score = 800
            //   7508                 | jne                 0xa
            //   83c8ff               | or                  eax, 0xffffffff
            //   e9????????           |                     
            //   ff75ec               | push                dword ptr [ebp - 0x14]
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   8bf0                 | mov                 esi, eax

        $sequence_8 = { 894e08 89560c 834dfcff 8b4df4 64890d00000000 5f 5e }
            // n = 7, score = 800
            //   894e08               | mov                 dword ptr [esi + 8], ecx
            //   89560c               | mov                 dword ptr [esi + 0xc], edx
            //   834dfcff             | or                  dword ptr [ebp - 4], 0xffffffff
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]
            //   64890d00000000       | mov                 dword ptr fs:[0], ecx
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi

        $sequence_9 = { 8b00 57 03c2 8bce }
            // n = 4, score = 800
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   57                   | push                edi
            //   03c2                 | add                 eax, edx
            //   8bce                 | mov                 ecx, esi

    condition:
        7 of them and filesize < 2211840
}