rule win_prestige_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.prestige."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.prestige"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 894648 8b7a4c 897e4c 837a4c10 7706 }
            // n = 5, score = 100
            //   894648               | mov                 dword ptr [esi + 0x48], eax
            //   8b7a4c               | mov                 edi, dword ptr [edx + 0x4c]
            //   897e4c               | mov                 dword ptr [esi + 0x4c], edi
            //   837a4c10             | cmp                 dword ptr [edx + 0x4c], 0x10
            //   7706                 | ja                  8

        $sequence_1 = { 03f3 c706652b3030 8d4604 33d2 e9???????? 8bd1 c745c409000000 }
            // n = 7, score = 100
            //   03f3                 | add                 esi, ebx
            //   c706652b3030         | mov                 dword ptr [esi], 0x30302b65
            //   8d4604               | lea                 eax, [esi + 4]
            //   33d2                 | xor                 edx, edx
            //   e9????????           |                     
            //   8bd1                 | mov                 edx, ecx
            //   c745c409000000       | mov                 dword ptr [ebp - 0x3c], 9

        $sequence_2 = { 83f826 7603 6a26 58 0fb60c85be534700 0fb63485bf534700 }
            // n = 6, score = 100
            //   83f826               | cmp                 eax, 0x26
            //   7603                 | jbe                 5
            //   6a26                 | push                0x26
            //   58                   | pop                 eax
            //   0fb60c85be534700     | movzx               ecx, byte ptr [eax*4 + 0x4753be]
            //   0fb63485bf534700     | movzx               esi, byte ptr [eax*4 + 0x4753bf]

        $sequence_3 = { b9fe020000 3bc1 0f4fc1 8d8decfcffff 50 8985e8fcffff e8???????? }
            // n = 7, score = 100
            //   b9fe020000           | mov                 ecx, 0x2fe
            //   3bc1                 | cmp                 eax, ecx
            //   0f4fc1               | cmovg               eax, ecx
            //   8d8decfcffff         | lea                 ecx, [ebp - 0x314]
            //   50                   | push                eax
            //   8985e8fcffff         | mov                 dword ptr [ebp - 0x318], eax
            //   e8????????           |                     

        $sequence_4 = { 3bf0 730a 8bc6 89742410 897c2414 50 ff7508 }
            // n = 7, score = 100
            //   3bf0                 | cmp                 esi, eax
            //   730a                 | jae                 0xc
            //   8bc6                 | mov                 eax, esi
            //   89742410             | mov                 dword ptr [esp + 0x10], esi
            //   897c2414             | mov                 dword ptr [esp + 0x14], edi
            //   50                   | push                eax
            //   ff7508               | push                dword ptr [ebp + 8]

        $sequence_5 = { 8d45fc 50 8bd6 e8???????? 8b7508 8bf8 59 }
            // n = 7, score = 100
            //   8d45fc               | lea                 eax, [ebp - 4]
            //   50                   | push                eax
            //   8bd6                 | mov                 edx, esi
            //   e8????????           |                     
            //   8b7508               | mov                 esi, dword ptr [ebp + 8]
            //   8bf8                 | mov                 edi, eax
            //   59                   | pop                 ecx

        $sequence_6 = { 8bf2 57 8bf9 8d4e02 668b06 83c602 6685c0 }
            // n = 7, score = 100
            //   8bf2                 | mov                 esi, edx
            //   57                   | push                edi
            //   8bf9                 | mov                 edi, ecx
            //   8d4e02               | lea                 ecx, [esi + 2]
            //   668b06               | mov                 ax, word ptr [esi]
            //   83c602               | add                 esi, 2
            //   6685c0               | test                ax, ax

        $sequence_7 = { 85c0 740c 8d432c 8945f8 8b00 }
            // n = 5, score = 100
            //   85c0                 | test                eax, eax
            //   740c                 | je                  0xe
            //   8d432c               | lea                 eax, [ebx + 0x2c]
            //   8945f8               | mov                 dword ptr [ebp - 8], eax
            //   8b00                 | mov                 eax, dword ptr [eax]

        $sequence_8 = { 8945d8 8b45e8 5e 13ce f765e0 6a00 8945ec }
            // n = 7, score = 100
            //   8945d8               | mov                 dword ptr [ebp - 0x28], eax
            //   8b45e8               | mov                 eax, dword ptr [ebp - 0x18]
            //   5e                   | pop                 esi
            //   13ce                 | adc                 ecx, esi
            //   f765e0               | mul                 dword ptr [ebp - 0x20]
            //   6a00                 | push                0
            //   8945ec               | mov                 dword ptr [ebp - 0x14], eax

        $sequence_9 = { 59 c3 8b4c240c 68???????? e8???????? 8b44240c 5e }
            // n = 7, score = 100
            //   59                   | pop                 ecx
            //   c3                   | ret                 
            //   8b4c240c             | mov                 ecx, dword ptr [esp + 0xc]
            //   68????????           |                     
            //   e8????????           |                     
            //   8b44240c             | mov                 eax, dword ptr [esp + 0xc]
            //   5e                   | pop                 esi

    condition:
        7 of them and filesize < 1518592
}