rule win_pss_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.pss."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.pss"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d48fe e8???????? e9???????? 83f811 }
            // n = 4, score = 300
            //   8d48fe               | lea                 ecx, [eax - 2]
            //   e8????????           |                     
            //   e9????????           |                     
            //   83f811               | cmp                 eax, 0x11

        $sequence_1 = { 7437 ff15???????? 3de5030000 752a }
            // n = 4, score = 300
            //   7437                 | je                  0x39
            //   ff15????????         |                     
            //   3de5030000           | cmp                 eax, 0x3e5
            //   752a                 | jne                 0x2c

        $sequence_2 = { ff15???????? 83ceff 3bc6 7504 }
            // n = 4, score = 300
            //   ff15????????         |                     
            //   83ceff               | or                  esi, 0xffffffff
            //   3bc6                 | cmp                 eax, esi
            //   7504                 | jne                 6

        $sequence_3 = { 5e 5b 0f42ca 85c0 0f45c8 }
            // n = 5, score = 200
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx
            //   0f42ca               | cmovb               ecx, edx
            //   85c0                 | test                eax, eax
            //   0f45c8               | cmovne              ecx, eax

        $sequence_4 = { 0fb619 0fb6c0 eb17 81fb00010000 7313 8a87a4f10110 }
            // n = 6, score = 200
            //   0fb619               | movzx               ebx, byte ptr [ecx]
            //   0fb6c0               | movzx               eax, al
            //   eb17                 | jmp                 0x19
            //   81fb00010000         | cmp                 ebx, 0x100
            //   7313                 | jae                 0x15
            //   8a87a4f10110         | mov                 al, byte ptr [edi + 0x1001f1a4]

        $sequence_5 = { 8d542418 8bce e8???????? 59 59 }
            // n = 5, score = 200
            //   8d542418             | lea                 edx, [esp + 0x18]
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx

        $sequence_6 = { 8bf9 46 85ff 744f 833fff 7410 ff37 }
            // n = 7, score = 200
            //   8bf9                 | mov                 edi, ecx
            //   46                   | inc                 esi
            //   85ff                 | test                edi, edi
            //   744f                 | je                  0x51
            //   833fff               | cmp                 dword ptr [edi], -1
            //   7410                 | je                  0x12
            //   ff37                 | push                dword ptr [edi]

        $sequence_7 = { 0fb6c0 5f 5e 5b c9 }
            // n = 5, score = 200
            //   0fb6c0               | movzx               eax, al
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx
            //   c9                   | leave               

        $sequence_8 = { 488d4c2428 e8???????? 90 4c8d05b3b70000 488bd0 488d0db1610100 }
            // n = 6, score = 100
            //   488d4c2428           | mov                 ecx, dword ptr [ebp - 0x19]
            //   e8????????           |                     
            //   90                   | dec                 eax
            //   4c8d05b3b70000       | mov                 dword ptr [ebp - 1], 7
            //   488bd0               | dec                 eax
            //   488d0db1610100       | mov                 dword ptr [ebp - 9], edi

        $sequence_9 = { ff15???????? b001 eb25 e8???????? }
            // n = 4, score = 100
            //   ff15????????         |                     
            //   b001                 | mov                 edx, eax
            //   eb25                 | dec                 eax
            //   e8????????           |                     

        $sequence_10 = { e8???????? 90 4c8d05d3b50000 488bd0 }
            // n = 4, score = 100
            //   e8????????           |                     
            //   90                   | dec                 eax
            //   4c8d05d3b50000       | mov                 ecx, ebx
            //   488bd0               | nop                 

        $sequence_11 = { 488bcb e8???????? e9???????? ba80000000 488bcb }
            // n = 5, score = 100
            //   488bcb               | dec                 eax
            //   e8????????           |                     
            //   e9????????           |                     
            //   ba80000000           | mov                 ecx, ebx
            //   488bcb               | mov                 edx, 0x80

        $sequence_12 = { 488b4de7 e8???????? 48c745ff07000000 48897df7 }
            // n = 4, score = 100
            //   488b4de7             | dec                 esp
            //   e8????????           |                     
            //   48c745ff07000000     | lea                 eax, [0xb5d3]
            //   48897df7             | dec                 eax

    condition:
        7 of them and filesize < 421888
}