rule win_punkey_pos_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.punkey_pos."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.punkey_pos"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ffd7 a3???????? 85c0 74ae 5f }
            // n = 5, score = 200
            //   ffd7                 | call                edi
            //   a3????????           |                     
            //   85c0                 | test                eax, eax
            //   74ae                 | je                  0xffffffb0
            //   5f                   | pop                 edi

        $sequence_1 = { 8bec 837d0c01 56 57 756b }
            // n = 5, score = 200
            //   8bec                 | mov                 ebp, esp
            //   837d0c01             | cmp                 dword ptr [ebp + 0xc], 1
            //   56                   | push                esi
            //   57                   | push                edi
            //   756b                 | jne                 0x6d

        $sequence_2 = { 837d0c01 56 57 756b 8b4508 }
            // n = 5, score = 200
            //   837d0c01             | cmp                 dword ptr [ebp + 0xc], 1
            //   56                   | push                esi
            //   57                   | push                edi
            //   756b                 | jne                 0x6d
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]

        $sequence_3 = { ff15???????? 8bf0 85f6 7508 5f 33c0 5e }
            // n = 7, score = 200
            //   ff15????????         |                     
            //   8bf0                 | mov                 esi, eax
            //   85f6                 | test                esi, esi
            //   7508                 | jne                 0xa
            //   5f                   | pop                 edi
            //   33c0                 | xor                 eax, eax
            //   5e                   | pop                 esi

        $sequence_4 = { 33c0 5e 5d c20c00 8b3d???????? }
            // n = 5, score = 200
            //   33c0                 | xor                 eax, eax
            //   5e                   | pop                 esi
            //   5d                   | pop                 ebp
            //   c20c00               | ret                 0xc
            //   8b3d????????         |                     

        $sequence_5 = { 68e7070000 50 ff15???????? ff05???????? 8b0d???????? }
            // n = 5, score = 200
            //   68e7070000           | push                0x7e7
            //   50                   | push                eax
            //   ff15????????         |                     
            //   ff05????????         |                     
            //   8b0d????????         |                     

        $sequence_6 = { 55 8bec 8b4508 85c0 7919 8b4d10 8b550c }
            // n = 7, score = 200
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   85c0                 | test                eax, eax
            //   7919                 | jns                 0x1b
            //   8b4d10               | mov                 ecx, dword ptr [ebp + 0x10]
            //   8b550c               | mov                 edx, dword ptr [ebp + 0xc]

        $sequence_7 = { 6a02 a3???????? ff15???????? a3???????? 33c0 }
            // n = 5, score = 200
            //   6a02                 | push                2
            //   a3????????           |                     
            //   ff15????????         |                     
            //   a3????????           |                     
            //   33c0                 | xor                 eax, eax

        $sequence_8 = { 52 50 a1???????? 50 ff15???????? 5d c20c00 }
            // n = 7, score = 200
            //   52                   | push                edx
            //   50                   | push                eax
            //   a1????????           |                     
            //   50                   | push                eax
            //   ff15????????         |                     
            //   5d                   | pop                 ebp
            //   c20c00               | ret                 0xc

        $sequence_9 = { 8bf0 85f6 7508 5f 33c0 5e }
            // n = 6, score = 200
            //   8bf0                 | mov                 esi, eax
            //   85f6                 | test                esi, esi
            //   7508                 | jne                 0xa
            //   5f                   | pop                 edi
            //   33c0                 | xor                 eax, eax
            //   5e                   | pop                 esi

    condition:
        7 of them and filesize < 499712
}