rule win_pwnpos_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.pwnpos."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.pwnpos"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d8dbcf9ffff 3985b4f9ffff 8b85a0f9ffff 7306 8d85a0f9ffff 51 50 }
            // n = 7, score = 100
            //   8d8dbcf9ffff         | lea                 ecx, [ebp - 0x644]
            //   3985b4f9ffff         | cmp                 dword ptr [ebp - 0x64c], eax
            //   8b85a0f9ffff         | mov                 eax, dword ptr [ebp - 0x660]
            //   7306                 | jae                 8
            //   8d85a0f9ffff         | lea                 eax, [ebp - 0x660]
            //   51                   | push                ecx
            //   50                   | push                eax

        $sequence_1 = { 391d???????? 0f84a4000000 8d75d4 e8???????? 68???????? 50 c645fc01 }
            // n = 7, score = 100
            //   391d????????         |                     
            //   0f84a4000000         | je                  0xaa
            //   8d75d4               | lea                 esi, [ebp - 0x2c]
            //   e8????????           |                     
            //   68????????           |                     
            //   50                   | push                eax
            //   c645fc01             | mov                 byte ptr [ebp - 4], 1

        $sequence_2 = { 51 c745fc00000000 ffd3 85c0 7507 e8???????? eb0c }
            // n = 7, score = 100
            //   51                   | push                ecx
            //   c745fc00000000       | mov                 dword ptr [ebp - 4], 0
            //   ffd3                 | call                ebx
            //   85c0                 | test                eax, eax
            //   7507                 | jne                 9
            //   e8????????           |                     
            //   eb0c                 | jmp                 0xe

        $sequence_3 = { 6800400000 8d8c2494000000 51 ff15???????? 85c0 7526 8b8c2498400000 }
            // n = 7, score = 100
            //   6800400000           | push                0x4000
            //   8d8c2494000000       | lea                 ecx, [esp + 0x94]
            //   51                   | push                ecx
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7526                 | jne                 0x28
            //   8b8c2498400000       | mov                 ecx, dword ptr [esp + 0x4098]

        $sequence_4 = { 762a 56 e8???????? 8d0445fc6c4400 8bc8 }
            // n = 5, score = 100
            //   762a                 | jbe                 0x2c
            //   56                   | push                esi
            //   e8????????           |                     
            //   8d0445fc6c4400       | lea                 eax, [eax*2 + 0x446cfc]
            //   8bc8                 | mov                 ecx, eax

        $sequence_5 = { 89564c 895e44 6a08 b9???????? }
            // n = 4, score = 100
            //   89564c               | mov                 dword ptr [esi + 0x4c], edx
            //   895e44               | mov                 dword ptr [esi + 0x44], ebx
            //   6a08                 | push                8
            //   b9????????           |                     

        $sequence_6 = { eb14 807a2100 740a 3935???????? 7302 8bd1 }
            // n = 6, score = 100
            //   eb14                 | jmp                 0x16
            //   807a2100             | cmp                 byte ptr [edx + 0x21], 0
            //   740a                 | je                  0xc
            //   3935????????         |                     
            //   7302                 | jae                 4
            //   8bd1                 | mov                 edx, ecx

        $sequence_7 = { 3d00010000 752d 837c241c00 7626 }
            // n = 4, score = 100
            //   3d00010000           | cmp                 eax, 0x100
            //   752d                 | jne                 0x2f
            //   837c241c00           | cmp                 dword ptr [esp + 0x1c], 0
            //   7626                 | jbe                 0x28

        $sequence_8 = { e9???????? 8d9580f9ffff 52 b801000000 898d84f9ffff 898d88f9ffff 6a02 }
            // n = 7, score = 100
            //   e9????????           |                     
            //   8d9580f9ffff         | lea                 edx, [ebp - 0x680]
            //   52                   | push                edx
            //   b801000000           | mov                 eax, 1
            //   898d84f9ffff         | mov                 dword ptr [ebp - 0x67c], ecx
            //   898d88f9ffff         | mov                 dword ptr [ebp - 0x678], ecx
            //   6a02                 | push                2

        $sequence_9 = { 8bd1 8b09 eb03 8b4908 80792100 74e6 5f }
            // n = 7, score = 100
            //   8bd1                 | mov                 edx, ecx
            //   8b09                 | mov                 ecx, dword ptr [ecx]
            //   eb03                 | jmp                 5
            //   8b4908               | mov                 ecx, dword ptr [ecx + 8]
            //   80792100             | cmp                 byte ptr [ecx + 0x21], 0
            //   74e6                 | je                  0xffffffe8
            //   5f                   | pop                 edi

    condition:
        7 of them and filesize < 638976
}