rule win_qaccel_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.qaccel."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.qaccel"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 68???????? 50 64892500000000 56 57 8bf9 0f8816000000 }
            // n = 7, score = 100
            //   68????????           |                     
            //   50                   | push                eax
            //   64892500000000       | mov                 dword ptr fs:[0], esp
            //   56                   | push                esi
            //   57                   | push                edi
            //   8bf9                 | mov                 edi, ecx
            //   0f8816000000         | js                  0x1c

        $sequence_1 = { 5f 5f 5f 5f 5f b801000000 5e }
            // n = 7, score = 100
            //   5f                   | pop                 edi
            //   5f                   | pop                 edi
            //   5f                   | pop                 edi
            //   5f                   | pop                 edi
            //   5f                   | pop                 edi
            //   b801000000           | mov                 eax, 1
            //   5e                   | pop                 esi

        $sequence_2 = { 53 03c6 51 50 c7450c00000000 }
            // n = 5, score = 100
            //   53                   | push                ebx
            //   03c6                 | add                 eax, esi
            //   51                   | push                ecx
            //   50                   | push                eax
            //   c7450c00000000       | mov                 dword ptr [ebp + 0xc], 0

        $sequence_3 = { 83cbff 0f8819000000 0f8913000000 5f 5f 5f 5f }
            // n = 7, score = 100
            //   83cbff               | or                  ebx, 0xffffffff
            //   0f8819000000         | js                  0x1f
            //   0f8913000000         | jns                 0x19
            //   5f                   | pop                 edi
            //   5f                   | pop                 edi
            //   5f                   | pop                 edi
            //   5f                   | pop                 edi

        $sequence_4 = { 8b4020 6a05 50 ffd6 50 e8???????? 8b4820 }
            // n = 7, score = 100
            //   8b4020               | mov                 eax, dword ptr [eax + 0x20]
            //   6a05                 | push                5
            //   50                   | push                eax
            //   ffd6                 | call                esi
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b4820               | mov                 ecx, dword ptr [eax + 0x20]

        $sequence_5 = { 8d55e8 51 52 ff15???????? 8b45fc 8b4df8 6a00 }
            // n = 7, score = 100
            //   8d55e8               | lea                 edx, [ebp - 0x18]
            //   51                   | push                ecx
            //   52                   | push                edx
            //   ff15????????         |                     
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   8b4df8               | mov                 ecx, dword ptr [ebp - 8]
            //   6a00                 | push                0

        $sequence_6 = { 50 ffd6 50 e8???????? 0fbe4dff 8b5020 6801001c00 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   ffd6                 | call                esi
            //   50                   | push                eax
            //   e8????????           |                     
            //   0fbe4dff             | movsx               ecx, byte ptr [ebp - 1]
            //   8b5020               | mov                 edx, dword ptr [eax + 0x20]
            //   6801001c00           | push                0x1c0001

        $sequence_7 = { 5f 5f 5f 68???????? ff15???????? 85c0 }
            // n = 6, score = 100
            //   5f                   | pop                 edi
            //   5f                   | pop                 edi
            //   5f                   | pop                 edi
            //   68????????           |                     
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax

        $sequence_8 = { 5f 5f 5f 5f 6a00 50 }
            // n = 6, score = 100
            //   5f                   | pop                 edi
            //   5f                   | pop                 edi
            //   5f                   | pop                 edi
            //   5f                   | pop                 edi
            //   6a00                 | push                0
            //   50                   | push                eax

        $sequence_9 = { 5f 5f 5f 66a1???????? 8b3d???????? 6800010000 668903 }
            // n = 7, score = 100
            //   5f                   | pop                 edi
            //   5f                   | pop                 edi
            //   5f                   | pop                 edi
            //   66a1????????         |                     
            //   8b3d????????         |                     
            //   6800010000           | push                0x100
            //   668903               | mov                 word ptr [ebx], ax

    condition:
        7 of them and filesize < 106496
}