rule win_r980_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.r980."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.r980"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 51 8d4dd4 e8???????? 837de810 8d45d4 53 0f4345d4 }
            // n = 7, score = 200
            //   51                   | push                ecx
            //   8d4dd4               | lea                 ecx, [ebp - 0x2c]
            //   e8????????           |                     
            //   837de810             | cmp                 dword ptr [ebp - 0x18], 0x10
            //   8d45d4               | lea                 eax, [ebp - 0x2c]
            //   53                   | push                ebx
            //   0f4345d4             | cmovae              eax, dword ptr [ebp - 0x2c]

        $sequence_1 = { e8???????? 56 8b08 8b01 ff5070 56 50 }
            // n = 7, score = 200
            //   e8????????           |                     
            //   56                   | push                esi
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   8b01                 | mov                 eax, dword ptr [ecx]
            //   ff5070               | call                dword ptr [eax + 0x70]
            //   56                   | push                esi
            //   50                   | push                eax

        $sequence_2 = { 8d4dbc e8???????? 8d4dd4 e8???????? 8d4da4 e8???????? 8b4df4 }
            // n = 7, score = 200
            //   8d4dbc               | lea                 ecx, [ebp - 0x44]
            //   e8????????           |                     
            //   8d4dd4               | lea                 ecx, [ebp - 0x2c]
            //   e8????????           |                     
            //   8d4da4               | lea                 ecx, [ebp - 0x5c]
            //   e8????????           |                     
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]

        $sequence_3 = { 85c0 7409 ff7608 50 e8???????? c7460800000000 c7460400000000 }
            // n = 7, score = 200
            //   85c0                 | test                eax, eax
            //   7409                 | je                  0xb
            //   ff7608               | push                dword ptr [esi + 8]
            //   50                   | push                eax
            //   e8????????           |                     
            //   c7460800000000       | mov                 dword ptr [esi + 8], 0
            //   c7460400000000       | mov                 dword ptr [esi + 4], 0

        $sequence_4 = { 50 e8???????? 8bce e8???????? 8b4d1c 83c418 }
            // n = 6, score = 200
            //   50                   | push                eax
            //   e8????????           |                     
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     
            //   8b4d1c               | mov                 ecx, dword ptr [ebp + 0x1c]
            //   83c418               | add                 esp, 0x18

        $sequence_5 = { 8bc7 f00fc14104 7515 8b01 ff10 8b4db4 8bc7 }
            // n = 7, score = 200
            //   8bc7                 | mov                 eax, edi
            //   f00fc14104           | lock xadd           dword ptr [ecx + 4], eax
            //   7515                 | jne                 0x17
            //   8b01                 | mov                 eax, dword ptr [ecx]
            //   ff10                 | call                dword ptr [eax]
            //   8b4db4               | mov                 ecx, dword ptr [ebp - 0x4c]
            //   8bc7                 | mov                 eax, edi

        $sequence_6 = { ff4654 837e5440 750c c7465400000000 e8???????? 8b4658 83f8f8 }
            // n = 7, score = 200
            //   ff4654               | inc                 dword ptr [esi + 0x54]
            //   837e5440             | cmp                 dword ptr [esi + 0x54], 0x40
            //   750c                 | jne                 0xe
            //   c7465400000000       | mov                 dword ptr [esi + 0x54], 0
            //   e8????????           |                     
            //   8b4658               | mov                 eax, dword ptr [esi + 0x58]
            //   83f8f8               | cmp                 eax, -8

        $sequence_7 = { e8???????? 83ec18 8d8424c0000000 8bcc 50 e8???????? e9???????? }
            // n = 7, score = 200
            //   e8????????           |                     
            //   83ec18               | sub                 esp, 0x18
            //   8d8424c0000000       | lea                 eax, [esp + 0xc0]
            //   8bcc                 | mov                 ecx, esp
            //   50                   | push                eax
            //   e8????????           |                     
            //   e9????????           |                     

        $sequence_8 = { 8bc8 e8???????? 33c9 894ddc 8b448dc8 0f57c0 41 }
            // n = 7, score = 200
            //   8bc8                 | mov                 ecx, eax
            //   e8????????           |                     
            //   33c9                 | xor                 ecx, ecx
            //   894ddc               | mov                 dword ptr [ebp - 0x24], ecx
            //   8b448dc8             | mov                 eax, dword ptr [ebp + ecx*4 - 0x38]
            //   0f57c0               | xorps               xmm0, xmm0
            //   41                   | inc                 ecx

        $sequence_9 = { c745fc00000000 8b30 8d45ec 50 e8???????? 83c404 8d4dec }
            // n = 7, score = 200
            //   c745fc00000000       | mov                 dword ptr [ebp - 4], 0
            //   8b30                 | mov                 esi, dword ptr [eax]
            //   8d45ec               | lea                 eax, [ebp - 0x14]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   8d4dec               | lea                 ecx, [ebp - 0x14]

    condition:
        7 of them and filesize < 3178496
}