rule win_rad_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.rad."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.rad"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c644242000 e8???????? 8d542420 52 8d8c2498000000 c684240c06000018 ff15???????? }
            // n = 7, score = 100
            //   c644242000           | mov                 byte ptr [esp + 0x20], 0
            //   e8????????           |                     
            //   8d542420             | lea                 edx, [esp + 0x20]
            //   52                   | push                edx
            //   8d8c2498000000       | lea                 ecx, [esp + 0x98]
            //   c684240c06000018     | mov                 byte ptr [esp + 0x60c], 0x18
            //   ff15????????         |                     

        $sequence_1 = { 8b8680000000 3bc3 741b 8bbe84000000 e8???????? 8b8680000000 }
            // n = 6, score = 100
            //   8b8680000000         | mov                 eax, dword ptr [esi + 0x80]
            //   3bc3                 | cmp                 eax, ebx
            //   741b                 | je                  0x1d
            //   8bbe84000000         | mov                 edi, dword ptr [esi + 0x84]
            //   e8????????           |                     
            //   8b8680000000         | mov                 eax, dword ptr [esi + 0x80]

        $sequence_2 = { a1???????? 33c4 89442434 8b4508 8b00 85c0 751a }
            // n = 7, score = 100
            //   a1????????           |                     
            //   33c4                 | xor                 eax, esp
            //   89442434             | mov                 dword ptr [esp + 0x34], eax
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   85c0                 | test                eax, eax
            //   751a                 | jne                 0x1c

        $sequence_3 = { 8b84241c010000 50 ffd6 83c404 8b8c2400060000 64890d00000000 }
            // n = 6, score = 100
            //   8b84241c010000       | mov                 eax, dword ptr [esp + 0x11c]
            //   50                   | push                eax
            //   ffd6                 | call                esi
            //   83c404               | add                 esp, 4
            //   8b8c2400060000       | mov                 ecx, dword ptr [esp + 0x600]
            //   64890d00000000       | mov                 dword ptr fs:[0], ecx

        $sequence_4 = { 8d8d70ffffff ff25???????? 8b8578ffffff 83e002 0f8413000000 83a578fffffffd }
            // n = 6, score = 100
            //   8d8d70ffffff         | lea                 ecx, [ebp - 0x90]
            //   ff25????????         |                     
            //   8b8578ffffff         | mov                 eax, dword ptr [ebp - 0x88]
            //   83e002               | and                 eax, 2
            //   0f8413000000         | je                  0x19
            //   83a578fffffffd       | and                 dword ptr [ebp - 0x88], 0xfffffffd

        $sequence_5 = { ffd3 8d8c2494000000 c684240806000005 ff15???????? 8b4c2418 51 8d8c2498000000 }
            // n = 7, score = 100
            //   ffd3                 | call                ebx
            //   8d8c2494000000       | lea                 ecx, [esp + 0x94]
            //   c684240806000005     | mov                 byte ptr [esp + 0x608], 5
            //   ff15????????         |                     
            //   8b4c2418             | mov                 ecx, dword ptr [esp + 0x18]
            //   51                   | push                ecx
            //   8d8c2498000000       | lea                 ecx, [esp + 0x98]

        $sequence_6 = { ff15???????? 8d8c2494000000 c684240806000020 ff15???????? b8???????? 8d4c2420 }
            // n = 6, score = 100
            //   ff15????????         |                     
            //   8d8c2494000000       | lea                 ecx, [esp + 0x94]
            //   c684240806000020     | mov                 byte ptr [esp + 0x608], 0x20
            //   ff15????????         |                     
            //   b8????????           |                     
            //   8d4c2420             | lea                 ecx, [esp + 0x20]

        $sequence_7 = { e8???????? 8bc7 50 c645fc02 e8???????? 8bc8 }
            // n = 6, score = 100
            //   e8????????           |                     
            //   8bc7                 | mov                 eax, edi
            //   50                   | push                eax
            //   c645fc02             | mov                 byte ptr [ebp - 4], 2
            //   e8????????           |                     
            //   8bc8                 | mov                 ecx, eax

        $sequence_8 = { 720a 8b4c2434 51 ffd6 83c404 8d9424a8000000 52 }
            // n = 7, score = 100
            //   720a                 | jb                  0xc
            //   8b4c2434             | mov                 ecx, dword ptr [esp + 0x34]
            //   51                   | push                ecx
            //   ffd6                 | call                esi
            //   83c404               | add                 esp, 4
            //   8d9424a8000000       | lea                 edx, [esp + 0xa8]
            //   52                   | push                edx

        $sequence_9 = { 8d7e04 c645fc29 8d4f04 c706???????? 89bd10fdffff ff15???????? }
            // n = 6, score = 100
            //   8d7e04               | lea                 edi, [esi + 4]
            //   c645fc29             | mov                 byte ptr [ebp - 4], 0x29
            //   8d4f04               | lea                 ecx, [edi + 4]
            //   c706????????         |                     
            //   89bd10fdffff         | mov                 dword ptr [ebp - 0x2f0], edi
            //   ff15????????         |                     

    condition:
        7 of them and filesize < 207872
}