rule win_radamant_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.radamant."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.radamant"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8802 8b5510 42 8b45f8 }
            // n = 4, score = 100
            //   8802                 | mov                 byte ptr [edx], al
            //   8b5510               | mov                 edx, dword ptr [ebp + 0x10]
            //   42                   | inc                 edx
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]

        $sequence_1 = { 890424 e8???????? 8b85c8f6ffff 890424 e8???????? 8b85d4f6ffff 890424 }
            // n = 7, score = 100
            //   890424               | mov                 dword ptr [esp], eax
            //   e8????????           |                     
            //   8b85c8f6ffff         | mov                 eax, dword ptr [ebp - 0x938]
            //   890424               | mov                 dword ptr [esp], eax
            //   e8????????           |                     
            //   8b85d4f6ffff         | mov                 eax, dword ptr [ebp - 0x92c]
            //   890424               | mov                 dword ptr [esp], eax

        $sequence_2 = { 8d45f0 ff00 eb9b c9 }
            // n = 4, score = 100
            //   8d45f0               | lea                 eax, [ebp - 0x10]
            //   ff00                 | inc                 dword ptr [eax]
            //   eb9b                 | jmp                 0xffffff9d
            //   c9                   | leave               

        $sequence_3 = { 01d0 8d148500000000 01d0 29c1 89c8 83c061 8945b0 }
            // n = 7, score = 100
            //   01d0                 | add                 eax, edx
            //   8d148500000000       | lea                 edx, [eax*4]
            //   01d0                 | add                 eax, edx
            //   29c1                 | sub                 ecx, eax
            //   89c8                 | mov                 eax, ecx
            //   83c061               | add                 eax, 0x61
            //   8945b0               | mov                 dword ptr [ebp - 0x50], eax

        $sequence_4 = { 331485b0164100 89d0 8945e8 8b55fc 83c204 8b45f4 c1e818 }
            // n = 7, score = 100
            //   331485b0164100       | xor                 edx, dword ptr [eax*4 + 0x4116b0]
            //   89d0                 | mov                 eax, edx
            //   8945e8               | mov                 dword ptr [ebp - 0x18], eax
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   83c204               | add                 edx, 4
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]
            //   c1e818               | shr                 eax, 0x18

        $sequence_5 = { 8d148500000000 01d0 29c1 89c8 83c061 8945b0 }
            // n = 6, score = 100
            //   8d148500000000       | lea                 edx, [eax*4]
            //   01d0                 | add                 eax, edx
            //   29c1                 | sub                 ecx, eax
            //   89c8                 | mov                 eax, ecx
            //   83c061               | add                 eax, 0x61
            //   8945b0               | mov                 dword ptr [ebp - 0x50], eax

        $sequence_6 = { c1e818 0fb6c0 0fb680b0094100 31d0 8901 8b4df4 83c124 }
            // n = 7, score = 100
            //   c1e818               | shr                 eax, 0x18
            //   0fb6c0               | movzx               eax, al
            //   0fb680b0094100       | movzx               eax, byte ptr [eax + 0x4109b0]
            //   31d0                 | xor                 eax, edx
            //   8901                 | mov                 dword ptr [ecx], eax
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]
            //   83c124               | add                 ecx, 0x24

        $sequence_7 = { 8b8520feffff 890424 e8???????? 83ec0c 83f8ff 752a 8b45c4 }
            // n = 7, score = 100
            //   8b8520feffff         | mov                 eax, dword ptr [ebp - 0x1e0]
            //   890424               | mov                 dword ptr [esp], eax
            //   e8????????           |                     
            //   83ec0c               | sub                 esp, 0xc
            //   83f8ff               | cmp                 eax, -1
            //   752a                 | jne                 0x2c
            //   8b45c4               | mov                 eax, dword ptr [ebp - 0x3c]

        $sequence_8 = { e8???????? 8b45f4 890424 e8???????? 83c424 5b 5d }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]
            //   890424               | mov                 dword ptr [esp], eax
            //   e8????????           |                     
            //   83c424               | add                 esp, 0x24
            //   5b                   | pop                 ebx
            //   5d                   | pop                 ebp

        $sequence_9 = { 8d45e8 c1000a 8b55f4 8d45e8 0110 8b45f0 f7d0 }
            // n = 7, score = 100
            //   8d45e8               | lea                 eax, [ebp - 0x18]
            //   c1000a               | rol                 dword ptr [eax], 0xa
            //   8b55f4               | mov                 edx, dword ptr [ebp - 0xc]
            //   8d45e8               | lea                 eax, [ebp - 0x18]
            //   0110                 | add                 dword ptr [eax], edx
            //   8b45f0               | mov                 eax, dword ptr [ebp - 0x10]
            //   f7d0                 | not                 eax

    condition:
        7 of them and filesize < 204800
}