rule win_radrat_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.radrat."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.radrat"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d8d1cffffff e8???????? c685f0feffff00 c645fc00 8d4dcc e8???????? c745fcffffffff }
            // n = 7, score = 100
            //   8d8d1cffffff         | lea                 ecx, [ebp - 0xe4]
            //   e8????????           |                     
            //   c685f0feffff00       | mov                 byte ptr [ebp - 0x110], 0
            //   c645fc00             | mov                 byte ptr [ebp - 4], 0
            //   8d4dcc               | lea                 ecx, [ebp - 0x34]
            //   e8????????           |                     
            //   c745fcffffffff       | mov                 dword ptr [ebp - 4], 0xffffffff

        $sequence_1 = { c6855497ffff01 c645fc01 8d8d58ffffff e8???????? c745fcffffffff 8d4d80 e8???????? }
            // n = 7, score = 100
            //   c6855497ffff01       | mov                 byte ptr [ebp - 0x68ac], 1
            //   c645fc01             | mov                 byte ptr [ebp - 4], 1
            //   8d8d58ffffff         | lea                 ecx, [ebp - 0xa8]
            //   e8????????           |                     
            //   c745fcffffffff       | mov                 dword ptr [ebp - 4], 0xffffffff
            //   8d4d80               | lea                 ecx, [ebp - 0x80]
            //   e8????????           |                     

        $sequence_2 = { 8d8d74ffffff e8???????? 68a0000000 8d8d74ffffff e8???????? 6a30 8d8d74ffffff }
            // n = 7, score = 100
            //   8d8d74ffffff         | lea                 ecx, [ebp - 0x8c]
            //   e8????????           |                     
            //   68a0000000           | push                0xa0
            //   8d8d74ffffff         | lea                 ecx, [ebp - 0x8c]
            //   e8????????           |                     
            //   6a30                 | push                0x30
            //   8d8d74ffffff         | lea                 ecx, [ebp - 0x8c]

        $sequence_3 = { ff15???????? 8b4df4 894168 8b45f4 837868ff 750d ff15???????? }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]
            //   894168               | mov                 dword ptr [ecx + 0x68], eax
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]
            //   837868ff             | cmp                 dword ptr [eax + 0x68], -1
            //   750d                 | jne                 0xf
            //   ff15????????         |                     

        $sequence_4 = { 8d8dd8feffff e8???????? 8d8d0cffffff 51 8d55c4 52 8b45ec }
            // n = 7, score = 100
            //   8d8dd8feffff         | lea                 ecx, [ebp - 0x128]
            //   e8????????           |                     
            //   8d8d0cffffff         | lea                 ecx, [ebp - 0xf4]
            //   51                   | push                ecx
            //   8d55c4               | lea                 edx, [ebp - 0x3c]
            //   52                   | push                edx
            //   8b45ec               | mov                 eax, dword ptr [ebp - 0x14]

        $sequence_5 = { e8???????? 8a854c98ffff e9???????? 8b8d24d6ffff 83c15c 51 8b9524d6ffff }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8a854c98ffff         | mov                 al, byte ptr [ebp - 0x67b4]
            //   e9????????           |                     
            //   8b8d24d6ffff         | mov                 ecx, dword ptr [ebp - 0x29dc]
            //   83c15c               | add                 ecx, 0x5c
            //   51                   | push                ecx
            //   8b9524d6ffff         | mov                 edx, dword ptr [ebp - 0x29dc]

        $sequence_6 = { 8d8d50ffffff 51 e8???????? 83c408 8b9548ffffff 83c258 52 }
            // n = 7, score = 100
            //   8d8d50ffffff         | lea                 ecx, [ebp - 0xb0]
            //   51                   | push                ecx
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   8b9548ffffff         | mov                 edx, dword ptr [ebp - 0xb8]
            //   83c258               | add                 edx, 0x58
            //   52                   | push                edx

        $sequence_7 = { e9???????? 8d4d9c e8???????? c645fc01 8d8d38ffffff 51 8d4d9c }
            // n = 7, score = 100
            //   e9????????           |                     
            //   8d4d9c               | lea                 ecx, [ebp - 0x64]
            //   e8????????           |                     
            //   c645fc01             | mov                 byte ptr [ebp - 4], 1
            //   8d8d38ffffff         | lea                 ecx, [ebp - 0xc8]
            //   51                   | push                ecx
            //   8d4d9c               | lea                 ecx, [ebp - 0x64]

        $sequence_8 = { 8b4dd8 8b9130010000 52 ff15???????? 8b45d8 c7803001000000000000 8b4dd8 }
            // n = 7, score = 100
            //   8b4dd8               | mov                 ecx, dword ptr [ebp - 0x28]
            //   8b9130010000         | mov                 edx, dword ptr [ecx + 0x130]
            //   52                   | push                edx
            //   ff15????????         |                     
            //   8b45d8               | mov                 eax, dword ptr [ebp - 0x28]
            //   c7803001000000000000     | mov    dword ptr [eax + 0x130], 0
            //   8b4dd8               | mov                 ecx, dword ptr [ebp - 0x28]

        $sequence_9 = { 8d8560fbffff 50 8d8da8fdffff e8???????? 89854cf8ffff 8b8d4cf8ffff 898d48f8ffff }
            // n = 7, score = 100
            //   8d8560fbffff         | lea                 eax, [ebp - 0x4a0]
            //   50                   | push                eax
            //   8d8da8fdffff         | lea                 ecx, [ebp - 0x258]
            //   e8????????           |                     
            //   89854cf8ffff         | mov                 dword ptr [ebp - 0x7b4], eax
            //   8b8d4cf8ffff         | mov                 ecx, dword ptr [ebp - 0x7b4]
            //   898d48f8ffff         | mov                 dword ptr [ebp - 0x7b8], ecx

    condition:
        7 of them and filesize < 2080768
}