rule win_ragnarlocker_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.ragnarlocker."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.ragnarlocker"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 898df4feffff 894dc0 8b4f14 898decfeffff 894df8 8b4d0c 0fb601 }
            // n = 7, score = 300
            //   898df4feffff         | mov                 dword ptr [ebp - 0x10c], ecx
            //   894dc0               | mov                 dword ptr [ebp - 0x40], ecx
            //   8b4f14               | mov                 ecx, dword ptr [edi + 0x14]
            //   898decfeffff         | mov                 dword ptr [ebp - 0x114], ecx
            //   894df8               | mov                 dword ptr [ebp - 8], ecx
            //   8b4d0c               | mov                 ecx, dword ptr [ebp + 0xc]
            //   0fb601               | movzx               eax, byte ptr [ecx]

        $sequence_1 = { 33f1 8b4de8 8bd0 2345d4 3355d4 2355c8 33d0 }
            // n = 7, score = 300
            //   33f1                 | xor                 esi, ecx
            //   8b4de8               | mov                 ecx, dword ptr [ebp - 0x18]
            //   8bd0                 | mov                 edx, eax
            //   2345d4               | and                 eax, dword ptr [ebp - 0x2c]
            //   3355d4               | xor                 edx, dword ptr [ebp - 0x2c]
            //   2355c8               | and                 edx, dword ptr [ebp - 0x38]
            //   33d0                 | xor                 edx, eax

        $sequence_2 = { 0fb6c5 6a04 0bd0 0fb6c1 6800300000 c1e208 53 }
            // n = 7, score = 300
            //   0fb6c5               | movzx               eax, ch
            //   6a04                 | push                4
            //   0bd0                 | or                  edx, eax
            //   0fb6c1               | movzx               eax, cl
            //   6800300000           | push                0x3000
            //   c1e208               | shl                 edx, 8
            //   53                   | push                ebx

        $sequence_3 = { 039d28ffffff 13bd24ffffff 035d94 137d98 81c338b548f3 81d75bc25639 015df4 }
            // n = 7, score = 300
            //   039d28ffffff         | add                 ebx, dword ptr [ebp - 0xd8]
            //   13bd24ffffff         | adc                 edi, dword ptr [ebp - 0xdc]
            //   035d94               | add                 ebx, dword ptr [ebp - 0x6c]
            //   137d98               | adc                 edi, dword ptr [ebp - 0x68]
            //   81c338b548f3         | add                 ebx, 0xf348b538
            //   81d75bc25639         | adc                 edi, 0x3956c25b
            //   015df4               | add                 dword ptr [ebp - 0xc], ebx

        $sequence_4 = { 0fa4ca17 c1ee09 c1e117 0bda 8b55dc 0bf1 8b4de0 }
            // n = 7, score = 300
            //   0fa4ca17             | shld                edx, ecx, 0x17
            //   c1ee09               | shr                 esi, 9
            //   c1e117               | shl                 ecx, 0x17
            //   0bda                 | or                  ebx, edx
            //   8b55dc               | mov                 edx, dword ptr [ebp - 0x24]
            //   0bf1                 | or                  esi, ecx
            //   8b4de0               | mov                 ecx, dword ptr [ebp - 0x20]

        $sequence_5 = { 8bfa 8b4dd4 8bf1 337de8 3375f4 237dac 2355e8 }
            // n = 7, score = 300
            //   8bfa                 | mov                 edi, edx
            //   8b4dd4               | mov                 ecx, dword ptr [ebp - 0x2c]
            //   8bf1                 | mov                 esi, ecx
            //   337de8               | xor                 edi, dword ptr [ebp - 0x18]
            //   3375f4               | xor                 esi, dword ptr [ebp - 0xc]
            //   237dac               | and                 edi, dword ptr [ebp - 0x54]
            //   2355e8               | and                 edx, dword ptr [ebp - 0x18]

        $sequence_6 = { 897dfc 8bbd34ffffff 8bf7 8bcf c1e618 0facd108 }
            // n = 6, score = 300
            //   897dfc               | mov                 dword ptr [ebp - 4], edi
            //   8bbd34ffffff         | mov                 edi, dword ptr [ebp - 0xcc]
            //   8bf7                 | mov                 esi, edi
            //   8bcf                 | mov                 ecx, edi
            //   c1e618               | shl                 esi, 0x18
            //   0facd108             | shrd                ecx, edx, 8

        $sequence_7 = { 3375ec 8b55e8 2355c0 2375d4 33fa 8b4df4 234dec }
            // n = 7, score = 300
            //   3375ec               | xor                 esi, dword ptr [ebp - 0x14]
            //   8b55e8               | mov                 edx, dword ptr [ebp - 0x18]
            //   2355c0               | and                 edx, dword ptr [ebp - 0x40]
            //   2375d4               | and                 esi, dword ptr [ebp - 0x2c]
            //   33fa                 | xor                 edi, edx
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]
            //   234dec               | and                 ecx, dword ptr [ebp - 0x14]

        $sequence_8 = { 03c3 8945b8 13cf 33ff 894de0 }
            // n = 5, score = 300
            //   03c3                 | add                 eax, ebx
            //   8945b8               | mov                 dword ptr [ebp - 0x48], eax
            //   13cf                 | adc                 ecx, edi
            //   33ff                 | xor                 edi, edi
            //   894de0               | mov                 dword ptr [ebp - 0x20], ecx

        $sequence_9 = { c1e108 0bc8 0fb64604 c1e108 0bc8 894b14 0f114318 }
            // n = 7, score = 300
            //   c1e108               | shl                 ecx, 8
            //   0bc8                 | or                  ecx, eax
            //   0fb64604             | movzx               eax, byte ptr [esi + 4]
            //   c1e108               | shl                 ecx, 8
            //   0bc8                 | or                  ecx, eax
            //   894b14               | mov                 dword ptr [ebx + 0x14], ecx
            //   0f114318             | movups              xmmword ptr [ebx + 0x18], xmm0

    condition:
        7 of them and filesize < 147456
}