rule win_rambo_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.rambo."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.rambo"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ff7508 e8???????? 59 50 ff7508 ff15???????? 56 }
            // n = 7, score = 200
            //   ff7508               | push                dword ptr [ebp + 8]
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   50                   | push                eax
            //   ff7508               | push                dword ptr [ebp + 8]
            //   ff15????????         |                     
            //   56                   | push                esi

        $sequence_1 = { e8???????? ff750c 8d85ecfdffff 50 e8???????? }
            // n = 5, score = 200
            //   e8????????           |                     
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   8d85ecfdffff         | lea                 eax, [ebp - 0x214]
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_2 = { ff15???????? 83c41c 6a01 58 5e c9 }
            // n = 6, score = 200
            //   ff15????????         |                     
            //   83c41c               | add                 esp, 0x1c
            //   6a01                 | push                1
            //   58                   | pop                 eax
            //   5e                   | pop                 esi
            //   c9                   | leave               

        $sequence_3 = { 85f6 7437 56 6a01 }
            // n = 4, score = 200
            //   85f6                 | test                esi, esi
            //   7437                 | je                  0x39
            //   56                   | push                esi
            //   6a01                 | push                1

        $sequence_4 = { ff7508 8d85f8feffff 50 e8???????? 8065fe00 8d45fc 50 }
            // n = 7, score = 200
            //   ff7508               | push                dword ptr [ebp + 8]
            //   8d85f8feffff         | lea                 eax, [ebp - 0x108]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8065fe00             | and                 byte ptr [ebp - 2], 0
            //   8d45fc               | lea                 eax, [ebp - 4]
            //   50                   | push                eax

        $sequence_5 = { 83c428 6a32 ff15???????? 8d85f8faffff 50 68???????? }
            // n = 6, score = 200
            //   83c428               | add                 esp, 0x28
            //   6a32                 | push                0x32
            //   ff15????????         |                     
            //   8d85f8faffff         | lea                 eax, [ebp - 0x508]
            //   50                   | push                eax
            //   68????????           |                     

        $sequence_6 = { 56 57 8d85f8faffff 6a01 50 ff15???????? 80a43df8faffff00 }
            // n = 7, score = 200
            //   56                   | push                esi
            //   57                   | push                edi
            //   8d85f8faffff         | lea                 eax, [ebp - 0x508]
            //   6a01                 | push                1
            //   50                   | push                eax
            //   ff15????????         |                     
            //   80a43df8faffff00     | and                 byte ptr [ebp + edi - 0x508], 0

        $sequence_7 = { 50 8d85f8feffff 50 c645fc72 }
            // n = 4, score = 200
            //   50                   | push                eax
            //   8d85f8feffff         | lea                 eax, [ebp - 0x108]
            //   50                   | push                eax
            //   c645fc72             | mov                 byte ptr [ebp - 4], 0x72

        $sequence_8 = { 756b 57 b940000000 8d7c240d 8844240c f3ab }
            // n = 6, score = 100
            //   756b                 | jne                 0x6d
            //   57                   | push                edi
            //   b940000000           | mov                 ecx, 0x40
            //   8d7c240d             | lea                 edi, [esp + 0xd]
            //   8844240c             | mov                 byte ptr [esp + 0xc], al
            //   f3ab                 | rep stosd           dword ptr es:[edi], eax

        $sequence_9 = { f3aa 8bcb 8d7c2474 8bc1 }
            // n = 4, score = 100
            //   f3aa                 | rep stosb           byte ptr es:[edi], al
            //   8bcb                 | mov                 ecx, ebx
            //   8d7c2474             | lea                 edi, [esp + 0x74]
            //   8bc1                 | mov                 eax, ecx

        $sequence_10 = { e8???????? 8d4c2410 c684240004000007 e8???????? 68b6000000 8d542414 }
            // n = 6, score = 100
            //   e8????????           |                     
            //   8d4c2410             | lea                 ecx, [esp + 0x10]
            //   c684240004000007     | mov                 byte ptr [esp + 0x400], 7
            //   e8????????           |                     
            //   68b6000000           | push                0xb6
            //   8d542414             | lea                 edx, [esp + 0x14]

        $sequence_11 = { 8d8c2488000000 e8???????? 57 57 8d4c2424 }
            // n = 5, score = 100
            //   8d8c2488000000       | lea                 ecx, [esp + 0x88]
            //   e8????????           |                     
            //   57                   | push                edi
            //   57                   | push                edi
            //   8d4c2424             | lea                 ecx, [esp + 0x24]

        $sequence_12 = { e8???????? 8d4c2428 c684240004000005 e8???????? 8d4c2414 c684240004000004 }
            // n = 6, score = 100
            //   e8????????           |                     
            //   8d4c2428             | lea                 ecx, [esp + 0x28]
            //   c684240004000005     | mov                 byte ptr [esp + 0x400], 5
            //   e8????????           |                     
            //   8d4c2414             | lea                 ecx, [esp + 0x14]
            //   c684240004000004     | mov                 byte ptr [esp + 0x400], 4

        $sequence_13 = { 8b35???????? a3???????? ffd6 3db7000000 7418 }
            // n = 5, score = 100
            //   8b35????????         |                     
            //   a3????????           |                     
            //   ffd6                 | call                esi
            //   3db7000000           | cmp                 eax, 0xb7
            //   7418                 | je                  0x1a

        $sequence_14 = { 89442418 8b4309 84c9 7403 50 }
            // n = 5, score = 100
            //   89442418             | mov                 dword ptr [esp + 0x18], eax
            //   8b4309               | mov                 eax, dword ptr [ebx + 9]
            //   84c9                 | test                cl, cl
            //   7403                 | je                  5
            //   50                   | push                eax

        $sequence_15 = { f3a5 8bcb 8d9424f8020000 83e103 f3a4 bf???????? 83c9ff }
            // n = 7, score = 100
            //   f3a5                 | rep movsd           dword ptr es:[edi], dword ptr [esi]
            //   8bcb                 | mov                 ecx, ebx
            //   8d9424f8020000       | lea                 edx, [esp + 0x2f8]
            //   83e103               | and                 ecx, 3
            //   f3a4                 | rep movsb           byte ptr es:[edi], byte ptr [esi]
            //   bf????????           |                     
            //   83c9ff               | or                  ecx, 0xffffffff

    condition:
        7 of them and filesize < 57344
}