rule win_ratankba_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.ratankba."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.ratankba"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 5d c20800 8b4d0c 803900 7416 807d0b00 7410 }
            // n = 7, score = 400
            //   5d                   | pop                 ebp
            //   c20800               | ret                 8
            //   8b4d0c               | mov                 ecx, dword ptr [ebp + 0xc]
            //   803900               | cmp                 byte ptr [ecx], 0
            //   7416                 | je                  0x18
            //   807d0b00             | cmp                 byte ptr [ebp + 0xb], 0
            //   7410                 | je                  0x12

        $sequence_1 = { 53 b8???????? 668911 e8???????? 8d8ec0000000 c645fc05 33c0 }
            // n = 7, score = 400
            //   53                   | push                ebx
            //   b8????????           |                     
            //   668911               | mov                 word ptr [ecx], dx
            //   e8????????           |                     
            //   8d8ec0000000         | lea                 ecx, [esi + 0xc0]
            //   c645fc05             | mov                 byte ptr [ebp - 4], 5
            //   33c0                 | xor                 eax, eax

        $sequence_2 = { 53 ff15???????? 85c0 740e 8b45fc 85c0 7407 }
            // n = 7, score = 400
            //   53                   | push                ebx
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   740e                 | je                  0x10
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   85c0                 | test                eax, eax
            //   7407                 | je                  9

        $sequence_3 = { 55 8bec ff4724 8b4724 53 56 394718 }
            // n = 7, score = 400
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   ff4724               | inc                 dword ptr [edi + 0x24]
            //   8b4724               | mov                 eax, dword ptr [edi + 0x24]
            //   53                   | push                ebx
            //   56                   | push                esi
            //   394718               | cmp                 dword ptr [edi + 0x18], eax

        $sequence_4 = { e8???????? 8b4310 33ff 3bc7 7649 397e10 7644 }
            // n = 7, score = 400
            //   e8????????           |                     
            //   8b4310               | mov                 eax, dword ptr [ebx + 0x10]
            //   33ff                 | xor                 edi, edi
            //   3bc7                 | cmp                 eax, edi
            //   7649                 | jbe                 0x4b
            //   397e10               | cmp                 dword ptr [esi + 0x10], edi
            //   7644                 | jbe                 0x46

        $sequence_5 = { 720a b857000780 e8???????? 8b4b04 5f 8944d104 8bc2 }
            // n = 7, score = 400
            //   720a                 | jb                  0xc
            //   b857000780           | mov                 eax, 0x80070057
            //   e8????????           |                     
            //   8b4b04               | mov                 ecx, dword ptr [ebx + 4]
            //   5f                   | pop                 edi
            //   8944d104             | mov                 dword ptr [ecx + edx*8 + 4], eax
            //   8bc2                 | mov                 eax, edx

        $sequence_6 = { 83c414 85c0 744f 8bc8 e8???????? 8bf0 a1???????? }
            // n = 7, score = 400
            //   83c414               | add                 esp, 0x14
            //   85c0                 | test                eax, eax
            //   744f                 | je                  0x51
            //   8bc8                 | mov                 ecx, eax
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax
            //   a1????????           |                     

        $sequence_7 = { 0f849b010000 83c302 46 ebaa 8b5710 8bc6 8955e4 }
            // n = 7, score = 400
            //   0f849b010000         | je                  0x1a1
            //   83c302               | add                 ebx, 2
            //   46                   | inc                 esi
            //   ebaa                 | jmp                 0xffffffac
            //   8b5710               | mov                 edx, dword ptr [edi + 0x10]
            //   8bc6                 | mov                 eax, esi
            //   8955e4               | mov                 dword ptr [ebp - 0x1c], edx

        $sequence_8 = { 8975f4 85f6 790b 5e 83c8ff 5b 8be5 }
            // n = 7, score = 400
            //   8975f4               | mov                 dword ptr [ebp - 0xc], esi
            //   85f6                 | test                esi, esi
            //   790b                 | jns                 0xd
            //   5e                   | pop                 esi
            //   83c8ff               | or                  eax, 0xffffffff
            //   5b                   | pop                 ebx
            //   8be5                 | mov                 esp, ebp

        $sequence_9 = { 56 66898578efffff 51 83c8ff 8dbd78efffff c7858cefffff07000000 }
            // n = 6, score = 400
            //   56                   | push                esi
            //   66898578efffff       | mov                 word ptr [ebp - 0x1088], ax
            //   51                   | push                ecx
            //   83c8ff               | or                  eax, 0xffffffff
            //   8dbd78efffff         | lea                 edi, [ebp - 0x1088]
            //   c7858cefffff07000000     | mov    dword ptr [ebp - 0x1074], 7

    condition:
        7 of them and filesize < 303104
}