rule win_ratankbapos_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.ratankbapos."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.ratankbapos"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d542444 56 52 e8???????? 8d44244c 83c424 33d2 }
            // n = 7, score = 300
            //   8d542444             | lea                 edx, [esp + 0x44]
            //   56                   | push                esi
            //   52                   | push                edx
            //   e8????????           |                     
            //   8d44244c             | lea                 eax, [esp + 0x4c]
            //   83c424               | add                 esp, 0x24
            //   33d2                 | xor                 edx, edx

        $sequence_1 = { 83c424 33d2 8d7001 8d4900 8a08 40 3acb }
            // n = 7, score = 300
            //   83c424               | add                 esp, 0x24
            //   33d2                 | xor                 edx, edx
            //   8d7001               | lea                 esi, [eax + 1]
            //   8d4900               | lea                 ecx, [ecx]
            //   8a08                 | mov                 cl, byte ptr [eax]
            //   40                   | inc                 eax
            //   3acb                 | cmp                 cl, bl

        $sequence_2 = { 897304 8d7901 90 8a01 41 84c0 }
            // n = 6, score = 300
            //   897304               | mov                 dword ptr [ebx + 4], esi
            //   8d7901               | lea                 edi, [ecx + 1]
            //   90                   | nop                 
            //   8a01                 | mov                 al, byte ptr [ecx]
            //   41                   | inc                 ecx
            //   84c0                 | test                al, al

        $sequence_3 = { 8b4b0c 03f0 c68405fcdfffff00 8d85fcdfffff 89b5f4dfffff c6040e00 }
            // n = 6, score = 300
            //   8b4b0c               | mov                 ecx, dword ptr [ebx + 0xc]
            //   03f0                 | add                 esi, eax
            //   c68405fcdfffff00     | mov                 byte ptr [ebp + eax - 0x2004], 0
            //   8d85fcdfffff         | lea                 eax, [ebp - 0x2004]
            //   89b5f4dfffff         | mov                 dword ptr [ebp - 0x200c], esi
            //   c6040e00             | mov                 byte ptr [esi + ecx], 0

        $sequence_4 = { e8???????? 8b4510 33c9 8a4801 8d14cdd8ea0010 }
            // n = 5, score = 300
            //   e8????????           |                     
            //   8b4510               | mov                 eax, dword ptr [ebp + 0x10]
            //   33c9                 | xor                 ecx, ecx
            //   8a4801               | mov                 cl, byte ptr [eax + 1]
            //   8d14cdd8ea0010       | lea                 edx, [ecx*8 + 0x1000ead8]

        $sequence_5 = { ffb7c03d0110 ff15???????? 8987c03d0110 83c704 83ff28 72e6 5f }
            // n = 7, score = 300
            //   ffb7c03d0110         | push                dword ptr [edi + 0x10013dc0]
            //   ff15????????         |                     
            //   8987c03d0110         | mov                 dword ptr [edi + 0x10013dc0], eax
            //   83c704               | add                 edi, 4
            //   83ff28               | cmp                 edi, 0x28
            //   72e6                 | jb                  0xffffffe8
            //   5f                   | pop                 edi

        $sequence_6 = { ff15???????? 83c41c 8bf0 ff15???????? 50 }
            // n = 5, score = 300
            //   ff15????????         |                     
            //   83c41c               | add                 esp, 0x1c
            //   8bf0                 | mov                 esi, eax
            //   ff15????????         |                     
            //   50                   | push                eax

        $sequence_7 = { 8b4dfc 33cd 83c408 b001 }
            // n = 4, score = 300
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   33cd                 | xor                 ecx, ebp
            //   83c408               | add                 esp, 8
            //   b001                 | mov                 al, 1

        $sequence_8 = { b801000000 894588 8945a4 33c9 8bc2 c78574ffffff3c000000 }
            // n = 6, score = 300
            //   b801000000           | mov                 eax, 1
            //   894588               | mov                 dword ptr [ebp - 0x78], eax
            //   8945a4               | mov                 dword ptr [ebp - 0x5c], eax
            //   33c9                 | xor                 ecx, ecx
            //   8bc2                 | mov                 eax, edx
            //   c78574ffffff3c000000     | mov    dword ptr [ebp - 0x8c], 0x3c

        $sequence_9 = { 8bc8 c1f905 8d3c8de04d0110 8bf0 }
            // n = 4, score = 300
            //   8bc8                 | mov                 ecx, eax
            //   c1f905               | sar                 ecx, 5
            //   8d3c8de04d0110       | lea                 edi, [ecx*4 + 0x10014de0]
            //   8bf0                 | mov                 esi, eax

    condition:
        7 of them and filesize < 327680
}