rule win_redleaves_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.redleaves."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.redleaves"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 51 7565 7279 55 7365 7254 }
            // n = 6, score = 400
            //   51                   | push                ecx
            //   7565                 | jne                 0x67
            //   7279                 | jb                  0x7b
            //   55                   | push                ebp
            //   7365                 | jae                 0x67
            //   7254                 | jb                  0x56

        $sequence_1 = { 47 657449 7041 64647254 }
            // n = 4, score = 400
            //   47                   | inc                 edi
            //   657449               | je                  0x4c
            //   7041                 | jo                  0x43
            //   64647254             | jb                  0x58

        $sequence_2 = { 54 53 51 7565 }
            // n = 4, score = 400
            //   54                   | push                esp
            //   53                   | push                ebx
            //   51                   | push                ecx
            //   7565                 | jne                 0x67

        $sequence_3 = { 9c 894504 9c 9c }
            // n = 4, score = 400
            //   9c                   | pushfd              
            //   894504               | mov                 dword ptr [ebp + 4], eax
            //   9c                   | pushfd              
            //   9c                   | pushfd              

        $sequence_4 = { 83e901 0f85edffffff 89d0 29f8 5f 5b }
            // n = 6, score = 400
            //   83e901               | sub                 ecx, 1
            //   0f85edffffff         | jne                 0xfffffff3
            //   89d0                 | mov                 eax, edx
            //   29f8                 | sub                 eax, edi
            //   5f                   | pop                 edi
            //   5b                   | pop                 ebx

        $sequence_5 = { 8d64241c d2c0 8a01 9c }
            // n = 4, score = 400
            //   8d64241c             | lea                 esp, [esp + 0x1c]
            //   d2c0                 | rol                 al, cl
            //   8a01                 | mov                 al, byte ptr [ecx]
            //   9c                   | pushfd              

        $sequence_6 = { 59 89f9 8d64241c d2c0 }
            // n = 4, score = 400
            //   59                   | pop                 ecx
            //   89f9                 | mov                 ecx, edi
            //   8d64241c             | lea                 esp, [esp + 0x1c]
            //   d2c0                 | rol                 al, cl

        $sequence_7 = { 8b04b0 8b4018 898588fdffff 8d8578fdffff }
            // n = 4, score = 300
            //   8b04b0               | mov                 eax, dword ptr [eax + esi*4]
            //   8b4018               | mov                 eax, dword ptr [eax + 0x18]
            //   898588fdffff         | mov                 dword ptr [ebp - 0x278], eax
            //   8d8578fdffff         | lea                 eax, [ebp - 0x288]

        $sequence_8 = { 8b04b0 ff7018 ff701c 8d85acfdffff }
            // n = 4, score = 300
            //   8b04b0               | mov                 eax, dword ptr [eax + esi*4]
            //   ff7018               | push                dword ptr [eax + 0x18]
            //   ff701c               | push                dword ptr [eax + 0x1c]
            //   8d85acfdffff         | lea                 eax, [ebp - 0x254]

        $sequence_9 = { 8bec 8b550c 53 8bd9 85d2 7f05 }
            // n = 6, score = 300
            //   8bec                 | mov                 ebp, esp
            //   8b550c               | mov                 edx, dword ptr [ebp + 0xc]
            //   53                   | push                ebx
            //   8bd9                 | mov                 ebx, ecx
            //   85d2                 | test                edx, edx
            //   7f05                 | jg                  7

        $sequence_10 = { 50 57 ffb610020000 e8???????? }
            // n = 4, score = 300
            //   50                   | push                eax
            //   57                   | push                edi
            //   ffb610020000         | push                dword ptr [esi + 0x210]
            //   e8????????           |                     

        $sequence_11 = { 8bec a1???????? 56 85c0 7452 }
            // n = 5, score = 300
            //   8bec                 | mov                 ebp, esp
            //   a1????????           |                     
            //   56                   | push                esi
            //   85c0                 | test                eax, eax
            //   7452                 | je                  0x54

        $sequence_12 = { 53 53 6804010000 8d85acfeffff }
            // n = 4, score = 300
            //   53                   | push                ebx
            //   53                   | push                ebx
            //   6804010000           | push                0x104
            //   8d85acfeffff         | lea                 eax, [ebp - 0x154]

        $sequence_13 = { 8b04b0 83c41c 53 53 }
            // n = 4, score = 300
            //   8b04b0               | mov                 eax, dword ptr [eax + esi*4]
            //   83c41c               | add                 esp, 0x1c
            //   53                   | push                ebx
            //   53                   | push                ebx

        $sequence_14 = { 50 57 ffb60c020000 e8???????? 83c40c 8b860c020000 }
            // n = 6, score = 300
            //   50                   | push                eax
            //   57                   | push                edi
            //   ffb60c020000         | push                dword ptr [esi + 0x20c]
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   8b860c020000         | mov                 eax, dword ptr [esi + 0x20c]

        $sequence_15 = { 54 9c 60 9c }
            // n = 4, score = 300
            //   54                   | push                esp
            //   9c                   | pushfd              
            //   60                   | pushal              
            //   9c                   | pushfd              

        $sequence_16 = { 9c 9c 8f442420 9c }
            // n = 4, score = 300
            //   9c                   | pushfd              
            //   9c                   | pushfd              
            //   8f442420             | pop                 dword ptr [esp + 0x20]
            //   9c                   | pushfd              

    condition:
        7 of them and filesize < 1679360
}