rule win_redshawl_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.redshawl."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.redshawl"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ffc6 488d0c80 488d05baaa0000 488d0cc8 48890f ff15???????? 85c0 }
            // n = 7, score = 100
            //   ffc6                 | test                eax, eax
            //   488d0c80             | jne                 0x2d3
            //   488d05baaa0000       | dec                 eax
            //   488d0cc8             | lea                 eax, [0xbd53]
            //   48890f               | jmp                 0x2d7
            //   ff15????????         |                     
            //   85c0                 | dec                 eax

        $sequence_1 = { e8???????? 488b8b58010000 e8???????? 488d7b58 be06000000 488d0519c30000 483947f0 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   488b8b58010000       | xor                 eax, esp
            //   e8????????           |                     
            //   488d7b58             | dec                 eax
            //   be06000000           | mov                 dword ptr [esp + 0x350], eax
            //   488d0519c30000       | dec                 eax
            //   483947f0             | mov                 dword ptr [esp + 0x70], esp

        $sequence_2 = { 488bce 488bc6 488d15709a0000 83e11f }
            // n = 4, score = 100
            //   488bce               | ret                 
            //   488bc6               | dec                 eax
            //   488d15709a0000       | lea                 edx, [esp + 0x40]
            //   83e11f               | dec                 eax

        $sequence_3 = { 488b8b58010000 e8???????? 488d7b58 be06000000 488d0519c30000 }
            // n = 5, score = 100
            //   488b8b58010000       | inc                 ecx
            //   e8????????           |                     
            //   488d7b58             | cmp                 eax, edi
            //   be06000000           | je                  0x58
            //   488d0519c30000       | dec                 eax

        $sequence_4 = { e9???????? 4c8d2552940000 488b0d???????? eb7c }
            // n = 4, score = 100
            //   e9????????           |                     
            //   4c8d2552940000       | mov                 eax, ecx
            //   488b0d????????       |                     
            //   eb7c                 | dec                 esp

        $sequence_5 = { eb76 33c9 488d1543bb0000 48891401 4883c230 4883c108 48ffcb }
            // n = 7, score = 100
            //   eb76                 | add                 ebx, 8
            //   33c9                 | dec                 eax
            //   488d1543bb0000       | mov                 ecx, dword ptr [ebx]
            //   48891401             | inc                 esp
            //   4883c230             | mov                 esp, eax
            //   4883c108             | mov                 dword ptr [esp + 0xb0], eax
            //   48ffcb               | dec                 esp

        $sequence_6 = { 8905???????? 8b430c 8905???????? 8bd7 4c8d0520d1ffff 89542420 }
            // n = 6, score = 100
            //   8905????????         |                     
            //   8b430c               | jne                 0x2a2
            //   8905????????         |                     
            //   8bd7                 | inc                 eax
            //   4c8d0520d1ffff       | push                ebx
            //   89542420             | dec                 eax

        $sequence_7 = { 8bd8 488bcf ff15???????? 488b742438 8bc3 }
            // n = 5, score = 100
            //   8bd8                 | inc                 ebp
            //   488bcf               | xor                 esp, esp
            //   ff15????????         |                     
            //   488b742438           | dec                 eax
            //   8bc3                 | mov                 dword ptr [esp + 0x10], esi

        $sequence_8 = { 72ed 48833d????????00 741f 488d0dc2c10000 e8???????? 85c0 }
            // n = 6, score = 100
            //   72ed                 | lea                 ecx, [ebp - 0x60]
            //   48833d????????00     |                     
            //   741f                 | dec                 eax
            //   488d0dc2c10000       | lea                 ecx, [ebp - 0x40]
            //   e8????????           |                     
            //   85c0                 | dec                 eax

        $sequence_9 = { 4c8d251ac70000 4863f8 49833cfc00 752b b900100000 }
            // n = 5, score = 100
            //   4c8d251ac70000       | jne                 0x3f
            //   4863f8               | dec                 eax
            //   49833cfc00           | lea                 ecx, [0x9a9a]
            //   752b                 | dec                 eax
            //   b900100000           | mov                 dword ptr [esp + 0x50], 0

    condition:
        7 of them and filesize < 174080
}