rule win_remy_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.remy."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.remy"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 83c404 3bc3 7420 50 8bc6 8d7c241c }
            // n = 6, score = 200
            //   83c404               | add                 esp, 4
            //   3bc3                 | cmp                 eax, ebx
            //   7420                 | je                  0x22
            //   50                   | push                eax
            //   8bc6                 | mov                 eax, esi
            //   8d7c241c             | lea                 edi, [esp + 0x1c]

        $sequence_1 = { 56 81c30f010000 53 e8???????? 8d46f0 }
            // n = 5, score = 200
            //   56                   | push                esi
            //   81c30f010000         | add                 ebx, 0x10f
            //   53                   | push                ebx
            //   e8????????           |                     
            //   8d46f0               | lea                 eax, [esi - 0x10]

        $sequence_2 = { 3dc8000000 0f85c50b0000 6a28 8d742424 895c2424 895c2428 895c242c }
            // n = 7, score = 200
            //   3dc8000000           | cmp                 eax, 0xc8
            //   0f85c50b0000         | jne                 0xbcb
            //   6a28                 | push                0x28
            //   8d742424             | lea                 esi, [esp + 0x24]
            //   895c2424             | mov                 dword ptr [esp + 0x24], ebx
            //   895c2428             | mov                 dword ptr [esp + 0x28], ebx
            //   895c242c             | mov                 dword ptr [esp + 0x2c], ebx

        $sequence_3 = { 5d c3 8b7dfc 8d4fff 81f9ffff0000 7728 }
            // n = 6, score = 200
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   8b7dfc               | mov                 edi, dword ptr [ebp - 4]
            //   8d4fff               | lea                 ecx, [edi - 1]
            //   81f9ffff0000         | cmp                 ecx, 0xffff
            //   7728                 | ja                  0x2a

        $sequence_4 = { 7451 8d4634 898638100000 8d8634100000 c70000100000 895d0c 895d08 }
            // n = 7, score = 200
            //   7451                 | je                  0x53
            //   8d4634               | lea                 eax, [esi + 0x34]
            //   898638100000         | mov                 dword ptr [esi + 0x1038], eax
            //   8d8634100000         | lea                 eax, [esi + 0x1034]
            //   c70000100000         | mov                 dword ptr [eax], 0x1000
            //   895d0c               | mov                 dword ptr [ebp + 0xc], ebx
            //   895d08               | mov                 dword ptr [ebp + 8], ebx

        $sequence_5 = { 51 8d570c 52 e8???????? 83c40c 8b4508 83c010 }
            // n = 7, score = 200
            //   51                   | push                ecx
            //   8d570c               | lea                 edx, [edi + 0xc]
            //   52                   | push                edx
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   83c010               | add                 eax, 0x10

        $sequence_6 = { 8b5604 2bc8 2bd0 c1f902 c1fa02 3bd1 }
            // n = 6, score = 200
            //   8b5604               | mov                 edx, dword ptr [esi + 4]
            //   2bc8                 | sub                 ecx, eax
            //   2bd0                 | sub                 edx, eax
            //   c1f902               | sar                 ecx, 2
            //   c1fa02               | sar                 edx, 2
            //   3bd1                 | cmp                 edx, ecx

        $sequence_7 = { 8d8748100000 57 8908 8d4da4 51 8d55a0 52 }
            // n = 7, score = 200
            //   8d8748100000         | lea                 eax, [edi + 0x1048]
            //   57                   | push                edi
            //   8908                 | mov                 dword ptr [eax], ecx
            //   8d4da4               | lea                 ecx, [ebp - 0x5c]
            //   51                   | push                ecx
            //   8d55a0               | lea                 edx, [ebp - 0x60]
            //   52                   | push                edx

        $sequence_8 = { 8d4d90 e8???????? 83c41c c645fc02 895e40 8bff 8b4d94 }
            // n = 7, score = 200
            //   8d4d90               | lea                 ecx, [ebp - 0x70]
            //   e8????????           |                     
            //   83c41c               | add                 esp, 0x1c
            //   c645fc02             | mov                 byte ptr [ebp - 4], 2
            //   895e40               | mov                 dword ptr [esi + 0x40], ebx
            //   8bff                 | mov                 edi, edi
            //   8b4d94               | mov                 ecx, dword ptr [ebp - 0x6c]

        $sequence_9 = { 50 ff15???????? 8b95b4feffff 52 ff15???????? 8b4df4 64890d00000000 }
            // n = 7, score = 200
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8b95b4feffff         | mov                 edx, dword ptr [ebp - 0x14c]
            //   52                   | push                edx
            //   ff15????????         |                     
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]
            //   64890d00000000       | mov                 dword ptr fs:[0], ecx

    condition:
        7 of them and filesize < 507904
}