rule win_rhino_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.rhino."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.rhino"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b4160 c3 6a40 58 c3 b8???????? e8???????? }
            // n = 7, score = 400
            //   8b4160               | mov                 eax, dword ptr [ecx + 0x60]
            //   c3                   | ret                 
            //   6a40                 | push                0x40
            //   58                   | pop                 eax
            //   c3                   | ret                 
            //   b8????????           |                     
            //   e8????????           |                     

        $sequence_1 = { c745f00f000000 885ddc 53 be04010000 895dfc 56 8d4ddc }
            // n = 7, score = 400
            //   c745f00f000000       | mov                 dword ptr [ebp - 0x10], 0xf
            //   885ddc               | mov                 byte ptr [ebp - 0x24], bl
            //   53                   | push                ebx
            //   be04010000           | mov                 esi, 0x104
            //   895dfc               | mov                 dword ptr [ebp - 4], ebx
            //   56                   | push                esi
            //   8d4ddc               | lea                 ecx, [ebp - 0x24]

        $sequence_2 = { c1c105 8b400c 89442440 8bc5 034c2440 33c3 23c6 }
            // n = 7, score = 400
            //   c1c105               | rol                 ecx, 5
            //   8b400c               | mov                 eax, dword ptr [eax + 0xc]
            //   89442440             | mov                 dword ptr [esp + 0x40], eax
            //   8bc5                 | mov                 eax, ebp
            //   034c2440             | add                 ecx, dword ptr [esp + 0x40]
            //   33c3                 | xor                 eax, ebx
            //   23c6                 | and                 eax, esi

        $sequence_3 = { 2b16 b8ffffff03 c1fa06 2bc2 3bc1 7217 8d040a }
            // n = 7, score = 400
            //   2b16                 | sub                 edx, dword ptr [esi]
            //   b8ffffff03           | mov                 eax, 0x3ffffff
            //   c1fa06               | sar                 edx, 6
            //   2bc2                 | sub                 eax, edx
            //   3bc1                 | cmp                 eax, ecx
            //   7217                 | jb                  0x19
            //   8d040a               | lea                 eax, [edx + ecx]

        $sequence_4 = { e8???????? 8bf9 897df0 8b7508 8d4f0c c74704???????? 56 }
            // n = 7, score = 400
            //   e8????????           |                     
            //   8bf9                 | mov                 edi, ecx
            //   897df0               | mov                 dword ptr [ebp - 0x10], edi
            //   8b7508               | mov                 esi, dword ptr [ebp + 8]
            //   8d4f0c               | lea                 ecx, [edi + 0xc]
            //   c74704????????       |                     
            //   56                   | push                esi

        $sequence_5 = { e8???????? 895d60 897d64 8b06 8d4de0 51 8bce }
            // n = 7, score = 400
            //   e8????????           |                     
            //   895d60               | mov                 dword ptr [ebp + 0x60], ebx
            //   897d64               | mov                 dword ptr [ebp + 0x64], edi
            //   8b06                 | mov                 eax, dword ptr [esi]
            //   8d4de0               | lea                 ecx, [ebp - 0x20]
            //   51                   | push                ecx
            //   8bce                 | mov                 ecx, esi

        $sequence_6 = { 890496 85c9 75e6 42 3b54240c 72ec 33c0 }
            // n = 7, score = 400
            //   890496               | mov                 dword ptr [esi + edx*4], eax
            //   85c9                 | test                ecx, ecx
            //   75e6                 | jne                 0xffffffe8
            //   42                   | inc                 edx
            //   3b54240c             | cmp                 edx, dword ptr [esp + 0xc]
            //   72ec                 | jb                  0xffffffee
            //   33c0                 | xor                 eax, eax

        $sequence_7 = { 74af 8b4634 8d4d08 51 50 50 894508 }
            // n = 7, score = 400
            //   74af                 | je                  0xffffffb1
            //   8b4634               | mov                 eax, dword ptr [esi + 0x34]
            //   8d4d08               | lea                 ecx, [ebp + 8]
            //   51                   | push                ecx
            //   50                   | push                eax
            //   50                   | push                eax
            //   894508               | mov                 dword ptr [ebp + 8], eax

        $sequence_8 = { 5e 64890d00000000 c9 c3 8b514c 395148 57 }
            // n = 7, score = 400
            //   5e                   | pop                 esi
            //   64890d00000000       | mov                 dword ptr fs:[0], ecx
            //   c9                   | leave               
            //   c3                   | ret                 
            //   8b514c               | mov                 edx, dword ptr [ecx + 0x4c]
            //   395148               | cmp                 dword ptr [ecx + 0x48], edx
            //   57                   | push                edi

        $sequence_9 = { 8b4f14 8b4114 3b410c 7507 8bcf e8???????? 33c0 }
            // n = 7, score = 400
            //   8b4f14               | mov                 ecx, dword ptr [edi + 0x14]
            //   8b4114               | mov                 eax, dword ptr [ecx + 0x14]
            //   3b410c               | cmp                 eax, dword ptr [ecx + 0xc]
            //   7507                 | jne                 9
            //   8bcf                 | mov                 ecx, edi
            //   e8????????           |                     
            //   33c0                 | xor                 eax, eax

    condition:
        7 of them and filesize < 1288192
}