rule win_rhttpctrl_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.rhttpctrl."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.rhttpctrl"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 83c404 833d????????ff 7533 ff15???????? 68???????? c705????????dcfb4100 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   833d????????ff       |                     
            //   7533                 | jne                 0x35
            //   ff15????????         |                     
            //   68????????           |                     
            //   c705????????dcfb4100     |     

        $sequence_1 = { e8???????? 8b404c 83b8a800000000 750e 8b04bd30424200 807c302900 741d }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8b404c               | mov                 eax, dword ptr [eax + 0x4c]
            //   83b8a800000000       | cmp                 dword ptr [eax + 0xa8], 0
            //   750e                 | jne                 0x10
            //   8b04bd30424200       | mov                 eax, dword ptr [edi*4 + 0x424230]
            //   807c302900           | cmp                 byte ptr [eax + esi + 0x29], 0
            //   741d                 | je                  0x1f

        $sequence_2 = { ffb5dcfbffff c785d8fbffff10fc4100 ff15???????? 33c0 }
            // n = 4, score = 100
            //   ffb5dcfbffff         | push                dword ptr [ebp - 0x424]
            //   c785d8fbffff10fc4100     | mov    dword ptr [ebp - 0x428], 0x41fc10
            //   ff15????????         |                     
            //   33c0                 | xor                 eax, eax

        $sequence_3 = { c645d800 68???????? 8d45d8 660fd645e9 }
            // n = 4, score = 100
            //   c645d800             | mov                 byte ptr [ebp - 0x28], 0
            //   68????????           |                     
            //   8d45d8               | lea                 eax, [ebp - 0x28]
            //   660fd645e9           | movq                qword ptr [ebp - 0x17], xmm0

        $sequence_4 = { 8be5 5d c3 68???????? ff15???????? 833d????????00 b301 }
            // n = 7, score = 100
            //   8be5                 | mov                 esp, ebp
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   68????????           |                     
            //   ff15????????         |                     
            //   833d????????00       |                     
            //   b301                 | mov                 bl, 1

        $sequence_5 = { 3bf1 756e 8b4bf0 8d73f0 8b01 ff5010 397e0c }
            // n = 7, score = 100
            //   3bf1                 | cmp                 esi, ecx
            //   756e                 | jne                 0x70
            //   8b4bf0               | mov                 ecx, dword ptr [ebx - 0x10]
            //   8d73f0               | lea                 esi, [ebx - 0x10]
            //   8b01                 | mov                 eax, dword ptr [ecx]
            //   ff5010               | call                dword ptr [eax + 0x10]
            //   397e0c               | cmp                 dword ptr [esi + 0xc], edi

        $sequence_6 = { 8b08 85c9 7407 395004 }
            // n = 4, score = 100
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   85c9                 | test                ecx, ecx
            //   7407                 | je                  9
            //   395004               | cmp                 dword ptr [eax + 4], edx

        $sequence_7 = { 50 8d842498000000 50 e8???????? 83cbff 85c0 }
            // n = 6, score = 100
            //   50                   | push                eax
            //   8d842498000000       | lea                 eax, [esp + 0x98]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83cbff               | or                  ebx, 0xffffffff
            //   85c0                 | test                eax, eax

        $sequence_8 = { 50 56 ff15???????? 85c0 7536 8b4714 8b35???????? }
            // n = 7, score = 100
            //   50                   | push                eax
            //   56                   | push                esi
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7536                 | jne                 0x38
            //   8b4714               | mov                 eax, dword ptr [edi + 0x14]
            //   8b35????????         |                     

        $sequence_9 = { 57 e8???????? ffb5f8feffff 8d85fcfeffff 50 }
            // n = 5, score = 100
            //   57                   | push                edi
            //   e8????????           |                     
            //   ffb5f8feffff         | push                dword ptr [ebp - 0x108]
            //   8d85fcfeffff         | lea                 eax, [ebp - 0x104]
            //   50                   | push                eax

    condition:
        7 of them and filesize < 339968
}