rule win_rombertik_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.rombertik."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.rombertik"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8945f4 3bc1 0f8271ffffff 5f 5e }
            // n = 5, score = 200
            //   8945f4               | mov                 dword ptr [ebp - 0xc], eax
            //   3bc1                 | cmp                 eax, ecx
            //   0f8271ffffff         | jb                  0xffffff77
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi

        $sequence_1 = { 8bff 8b4104 85c0 7446 83c0f8 33ff }
            // n = 6, score = 200
            //   8bff                 | mov                 edi, edi
            //   8b4104               | mov                 eax, dword ptr [ecx + 4]
            //   85c0                 | test                eax, eax
            //   7446                 | je                  0x48
            //   83c0f8               | add                 eax, -8
            //   33ff                 | xor                 edi, edi

        $sequence_2 = { 8bcf e8???????? 50 8d8dfcfeffff }
            // n = 4, score = 200
            //   8bcf                 | mov                 ecx, edi
            //   e8????????           |                     
            //   50                   | push                eax
            //   8d8dfcfeffff         | lea                 ecx, [ebp - 0x104]

        $sequence_3 = { 47 41 3bfb 72be 8b5df0 }
            // n = 5, score = 200
            //   47                   | inc                 edi
            //   41                   | inc                 ecx
            //   3bfb                 | cmp                 edi, ebx
            //   72be                 | jb                  0xffffffc0
            //   8b5df0               | mov                 ebx, dword ptr [ebp - 0x10]

        $sequence_4 = { 50 ff15???????? 8bf8 85ff 0f8488000000 }
            // n = 5, score = 200
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8bf8                 | mov                 edi, eax
            //   85ff                 | test                edi, edi
            //   0f8488000000         | je                  0x8e

        $sequence_5 = { 33db 57 895df8 ff15???????? 85c0 }
            // n = 5, score = 200
            //   33db                 | xor                 ebx, ebx
            //   57                   | push                edi
            //   895df8               | mov                 dword ptr [ebp - 8], ebx
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax

        $sequence_6 = { 8b5d0c 85db 0f84cb000000 837d1400 0f84c1000000 817d18a00f0000 0f87b4000000 }
            // n = 7, score = 200
            //   8b5d0c               | mov                 ebx, dword ptr [ebp + 0xc]
            //   85db                 | test                ebx, ebx
            //   0f84cb000000         | je                  0xd1
            //   837d1400             | cmp                 dword ptr [ebp + 0x14], 0
            //   0f84c1000000         | je                  0xc7
            //   817d18a00f0000       | cmp                 dword ptr [ebp + 0x18], 0xfa0
            //   0f87b4000000         | ja                  0xba

        $sequence_7 = { 50 8bc2 50 8d8decfeffff 51 ffd6 }
            // n = 6, score = 200
            //   50                   | push                eax
            //   8bc2                 | mov                 eax, edx
            //   50                   | push                eax
            //   8d8decfeffff         | lea                 ecx, [ebp - 0x114]
            //   51                   | push                ecx
            //   ffd6                 | call                esi

        $sequence_8 = { 895dfc 85db 0f84d8000000 85ff }
            // n = 4, score = 200
            //   895dfc               | mov                 dword ptr [ebp - 4], ebx
            //   85db                 | test                ebx, ebx
            //   0f84d8000000         | je                  0xde
            //   85ff                 | test                edi, edi

        $sequence_9 = { 6a03 6a00 6a02 68000000c0 68???????? ff15???????? 8906 }
            // n = 7, score = 200
            //   6a03                 | push                3
            //   6a00                 | push                0
            //   6a02                 | push                2
            //   68000000c0           | push                0xc0000000
            //   68????????           |                     
            //   ff15????????         |                     
            //   8906                 | mov                 dword ptr [esi], eax

    condition:
        7 of them and filesize < 73728
}