rule win_roopy_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.roopy."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.roopy"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d45d8 30c9 6631d2 e8???????? 6a00 8b45ec 8945c0 }
            // n = 7, score = 300
            //   8d45d8               | lea                 eax, [ebp - 0x28]
            //   30c9                 | xor                 cl, cl
            //   6631d2               | xor                 dx, dx
            //   e8????????           |                     
            //   6a00                 | push                0
            //   8b45ec               | mov                 eax, dword ptr [ebp - 0x14]
            //   8945c0               | mov                 dword ptr [ebp - 0x40], eax

        $sequence_1 = { 89e5 8da42478fdffff 53 56 8945fc }
            // n = 5, score = 300
            //   89e5                 | mov                 ebp, esp
            //   8da42478fdffff       | lea                 esp, [esp - 0x288]
            //   53                   | push                ebx
            //   56                   | push                esi
            //   8945fc               | mov                 dword ptr [ebp - 4], eax

        $sequence_2 = { 68???????? 64ff30 648920 8d431c 8b55fc e8???????? 89d8 }
            // n = 7, score = 300
            //   68????????           |                     
            //   64ff30               | push                dword ptr fs:[eax]
            //   648920               | mov                 dword ptr fs:[eax], esp
            //   8d431c               | lea                 eax, [ebx + 0x1c]
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   e8????????           |                     
            //   89d8                 | mov                 eax, ebx

        $sequence_3 = { 85db 7403 8b40fc 3d04010000 0f8e91000000 89da }
            // n = 6, score = 300
            //   85db                 | test                ebx, ebx
            //   7403                 | je                  5
            //   8b40fc               | mov                 eax, dword ptr [eax - 4]
            //   3d04010000           | cmp                 eax, 0x104
            //   0f8e91000000         | jle                 0x97
            //   89da                 | mov                 edx, ebx

        $sequence_4 = { e9???????? 8d8decfeffff 8d95a0fcffff b810010000 e8???????? e8???????? }
            // n = 6, score = 300
            //   e9????????           |                     
            //   8d8decfeffff         | lea                 ecx, [ebp - 0x114]
            //   8d95a0fcffff         | lea                 edx, [ebp - 0x360]
            //   b810010000           | mov                 eax, 0x110
            //   e8????????           |                     
            //   e8????????           |                     

        $sequence_5 = { c745f800000000 c7859cfeffff00000000 c78598feffff00000000 c78594feffff00000000 c78578fdffff00000000 c7857cfdffff00000000 c78580fdffff00000000 }
            // n = 7, score = 300
            //   c745f800000000       | mov                 dword ptr [ebp - 8], 0
            //   c7859cfeffff00000000     | mov    dword ptr [ebp - 0x164], 0
            //   c78598feffff00000000     | mov    dword ptr [ebp - 0x168], 0
            //   c78594feffff00000000     | mov    dword ptr [ebp - 0x16c], 0
            //   c78578fdffff00000000     | mov    dword ptr [ebp - 0x288], 0
            //   c7857cfdffff00000000     | mov    dword ptr [ebp - 0x284], 0
            //   c78580fdffff00000000     | mov    dword ptr [ebp - 0x280], 0

        $sequence_6 = { e8???????? 6a00 a1???????? 8945d8 }
            // n = 4, score = 300
            //   e8????????           |                     
            //   6a00                 | push                0
            //   a1????????           |                     
            //   8945d8               | mov                 dword ptr [ebp - 0x28], eax

        $sequence_7 = { 30d2 e8???????? 6a00 8d45e4 e8???????? 6a00 a1???????? }
            // n = 7, score = 300
            //   30d2                 | xor                 dl, dl
            //   e8????????           |                     
            //   6a00                 | push                0
            //   8d45e4               | lea                 eax, [ebp - 0x1c]
            //   e8????????           |                     
            //   6a00                 | push                0
            //   a1????????           |                     

        $sequence_8 = { e8???????? 8d8d8cfcffff 6631d2 8d8570fbffff e8???????? 8d858cfcffff 30c9 }
            // n = 7, score = 300
            //   e8????????           |                     
            //   8d8d8cfcffff         | lea                 ecx, [ebp - 0x374]
            //   6631d2               | xor                 dx, dx
            //   8d8570fbffff         | lea                 eax, [ebp - 0x490]
            //   e8????????           |                     
            //   8d858cfcffff         | lea                 eax, [ebp - 0x374]
            //   30c9                 | xor                 cl, cl

        $sequence_9 = { 8b45dc 8d70ff f745e401000000 740d f745dcffffffff 0f856fffffff 8b45f0 }
            // n = 7, score = 300
            //   8b45dc               | mov                 eax, dword ptr [ebp - 0x24]
            //   8d70ff               | lea                 esi, [eax - 1]
            //   f745e401000000       | test                dword ptr [ebp - 0x1c], 1
            //   740d                 | je                  0xf
            //   f745dcffffffff       | test                dword ptr [ebp - 0x24], 0xffffffff
            //   0f856fffffff         | jne                 0xffffff75
            //   8b45f0               | mov                 eax, dword ptr [ebp - 0x10]

    condition:
        7 of them and filesize < 739328
}