rule win_ryuk_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.ryuk."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.ryuk"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 68???????? 6a01 6a00 6814010000 }
            // n = 4, score = 2400
            //   68????????           |                     
            //   6a01                 | sub                 esi, edx
            //   6a00                 | push                ebx
            //   6814010000           | push                ebx

        $sequence_1 = { ff15???????? 85c0 7508 6a01 ff15???????? 68???????? 6a01 }
            // n = 7, score = 2300
            //   ff15????????         |                     
            //   85c0                 | jne                 0
            //   7508                 | lea                 edi, [ebx - 2]
            //   6a01                 | sub                 edx, esi
            //   ff15????????         |                     
            //   68????????           |                     
            //   6a01                 | push                ebx

        $sequence_2 = { 6a08 6a18 68???????? 68???????? 68???????? ff15???????? }
            // n = 6, score = 1900
            //   6a08                 | mov                 eax, 1
            //   6a18                 | jmp                 0x12
            //   68????????           |                     
            //   68????????           |                     
            //   68????????           |                     
            //   ff15????????         |                     

        $sequence_3 = { 754c b90b010000 66398818000035 753e 8b4508 b9???????? 2bc1 }
            // n = 7, score = 1800
            //   754c                 | mov                 eax, ebx
            //   b90b010000           | dec                 eax
            //   66398818000035       | add                 esp, 0x30
            //   753e                 | pop                 ebx
            //   8b4508               | ret                 
            //   b9????????           |                     
            //   2bc1                 | dec                 eax

        $sequence_4 = { 68???????? ff15???????? 85c0 7578 6a10 6a18 }
            // n = 6, score = 1800
            //   68????????           |                     
            //   ff15????????         |                     
            //   85c0                 | je                  9
            //   7578                 | mov                 eax, 1
            //   6a10                 | jmp                 0x12
            //   6a18                 | jmp                 0xd

        $sequence_5 = { 755d a1???????? 81b8????????50450000 754c b90b010000 66398818000035 }
            // n = 6, score = 1800
            //   755d                 | ret                 
            //   a1????????           |                     
            //   81b8????????50450000     |     
            //   754c                 | inc                 eax
            //   b90b010000           | push                ebx
            //   66398818000035       | dec                 eax

        $sequence_6 = { 68???????? ff15???????? 85c0 7542 6a28 6a18 }
            // n = 6, score = 1800
            //   68????????           |                     
            //   ff15????????         |                     
            //   85c0                 | je                  9
            //   7542                 | mov                 eax, 1
            //   6a28                 | jmp                 0x14
            //   6a18                 | jmp                 0xf

        $sequence_7 = { 68c0cf6a00 ff15???????? 6a01 ff15???????? }
            // n = 4, score = 1700
            //   68c0cf6a00           | dec                 eax
            //   ff15????????         |                     
            //   6a01                 | sub                 esp, 0x20
            //   ff15????????         |                     

        $sequence_8 = { 7407 b801000000 eb0b eb04 }
            // n = 4, score = 1400
            //   7407                 | mov                 eax, ecx
            //   b801000000           | ret                 
            //   eb0b                 | inc                 eax
            //   eb04                 | push                ebx

        $sequence_9 = { e8???????? 68e8030000 ff15???????? 68???????? e8???????? }
            // n = 5, score = 1400
            //   e8????????           |                     
            //   68e8030000           | lea                 edi, [edi + 2]
            //   ff15????????         |                     
            //   68????????           |                     
            //   e8????????           |                     

        $sequence_10 = { 720f b901000000 6bd103 8b45fc c6041000 }
            // n = 5, score = 1300
            //   720f                 | push                8
            //   b901000000           | push                0x18
            //   6bd103               | test                eax, eax
            //   8b45fc               | push                8
            //   c6041000             | push                0x18

        $sequence_11 = { 83c101 ba01000000 d1e2 8b45fc }
            // n = 4, score = 1300
            //   83c101               | test                eax, eax
            //   ba01000000           | jne                 0x7a
            //   d1e2                 | push                0x10
            //   8b45fc               | test                eax, eax

        $sequence_12 = { 8908 895004 837df800 7709 }
            // n = 4, score = 1300
            //   8908                 | test                eax, eax
            //   895004               | jne                 0x44
            //   837df800             | test                eax, eax
            //   7709                 | jne                 0x7a

        $sequence_13 = { 89459c 8955a0 8b55a0 3b55f8 0f870b020000 }
            // n = 5, score = 1300
            //   89459c               | jne                 0x7a
            //   8955a0               | push                0x10
            //   8b55a0               | push                0x18
            //   3b55f8               | test                eax, eax
            //   0f870b020000         | jne                 0x44

        $sequence_14 = { ba01000000 6bc203 8b55fc 880c02 b804000000 }
            // n = 5, score = 1300
            //   ba01000000           | push                0x28
            //   6bc203               | test                eax, eax
            //   8b55fc               | jne                 0x27
            //   880c02               | push                8
            //   b804000000           | push                0x18

        $sequence_15 = { ff15???????? b811000000 e9???????? e9???????? }
            // n = 4, score = 1200
            //   ff15????????         |                     
            //   b811000000           | cmp                 word ptr [edi], 0x4e
            //   e9????????           |                     
            //   e9????????           |                     

        $sequence_16 = { ff15???????? 833d????????00 6a10 6a18 }
            // n = 4, score = 900
            //   ff15????????         |                     
            //   833d????????00       |                     
            //   6a10                 | lea                 edx, [eax + 2]
            //   6a18                 | test                cx, cx

        $sequence_17 = { 6a00 6814010000 ff7508 ff35???????? }
            // n = 4, score = 900
            //   6a00                 | sar                 esi, 1
            //   6814010000           | and                 ecx, 3
            //   ff7508               | rep movsb           byte ptr es:[edi], byte ptr [esi]
            //   ff35????????         |                     

        $sequence_18 = { 7407 48 85c0 7ff0 }
            // n = 4, score = 900
            //   7407                 | sub                 esi, edx
            //   48                   | push                ebx
            //   85c0                 | sar                 esi, 1
            //   7ff0                 | add                 esp, 8

        $sequence_19 = { ff15???????? b803000000 eb05 b805000000 }
            // n = 4, score = 800
            //   ff15????????         |                     
            //   b803000000           | mov                 eax, 3
            //   eb05                 | jmp                 7
            //   b805000000           | mov                 eax, 5

        $sequence_20 = { 2bf0 33c0 66890473 83ffff }
            // n = 4, score = 800
            //   2bf0                 | add                 esp, 0x28
            //   33c0                 | ret                 
            //   66890473             | dec                 eax
            //   83ffff               | mov                 dword ptr [esp + 8], ebx

        $sequence_21 = { 751b ff35???????? ff35???????? 6a01 68???????? e8???????? }
            // n = 6, score = 800
            //   751b                 | lea                 edi, [edx - 2]
            //   ff35????????         |                     
            //   ff35????????         |                     
            //   6a01                 | mov                 ax, word ptr [edi + 2]
            //   68????????           |                     
            //   e8????????           |                     

        $sequence_22 = { eb0b 8bc1 99 f7fe }
            // n = 4, score = 700
            //   eb0b                 | lea                 edi, [edx - 2]
            //   8bc1                 | mov                 ax, word ptr [edi + 2]
            //   99                   | lea                 edi, [edi + 2]
            //   f7fe                 | test                ax, ax

        $sequence_23 = { 56 ff15???????? 8bcb 8d5102 }
            // n = 4, score = 700
            //   56                   | mov                 eax, ecx
            //   ff15????????         |                     
            //   8bcb                 | ret                 
            //   8d5102               | inc                 eax

        $sequence_24 = { 7714 7212 81f9d0070000 770a 85d2 }
            // n = 5, score = 700
            //   7714                 | jne                 0x4e
            //   7212                 | mov                 ecx, 0x10b
            //   81f9d0070000         | cmp                 word ptr [eax + 0x35000018], cx
            //   770a                 | jne                 0x47
            //   85d2                 | jne                 0x4e

        $sequence_25 = { e8???????? e8???????? b9e8030000 ff15???????? }
            // n = 4, score = 700
            //   e8????????           |                     
            //   e8????????           |                     
            //   b9e8030000           | mov                 ecx, 0x3e8
            //   ff15????????         |                     

        $sequence_26 = { 668b02 83c202 6685c0 75f5 8d7bfe 2bd6 }
            // n = 6, score = 600
            //   668b02               | cmp                 word ptr [edi], 0x4e
            //   83c202               | jne                 0x18
            //   6685c0               | cmp                 word ptr [edi + 2], 0x54
            //   75f5                 | jne                 0x18
            //   8d7bfe               | cmp                 word ptr [edi + 6], 0x41
            //   2bd6                 | cmp                 word ptr [edi], 0x4e

        $sequence_27 = { 0f9fc0 5d c3 8bff 55 8bec 8b4508 }
            // n = 7, score = 600
            //   0f9fc0               | test                eax, eax
            //   5d                   | jne                 0xc
            //   c3                   | push                1
            //   8bff                 | push                1
            //   55                   | test                eax, eax
            //   8bec                 | jne                 0xc
            //   8b4508               | push                1

        $sequence_28 = { 5d c3 8bcb 8d5102 }
            // n = 4, score = 600
            //   5d                   | shr                 eax, 6
            //   c3                   | imul                eax, eax, 0x5a
            //   8bcb                 | shr                 eax, 1
            //   8d5102               | add                 eax, edx

        $sequence_29 = { d1fa 2bca 33c0 6689444bfe e9???????? 33c0 }
            // n = 6, score = 600
            //   d1fa                 | lea                 edx, [ecx + 2]
            //   2bca                 | sub                 eax, edx
            //   33c0                 | sar                 eax, 1
            //   6689444bfe           | sub                 esi, eax
            //   e9????????           |                     
            //   33c0                 | xor                 eax, eax

        $sequence_30 = { 488bc3 4883c430 5b c3 48895c2408 48896c2410 4889742418 }
            // n = 7, score = 600
            //   488bc3               | sub                 esp, 0x20
            //   4883c430             | mov                 eax, ecx
            //   5b                   | dec                 ecx
            //   c3                   | mov                 ebx, eax
            //   48895c2408           | dec                 eax
            //   48896c2410           | mov                 eax, ebx
            //   4889742418           | dec                 eax

        $sequence_31 = { 68???????? 53 d1fe e8???????? 83c408 8d5002 }
            // n = 6, score = 600
            //   68????????           |                     
            //   53                   | dec                 eax
            //   d1fe                 | sub                 esp, 0x30
            //   e8????????           |                     
            //   83c408               | and                 dword ptr [esp + 0x20], 0
            //   8d5002               | cmp                 word ptr [edi], 0x4e

        $sequence_32 = { 498bc1 c3 4053 4883ec20 8bc1 498bd8 }
            // n = 6, score = 600
            //   498bc1               | dec                 ecx
            //   c3                   | mov                 eax, ecx
            //   4053                 | ret                 
            //   4883ec20             | inc                 eax
            //   8bc1                 | push                ebx
            //   498bd8               | dec                 eax

        $sequence_33 = { 50 51 e8???????? 6a00 6840420f00 52 50 }
            // n = 7, score = 600
            //   50                   | push                1
            //   51                   | push                1
            //   e8????????           |                     
            //   6a00                 | push                1
            //   6840420f00           | push                0
            //   52                   | push                0x114
            //   50                   | jne                 0xa

        $sequence_34 = { 83c602 6685c9 75f5 2bf2 68???????? 53 }
            // n = 6, score = 600
            //   83c602               | jne                 0x18
            //   6685c9               | cmp                 word ptr [edi + 2], 0x54
            //   75f5                 | jne                 0x18
            //   2bf2                 | cmp                 word ptr [edi + 6], 0x41
            //   68????????           |                     
            //   53                   | cmp                 word ptr [edi + 2], 0x54

        $sequence_35 = { f3a4 8d7afe 668b4702 8d7f02 6685c0 75f4 a1???????? }
            // n = 7, score = 600
            //   f3a4                 | dec                 eax
            //   8d7afe               | add                 esp, 0x28
            //   668b4702             | ret                 
            //   8d7f02               | dec                 eax
            //   6685c0               | mov                 dword ptr [esp + 8], ebx
            //   75f4                 | push                edi
            //   a1????????           |                     

        $sequence_36 = { 4883c428 c3 48895c2408 57 4883ec30 8364242000 }
            // n = 6, score = 600
            //   4883c428             | dec                 eax
            //   c3                   | add                 esp, 0x30
            //   48895c2408           | pop                 ebx
            //   57                   | ret                 
            //   4883ec30             | dec                 eax
            //   8364242000           | mov                 dword ptr [esp + 8], ebx

        $sequence_37 = { 33c9 ba10270000 41b800100000 448d4904 ff15???????? }
            // n = 5, score = 500
            //   33c9                 | cmp                 word ptr [edi + 6], 0x41
            //   ba10270000           | inc                 ebp
            //   41b800100000         | xor                 ecx, ecx
            //   448d4904             | inc                 ebp
            //   ff15????????         |                     

        $sequence_38 = { f7e1 8bc1 2bc2 d1e8 03c2 c1e806 6bc05a }
            // n = 7, score = 500
            //   f7e1                 | dec                 eax
            //   8bc1                 | sub                 esp, 0x20
            //   2bc2                 | mov                 eax, ecx
            //   d1e8                 | dec                 ecx
            //   03c2                 | mov                 ebx, eax
            //   c1e806               | cmp                 word ptr [edi], 0x4e
            //   6bc05a               | jne                 0x18

        $sequence_39 = { ff15???????? 41b900300000 c744242040000000 448bc3 488bd6 488bcf }
            // n = 6, score = 500
            //   ff15????????         |                     
            //   41b900300000         | jne                 0x18
            //   c744242040000000     | cmp                 word ptr [edi + 2], 0x54
            //   448bc3               | jne                 0x11
            //   488bd6               | cmp                 word ptr [edi + 6], 0x41
            //   488bcf               | jne                 0x11

        $sequence_40 = { c744242802000000 4533c9 4533c0 c744242002000000 ba000000c0 }
            // n = 5, score = 500
            //   c744242802000000     | jne                 0x18
            //   4533c9               | cmp                 word ptr [edi + 2], 0x54
            //   4533c0               | jne                 0x16
            //   c744242002000000     | cmp                 word ptr [edi + 6], 0x41
            //   ba000000c0           | jne                 0x16

        $sequence_41 = { ff15???????? 488bd8 ff15???????? 83f820 7510 488bcb ff15???????? }
            // n = 7, score = 500
            //   ff15????????         |                     
            //   488bd8               | cmp                 word ptr [edi], 0x4e
            //   ff15????????         |                     
            //   83f820               | jne                 0x18
            //   7510                 | cmp                 word ptr [edi + 2], 0x54
            //   488bcb               | jne                 0x18
            //   ff15????????         |                     

        $sequence_42 = { 4533c9 4533c0 c744242003000000 ba00000040 ff15???????? 488bd8 ff15???????? }
            // n = 7, score = 500
            //   4533c9               | ret                 
            //   4533c0               | inc                 eax
            //   c744242003000000     | push                ebx
            //   ba00000040           | dec                 eax
            //   ff15????????         |                     
            //   488bd8               | sub                 esp, 0x20
            //   ff15????????         |                     

        $sequence_43 = { 66837f0254 750f 66837f0641 7508 }
            // n = 4, score = 500
            //   66837f0254           | push                ebx
            //   750f                 | dec                 eax
            //   66837f0641           | sub                 esp, 0x20
            //   7508                 | mov                 eax, ecx

        $sequence_44 = { 4889442420 4c8bc6 488bd3 488bcf ff15???????? }
            // n = 5, score = 500
            //   4889442420           | cmp                 word ptr [edi], 0x4e
            //   4c8bc6               | jne                 0x18
            //   488bd3               | cmp                 word ptr [edi + 2], 0x54
            //   488bcf               | jne                 0x18
            //   ff15????????         |                     

        $sequence_45 = { ff15???????? 66833f4e 7516 66837f0254 750f }
            // n = 5, score = 500
            //   ff15????????         |                     
            //   66833f4e             | mov                 eax, ebx
            //   7516                 | dec                 eax
            //   66837f0254           | add                 esp, 0x30
            //   750f                 | pop                 ebx

        $sequence_46 = { 84c0 746c e8???????? 488d0d63080000 e8???????? e8???????? }
            // n = 6, score = 400
            //   84c0                 | push                0x114
            //   746c                 | test                eax, eax
            //   e8????????           |                     
            //   488d0d63080000       | jne                 0xc
            //   e8????????           |                     
            //   e8????????           |                     

    condition:
        7 of them and filesize < 7450624
}