rule win_sality_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.sality."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.sality"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 0302 50 6878563412 e8???????? }
            // n = 4, score = 400
            //   0302                 | add                 eax, dword ptr [edx]
            //   50                   | push                eax
            //   6878563412           | push                0x12345678
            //   e8????????           |                     

        $sequence_1 = { 0255fc 8855ec 8b45ec 25ff000000 }
            // n = 4, score = 400
            //   0255fc               | add                 dl, byte ptr [ebp - 4]
            //   8855ec               | mov                 byte ptr [ebp - 0x14], dl
            //   8b45ec               | mov                 eax, dword ptr [ebp - 0x14]
            //   25ff000000           | and                 eax, 0xff

        $sequence_2 = { 02040a 8845fc 8b4dfc 81e1ff000000 }
            // n = 4, score = 400
            //   02040a               | add                 al, byte ptr [edx + ecx]
            //   8845fc               | mov                 byte ptr [ebp - 4], al
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   81e1ff000000         | and                 ecx, 0xff

        $sequence_3 = { 0302 50 6a00 e8???????? }
            // n = 4, score = 400
            //   0302                 | add                 eax, dword ptr [edx]
            //   50                   | push                eax
            //   6a00                 | push                0
            //   e8????????           |                     

        $sequence_4 = { 837da000 751b 8b551c 52 8b4514 50 8b4d10 }
            // n = 7, score = 400
            //   837da000             | cmp                 dword ptr [ebp - 0x60], 0
            //   751b                 | jne                 0x1d
            //   8b551c               | mov                 edx, dword ptr [ebp + 0x1c]
            //   52                   | push                edx
            //   8b4514               | mov                 eax, dword ptr [ebp + 0x14]
            //   50                   | push                eax
            //   8b4d10               | mov                 ecx, dword ptr [ebp + 0x10]

        $sequence_5 = { 02c8 884dec 8b55f0 83c201 }
            // n = 4, score = 400
            //   02c8                 | add                 cl, al
            //   884dec               | mov                 byte ptr [ebp - 0x14], cl
            //   8b55f0               | mov                 edx, dword ptr [ebp - 0x10]
            //   83c201               | add                 edx, 1

        $sequence_6 = { 0311 52 6878563412 e8???????? }
            // n = 4, score = 400
            //   0311                 | add                 edx, dword ptr [ecx]
            //   52                   | push                edx
            //   6878563412           | push                0x12345678
            //   e8????????           |                     

        $sequence_7 = { 0302 8945fc 8b4d10 8b55fc }
            // n = 4, score = 400
            //   0302                 | add                 eax, dword ptr [edx]
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   8b4d10               | mov                 ecx, dword ptr [ebp + 0x10]
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]

        $sequence_8 = { 52 50 ff9539154000 58 6a00 }
            // n = 5, score = 200
            //   52                   | push                edx
            //   50                   | push                eax
            //   ff9539154000         | call                dword ptr [ebp + 0x401539]
            //   58                   | pop                 eax
            //   6a00                 | push                0

        $sequence_9 = { 8b5678 0354240c 8b5a20 035c240c 33c0 8b3b }
            // n = 6, score = 200
            //   8b5678               | mov                 edx, dword ptr [esi + 0x78]
            //   0354240c             | add                 edx, dword ptr [esp + 0xc]
            //   8b5a20               | mov                 ebx, dword ptr [edx + 0x20]
            //   035c240c             | add                 ebx, dword ptr [esp + 0xc]
            //   33c0                 | xor                 eax, eax
            //   8b3b                 | mov                 edi, dword ptr [ebx]

        $sequence_10 = { 240f 3c0a 1c69 2f 8803 43 }
            // n = 6, score = 200
            //   240f                 | and                 al, 0xf
            //   3c0a                 | cmp                 al, 0xa
            //   1c69                 | sbb                 al, 0x69
            //   2f                   | das                 
            //   8803                 | mov                 byte ptr [ebx], al
            //   43                   | inc                 ebx

        $sequence_11 = { f3a6 61 7513 8bc2 83e804 8b00 }
            // n = 6, score = 200
            //   f3a6                 | repe cmpsb          byte ptr [esi], byte ptr es:[edi]
            //   61                   | popal               
            //   7513                 | jne                 0x15
            //   8bc2                 | mov                 eax, edx
            //   83e804               | sub                 eax, 4
            //   8b00                 | mov                 eax, dword ptr [eax]

        $sequence_12 = { eb0c 58 e8???????? b801000000 c3 }
            // n = 5, score = 200
            //   eb0c                 | jmp                 0xe
            //   58                   | pop                 eax
            //   e8????????           |                     
            //   b801000000           | mov                 eax, 1
            //   c3                   | ret                 

        $sequence_13 = { 7461 8bc8 48 c6857b27400000 }
            // n = 4, score = 200
            //   7461                 | je                  0x63
            //   8bc8                 | mov                 ecx, eax
            //   48                   | dec                 eax
            //   c6857b27400000       | mov                 byte ptr [ebp + 0x40277b], 0

        $sequence_14 = { 8b00 0344240c eb02 33c0 }
            // n = 4, score = 200
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   0344240c             | add                 eax, dword ptr [esp + 0xc]
            //   eb02                 | jmp                 4
            //   33c0                 | xor                 eax, eax

        $sequence_15 = { ff95bc154000 85c0 7415 58 }
            // n = 4, score = 200
            //   ff95bc154000         | call                dword ptr [ebp + 0x4015bc]
            //   85c0                 | test                eax, eax
            //   7415                 | je                  0x17
            //   58                   | pop                 eax

        $sequence_16 = { 010d???????? 83c004 5f 5e }
            // n = 4, score = 100
            //   010d????????         |                     
            //   83c004               | add                 eax, 4
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi

        $sequence_17 = { 0007 7307 c607ff 8ac1 }
            // n = 4, score = 100
            //   0007                 | add                 byte ptr [edi], al
            //   7307                 | jae                 9
            //   c607ff               | mov                 byte ptr [edi], 0xff
            //   8ac1                 | mov                 al, cl

        $sequence_18 = { 031e ff7608 ff7604 e8???????? }
            // n = 4, score = 100
            //   031e                 | add                 ebx, dword ptr [esi]
            //   ff7608               | push                dword ptr [esi + 8]
            //   ff7604               | push                dword ptr [esi + 4]
            //   e8????????           |                     

        $sequence_19 = { 00fb fb 804880bc 280d???????? }
            // n = 4, score = 100
            //   00fb                 | add                 bl, bh
            //   fb                   | sti                 
            //   804880bc             | or                  byte ptr [eax - 0x80], 0xbc
            //   280d????????         |                     

        $sequence_20 = { 0306 50 8d5604 e8???????? }
            // n = 4, score = 100
            //   0306                 | add                 eax, dword ptr [esi]
            //   50                   | push                eax
            //   8d5604               | lea                 edx, [esi + 4]
            //   e8????????           |                     

        $sequence_21 = { 0306 50 8b4e04 8d5608 }
            // n = 4, score = 100
            //   0306                 | add                 eax, dword ptr [esi]
            //   50                   | push                eax
            //   8b4e04               | mov                 ecx, dword ptr [esi + 4]
            //   8d5608               | lea                 edx, [esi + 8]

        $sequence_22 = { 0202 7466 0fb77202 8b7a04 }
            // n = 4, score = 100
            //   0202                 | add                 al, byte ptr [edx]
            //   7466                 | je                  0x68
            //   0fb77202             | movzx               esi, word ptr [edx + 2]
            //   8b7a04               | mov                 edi, dword ptr [edx + 4]

        $sequence_23 = { 014304 c3 53 56 }
            // n = 4, score = 100
            //   014304               | add                 dword ptr [ebx + 4], eax
            //   c3                   | ret                 
            //   53                   | push                ebx
            //   56                   | push                esi

    condition:
        7 of them and filesize < 1523712
}