rule win_scranos_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.scranos."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.scranos"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 83c404 8b55cc 8d440201 8945cc ebb5 8b4de4 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   8b55cc               | mov                 edx, dword ptr [ebp - 0x34]
            //   8d440201             | lea                 eax, [edx + eax + 1]
            //   8945cc               | mov                 dword ptr [ebp - 0x34], eax
            //   ebb5                 | jmp                 0xffffffb7
            //   8b4de4               | mov                 ecx, dword ptr [ebp - 0x1c]

        $sequence_1 = { 8b8e70010000 8d542430 52 8b966c010000 8d442438 50 8d86b0030000 }
            // n = 7, score = 100
            //   8b8e70010000         | mov                 ecx, dword ptr [esi + 0x170]
            //   8d542430             | lea                 edx, [esp + 0x30]
            //   52                   | push                edx
            //   8b966c010000         | mov                 edx, dword ptr [esi + 0x16c]
            //   8d442438             | lea                 eax, [esp + 0x38]
            //   50                   | push                eax
            //   8d86b0030000         | lea                 eax, [esi + 0x3b0]

        $sequence_2 = { eb13 8b4608 8b4e04 8b16 50 51 52 }
            // n = 7, score = 100
            //   eb13                 | jmp                 0x15
            //   8b4608               | mov                 eax, dword ptr [esi + 8]
            //   8b4e04               | mov                 ecx, dword ptr [esi + 4]
            //   8b16                 | mov                 edx, dword ptr [esi]
            //   50                   | push                eax
            //   51                   | push                ecx
            //   52                   | push                edx

        $sequence_3 = { e8???????? 83c428 e9???????? 8b55ec 8b42e4 50 8b4df4 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   83c428               | add                 esp, 0x28
            //   e9????????           |                     
            //   8b55ec               | mov                 edx, dword ptr [ebp - 0x14]
            //   8b42e4               | mov                 eax, dword ptr [edx - 0x1c]
            //   50                   | push                eax
            //   8b4df4               | mov                 ecx, dword ptr [ebp - 0xc]

        $sequence_4 = { e8???????? 83c40c 85c0 0f8515070000 8b54241c 52 56 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   85c0                 | test                eax, eax
            //   0f8515070000         | jne                 0x71b
            //   8b54241c             | mov                 edx, dword ptr [esp + 0x1c]
            //   52                   | push                edx
            //   56                   | push                esi

        $sequence_5 = { 89834c010000 7523 8b542410 52 8d442420 50 8d8bc8000000 }
            // n = 7, score = 100
            //   89834c010000         | mov                 dword ptr [ebx + 0x14c], eax
            //   7523                 | jne                 0x25
            //   8b542410             | mov                 edx, dword ptr [esp + 0x10]
            //   52                   | push                edx
            //   8d442420             | lea                 eax, [esp + 0x20]
            //   50                   | push                eax
            //   8d8bc8000000         | lea                 ecx, [ebx + 0xc8]

        $sequence_6 = { 8b4d24 e8???????? 8945a0 8b4da0 894d9c c745fc00000000 8d55ac }
            // n = 7, score = 100
            //   8b4d24               | mov                 ecx, dword ptr [ebp + 0x24]
            //   e8????????           |                     
            //   8945a0               | mov                 dword ptr [ebp - 0x60], eax
            //   8b4da0               | mov                 ecx, dword ptr [ebp - 0x60]
            //   894d9c               | mov                 dword ptr [ebp - 0x64], ecx
            //   c745fc00000000       | mov                 dword ptr [ebp - 4], 0
            //   8d55ac               | lea                 edx, [ebp - 0x54]

        $sequence_7 = { 8b55e8 8b849544ffffff 89448d8c 8b4de8 8b948d30ffffff 8b4248 8b4de8 }
            // n = 7, score = 100
            //   8b55e8               | mov                 edx, dword ptr [ebp - 0x18]
            //   8b849544ffffff       | mov                 eax, dword ptr [ebp + edx*4 - 0xbc]
            //   89448d8c             | mov                 dword ptr [ebp + ecx*4 - 0x74], eax
            //   8b4de8               | mov                 ecx, dword ptr [ebp - 0x18]
            //   8b948d30ffffff       | mov                 edx, dword ptr [ebp + ecx*4 - 0xd0]
            //   8b4248               | mov                 eax, dword ptr [edx + 0x48]
            //   8b4de8               | mov                 ecx, dword ptr [ebp - 0x18]

        $sequence_8 = { 8b6c2410 57 8b7d00 8b87840c0000 81c7680c0000 8d4f0c 8944240c }
            // n = 7, score = 100
            //   8b6c2410             | mov                 ebp, dword ptr [esp + 0x10]
            //   57                   | push                edi
            //   8b7d00               | mov                 edi, dword ptr [ebp]
            //   8b87840c0000         | mov                 eax, dword ptr [edi + 0xc84]
            //   81c7680c0000         | add                 edi, 0xc68
            //   8d4f0c               | lea                 ecx, [edi + 0xc]
            //   8944240c             | mov                 dword ptr [esp + 0xc], eax

        $sequence_9 = { c645fc00 8d4dc8 e8???????? c745fcffffffff 8d4da8 e8???????? 8b4594 }
            // n = 7, score = 100
            //   c645fc00             | mov                 byte ptr [ebp - 4], 0
            //   8d4dc8               | lea                 ecx, [ebp - 0x38]
            //   e8????????           |                     
            //   c745fcffffffff       | mov                 dword ptr [ebp - 4], 0xffffffff
            //   8d4da8               | lea                 ecx, [ebp - 0x58]
            //   e8????????           |                     
            //   8b4594               | mov                 eax, dword ptr [ebp - 0x6c]

    condition:
        7 of them and filesize < 2859008
}