rule win_sedll_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.sedll."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.sedll"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 6a00 6a00 6a00 8d8424b0030000 }
            // n = 4, score = 200
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   8d8424b0030000       | lea                 eax, [esp + 0x3b0]

        $sequence_1 = { 50 ff15???????? 8b4df8 85c9 7407 }
            // n = 5, score = 200
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8b4df8               | mov                 ecx, dword ptr [ebp - 8]
            //   85c9                 | test                ecx, ecx
            //   7407                 | je                  9

        $sequence_2 = { 74e3 57 33c9 33ff 85db 0f848f000000 }
            // n = 6, score = 200
            //   74e3                 | je                  0xffffffe5
            //   57                   | push                edi
            //   33c9                 | xor                 ecx, ecx
            //   33ff                 | xor                 edi, edi
            //   85db                 | test                ebx, ebx
            //   0f848f000000         | je                  0x95

        $sequence_3 = { 56 6800010000 8d85f0feffff 8bf1 6880000000 50 }
            // n = 6, score = 200
            //   56                   | push                esi
            //   6800010000           | push                0x100
            //   8d85f0feffff         | lea                 eax, [ebp - 0x110]
            //   8bf1                 | mov                 esi, ecx
            //   6880000000           | push                0x80
            //   50                   | push                eax

        $sequence_4 = { 8d842484010000 50 8d842498030000 50 ff15???????? }
            // n = 5, score = 200
            //   8d842484010000       | lea                 eax, [esp + 0x184]
            //   50                   | push                eax
            //   8d842498030000       | lea                 eax, [esp + 0x398]
            //   50                   | push                eax
            //   ff15????????         |                     

        $sequence_5 = { 6a00 53 e8???????? 83c410 6a00 6a00 ff75f4 }
            // n = 7, score = 200
            //   6a00                 | push                0
            //   53                   | push                ebx
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   ff75f4               | push                dword ptr [ebp - 0xc]

        $sequence_6 = { ff15???????? 85c0 7523 85ff }
            // n = 4, score = 200
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7523                 | jne                 0x25
            //   85ff                 | test                edi, edi

        $sequence_7 = { 57 6aff ff75fc 6a00 6a00 ffd3 8bc7 }
            // n = 7, score = 200
            //   57                   | push                edi
            //   6aff                 | push                -1
            //   ff75fc               | push                dword ptr [ebp - 4]
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   ffd3                 | call                ebx
            //   8bc7                 | mov                 eax, edi

        $sequence_8 = { 8b4514 8908 a1???????? 50 }
            // n = 4, score = 200
            //   8b4514               | mov                 eax, dword ptr [ebp + 0x14]
            //   8908                 | mov                 dword ptr [eax], ecx
            //   a1????????           |                     
            //   50                   | push                eax

        $sequence_9 = { 7604 8bf8 2bfb 8d7701 56 }
            // n = 5, score = 200
            //   7604                 | jbe                 6
            //   8bf8                 | mov                 edi, eax
            //   2bfb                 | sub                 edi, ebx
            //   8d7701               | lea                 esi, [edi + 1]
            //   56                   | push                esi

    condition:
        7 of them and filesize < 65536
}