rule win_selfmake_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.selfmake."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.selfmake"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 83c104 3bf0 7ce3 68???????? }
            // n = 4, score = 400
            //   83c104               | add                 ecx, 4
            //   3bf0                 | cmp                 esi, eax
            //   7ce3                 | jl                  0xffffffe5
            //   68????????           |                     

        $sequence_1 = { 83e107 894df4 8b55f4 52 ff15???????? a1???????? 8be5 }
            // n = 7, score = 400
            //   83e107               | and                 ecx, 7
            //   894df4               | mov                 dword ptr [ebp - 0xc], ecx
            //   8b55f4               | mov                 edx, dword ptr [ebp - 0xc]
            //   52                   | push                edx
            //   ff15????????         |                     
            //   a1????????           |                     
            //   8be5                 | mov                 esp, ebp

        $sequence_2 = { 8d742430 742e e8???????? 6aff }
            // n = 4, score = 400
            //   8d742430             | lea                 esi, [esp + 0x30]
            //   742e                 | je                  0x30
            //   e8????????           |                     
            //   6aff                 | push                -1

        $sequence_3 = { 47 84c0 75f8 66a1???????? 668907 8d44243c 8bd0 }
            // n = 7, score = 400
            //   47                   | inc                 edi
            //   84c0                 | test                al, al
            //   75f8                 | jne                 0xfffffffa
            //   66a1????????         |                     
            //   668907               | mov                 word ptr [edi], ax
            //   8d44243c             | lea                 eax, [esp + 0x3c]
            //   8bd0                 | mov                 edx, eax

        $sequence_4 = { 8945f8 837df800 7408 8b45f8 e9???????? e8???????? }
            // n = 6, score = 400
            //   8945f8               | mov                 dword ptr [ebp - 8], eax
            //   837df800             | cmp                 dword ptr [ebp - 8], 0
            //   7408                 | je                  0xa
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   e9????????           |                     
            //   e8????????           |                     

        $sequence_5 = { 8b4b2c 6a00 6a01 51 ffd0 8b16 83c604 }
            // n = 7, score = 400
            //   8b4b2c               | mov                 ecx, dword ptr [ebx + 0x2c]
            //   6a00                 | push                0
            //   6a01                 | push                1
            //   51                   | push                ecx
            //   ffd0                 | call                eax
            //   8b16                 | mov                 edx, dword ptr [esi]
            //   83c604               | add                 esi, 4

        $sequence_6 = { 7604 2bf1 eb02 33f6 8b4310 25c0010000 83f840 }
            // n = 7, score = 400
            //   7604                 | jbe                 6
            //   2bf1                 | sub                 esi, ecx
            //   eb02                 | jmp                 4
            //   33f6                 | xor                 esi, esi
            //   8b4310               | mov                 eax, dword ptr [ebx + 0x10]
            //   25c0010000           | and                 eax, 0x1c0
            //   83f840               | cmp                 eax, 0x40

        $sequence_7 = { 81fa???????? 7209 83c014 3bc1 72eb }
            // n = 5, score = 400
            //   81fa????????         |                     
            //   7209                 | jb                  0xb
            //   83c014               | add                 eax, 0x14
            //   3bc1                 | cmp                 eax, ecx
            //   72eb                 | jb                  0xffffffed

        $sequence_8 = { 51 e8???????? 8b742418 8bbc2418020000 }
            // n = 4, score = 400
            //   51                   | push                ecx
            //   e8????????           |                     
            //   8b742418             | mov                 esi, dword ptr [esp + 0x18]
            //   8bbc2418020000       | mov                 edi, dword ptr [esp + 0x218]

        $sequence_9 = { e8???????? 56 e8???????? 8b442424 8b35???????? 83c414 50 }
            // n = 7, score = 400
            //   e8????????           |                     
            //   56                   | push                esi
            //   e8????????           |                     
            //   8b442424             | mov                 eax, dword ptr [esp + 0x24]
            //   8b35????????         |                     
            //   83c414               | add                 esp, 0x14
            //   50                   | push                eax

    condition:
        7 of them and filesize < 932864
}