rule win_sepulcher_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.sepulcher."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.sepulcher"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 56 57 6a43 8bf9 58 6a4d 8db784480000 }
            // n = 7, score = 100
            //   56                   | push                esi
            //   57                   | push                edi
            //   6a43                 | push                0x43
            //   8bf9                 | mov                 edi, ecx
            //   58                   | pop                 eax
            //   6a4d                 | push                0x4d
            //   8db784480000         | lea                 esi, [edi + 0x4884]

        $sequence_1 = { 7515 6a04 8d45bc 50 e8???????? 8b4db8 8bd0 }
            // n = 7, score = 100
            //   7515                 | jne                 0x17
            //   6a04                 | push                4
            //   8d45bc               | lea                 eax, [ebp - 0x44]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b4db8               | mov                 ecx, dword ptr [ebp - 0x48]
            //   8bd0                 | mov                 edx, eax

        $sequence_2 = { 58 6a74 59 6a53 668945ea 58 }
            // n = 6, score = 100
            //   58                   | pop                 eax
            //   6a74                 | push                0x74
            //   59                   | pop                 ecx
            //   6a53                 | push                0x53
            //   668945ea             | mov                 word ptr [ebp - 0x16], ax
            //   58                   | pop                 eax

        $sequence_3 = { 0fb71408 8bc2 c1e002 66393408 75f1 }
            // n = 5, score = 100
            //   0fb71408             | movzx               edx, word ptr [eax + ecx]
            //   8bc2                 | mov                 eax, edx
            //   c1e002               | shl                 eax, 2
            //   66393408             | cmp                 word ptr [eax + ecx], si
            //   75f1                 | jne                 0xfffffff3

        $sequence_4 = { eb1a 8d45fc 50 8b04bd50de0110 ff743018 }
            // n = 5, score = 100
            //   eb1a                 | jmp                 0x1c
            //   8d45fc               | lea                 eax, [ebp - 4]
            //   50                   | push                eax
            //   8b04bd50de0110       | mov                 eax, dword ptr [edi*4 + 0x1001de50]
            //   ff743018             | push                dword ptr [eax + esi + 0x18]

        $sequence_5 = { 668945d2 b8???????? 66894db4 66894dba 66894dc0 }
            // n = 5, score = 100
            //   668945d2             | mov                 word ptr [ebp - 0x2e], ax
            //   b8????????           |                     
            //   66894db4             | mov                 word ptr [ebp - 0x4c], cx
            //   66894dba             | mov                 word ptr [ebp - 0x46], cx
            //   66894dc0             | mov                 word ptr [ebp - 0x40], cx

        $sequence_6 = { 56 57 6a5a 58 6a52 }
            // n = 5, score = 100
            //   56                   | push                esi
            //   57                   | push                edi
            //   6a5a                 | push                0x5a
            //   58                   | pop                 eax
            //   6a52                 | push                0x52

        $sequence_7 = { c1f906 6bd030 8b45fc 03148d50de0110 8b00 894218 }
            // n = 6, score = 100
            //   c1f906               | sar                 ecx, 6
            //   6bd030               | imul                edx, eax, 0x30
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   03148d50de0110       | add                 edx, dword ptr [ecx*4 + 0x1001de50]
            //   8b00                 | mov                 eax, dword ptr [eax]
            //   894218               | mov                 dword ptr [edx + 0x18], eax

        $sequence_8 = { 8bd8 895db0 8d0c4dffff0000 51 57 53 e8???????? }
            // n = 7, score = 100
            //   8bd8                 | mov                 ebx, eax
            //   895db0               | mov                 dword ptr [ebp - 0x50], ebx
            //   8d0c4dffff0000       | lea                 ecx, [ecx*2 + 0xffff]
            //   51                   | push                ecx
            //   57                   | push                edi
            //   53                   | push                ebx
            //   e8????????           |                     

        $sequence_9 = { 58 6a33 668945e8 668945ea 58 6a32 668945ec }
            // n = 7, score = 100
            //   58                   | pop                 eax
            //   6a33                 | push                0x33
            //   668945e8             | mov                 word ptr [ebp - 0x18], ax
            //   668945ea             | mov                 word ptr [ebp - 0x16], ax
            //   58                   | pop                 eax
            //   6a32                 | push                0x32
            //   668945ec             | mov                 word ptr [ebp - 0x14], ax

    condition:
        7 of them and filesize < 279552
}