rule win_shadowpad_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.shadowpad."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.shadowpad"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 59 8d75dc a3???????? e8???????? 53 ff15???????? }
            // n = 7, score = 200
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   8d75dc               | lea                 esi, [ebp - 0x24]
            //   a3????????           |                     
            //   e8????????           |                     
            //   53                   | push                ebx
            //   ff15????????         |                     

        $sequence_1 = { 5b c9 c3 55 8bec b8f8100000 e8???????? }
            // n = 7, score = 200
            //   5b                   | pop                 ebx
            //   c9                   | leave               
            //   c3                   | ret                 
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   b8f8100000           | mov                 eax, 0x10f8
            //   e8????????           |                     

        $sequence_2 = { 8bec 53 57 ff7508 ff15???????? 8d7801 }
            // n = 6, score = 200
            //   8bec                 | mov                 ebp, esp
            //   53                   | push                ebx
            //   57                   | push                edi
            //   ff7508               | push                dword ptr [ebp + 8]
            //   ff15????????         |                     
            //   8d7801               | lea                 edi, [eax + 1]

        $sequence_3 = { 8d45e8 50 53 8d75d0 }
            // n = 4, score = 200
            //   8d45e8               | lea                 eax, [ebp - 0x18]
            //   50                   | push                eax
            //   53                   | push                ebx
            //   8d75d0               | lea                 esi, [ebp - 0x30]

        $sequence_4 = { 7e25 8a0c56 8a445601 80e961 2c6a }
            // n = 5, score = 200
            //   7e25                 | jle                 0x27
            //   8a0c56               | mov                 cl, byte ptr [esi + edx*2]
            //   8a445601             | mov                 al, byte ptr [esi + edx*2 + 1]
            //   80e961               | sub                 cl, 0x61
            //   2c6a                 | sub                 al, 0x6a

        $sequence_5 = { 50 6a04 5f e8???????? 85c0 75ae 8d4310 }
            // n = 7, score = 200
            //   50                   | push                eax
            //   6a04                 | push                4
            //   5f                   | pop                 edi
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   75ae                 | jne                 0xffffffb0
            //   8d4310               | lea                 eax, [ebx + 0x10]

        $sequence_6 = { 83ec24 53 56 57 33ff 393d???????? }
            // n = 6, score = 200
            //   83ec24               | sub                 esp, 0x24
            //   53                   | push                ebx
            //   56                   | push                esi
            //   57                   | push                edi
            //   33ff                 | xor                 edi, edi
            //   393d????????         |                     

        $sequence_7 = { e8???????? 8b1d???????? 50 ffd3 6800010000 668945f0 }
            // n = 6, score = 200
            //   e8????????           |                     
            //   8b1d????????         |                     
            //   50                   | push                eax
            //   ffd3                 | call                ebx
            //   6800010000           | push                0x100
            //   668945f0             | mov                 word ptr [ebp - 0x10], ax

        $sequence_8 = { 8bfe 8d45e8 895de8 895dec 895df4 895df0 885df8 }
            // n = 7, score = 200
            //   8bfe                 | mov                 edi, esi
            //   8d45e8               | lea                 eax, [ebp - 0x18]
            //   895de8               | mov                 dword ptr [ebp - 0x18], ebx
            //   895dec               | mov                 dword ptr [ebp - 0x14], ebx
            //   895df4               | mov                 dword ptr [ebp - 0xc], ebx
            //   895df0               | mov                 dword ptr [ebp - 0x10], ebx
            //   885df8               | mov                 byte ptr [ebp - 8], bl

        $sequence_9 = { 0fb639 c1ce08 83cf20 03f7 83c102 81f6a3d9357c 663919 }
            // n = 7, score = 200
            //   0fb639               | movzx               edi, byte ptr [ecx]
            //   c1ce08               | ror                 esi, 8
            //   83cf20               | or                  edi, 0x20
            //   03f7                 | add                 esi, edi
            //   83c102               | add                 ecx, 2
            //   81f6a3d9357c         | xor                 esi, 0x7c35d9a3
            //   663919               | cmp                 word ptr [ecx], bx

    condition:
        7 of them and filesize < 188416
}