rule win_shareip_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.shareip."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.shareip"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d8534feffff e9???????? 8d8da8feffff e9???????? 8d8558feffff e9???????? 8d8544ffffff }
            // n = 7, score = 100
            //   8d8534feffff         | lea                 eax, [ebp - 0x1cc]
            //   e9????????           |                     
            //   8d8da8feffff         | lea                 ecx, [ebp - 0x158]
            //   e9????????           |                     
            //   8d8558feffff         | lea                 eax, [ebp - 0x1a8]
            //   e9????????           |                     
            //   8d8544ffffff         | lea                 eax, [ebp - 0xbc]

        $sequence_1 = { 894638 85c9 740f 8bd0 8d4900 8a01 8802 }
            // n = 7, score = 100
            //   894638               | mov                 dword ptr [esi + 0x38], eax
            //   85c9                 | test                ecx, ecx
            //   740f                 | je                  0x11
            //   8bd0                 | mov                 edx, eax
            //   8d4900               | lea                 ecx, [ecx]
            //   8a01                 | mov                 al, byte ptr [ecx]
            //   8802                 | mov                 byte ptr [edx], al

        $sequence_2 = { 8a8064954500 08443b1d 0fb64601 47 3bf8 76ea 8b7d08 }
            // n = 7, score = 100
            //   8a8064954500         | mov                 al, byte ptr [eax + 0x459564]
            //   08443b1d             | or                  byte ptr [ebx + edi + 0x1d], al
            //   0fb64601             | movzx               eax, byte ptr [esi + 1]
            //   47                   | inc                 edi
            //   3bf8                 | cmp                 edi, eax
            //   76ea                 | jbe                 0xffffffec
            //   8b7d08               | mov                 edi, dword ptr [ebp + 8]

        $sequence_3 = { 395c2444 7426 3bc3 7422 50 e8???????? 8b4c2444 }
            // n = 7, score = 100
            //   395c2444             | cmp                 dword ptr [esp + 0x44], ebx
            //   7426                 | je                  0x28
            //   3bc3                 | cmp                 eax, ebx
            //   7422                 | je                  0x24
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b4c2444             | mov                 ecx, dword ptr [esp + 0x44]

        $sequence_4 = { 834dfcff 894614 83c40c 8d45e4 50 e8???????? 8b07 }
            // n = 7, score = 100
            //   834dfcff             | or                  dword ptr [ebp - 4], 0xffffffff
            //   894614               | mov                 dword ptr [esi + 0x14], eax
            //   83c40c               | add                 esp, 0xc
            //   8d45e4               | lea                 eax, [ebp - 0x1c]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b07                 | mov                 eax, dword ptr [edi]

        $sequence_5 = { 8b44241c 50 8d8c24a0010000 51 53 53 53 }
            // n = 7, score = 100
            //   8b44241c             | mov                 eax, dword ptr [esp + 0x1c]
            //   50                   | push                eax
            //   8d8c24a0010000       | lea                 ecx, [esp + 0x1a0]
            //   51                   | push                ecx
            //   53                   | push                ebx
            //   53                   | push                ebx
            //   53                   | push                ebx

        $sequence_6 = { 55 8d4c245c e8???????? 8bd8 895c2414 83fbff 7541 }
            // n = 7, score = 100
            //   55                   | push                ebp
            //   8d4c245c             | lea                 ecx, [esp + 0x5c]
            //   e8????????           |                     
            //   8bd8                 | mov                 ebx, eax
            //   895c2414             | mov                 dword ptr [esp + 0x14], ebx
            //   83fbff               | cmp                 ebx, -1
            //   7541                 | jne                 0x43

        $sequence_7 = { 837de800 7e50 8b03 8b4804 0fb7541930 8d0419 8b4828 }
            // n = 7, score = 100
            //   837de800             | cmp                 dword ptr [ebp - 0x18], 0
            //   7e50                 | jle                 0x52
            //   8b03                 | mov                 eax, dword ptr [ebx]
            //   8b4804               | mov                 ecx, dword ptr [eax + 4]
            //   0fb7541930           | movzx               edx, word ptr [ecx + ebx + 0x30]
            //   8d0419               | lea                 eax, [ecx + ebx]
            //   8b4828               | mov                 ecx, dword ptr [eax + 0x28]

        $sequence_8 = { 8b9a80f34400 33f3 8b4538 33db 8b553c 33c6 33d6 }
            // n = 7, score = 100
            //   8b9a80f34400         | mov                 ebx, dword ptr [edx + 0x44f380]
            //   33f3                 | xor                 esi, ebx
            //   8b4538               | mov                 eax, dword ptr [ebp + 0x38]
            //   33db                 | xor                 ebx, ebx
            //   8b553c               | mov                 edx, dword ptr [ebp + 0x3c]
            //   33c6                 | xor                 eax, esi
            //   33d6                 | xor                 edx, esi

        $sequence_9 = { 33c0 eb05 1bc0 83d8ff 3bc3 7506 895c2418 }
            // n = 7, score = 100
            //   33c0                 | xor                 eax, eax
            //   eb05                 | jmp                 7
            //   1bc0                 | sbb                 eax, eax
            //   83d8ff               | sbb                 eax, -1
            //   3bc3                 | cmp                 eax, ebx
            //   7506                 | jne                 8
            //   895c2418             | mov                 dword ptr [esp + 0x18], ebx

    condition:
        7 of them and filesize < 811008
}