rule win_sharpknot_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.sharpknot."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.sharpknot"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 8d8c246c020000 c7842498050000ffffffff e8???????? 8b8c2490050000 }
            // n = 5, score = 100
            //   e8????????           |                     
            //   8d8c246c020000       | lea                 ecx, [esp + 0x26c]
            //   c7842498050000ffffffff     | mov    dword ptr [esp + 0x598], 0xffffffff
            //   e8????????           |                     
            //   8b8c2490050000       | mov                 ecx, dword ptr [esp + 0x590]

        $sequence_1 = { 8bf8 85ff 0f84a7000000 8b442434 53 }
            // n = 5, score = 100
            //   8bf8                 | mov                 edi, eax
            //   85ff                 | test                edi, edi
            //   0f84a7000000         | je                  0xad
            //   8b442434             | mov                 eax, dword ptr [esp + 0x34]
            //   53                   | push                ebx

        $sequence_2 = { 7c0a 817c241400000400 7304 8b7c2414 6a00 }
            // n = 5, score = 100
            //   7c0a                 | jl                  0xc
            //   817c241400000400     | cmp                 dword ptr [esp + 0x14], 0x40000
            //   7304                 | jae                 6
            //   8b7c2414             | mov                 edi, dword ptr [esp + 0x14]
            //   6a00                 | push                0

        $sequence_3 = { 8bd8 0f8494000000 85db 0f848c000000 }
            // n = 4, score = 100
            //   8bd8                 | mov                 ebx, eax
            //   0f8494000000         | je                  0x9a
            //   85db                 | test                ebx, ebx
            //   0f848c000000         | je                  0x92

        $sequence_4 = { 6804010000 8d842454010000 57 50 e8???????? }
            // n = 5, score = 100
            //   6804010000           | push                0x104
            //   8d842454010000       | lea                 eax, [esp + 0x154]
            //   57                   | push                edi
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_5 = { 2beb 8bc1 8bf7 8bfa 53 c1e902 f3a5 }
            // n = 7, score = 100
            //   2beb                 | sub                 ebp, ebx
            //   8bc1                 | mov                 eax, ecx
            //   8bf7                 | mov                 esi, edi
            //   8bfa                 | mov                 edi, edx
            //   53                   | push                ebx
            //   c1e902               | shr                 ecx, 2
            //   f3a5                 | rep movsd           dword ptr es:[edi], dword ptr [esi]

        $sequence_6 = { 50 ff15???????? 8b8c2428020000 6a00 6880000000 6a02 6a00 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8b8c2428020000       | mov                 ecx, dword ptr [esp + 0x228]
            //   6a00                 | push                0
            //   6880000000           | push                0x80
            //   6a02                 | push                2
            //   6a00                 | push                0

        $sequence_7 = { 57 ff15???????? 8b1d???????? 8d4c243c 8bf0 51 }
            // n = 6, score = 100
            //   57                   | push                edi
            //   ff15????????         |                     
            //   8b1d????????         |                     
            //   8d4c243c             | lea                 ecx, [esp + 0x3c]
            //   8bf0                 | mov                 esi, eax
            //   51                   | push                ecx

        $sequence_8 = { 50 57 ff15???????? 8b1d???????? 8d4c243c }
            // n = 5, score = 100
            //   50                   | push                eax
            //   57                   | push                edi
            //   ff15????????         |                     
            //   8b1d????????         |                     
            //   8d4c243c             | lea                 ecx, [esp + 0x3c]

        $sequence_9 = { 68???????? 51 ffd5 8d542410 8d842450010000 52 50 }
            // n = 7, score = 100
            //   68????????           |                     
            //   51                   | push                ecx
            //   ffd5                 | call                ebp
            //   8d542410             | lea                 edx, [esp + 0x10]
            //   8d842450010000       | lea                 eax, [esp + 0x150]
            //   52                   | push                edx
            //   50                   | push                eax

    condition:
        7 of them and filesize < 1032192
}