rule win_sierras_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.sierras."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.sierras"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { f3a4 8d8c2424050000 8d942430080000 51 }
            // n = 4, score = 200
            //   f3a4                 | rep movsb           byte ptr es:[edi], byte ptr [esi]
            //   8d8c2424050000       | lea                 ecx, [esp + 0x524]
            //   8d942430080000       | lea                 edx, [esp + 0x830]
            //   51                   | push                ecx

        $sequence_1 = { 56 8bf1 57 68???????? 8d4604 50 }
            // n = 6, score = 200
            //   56                   | push                esi
            //   8bf1                 | mov                 esi, ecx
            //   57                   | push                edi
            //   68????????           |                     
            //   8d4604               | lea                 eax, [esi + 4]
            //   50                   | push                eax

        $sequence_2 = { 50 8d45e0 50 e8???????? eb0f 8b4dec }
            // n = 6, score = 200
            //   50                   | push                eax
            //   8d45e0               | lea                 eax, [ebp - 0x20]
            //   50                   | push                eax
            //   e8????????           |                     
            //   eb0f                 | jmp                 0x11
            //   8b4dec               | mov                 ecx, dword ptr [ebp - 0x14]

        $sequence_3 = { e8???????? 50 8d442430 50 8d8c24ec000000 }
            // n = 5, score = 200
            //   e8????????           |                     
            //   50                   | push                eax
            //   8d442430             | lea                 eax, [esp + 0x30]
            //   50                   | push                eax
            //   8d8c24ec000000       | lea                 ecx, [esp + 0xec]

        $sequence_4 = { 0f8480030000 8b4dfc ff4df8 0fb611 8bcf }
            // n = 5, score = 200
            //   0f8480030000         | je                  0x386
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   ff4df8               | dec                 dword ptr [ebp - 8]
            //   0fb611               | movzx               edx, byte ptr [ecx]
            //   8bcf                 | mov                 ecx, edi

        $sequence_5 = { 7507 e8???????? eb05 e8???????? 0175f0 }
            // n = 5, score = 200
            //   7507                 | jne                 9
            //   e8????????           |                     
            //   eb05                 | jmp                 7
            //   e8????????           |                     
            //   0175f0               | add                 dword ptr [ebp - 0x10], esi

        $sequence_6 = { 8bf1 e8???????? 8b8698010000 5e }
            // n = 4, score = 200
            //   8bf1                 | mov                 esi, ecx
            //   e8????????           |                     
            //   8b8698010000         | mov                 eax, dword ptr [esi + 0x198]
            //   5e                   | pop                 esi

        $sequence_7 = { 8bc8 83e103 f3a4 8bbc2410040000 }
            // n = 4, score = 200
            //   8bc8                 | mov                 ecx, eax
            //   83e103               | and                 ecx, 3
            //   f3a4                 | rep movsb           byte ptr es:[edi], byte ptr [esi]
            //   8bbc2410040000       | mov                 edi, dword ptr [esp + 0x410]

        $sequence_8 = { 03fb 3b7d10 72b0 8b5df0 834dfcff 8d4de0 }
            // n = 6, score = 200
            //   03fb                 | add                 edi, ebx
            //   3b7d10               | cmp                 edi, dword ptr [ebp + 0x10]
            //   72b0                 | jb                  0xffffffb2
            //   8b5df0               | mov                 ebx, dword ptr [ebp - 0x10]
            //   834dfcff             | or                  dword ptr [ebp - 4], 0xffffffff
            //   8d4de0               | lea                 ecx, [ebp - 0x20]

        $sequence_9 = { 8bf1 33db 6a01 6a78 }
            // n = 4, score = 200
            //   8bf1                 | mov                 esi, ecx
            //   33db                 | xor                 ebx, ebx
            //   6a01                 | push                1
            //   6a78                 | push                0x78

        $sequence_10 = { f2ae f7d1 2bf9 8d942480000000 8bf7 8bd9 8bfa }
            // n = 7, score = 200
            //   f2ae                 | repne scasb         al, byte ptr es:[edi]
            //   f7d1                 | not                 ecx
            //   2bf9                 | sub                 edi, ecx
            //   8d942480000000       | lea                 edx, [esp + 0x80]
            //   8bf7                 | mov                 esi, edi
            //   8bd9                 | mov                 ebx, ecx
            //   8bfa                 | mov                 edi, edx

        $sequence_11 = { 8bf1 e8???????? 8b8608010000 5e c3 56 }
            // n = 6, score = 200
            //   8bf1                 | mov                 esi, ecx
            //   e8????????           |                     
            //   8b8608010000         | mov                 eax, dword ptr [esi + 0x108]
            //   5e                   | pop                 esi
            //   c3                   | ret                 
            //   56                   | push                esi

        $sequence_12 = { 397d08 897dfc 0f8cc0000000 837d0801 7e58 }
            // n = 5, score = 200
            //   397d08               | cmp                 dword ptr [ebp + 8], edi
            //   897dfc               | mov                 dword ptr [ebp - 4], edi
            //   0f8cc0000000         | jl                  0xc6
            //   837d0801             | cmp                 dword ptr [ebp + 8], 1
            //   7e58                 | jle                 0x5a

        $sequence_13 = { c7401880dd4000 e9???????? 83e00f c70613000000 894648 8b4648 85c0 }
            // n = 7, score = 200
            //   c7401880dd4000       | mov                 dword ptr [eax + 0x18], 0x40dd80
            //   e9????????           |                     
            //   83e00f               | and                 eax, 0xf
            //   c70613000000         | mov                 dword ptr [esi], 0x13
            //   894648               | mov                 dword ptr [esi + 0x48], eax
            //   8b4648               | mov                 eax, dword ptr [esi + 0x48]
            //   85c0                 | test                eax, eax

        $sequence_14 = { 58 0fb688c88c4000 6683bc8e7e0a000000 7506 }
            // n = 4, score = 200
            //   58                   | pop                 eax
            //   0fb688c88c4000       | movzx               ecx, byte ptr [eax + 0x408cc8]
            //   6683bc8e7e0a000000     | cmp    word ptr [esi + ecx*4 + 0xa7e], 0
            //   7506                 | jne                 8

        $sequence_15 = { 3bf8 7cce 8b442418 83c520 40 83f803 89442418 }
            // n = 7, score = 200
            //   3bf8                 | cmp                 edi, eax
            //   7cce                 | jl                  0xffffffd0
            //   8b442418             | mov                 eax, dword ptr [esp + 0x18]
            //   83c520               | add                 ebp, 0x20
            //   40                   | inc                 eax
            //   83f803               | cmp                 eax, 3
            //   89442418             | mov                 dword ptr [esp + 0x18], eax

    condition:
        7 of them and filesize < 131072
}