rule win_skyplex_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.skyplex."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.skyplex"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 6a00 ff15???????? 898508fcffff ff15???????? }
            // n = 4, score = 100
            //   6a00                 | push                0
            //   ff15????????         |                     
            //   898508fcffff         | mov                 dword ptr [ebp - 0x3f8], eax
            //   ff15????????         |                     

        $sequence_1 = { c3 8bff 56 57 33ff 8db704984100 ff36 }
            // n = 7, score = 100
            //   c3                   | ret                 
            //   8bff                 | mov                 edi, edi
            //   56                   | push                esi
            //   57                   | push                edi
            //   33ff                 | xor                 edi, edi
            //   8db704984100         | lea                 esi, [edi + 0x419804]
            //   ff36                 | push                dword ptr [esi]

        $sequence_2 = { 59 e9???????? 8b36 8bce c1f905 8b0c8dc0af4100 }
            // n = 6, score = 100
            //   59                   | pop                 ecx
            //   e9????????           |                     
            //   8b36                 | mov                 esi, dword ptr [esi]
            //   8bce                 | mov                 ecx, esi
            //   c1f905               | sar                 ecx, 5
            //   8b0c8dc0af4100       | mov                 ecx, dword ptr [ecx*4 + 0x41afc0]

        $sequence_3 = { 8b7d08 8bc7 c1f805 8d3485c0af4100 8b06 }
            // n = 5, score = 100
            //   8b7d08               | mov                 edi, dword ptr [ebp + 8]
            //   8bc7                 | mov                 eax, edi
            //   c1f805               | sar                 eax, 5
            //   8d3485c0af4100       | lea                 esi, [eax*4 + 0x41afc0]
            //   8b06                 | mov                 eax, dword ptr [esi]

        $sequence_4 = { 50 e8???????? 50 8b4df8 8b11 8b45f8 50 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   e8????????           |                     
            //   50                   | push                eax
            //   8b4df8               | mov                 ecx, dword ptr [ebp - 8]
            //   8b11                 | mov                 edx, dword ptr [ecx]
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   50                   | push                eax

        $sequence_5 = { c785b8f6ffff684c4100 c785bcf6ffffb04c4100 ff15???????? 50 e8???????? 83c404 }
            // n = 6, score = 100
            //   c785b8f6ffff684c4100     | mov    dword ptr [ebp - 0x948], 0x414c68
            //   c785bcf6ffffb04c4100     | mov    dword ptr [ebp - 0x944], 0x414cb0
            //   ff15????????         |                     
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c404               | add                 esp, 4

        $sequence_6 = { 33d2 b9???????? 57 8bc2 c1f805 8b0485c0af4100 8bfa }
            // n = 7, score = 100
            //   33d2                 | xor                 edx, edx
            //   b9????????           |                     
            //   57                   | push                edi
            //   8bc2                 | mov                 eax, edx
            //   c1f805               | sar                 eax, 5
            //   8b0485c0af4100       | mov                 eax, dword ptr [eax*4 + 0x41afc0]
            //   8bfa                 | mov                 edi, edx

        $sequence_7 = { 83bdf0feffff03 7327 8b85f0feffff 8b0c857c904100 51 }
            // n = 5, score = 100
            //   83bdf0feffff03       | cmp                 dword ptr [ebp - 0x110], 3
            //   7327                 | jae                 0x29
            //   8b85f0feffff         | mov                 eax, dword ptr [ebp - 0x110]
            //   8b0c857c904100       | mov                 ecx, dword ptr [eax*4 + 0x41907c]
            //   51                   | push                ecx

        $sequence_8 = { 66898c4558f7ffff 8d9558f7ffff 52 8d8540fbffff 50 }
            // n = 5, score = 100
            //   66898c4558f7ffff     | mov                 word ptr [ebp + eax*2 - 0x8a8], cx
            //   8d9558f7ffff         | lea                 edx, [ebp - 0x8a8]
            //   52                   | push                edx
            //   8d8540fbffff         | lea                 eax, [ebp - 0x4c0]
            //   50                   | push                eax

        $sequence_9 = { 6a01 ff15???????? c78544f6ffff01000000 eb0f 8b8d44f6ffff 83c101 898d44f6ffff }
            // n = 7, score = 100
            //   6a01                 | push                1
            //   ff15????????         |                     
            //   c78544f6ffff01000000     | mov    dword ptr [ebp - 0x9bc], 1
            //   eb0f                 | jmp                 0x11
            //   8b8d44f6ffff         | mov                 ecx, dword ptr [ebp - 0x9bc]
            //   83c101               | add                 ecx, 1
            //   898d44f6ffff         | mov                 dword ptr [ebp - 0x9bc], ecx

    condition:
        7 of them and filesize < 262144
}