rule win_smac_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.smac."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.smac"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 66898548ffffff 8bc3 6689854affffff 58 6a74 6689854cffffff 58 }
            // n = 7, score = 200
            //   66898548ffffff       | mov                 word ptr [ebp - 0xb8], ax
            //   8bc3                 | mov                 eax, ebx
            //   6689854affffff       | mov                 word ptr [ebp - 0xb6], ax
            //   58                   | pop                 eax
            //   6a74                 | push                0x74
            //   6689854cffffff       | mov                 word ptr [ebp - 0xb4], ax
            //   58                   | pop                 eax

        $sequence_1 = { 39bd78feffff 0f86b8000000 ffb578feffff e8???????? ffb578feffff 8bf0 57 }
            // n = 7, score = 200
            //   39bd78feffff         | cmp                 dword ptr [ebp - 0x188], edi
            //   0f86b8000000         | jbe                 0xbe
            //   ffb578feffff         | push                dword ptr [ebp - 0x188]
            //   e8????????           |                     
            //   ffb578feffff         | push                dword ptr [ebp - 0x188]
            //   8bf0                 | mov                 esi, eax
            //   57                   | push                edi

        $sequence_2 = { 668945ec 668975ea 8d8598feffff 8bf4 89a578feffff 50 }
            // n = 6, score = 200
            //   668945ec             | mov                 word ptr [ebp - 0x14], ax
            //   668975ea             | mov                 word ptr [ebp - 0x16], si
            //   8d8598feffff         | lea                 eax, [ebp - 0x168]
            //   8bf4                 | mov                 esi, esp
            //   89a578feffff         | mov                 dword ptr [ebp - 0x188], esp
            //   50                   | push                eax

        $sequence_3 = { 8d9d44ffffff e8???????? 6a01 33ff 8bf3 e8???????? 8b1d???????? }
            // n = 7, score = 200
            //   8d9d44ffffff         | lea                 ebx, [ebp - 0xbc]
            //   e8????????           |                     
            //   6a01                 | push                1
            //   33ff                 | xor                 edi, edi
            //   8bf3                 | mov                 esi, ebx
            //   e8????????           |                     
            //   8b1d????????         |                     

        $sequence_4 = { e8???????? 83ec1c c68424900100000e 8d842484000000 8bf4 8964245c }
            // n = 6, score = 200
            //   e8????????           |                     
            //   83ec1c               | sub                 esp, 0x1c
            //   c68424900100000e     | mov                 byte ptr [esp + 0x190], 0xe
            //   8d842484000000       | lea                 eax, [esp + 0x84]
            //   8bf4                 | mov                 esi, esp
            //   8964245c             | mov                 dword ptr [esp + 0x5c], esp

        $sequence_5 = { 8945f0 3bc3 7514 6a01 33ff 8d7508 e8???????? }
            // n = 7, score = 200
            //   8945f0               | mov                 dword ptr [ebp - 0x10], eax
            //   3bc3                 | cmp                 eax, ebx
            //   7514                 | jne                 0x16
            //   6a01                 | push                1
            //   33ff                 | xor                 edi, edi
            //   8d7508               | lea                 esi, [ebp + 8]
            //   e8????????           |                     

        $sequence_6 = { 83c42c 33f6 46 5b ffb5f480ffff ff15???????? }
            // n = 6, score = 200
            //   83c42c               | add                 esp, 0x2c
            //   33f6                 | xor                 esi, esi
            //   46                   | inc                 esi
            //   5b                   | pop                 ebx
            //   ffb5f480ffff         | push                dword ptr [ebp - 0x7f0c]
            //   ff15????????         |                     

        $sequence_7 = { 8986d8000000 ffd7 8986dc000000 8bc6 e8???????? c20800 6a00 }
            // n = 7, score = 200
            //   8986d8000000         | mov                 dword ptr [esi + 0xd8], eax
            //   ffd7                 | call                edi
            //   8986dc000000         | mov                 dword ptr [esi + 0xdc], eax
            //   8bc6                 | mov                 eax, esi
            //   e8????????           |                     
            //   c20800               | ret                 8
            //   6a00                 | push                0

        $sequence_8 = { 8bf4 89a578feffff 50 e8???????? 83ec1c c645fc04 8d4528 }
            // n = 7, score = 200
            //   8bf4                 | mov                 esi, esp
            //   89a578feffff         | mov                 dword ptr [ebp - 0x188], esp
            //   50                   | push                eax
            //   e8????????           |                     
            //   83ec1c               | sub                 esp, 0x1c
            //   c645fc04             | mov                 byte ptr [ebp - 4], 4
            //   8d4528               | lea                 eax, [ebp + 0x28]

        $sequence_9 = { 66899d42ffffff 5b 6a74 66899d44ffffff 5b }
            // n = 5, score = 200
            //   66899d42ffffff       | mov                 word ptr [ebp - 0xbe], bx
            //   5b                   | pop                 ebx
            //   6a74                 | push                0x74
            //   66899d44ffffff       | mov                 word ptr [ebp - 0xbc], bx
            //   5b                   | pop                 ebx

    condition:
        7 of them and filesize < 212992
}