rule win_smarteyes_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.smarteyes."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.smarteyes"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 51 8d85d4fdffff 50 e8???????? 8d85d4fdffff 889c35d4fdffff 83c40c }
            // n = 7, score = 100
            //   51                   | push                ecx
            //   8d85d4fdffff         | lea                 eax, [ebp - 0x22c]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8d85d4fdffff         | lea                 eax, [ebp - 0x22c]
            //   889c35d4fdffff       | mov                 byte ptr [ebp + esi - 0x22c], bl
            //   83c40c               | add                 esp, 0xc

        $sequence_1 = { 68???????? e9???????? 53 68???????? e8???????? 33c0 40 }
            // n = 7, score = 100
            //   68????????           |                     
            //   e9????????           |                     
            //   53                   | push                ebx
            //   68????????           |                     
            //   e8????????           |                     
            //   33c0                 | xor                 eax, eax
            //   40                   | inc                 eax

        $sequence_2 = { 3bc3 0f8426030000 8d842488040000 50 6804010000 ff15???????? 85c0 }
            // n = 7, score = 100
            //   3bc3                 | cmp                 eax, ebx
            //   0f8426030000         | je                  0x32c
            //   8d842488040000       | lea                 eax, [esp + 0x488]
            //   50                   | push                eax
            //   6804010000           | push                0x104
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax

        $sequence_3 = { 7478 83c00c 8bc8 8d7901 8a11 41 84d2 }
            // n = 7, score = 100
            //   7478                 | je                  0x7a
            //   83c00c               | add                 eax, 0xc
            //   8bc8                 | mov                 ecx, eax
            //   8d7901               | lea                 edi, [ecx + 1]
            //   8a11                 | mov                 dl, byte ptr [ecx]
            //   41                   | inc                 ecx
            //   84d2                 | test                dl, dl

        $sequence_4 = { 7413 8d85ecfeffff 57 50 }
            // n = 4, score = 100
            //   7413                 | je                  0x15
            //   8d85ecfeffff         | lea                 eax, [ebp - 0x114]
            //   57                   | push                edi
            //   50                   | push                eax

        $sequence_5 = { ff742424 ff742420 ff15???????? 85c0 7547 }
            // n = 5, score = 100
            //   ff742424             | push                dword ptr [esp + 0x24]
            //   ff742420             | push                dword ptr [esp + 0x20]
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7547                 | jne                 0x49

        $sequence_6 = { e8???????? 59 59 8d8548f5ffff 50 8d9d78f7ffff e8???????? }
            // n = 7, score = 100
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx
            //   8d8548f5ffff         | lea                 eax, [ebp - 0xab8]
            //   50                   | push                eax
            //   8d9d78f7ffff         | lea                 ebx, [ebp - 0x888]
            //   e8????????           |                     

        $sequence_7 = { 7514 8bf9 c744241001000000 e8???????? e9???????? 68???????? 8d442424 }
            // n = 7, score = 100
            //   7514                 | jne                 0x16
            //   8bf9                 | mov                 edi, ecx
            //   c744241001000000     | mov                 dword ptr [esp + 0x10], 1
            //   e8????????           |                     
            //   e9????????           |                     
            //   68????????           |                     
            //   8d442424             | lea                 eax, [esp + 0x24]

        $sequence_8 = { 8d45ff 50 e8???????? 8a4736 8845ff 53 8d45ff }
            // n = 7, score = 100
            //   8d45ff               | lea                 eax, [ebp - 1]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8a4736               | mov                 al, byte ptr [edi + 0x36]
            //   8845ff               | mov                 byte ptr [ebp - 1], al
            //   53                   | push                ebx
            //   8d45ff               | lea                 eax, [ebp - 1]

        $sequence_9 = { 8bd6 0fb7c0 6683f82f 7406 6683f85c 7502 8bca }
            // n = 7, score = 100
            //   8bd6                 | mov                 edx, esi
            //   0fb7c0               | movzx               eax, ax
            //   6683f82f             | cmp                 ax, 0x2f
            //   7406                 | je                  8
            //   6683f85c             | cmp                 ax, 0x5c
            //   7502                 | jne                 4
            //   8bca                 | mov                 ecx, edx

    condition:
        7 of them and filesize < 429056
}