rule win_sparrow_door_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.sparrow_door."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.sparrow_door"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 395c240c 7551 8b5604 8b3d???????? 52 68???????? }
            // n = 6, score = 100
            //   395c240c             | cmp                 dword ptr [esp + 0xc], ebx
            //   7551                 | jne                 0x53
            //   8b5604               | mov                 edx, dword ptr [esi + 4]
            //   8b3d????????         |                     
            //   52                   | push                edx
            //   68????????           |                     

        $sequence_1 = { 57 56 ff15???????? 85c0 0f8491010000 8b44243c 3bc5 }
            // n = 7, score = 100
            //   57                   | push                edi
            //   56                   | push                esi
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   0f8491010000         | je                  0x197
            //   8b44243c             | mov                 eax, dword ptr [esp + 0x3c]
            //   3bc5                 | cmp                 eax, ebp

        $sequence_2 = { 8d8c2440040000 51 55 8d94243c010000 52 6a00 68e9fd0000 }
            // n = 7, score = 100
            //   8d8c2440040000       | lea                 ecx, [esp + 0x440]
            //   51                   | push                ecx
            //   55                   | push                ebp
            //   8d94243c010000       | lea                 edx, [esp + 0x13c]
            //   52                   | push                edx
            //   6a00                 | push                0
            //   68e9fd0000           | push                0xfde9

        $sequence_3 = { 53 50 8bf1 895c2430 895c2438 889c244c060000 }
            // n = 6, score = 100
            //   53                   | push                ebx
            //   50                   | push                eax
            //   8bf1                 | mov                 esi, ecx
            //   895c2430             | mov                 dword ptr [esp + 0x30], ebx
            //   895c2438             | mov                 dword ptr [esp + 0x38], ebx
            //   889c244c060000       | mov                 byte ptr [esp + 0x64c], bl

        $sequence_4 = { 8d44245c 50 e8???????? 83c420 85c0 }
            // n = 5, score = 100
            //   8d44245c             | lea                 eax, [esp + 0x5c]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c420               | add                 esp, 0x20
            //   85c0                 | test                eax, eax

        $sequence_5 = { a1???????? a3???????? a1???????? c705????????05772a00 8935???????? }
            // n = 5, score = 100
            //   a1????????           |                     
            //   a3????????           |                     
            //   a1????????           |                     
            //   c705????????05772a00     |     
            //   8935????????         |                     

        $sequence_6 = { e8???????? 8d542470 52 8d442448 50 8b84249c010000 }
            // n = 6, score = 100
            //   e8????????           |                     
            //   8d542470             | lea                 edx, [esp + 0x70]
            //   52                   | push                edx
            //   8d442448             | lea                 eax, [esp + 0x48]
            //   50                   | push                eax
            //   8b84249c010000       | mov                 eax, dword ptr [esp + 0x19c]

        $sequence_7 = { 50 895c2438 c744244844000000 898c2480000000 c744247401010000 6689542478 889c2490000000 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   895c2438             | mov                 dword ptr [esp + 0x38], ebx
            //   c744244844000000     | mov                 dword ptr [esp + 0x48], 0x44
            //   898c2480000000       | mov                 dword ptr [esp + 0x80], ecx
            //   c744247401010000     | mov                 dword ptr [esp + 0x74], 0x101
            //   6689542478           | mov                 word ptr [esp + 0x78], dx
            //   889c2490000000       | mov                 byte ptr [esp + 0x90], bl

        $sequence_8 = { 894c2418 8954241c 3bc3 7555 }
            // n = 4, score = 100
            //   894c2418             | mov                 dword ptr [esp + 0x18], ecx
            //   8954241c             | mov                 dword ptr [esp + 0x1c], edx
            //   3bc3                 | cmp                 eax, ebx
            //   7555                 | jne                 0x57

        $sequence_9 = { 8d8c2400010000 51 56 52 ffd5 85c0 74a8 }
            // n = 7, score = 100
            //   8d8c2400010000       | lea                 ecx, [esp + 0x100]
            //   51                   | push                ecx
            //   56                   | push                esi
            //   52                   | push                edx
            //   ffd5                 | call                ebp
            //   85c0                 | test                eax, eax
            //   74a8                 | je                  0xffffffaa

    condition:
        7 of them and filesize < 155648
}