rule win_sslmm_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.sslmm."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.sslmm"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 89542440 8d4c2418 89442414 89542444 }
            // n = 4, score = 400
            //   89542440             | mov                 dword ptr [esp + 0x40], edx
            //   8d4c2418             | lea                 ecx, [esp + 0x18]
            //   89442414             | mov                 dword ptr [esp + 0x14], eax
            //   89542444             | mov                 dword ptr [esp + 0x44], edx

        $sequence_1 = { 8b8c2484000000 8bbc2480000000 8b54247c 51 57 52 8bcb }
            // n = 7, score = 400
            //   8b8c2484000000       | mov                 ecx, dword ptr [esp + 0x84]
            //   8bbc2480000000       | mov                 edi, dword ptr [esp + 0x80]
            //   8b54247c             | mov                 edx, dword ptr [esp + 0x7c]
            //   51                   | push                ecx
            //   57                   | push                edi
            //   52                   | push                edx
            //   8bcb                 | mov                 ecx, ebx

        $sequence_2 = { 8b442438 89742418 89542468 89442460 8b44241c 33f6 8d542428 }
            // n = 7, score = 400
            //   8b442438             | mov                 eax, dword ptr [esp + 0x38]
            //   89742418             | mov                 dword ptr [esp + 0x18], esi
            //   89542468             | mov                 dword ptr [esp + 0x68], edx
            //   89442460             | mov                 dword ptr [esp + 0x60], eax
            //   8b44241c             | mov                 eax, dword ptr [esp + 0x1c]
            //   33f6                 | xor                 esi, esi
            //   8d542428             | lea                 edx, [esp + 0x28]

        $sequence_3 = { e9???????? ff15???????? 50 eb13 5f 5e }
            // n = 6, score = 400
            //   e9????????           |                     
            //   ff15????????         |                     
            //   50                   | push                eax
            //   eb13                 | jmp                 0x15
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi

        $sequence_4 = { 8b868c000000 68???????? 85c0 7413 6800000200 6a00 }
            // n = 6, score = 400
            //   8b868c000000         | mov                 eax, dword ptr [esi + 0x8c]
            //   68????????           |                     
            //   85c0                 | test                eax, eax
            //   7413                 | je                  0x15
            //   6800000200           | push                0x20000
            //   6a00                 | push                0

        $sequence_5 = { 83c40c 899374010000 33ed 8b8374010000 }
            // n = 4, score = 400
            //   83c40c               | add                 esp, 0xc
            //   899374010000         | mov                 dword ptr [ebx + 0x174], edx
            //   33ed                 | xor                 ebp, ebp
            //   8b8374010000         | mov                 eax, dword ptr [ebx + 0x174]

        $sequence_6 = { 83f8ff 0f8477020000 3bc5 0f84fb010000 8b9374010000 55 03d0 }
            // n = 7, score = 400
            //   83f8ff               | cmp                 eax, -1
            //   0f8477020000         | je                  0x27d
            //   3bc5                 | cmp                 eax, ebp
            //   0f84fb010000         | je                  0x201
            //   8b9374010000         | mov                 edx, dword ptr [ebx + 0x174]
            //   55                   | push                ebp
            //   03d0                 | add                 edx, eax

        $sequence_7 = { 83c414 3bc3 770a 6a0a }
            // n = 4, score = 400
            //   83c414               | add                 esp, 0x14
            //   3bc3                 | cmp                 eax, ebx
            //   770a                 | ja                  0xc
            //   6a0a                 | push                0xa

        $sequence_8 = { 8db120010000 8b780c 42 897814 8b7808 897810 }
            // n = 6, score = 400
            //   8db120010000         | lea                 esi, [ecx + 0x120]
            //   8b780c               | mov                 edi, dword ptr [eax + 0xc]
            //   42                   | inc                 edx
            //   897814               | mov                 dword ptr [eax + 0x14], edi
            //   8b7808               | mov                 edi, dword ptr [eax + 8]
            //   897810               | mov                 dword ptr [eax + 0x10], edi

        $sequence_9 = { 8b7c2424 e9???????? 50 8bcf eb2e }
            // n = 5, score = 400
            //   8b7c2424             | mov                 edi, dword ptr [esp + 0x24]
            //   e9????????           |                     
            //   50                   | push                eax
            //   8bcf                 | mov                 ecx, edi
            //   eb2e                 | jmp                 0x30

    condition:
        7 of them and filesize < 188416
}