rule win_stormwind_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.stormwind."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.stormwind"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 83c404 8bf7 3b3b 75e2 }
            // n = 5, score = 100
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   8bf7                 | mov                 esi, edi
            //   3b3b                 | cmp                 edi, dword ptr [ebx]
            //   75e2                 | jne                 0xffffffe4

        $sequence_1 = { 83e4f8 81ec1c010000 53 8b5d10 56 57 8b7d0c }
            // n = 7, score = 100
            //   83e4f8               | and                 esp, 0xfffffff8
            //   81ec1c010000         | sub                 esp, 0x11c
            //   53                   | push                ebx
            //   8b5d10               | mov                 ebx, dword ptr [ebp + 0x10]
            //   56                   | push                esi
            //   57                   | push                edi
            //   8b7d0c               | mov                 edi, dword ptr [ebp + 0xc]

        $sequence_2 = { e8???????? 83ec0c c745fc00000000 8d4e04 e8???????? 85c0 8b06 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   83ec0c               | sub                 esp, 0xc
            //   c745fc00000000       | mov                 dword ptr [ebp - 4], 0
            //   8d4e04               | lea                 ecx, [esi + 4]
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   8b06                 | mov                 eax, dword ptr [esi]

        $sequence_3 = { 50 ff7604 56 e8???????? 894604 c745d801000000 8b4804 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   ff7604               | push                dword ptr [esi + 4]
            //   56                   | push                esi
            //   e8????????           |                     
            //   894604               | mov                 dword ptr [esi + 4], eax
            //   c745d801000000       | mov                 dword ptr [ebp - 0x28], 1
            //   8b4804               | mov                 ecx, dword ptr [eax + 4]

        $sequence_4 = { 59 8b7d08 33db 391cfd88e40410 755c 6a18 e8???????? }
            // n = 7, score = 100
            //   59                   | pop                 ecx
            //   8b7d08               | mov                 edi, dword ptr [ebp + 8]
            //   33db                 | xor                 ebx, ebx
            //   391cfd88e40410       | cmp                 dword ptr [edi*8 + 0x1004e488], ebx
            //   755c                 | jne                 0x5e
            //   6a18                 | push                0x18
            //   e8????????           |                     

        $sequence_5 = { 83fa05 7509 8b852cfdffff 89470c 6bc20c 57 ff90c04e0410 }
            // n = 7, score = 100
            //   83fa05               | cmp                 edx, 5
            //   7509                 | jne                 0xb
            //   8b852cfdffff         | mov                 eax, dword ptr [ebp - 0x2d4]
            //   89470c               | mov                 dword ptr [edi + 0xc], eax
            //   6bc20c               | imul                eax, edx, 0xc
            //   57                   | push                edi
            //   ff90c04e0410         | call                dword ptr [eax + 0x10044ec0]

        $sequence_6 = { 8d4de4 e8???????? 68???????? 8d45e4 c745e4740c0410 50 e8???????? }
            // n = 7, score = 100
            //   8d4de4               | lea                 ecx, [ebp - 0x1c]
            //   e8????????           |                     
            //   68????????           |                     
            //   8d45e4               | lea                 eax, [ebp - 0x1c]
            //   c745e4740c0410       | mov                 dword ptr [ebp - 0x1c], 0x10040c74
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_7 = { f7fe 57 8bc2 99 }
            // n = 4, score = 100
            //   f7fe                 | idiv                esi
            //   57                   | push                edi
            //   8bc2                 | mov                 eax, edx
            //   99                   | cdq                 

        $sequence_8 = { c74508???????? 50 8d4de4 e8???????? 68???????? 8d45e4 c745e4740c0410 }
            // n = 7, score = 100
            //   c74508????????       |                     
            //   50                   | push                eax
            //   8d4de4               | lea                 ecx, [ebp - 0x1c]
            //   e8????????           |                     
            //   68????????           |                     
            //   8d45e4               | lea                 eax, [ebp - 0x1c]
            //   c745e4740c0410       | mov                 dword ptr [ebp - 0x1c], 0x10040c74

        $sequence_9 = { 8975d4 68b8020000 c645fc01 e8???????? }
            // n = 4, score = 100
            //   8975d4               | mov                 dword ptr [ebp - 0x2c], esi
            //   68b8020000           | push                0x2b8
            //   c645fc01             | mov                 byte ptr [ebp - 4], 1
            //   e8????????           |                     

    condition:
        7 of them and filesize < 741376
}