rule win_stration_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.stration."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.stration"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 6a00 6a01 baf1000000 8bcb e8???????? 55 6a01 }
            // n = 7, score = 100
            //   6a00                 | push                0
            //   6a01                 | push                1
            //   baf1000000           | mov                 edx, 0xf1
            //   8bcb                 | mov                 ecx, ebx
            //   e8????????           |                     
            //   55                   | push                ebp
            //   6a01                 | push                1

        $sequence_1 = { 56 e8???????? 83c408 6a00 6a01 baf1000000 8bcd }
            // n = 7, score = 100
            //   56                   | push                esi
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   6a00                 | push                0
            //   6a01                 | push                1
            //   baf1000000           | mov                 edx, 0xf1
            //   8bcd                 | mov                 ecx, ebp

        $sequence_2 = { e8???????? 680b040000 56 8944241c }
            // n = 4, score = 100
            //   e8????????           |                     
            //   680b040000           | push                0x40b
            //   56                   | push                esi
            //   8944241c             | mov                 dword ptr [esp + 0x1c], eax

        $sequence_3 = { c1fa05 891424 8bd1 52 e8???????? a3???????? 8b4c241c }
            // n = 7, score = 100
            //   c1fa05               | sar                 edx, 5
            //   891424               | mov                 dword ptr [esp], edx
            //   8bd1                 | mov                 edx, ecx
            //   52                   | push                edx
            //   e8????????           |                     
            //   a3????????           |                     
            //   8b4c241c             | mov                 ecx, dword ptr [esp + 0x1c]

        $sequence_4 = { ba11010000 8bce e8???????? c705????????00000000 }
            // n = 4, score = 100
            //   ba11010000           | mov                 edx, 0x111
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     
            //   c705????????00000000     |     

        $sequence_5 = { 8b15???????? 89442404 a1???????? 894c2408 8a0d???????? 89442410 8954240c }
            // n = 7, score = 100
            //   8b15????????         |                     
            //   89442404             | mov                 dword ptr [esp + 4], eax
            //   a1????????           |                     
            //   894c2408             | mov                 dword ptr [esp + 8], ecx
            //   8a0d????????         |                     
            //   89442410             | mov                 dword ptr [esp + 0x10], eax
            //   8954240c             | mov                 dword ptr [esp + 0xc], edx

        $sequence_6 = { 33f6 85ff 893d???????? 7517 a1???????? 85c0 c605????????00 }
            // n = 7, score = 100
            //   33f6                 | xor                 esi, esi
            //   85ff                 | test                edi, edi
            //   893d????????         |                     
            //   7517                 | jne                 0x19
            //   a1????????           |                     
            //   85c0                 | test                eax, eax
            //   c605????????00       |                     

        $sequence_7 = { 8a540404 c1e910 32d1 88540404 }
            // n = 4, score = 100
            //   8a540404             | mov                 dl, byte ptr [esp + eax + 4]
            //   c1e910               | shr                 ecx, 0x10
            //   32d1                 | xor                 dl, cl
            //   88540404             | mov                 byte ptr [esp + eax + 4], dl

        $sequence_8 = { 83f80d 7cec 8b15???????? a1???????? 8b0d???????? 891424 668b15???????? }
            // n = 7, score = 100
            //   83f80d               | cmp                 eax, 0xd
            //   7cec                 | jl                  0xffffffee
            //   8b15????????         |                     
            //   a1????????           |                     
            //   8b0d????????         |                     
            //   891424               | mov                 dword ptr [esp], edx
            //   668b15????????       |                     

        $sequence_9 = { eb05 bd14000000 660935???????? 8d542434 52 8d8424b4000000 }
            // n = 6, score = 100
            //   eb05                 | jmp                 7
            //   bd14000000           | mov                 ebp, 0x14
            //   660935????????       |                     
            //   8d542434             | lea                 edx, [esp + 0x34]
            //   52                   | push                edx
            //   8d8424b4000000       | lea                 eax, [esp + 0xb4]

    condition:
        7 of them and filesize < 49152
}