rule win_swen_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.swen."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.swen"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ab 8d85a8fcffff 50 8d8564fcffff 50 56 56 }
            // n = 7, score = 100
            //   ab                   | stosd               dword ptr es:[edi], eax
            //   8d85a8fcffff         | lea                 eax, [ebp - 0x358]
            //   50                   | push                eax
            //   8d8564fcffff         | lea                 eax, [ebp - 0x39c]
            //   50                   | push                eax
            //   56                   | push                esi
            //   56                   | push                esi

        $sequence_1 = { 6a05 59 be???????? 8dbd1cfeffff f3a5 66a5 }
            // n = 6, score = 100
            //   6a05                 | push                5
            //   59                   | pop                 ecx
            //   be????????           |                     
            //   8dbd1cfeffff         | lea                 edi, [ebp - 0x1e4]
            //   f3a5                 | rep movsd           dword ptr es:[edi], dword ptr [esi]
            //   66a5                 | movsw               word ptr es:[edi], word ptr [esi]

        $sequence_2 = { 68b0040000 ff15???????? c9 c3 55 8bec 6aff }
            // n = 7, score = 100
            //   68b0040000           | push                0x4b0
            //   ff15????????         |                     
            //   c9                   | leave               
            //   c3                   | ret                 
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   6aff                 | push                -1

        $sequence_3 = { 33c9 85c0 0f95c1 41 890d???????? 8b450c 3905???????? }
            // n = 7, score = 100
            //   33c9                 | xor                 ecx, ecx
            //   85c0                 | test                eax, eax
            //   0f95c1               | setne               cl
            //   41                   | inc                 ecx
            //   890d????????         |                     
            //   8b450c               | mov                 eax, dword ptr [ebp + 0xc]
            //   3905????????         |                     

        $sequence_4 = { 59 59 50 8d8594fcffff 50 }
            // n = 5, score = 100
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx
            //   50                   | push                eax
            //   8d8594fcffff         | lea                 eax, [ebp - 0x36c]
            //   50                   | push                eax

        $sequence_5 = { 0fbe4602 8d48df 83f951 7408 83c00a 83f85c 755f }
            // n = 7, score = 100
            //   0fbe4602             | movsx               eax, byte ptr [esi + 2]
            //   8d48df               | lea                 ecx, [eax - 0x21]
            //   83f951               | cmp                 ecx, 0x51
            //   7408                 | je                  0xa
            //   83c00a               | add                 eax, 0xa
            //   83f85c               | cmp                 eax, 0x5c
            //   755f                 | jne                 0x61

        $sequence_6 = { 53 6880000000 6a04 53 6a03 6800000040 8d85e4feffff }
            // n = 7, score = 100
            //   53                   | push                ebx
            //   6880000000           | push                0x80
            //   6a04                 | push                4
            //   53                   | push                ebx
            //   6a03                 | push                3
            //   6800000040           | push                0x40000000
            //   8d85e4feffff         | lea                 eax, [ebp - 0x11c]

        $sequence_7 = { e8???????? 8d85d8fdffff 50 8d8550ffffff 50 e8???????? 8d4603 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8d85d8fdffff         | lea                 eax, [ebp - 0x228]
            //   50                   | push                eax
            //   8d8550ffffff         | lea                 eax, [ebp - 0xb0]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8d4603               | lea                 eax, [esi + 3]

        $sequence_8 = { 0f84b2000000 895de0 8b4de4 c1e902 8b45e0 3bc1 0f839e000000 }
            // n = 7, score = 100
            //   0f84b2000000         | je                  0xb8
            //   895de0               | mov                 dword ptr [ebp - 0x20], ebx
            //   8b4de4               | mov                 ecx, dword ptr [ebp - 0x1c]
            //   c1e902               | shr                 ecx, 2
            //   8b45e0               | mov                 eax, dword ptr [ebp - 0x20]
            //   3bc1                 | cmp                 eax, ecx
            //   0f839e000000         | jae                 0xa4

        $sequence_9 = { 3bc3 7410 8d8d80feffff 2bc1 40 40 89857cfeffff }
            // n = 7, score = 100
            //   3bc3                 | cmp                 eax, ebx
            //   7410                 | je                  0x12
            //   8d8d80feffff         | lea                 ecx, [ebp - 0x180]
            //   2bc1                 | sub                 eax, ecx
            //   40                   | inc                 eax
            //   40                   | inc                 eax
            //   89857cfeffff         | mov                 dword ptr [ebp - 0x184], eax

    condition:
        7 of them and filesize < 286720
}