rule win_synccrypt_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.synccrypt."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.synccrypt"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c744240477000000 c7042422000000 e8???????? e9???????? c7442410af000000 c744240c94195900 c74424087a000000 }
            // n = 7, score = 100
            //   c744240477000000     | mov                 dword ptr [esp + 4], 0x77
            //   c7042422000000       | mov                 dword ptr [esp], 0x22
            //   e8????????           |                     
            //   e9????????           |                     
            //   c7442410af000000     | mov                 dword ptr [esp + 0x10], 0xaf
            //   c744240c94195900     | mov                 dword ptr [esp + 0xc], 0x591994
            //   c74424087a000000     | mov                 dword ptr [esp + 8], 0x7a

        $sequence_1 = { ba01000000 89f8 e8???????? 85c0 8b4c242c 0f84aa000000 8b4714 }
            // n = 7, score = 100
            //   ba01000000           | mov                 edx, 1
            //   89f8                 | mov                 eax, edi
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   8b4c242c             | mov                 ecx, dword ptr [esp + 0x2c]
            //   0f84aa000000         | je                  0xb0
            //   8b4714               | mov                 eax, dword ptr [edi + 0x14]

        $sequence_2 = { 892c24 e8???????? 892c24 89c7 e8???????? 85c0 7517 }
            // n = 7, score = 100
            //   892c24               | mov                 dword ptr [esp], ebp
            //   e8????????           |                     
            //   892c24               | mov                 dword ptr [esp], ebp
            //   89c7                 | mov                 edi, eax
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   7517                 | jne                 0x19

        $sequence_3 = { c1e806 85c0 7523 897358 83c318 89742408 891c24 }
            // n = 7, score = 100
            //   c1e806               | shr                 eax, 6
            //   85c0                 | test                eax, eax
            //   7523                 | jne                 0x25
            //   897358               | mov                 dword ptr [ebx + 0x58], esi
            //   83c318               | add                 ebx, 0x18
            //   89742408             | mov                 dword ptr [esp + 8], esi
            //   891c24               | mov                 dword ptr [esp], ebx

        $sequence_4 = { e8???????? 85c0 74c8 8d442414 8974240c 895c2408 89442404 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   74c8                 | je                  0xffffffca
            //   8d442414             | lea                 eax, [esp + 0x14]
            //   8974240c             | mov                 dword ptr [esp + 0xc], esi
            //   895c2408             | mov                 dword ptr [esp + 8], ebx
            //   89442404             | mov                 dword ptr [esp + 4], eax

        $sequence_5 = { e8???????? 85c0 0f8413010000 8d7804 89c1 c7406800000000 89c3 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   0f8413010000         | je                  0x119
            //   8d7804               | lea                 edi, [eax + 4]
            //   89c1                 | mov                 ecx, eax
            //   c7406800000000       | mov                 dword ptr [eax + 0x68], 0
            //   89c3                 | mov                 ebx, eax

        $sequence_6 = { f6400c01 7451 891c24 e8???????? 83c001 c744240897010000 c7442404???????? }
            // n = 7, score = 100
            //   f6400c01             | test                byte ptr [eax + 0xc], 1
            //   7451                 | je                  0x53
            //   891c24               | mov                 dword ptr [esp], ebx
            //   e8????????           |                     
            //   83c001               | add                 eax, 1
            //   c744240897010000     | mov                 dword ptr [esp + 8], 0x197
            //   c7442404????????     |                     

        $sequence_7 = { c7442404???????? c7042402000000 a3???????? e8???????? c7442404???????? c704240b000000 a3???????? }
            // n = 7, score = 100
            //   c7442404????????     |                     
            //   c7042402000000       | mov                 dword ptr [esp], 2
            //   a3????????           |                     
            //   e8????????           |                     
            //   c7442404????????     |                     
            //   c704240b000000       | mov                 dword ptr [esp], 0xb
            //   a3????????           |                     

        $sequence_8 = { e8???????? 893424 e8???????? 8b442430 890424 e8???????? 39c7 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   893424               | mov                 dword ptr [esp], esi
            //   e8????????           |                     
            //   8b442430             | mov                 eax, dword ptr [esp + 0x30]
            //   890424               | mov                 dword ptr [esp], eax
            //   e8????????           |                     
            //   39c7                 | cmp                 edi, eax

        $sequence_9 = { 890424 8954240c e8???????? 3b6c2418 8d45fe 746e 8b570c }
            // n = 7, score = 100
            //   890424               | mov                 dword ptr [esp], eax
            //   8954240c             | mov                 dword ptr [esp + 0xc], edx
            //   e8????????           |                     
            //   3b6c2418             | cmp                 ebp, dword ptr [esp + 0x18]
            //   8d45fe               | lea                 eax, [ebp - 2]
            //   746e                 | je                  0x70
            //   8b570c               | mov                 edx, dword ptr [edi + 0xc]

    condition:
        7 of them and filesize < 4489216
}