rule win_synflooder_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.synflooder."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.synflooder"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ff35???????? ff15???????? 85c0 7442 8b7df4 85ff }
            // n = 6, score = 200
            //   ff35????????         |                     
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7442                 | je                  0x44
            //   8b7df4               | mov                 edi, dword ptr [ebp - 0xc]
            //   85ff                 | test                edi, edi

        $sequence_1 = { 83e61f 8d3c8520fc4000 8b07 c1e606 }
            // n = 4, score = 200
            //   83e61f               | and                 esi, 0x1f
            //   8d3c8520fc4000       | lea                 edi, [eax*4 + 0x40fc20]
            //   8b07                 | mov                 eax, dword ptr [edi]
            //   c1e606               | shl                 esi, 6

        $sequence_2 = { 750b 56 e8???????? 59 85c0 7407 }
            // n = 6, score = 200
            //   750b                 | jne                 0xd
            //   56                   | push                esi
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   85c0                 | test                eax, eax
            //   7407                 | je                  9

        $sequence_3 = { e8???????? 83c408 8b542420 52 68???????? e8???????? }
            // n = 6, score = 200
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   8b542420             | mov                 edx, dword ptr [esp + 0x20]
            //   52                   | push                edx
            //   68????????           |                     
            //   e8????????           |                     

        $sequence_4 = { 53 56 57 7408 33c0 40 e9???????? }
            // n = 7, score = 200
            //   53                   | push                ebx
            //   56                   | push                esi
            //   57                   | push                edi
            //   7408                 | je                  0xa
            //   33c0                 | xor                 eax, eax
            //   40                   | inc                 eax
            //   e9????????           |                     

        $sequence_5 = { c7465c20b04000 83660800 33ff 47 }
            // n = 4, score = 200
            //   c7465c20b04000       | mov                 dword ptr [esi + 0x5c], 0x40b020
            //   83660800             | and                 dword ptr [esi + 8], 0
            //   33ff                 | xor                 edi, edi
            //   47                   | inc                 edi

        $sequence_6 = { 55 8bec 81ec98050000 a1???????? 33c5 8945fc 8d8568faffff }
            // n = 7, score = 200
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   81ec98050000         | sub                 esp, 0x598
            //   a1????????           |                     
            //   33c5                 | xor                 eax, ebp
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   8d8568faffff         | lea                 eax, [ebp - 0x598]

        $sequence_7 = { 8bf0 89742414 83feff 7524 68???????? e8???????? 83c404 }
            // n = 7, score = 200
            //   8bf0                 | mov                 esi, eax
            //   89742414             | mov                 dword ptr [esp + 0x14], esi
            //   83feff               | cmp                 esi, -1
            //   7524                 | jne                 0x26
            //   68????????           |                     
            //   e8????????           |                     
            //   83c404               | add                 esp, 4

        $sequence_8 = { ff15???????? 83f8ff 7524 68???????? e8???????? 83c404 }
            // n = 6, score = 200
            //   ff15????????         |                     
            //   83f8ff               | cmp                 eax, -1
            //   7524                 | jne                 0x26
            //   68????????           |                     
            //   e8????????           |                     
            //   83c404               | add                 esp, 4

        $sequence_9 = { 33db 85db 7466 8d45f4 50 ff75f8 53 }
            // n = 7, score = 200
            //   33db                 | xor                 ebx, ebx
            //   85db                 | test                ebx, ebx
            //   7466                 | je                  0x68
            //   8d45f4               | lea                 eax, [ebp - 0xc]
            //   50                   | push                eax
            //   ff75f8               | push                dword ptr [ebp - 8]
            //   53                   | push                ebx

    condition:
        7 of them and filesize < 163840
}