rule win_systembc_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.systembc."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.systembc"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b8e88010000 8b968c010000 8bb690010000 8945e4 895df4 }
            // n = 5, score = 800
            //   8b8e88010000         | mov                 ecx, dword ptr [esi + 0x188]
            //   8b968c010000         | mov                 edx, dword ptr [esi + 0x18c]
            //   8bb690010000         | mov                 esi, dword ptr [esi + 0x190]
            //   8945e4               | mov                 dword ptr [ebp - 0x1c], eax
            //   895df4               | mov                 dword ptr [ebp - 0xc], ebx

        $sequence_1 = { 52 6a00 6a00 6a00 ffb568f9ffff }
            // n = 5, score = 800
            //   52                   | push                edx
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   ffb568f9ffff         | push                dword ptr [ebp - 0x698]

        $sequence_2 = { 668b9554f9ffff 6a00 6a00 6a03 6a00 6a00 }
            // n = 6, score = 800
            //   668b9554f9ffff       | mov                 dx, word ptr [ebp - 0x6ac]
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   6a03                 | push                3
            //   6a00                 | push                0
            //   6a00                 | push                0

        $sequence_3 = { 898568f9ffff c7856cf9ffff00040000 8d853cf9ffff 50 6a00 6a00 }
            // n = 6, score = 800
            //   898568f9ffff         | mov                 dword ptr [ebp - 0x698], eax
            //   c7856cf9ffff00040000     | mov    dword ptr [ebp - 0x694], 0x400
            //   8d853cf9ffff         | lea                 eax, [ebp - 0x6c4]
            //   50                   | push                eax
            //   6a00                 | push                0
            //   6a00                 | push                0

        $sequence_4 = { 81c200008000 81c200100000 81c200200000 6a00 52 }
            // n = 5, score = 800
            //   81c200008000         | add                 edx, 0x800000
            //   81c200100000         | add                 edx, 0x1000
            //   81c200200000         | add                 edx, 0x2000
            //   6a00                 | push                0
            //   52                   | push                edx

        $sequence_5 = { 8d851cf4ffff 50 6800010000 57 ffb530f4ffff }
            // n = 5, score = 800
            //   8d851cf4ffff         | lea                 eax, [ebp - 0xbe4]
            //   50                   | push                eax
            //   6800010000           | push                0x100
            //   57                   | push                edi
            //   ffb530f4ffff         | push                dword ptr [ebp - 0xbd0]

        $sequence_6 = { 50 e8???????? ffd0 8b85f4feffff }
            // n = 4, score = 800
            //   50                   | push                eax
            //   e8????????           |                     
            //   ffd0                 | call                eax
            //   8b85f4feffff         | mov                 eax, dword ptr [ebp - 0x10c]

        $sequence_7 = { 43 3b5dfc 7296 33c0 5e 5f }
            // n = 6, score = 800
            //   43                   | inc                 ebx
            //   3b5dfc               | cmp                 ebx, dword ptr [ebp - 4]
            //   7296                 | jb                  0xffffff98
            //   33c0                 | xor                 eax, eax
            //   5e                   | pop                 esi
            //   5f                   | pop                 edi

        $sequence_8 = { 668b9554f9ffff 6a00 6a00 6a03 6a00 }
            // n = 5, score = 800
            //   668b9554f9ffff       | mov                 dx, word ptr [ebp - 0x6ac]
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   6a03                 | push                3
            //   6a00                 | push                0

        $sequence_9 = { 57 56 8b7d10 33c0 }
            // n = 4, score = 800
            //   57                   | push                edi
            //   56                   | push                esi
            //   8b7d10               | mov                 edi, dword ptr [ebp + 0x10]
            //   33c0                 | xor                 eax, eax

    condition:
        7 of them and filesize < 57344
}