rule win_taintedscribe_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.taintedscribe."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.taintedscribe"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8bc8 8b858cf7ffff 83e103 6a02 f3a4 6a00 }
            // n = 6, score = 500
            //   8bc8                 | mov                 ecx, eax
            //   8b858cf7ffff         | mov                 eax, dword ptr [ebp - 0x874]
            //   83e103               | and                 ecx, 3
            //   6a02                 | push                2
            //   f3a4                 | rep movsb           byte ptr es:[edi], byte ptr [esi]
            //   6a00                 | push                0

        $sequence_1 = { 8d4ddc 898db8fcffff 8bcf 0facd108 }
            // n = 4, score = 500
            //   8d4ddc               | lea                 ecx, [ebp - 0x24]
            //   898db8fcffff         | mov                 dword ptr [ebp - 0x348], ecx
            //   8bcf                 | mov                 ecx, edi
            //   0facd108             | shrd                ecx, edx, 8

        $sequence_2 = { 8b5358 898d88fbffff 8b4b50 0f94c0 }
            // n = 4, score = 500
            //   8b5358               | mov                 edx, dword ptr [ebx + 0x58]
            //   898d88fbffff         | mov                 dword ptr [ebp - 0x478], ecx
            //   8b4b50               | mov                 ecx, dword ptr [ebx + 0x50]
            //   0f94c0               | sete                al

        $sequence_3 = { 85c0 7405 8b4d98 8908 85db }
            // n = 5, score = 500
            //   85c0                 | test                eax, eax
            //   7405                 | je                  7
            //   8b4d98               | mov                 ecx, dword ptr [ebp - 0x68]
            //   8908                 | mov                 dword ptr [eax], ecx
            //   85db                 | test                ebx, ebx

        $sequence_4 = { 894e3c 894e44 895648 33c0 5e 8b4dfc 33cd }
            // n = 7, score = 500
            //   894e3c               | mov                 dword ptr [esi + 0x3c], ecx
            //   894e44               | mov                 dword ptr [esi + 0x44], ecx
            //   895648               | mov                 dword ptr [esi + 0x48], edx
            //   33c0                 | xor                 eax, eax
            //   5e                   | pop                 esi
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   33cd                 | xor                 ecx, ebp

        $sequence_5 = { 8b4dcc 894308 8b45d0 50 }
            // n = 4, score = 500
            //   8b4dcc               | mov                 ecx, dword ptr [ebp - 0x34]
            //   894308               | mov                 dword ptr [ebx + 8], eax
            //   8b45d0               | mov                 eax, dword ptr [ebp - 0x30]
            //   50                   | push                eax

        $sequence_6 = { 42 83fa1c 7cbb 81ff00010000 0f94c1 0fb6c1 68???????? }
            // n = 7, score = 500
            //   42                   | inc                 edx
            //   83fa1c               | cmp                 edx, 0x1c
            //   7cbb                 | jl                  0xffffffbd
            //   81ff00010000         | cmp                 edi, 0x100
            //   0f94c1               | sete                cl
            //   0fb6c1               | movzx               eax, cl
            //   68????????           |                     

        $sequence_7 = { c68577fbffff01 7507 c68577fbffff00 c78570fbffff08000000 }
            // n = 4, score = 500
            //   c68577fbffff01       | mov                 byte ptr [ebp - 0x489], 1
            //   7507                 | jne                 9
            //   c68577fbffff00       | mov                 byte ptr [ebp - 0x489], 0
            //   c78570fbffff08000000     | mov    dword ptr [ebp - 0x490], 8

        $sequence_8 = { 83c40c 098658af0100 8d0419 89865caf0100 83f810 }
            // n = 5, score = 500
            //   83c40c               | add                 esp, 0xc
            //   098658af0100         | or                  dword ptr [esi + 0x1af58], eax
            //   8d0419               | lea                 eax, [ecx + ebx]
            //   89865caf0100         | mov                 dword ptr [esi + 0x1af5c], eax
            //   83f810               | cmp                 eax, 0x10

        $sequence_9 = { bb01000000 d3e3 33c0 85db 7e1e 8d4900 }
            // n = 6, score = 500
            //   bb01000000           | mov                 ebx, 1
            //   d3e3                 | shl                 ebx, cl
            //   33c0                 | xor                 eax, eax
            //   85db                 | test                ebx, ebx
            //   7e1e                 | jle                 0x20
            //   8d4900               | lea                 ecx, [ecx]

    condition:
        7 of them and filesize < 524288
}