rule win_taleret_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.taleret."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.taleret"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c68424b40300000d e8???????? 50 8d4b18 }
            // n = 4, score = 100
            //   c68424b40300000d     | mov                 byte ptr [esp + 0x3b4], 0xd
            //   e8????????           |                     
            //   50                   | push                eax
            //   8d4b18               | lea                 ecx, [ebx + 0x18]

        $sequence_1 = { 8b44240c 8b4c2408 8b542404 6a00 6a00 6a03 68???????? }
            // n = 7, score = 100
            //   8b44240c             | mov                 eax, dword ptr [esp + 0xc]
            //   8b4c2408             | mov                 ecx, dword ptr [esp + 8]
            //   8b542404             | mov                 edx, dword ptr [esp + 4]
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   6a03                 | push                3
            //   68????????           |                     

        $sequence_2 = { 51 50 68???????? 890d???????? }
            // n = 4, score = 100
            //   51                   | push                ecx
            //   50                   | push                eax
            //   68????????           |                     
            //   890d????????         |                     

        $sequence_3 = { 8d442408 c744242401000000 50 ff15???????? 85c0 7528 8b4c2438 }
            // n = 7, score = 100
            //   8d442408             | lea                 eax, [esp + 8]
            //   c744242401000000     | mov                 dword ptr [esp + 0x24], 1
            //   50                   | push                eax
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7528                 | jne                 0x2a
            //   8b4c2438             | mov                 ecx, dword ptr [esp + 0x38]

        $sequence_4 = { 8d4e3c c644241c05 e8???????? 8d4e40 c644241c06 e8???????? }
            // n = 6, score = 100
            //   8d4e3c               | lea                 ecx, [esi + 0x3c]
            //   c644241c05           | mov                 byte ptr [esp + 0x1c], 5
            //   e8????????           |                     
            //   8d4e40               | lea                 ecx, [esi + 0x40]
            //   c644241c06           | mov                 byte ptr [esp + 0x1c], 6
            //   e8????????           |                     

        $sequence_5 = { c60600 e8???????? 83c40c 85c0 7526 57 8d8c24e8000000 }
            // n = 7, score = 100
            //   c60600               | mov                 byte ptr [esi], 0
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   85c0                 | test                eax, eax
            //   7526                 | jne                 0x28
            //   57                   | push                edi
            //   8d8c24e8000000       | lea                 ecx, [esp + 0xe8]

        $sequence_6 = { 85c0 0f85b2000000 a1???????? 668b0d???????? 8a15???????? 89842480000000 }
            // n = 6, score = 100
            //   85c0                 | test                eax, eax
            //   0f85b2000000         | jne                 0xb8
            //   a1????????           |                     
            //   668b0d????????       |                     
            //   8a15????????         |                     
            //   89842480000000       | mov                 dword ptr [esp + 0x80], eax

        $sequence_7 = { c684247016000001 e8???????? 8b9c247c160000 8b6c241c e9???????? 8b442424 8b4c2414 }
            // n = 7, score = 100
            //   c684247016000001     | mov                 byte ptr [esp + 0x1670], 1
            //   e8????????           |                     
            //   8b9c247c160000       | mov                 ebx, dword ptr [esp + 0x167c]
            //   8b6c241c             | mov                 ebp, dword ptr [esp + 0x1c]
            //   e9????????           |                     
            //   8b442424             | mov                 eax, dword ptr [esp + 0x24]
            //   8b4c2414             | mov                 ecx, dword ptr [esp + 0x14]

        $sequence_8 = { 8a440444 eb02 b03d 83fd01 884301 7e33 }
            // n = 6, score = 100
            //   8a440444             | mov                 al, byte ptr [esp + eax + 0x44]
            //   eb02                 | jmp                 4
            //   b03d                 | mov                 al, 0x3d
            //   83fd01               | cmp                 ebp, 1
            //   884301               | mov                 byte ptr [ebx + 1], al
            //   7e33                 | jle                 0x35

        $sequence_9 = { e8???????? 83c408 33f6 e8???????? 8a96f0700010 32d0 }
            // n = 6, score = 100
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   33f6                 | xor                 esi, esi
            //   e8????????           |                     
            //   8a96f0700010         | mov                 dl, byte ptr [esi + 0x100070f0]
            //   32d0                 | xor                 dl, al

    condition:
        7 of them and filesize < 73728
}