rule win_tapaoux_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.tapaoux."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.tapaoux"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 83c404 8d9424d0020000 33f6 52 55 ffd3 85c0 }
            // n = 7, score = 200
            //   83c404               | add                 esp, 4
            //   8d9424d0020000       | lea                 edx, [esp + 0x2d0]
            //   33f6                 | xor                 esi, esi
            //   52                   | push                edx
            //   55                   | push                ebp
            //   ffd3                 | call                ebx
            //   85c0                 | test                eax, eax

        $sequence_1 = { f7d1 49 8d7c2454 894c2418 83c9ff f2ae f7d1 }
            // n = 7, score = 200
            //   f7d1                 | not                 ecx
            //   49                   | dec                 ecx
            //   8d7c2454             | lea                 edi, [esp + 0x54]
            //   894c2418             | mov                 dword ptr [esp + 0x18], ecx
            //   83c9ff               | or                  ecx, 0xffffffff
            //   f2ae                 | repne scasb         al, byte ptr es:[edi]
            //   f7d1                 | not                 ecx

        $sequence_2 = { 52 50 8d4c2420 68???????? 51 eb49 b900010000 }
            // n = 7, score = 200
            //   52                   | push                edx
            //   50                   | push                eax
            //   8d4c2420             | lea                 ecx, [esp + 0x20]
            //   68????????           |                     
            //   51                   | push                ecx
            //   eb49                 | jmp                 0x4b
            //   b900010000           | mov                 ecx, 0x100

        $sequence_3 = { 68???????? 52 ffd6 8d44245c 68???????? 50 }
            // n = 6, score = 200
            //   68????????           |                     
            //   52                   | push                edx
            //   ffd6                 | call                esi
            //   8d44245c             | lea                 eax, [esp + 0x5c]
            //   68????????           |                     
            //   50                   | push                eax

        $sequence_4 = { 8be8 83fdff 0f84b0000000 8b3d???????? }
            // n = 4, score = 200
            //   8be8                 | mov                 ebp, eax
            //   83fdff               | cmp                 ebp, -1
            //   0f84b0000000         | je                  0xb6
            //   8b3d????????         |                     

        $sequence_5 = { 83c404 8d4c2414 50 51 e8???????? 8d54241c }
            // n = 6, score = 200
            //   83c404               | add                 esp, 4
            //   8d4c2414             | lea                 ecx, [esp + 0x14]
            //   50                   | push                eax
            //   51                   | push                ecx
            //   e8????????           |                     
            //   8d54241c             | lea                 edx, [esp + 0x1c]

        $sequence_6 = { 8d442408 55 50 8d8c241c040000 6800040000 51 56 }
            // n = 7, score = 200
            //   8d442408             | lea                 eax, [esp + 8]
            //   55                   | push                ebp
            //   50                   | push                eax
            //   8d8c241c040000       | lea                 ecx, [esp + 0x41c]
            //   6800040000           | push                0x400
            //   51                   | push                ecx
            //   56                   | push                esi

        $sequence_7 = { c3 8d442408 8d4c240c 50 53 53 }
            // n = 6, score = 200
            //   c3                   | ret                 
            //   8d442408             | lea                 eax, [esp + 8]
            //   8d4c240c             | lea                 ecx, [esp + 0xc]
            //   50                   | push                eax
            //   53                   | push                ebx
            //   53                   | push                ebx

        $sequence_8 = { 68???????? 50 e8???????? 8b07 83c418 85c0 7526 }
            // n = 7, score = 200
            //   68????????           |                     
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b07                 | mov                 eax, dword ptr [edi]
            //   83c418               | add                 esp, 0x18
            //   85c0                 | test                eax, eax
            //   7526                 | jne                 0x28

        $sequence_9 = { aa 8bb424200c0000 b900010000 33c0 }
            // n = 4, score = 200
            //   aa                   | stosb               byte ptr es:[edi], al
            //   8bb424200c0000       | mov                 esi, dword ptr [esp + 0xc20]
            //   b900010000           | mov                 ecx, 0x100
            //   33c0                 | xor                 eax, eax

    condition:
        7 of them and filesize < 294912
}