rule win_targetcompany_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.targetcompany."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.targetcompany"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ff15???????? 85c0 7475 fe85a7fdffff 80bda7fdffff0c }
            // n = 5, score = 500
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7475                 | je                  0x77
            //   fe85a7fdffff         | inc                 byte ptr [ebp - 0x259]
            //   80bda7fdffff0c       | cmp                 byte ptr [ebp - 0x259], 0xc

        $sequence_1 = { 53 ff15???????? ff75e8 ff15???????? ff75e0 ff15???????? 3975f0 }
            // n = 7, score = 500
            //   53                   | push                ebx
            //   ff15????????         |                     
            //   ff75e8               | push                dword ptr [ebp - 0x18]
            //   ff15????????         |                     
            //   ff75e0               | push                dword ptr [ebp - 0x20]
            //   ff15????????         |                     
            //   3975f0               | cmp                 dword ptr [ebp - 0x10], esi

        $sequence_2 = { eb43 b900100000 3bc1 733a 53 51 }
            // n = 6, score = 500
            //   eb43                 | jmp                 0x45
            //   b900100000           | mov                 ecx, 0x1000
            //   3bc1                 | cmp                 eax, ecx
            //   733a                 | jae                 0x3c
            //   53                   | push                ebx
            //   51                   | push                ecx

        $sequence_3 = { 83c424 33cd 33c0 5f e8???????? c9 c3 }
            // n = 7, score = 500
            //   83c424               | add                 esp, 0x24
            //   33cd                 | xor                 ecx, ebp
            //   33c0                 | xor                 eax, eax
            //   5f                   | pop                 edi
            //   e8????????           |                     
            //   c9                   | leave               
            //   c3                   | ret                 

        $sequence_4 = { 813d????????a9aaaa0a 722b 68???????? 8d4dd4 }
            // n = 4, score = 500
            //   813d????????a9aaaa0a     |     
            //   722b                 | jb                  0x2d
            //   68????????           |                     
            //   8d4dd4               | lea                 ecx, [ebp - 0x2c]

        $sequence_5 = { e8???????? 57 6a0c 5a 8bce 8d45e0 e8???????? }
            // n = 7, score = 500
            //   e8????????           |                     
            //   57                   | push                edi
            //   6a0c                 | push                0xc
            //   5a                   | pop                 edx
            //   8bce                 | mov                 ecx, esi
            //   8d45e0               | lea                 eax, [ebp - 0x20]
            //   e8????????           |                     

        $sequence_6 = { 83ec40 53 56 33f6 57 8d5dc4 }
            // n = 6, score = 500
            //   83ec40               | sub                 esp, 0x40
            //   53                   | push                ebx
            //   56                   | push                esi
            //   33f6                 | xor                 esi, esi
            //   57                   | push                edi
            //   8d5dc4               | lea                 ebx, [ebp - 0x3c]

        $sequence_7 = { 50 8d45b0 50 e8???????? 8d45b0 50 8d85c0feffff }
            // n = 7, score = 500
            //   50                   | push                eax
            //   8d45b0               | lea                 eax, [ebp - 0x50]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8d45b0               | lea                 eax, [ebp - 0x50]
            //   50                   | push                eax
            //   8d85c0feffff         | lea                 eax, [ebp - 0x140]

        $sequence_8 = { bf???????? 8d75e8 e8???????? 8b1d???????? 8d75f0 }
            // n = 5, score = 500
            //   bf????????           |                     
            //   8d75e8               | lea                 esi, [ebp - 0x18]
            //   e8????????           |                     
            //   8b1d????????         |                     
            //   8d75f0               | lea                 esi, [ebp - 0x10]

        $sequence_9 = { 8945ec e8???????? 53 6a01 8d758c e8???????? 53 }
            // n = 7, score = 500
            //   8945ec               | mov                 dword ptr [ebp - 0x14], eax
            //   e8????????           |                     
            //   53                   | push                ebx
            //   6a01                 | push                1
            //   8d758c               | lea                 esi, [ebp - 0x74]
            //   e8????????           |                     
            //   53                   | push                ebx

    condition:
        7 of them and filesize < 328704
}