rule win_termite_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.termite."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.termite"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b4508 c1e003 89c2 c1e206 01d0 05???????? 8d5004 }
            // n = 7, score = 200
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   c1e003               | shl                 eax, 3
            //   89c2                 | mov                 edx, eax
            //   c1e206               | shl                 edx, 6
            //   01d0                 | add                 eax, edx
            //   05????????           |                     
            //   8d5004               | lea                 edx, [eax + 4]

        $sequence_1 = { e8???????? c744240814000000 8d45dc 89442404 8b45f4 890424 }
            // n = 6, score = 200
            //   e8????????           |                     
            //   c744240814000000     | mov                 dword ptr [esp + 8], 0x14
            //   8d45dc               | lea                 eax, [ebp - 0x24]
            //   89442404             | mov                 dword ptr [esp + 4], eax
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]
            //   890424               | mov                 dword ptr [esp], eax

        $sequence_2 = { c744241cffffffff c74424188cd44000 c7442414ffffffff 8b4510 89442410 8b450c 8944240c }
            // n = 7, score = 200
            //   c744241cffffffff     | mov                 dword ptr [esp + 0x1c], 0xffffffff
            //   c74424188cd44000     | mov                 dword ptr [esp + 0x18], 0x40d48c
            //   c7442414ffffffff     | mov                 dword ptr [esp + 0x14], 0xffffffff
            //   8b4510               | mov                 eax, dword ptr [ebp + 0x10]
            //   89442410             | mov                 dword ptr [esp + 0x10], eax
            //   8b450c               | mov                 eax, dword ptr [ebp + 0xc]
            //   8944240c             | mov                 dword ptr [esp + 0xc], eax

        $sequence_3 = { 837dfc00 75d7 b800000000 c9 c3 55 }
            // n = 6, score = 200
            //   837dfc00             | cmp                 dword ptr [ebp - 4], 0
            //   75d7                 | jne                 0xffffffd9
            //   b800000000           | mov                 eax, 0
            //   c9                   | leave               
            //   c3                   | ret                 
            //   55                   | push                ebp

        $sequence_4 = { 8b10 a1???????? 8b4d08 894c2408 89542404 890424 e8???????? }
            // n = 7, score = 200
            //   8b10                 | mov                 edx, dword ptr [eax]
            //   a1????????           |                     
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   894c2408             | mov                 dword ptr [esp + 8], ecx
            //   89542404             | mov                 dword ptr [esp + 4], edx
            //   890424               | mov                 dword ptr [esp], eax
            //   e8????????           |                     

        $sequence_5 = { e8???????? 83f814 7706 837d1400 7f0a b8ffffffff }
            // n = 6, score = 200
            //   e8????????           |                     
            //   83f814               | cmp                 eax, 0x14
            //   7706                 | ja                  8
            //   837d1400             | cmp                 dword ptr [ebp + 0x14], 0
            //   7f0a                 | jg                  0xc
            //   b8ffffffff           | mov                 eax, 0xffffffff

        $sequence_6 = { 837d0c00 750a b800000000 e9???????? 8b450c 8b4010 8945f0 }
            // n = 7, score = 200
            //   837d0c00             | cmp                 dword ptr [ebp + 0xc], 0
            //   750a                 | jne                 0xc
            //   b800000000           | mov                 eax, 0
            //   e9????????           |                     
            //   8b450c               | mov                 eax, dword ptr [ebp + 0xc]
            //   8b4010               | mov                 eax, dword ptr [eax + 0x10]
            //   8945f0               | mov                 dword ptr [ebp - 0x10], eax

        $sequence_7 = { 89442404 8b45f0 890424 e8???????? c70424???????? e8???????? 8b45f4 }
            // n = 7, score = 200
            //   89442404             | mov                 dword ptr [esp + 4], eax
            //   8b45f0               | mov                 eax, dword ptr [ebp - 0x10]
            //   890424               | mov                 dword ptr [esp], eax
            //   e8????????           |                     
            //   c70424????????       |                     
            //   e8????????           |                     
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]

        $sequence_8 = { c704240a000000 e8???????? eb0a c745f401000000 eb08 90 c745f400000000 }
            // n = 7, score = 200
            //   c704240a000000       | mov                 dword ptr [esp], 0xa
            //   e8????????           |                     
            //   eb0a                 | jmp                 0xc
            //   c745f401000000       | mov                 dword ptr [ebp - 0xc], 1
            //   eb08                 | jmp                 0xa
            //   90                   | nop                 
            //   c745f400000000       | mov                 dword ptr [ebp - 0xc], 0

        $sequence_9 = { 83ec04 89442404 8d85b4feffff 890424 e8???????? 8d85b4feffff 89442404 }
            // n = 7, score = 200
            //   83ec04               | sub                 esp, 4
            //   89442404             | mov                 dword ptr [esp + 4], eax
            //   8d85b4feffff         | lea                 eax, [ebp - 0x14c]
            //   890424               | mov                 dword ptr [esp], eax
            //   e8????????           |                     
            //   8d85b4feffff         | lea                 eax, [ebp - 0x14c]
            //   89442404             | mov                 dword ptr [esp + 4], eax

    condition:
        7 of them and filesize < 312320
}