rule win_thanatos_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.thanatos."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.thanatos"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 85f6 0f849b010000 ff742428 6a00 68ffff1f00 ff15???????? 8bf8 }
            // n = 7, score = 500
            //   85f6                 | test                esi, esi
            //   0f849b010000         | je                  0x1a1
            //   ff742428             | push                dword ptr [esp + 0x28]
            //   6a00                 | push                0
            //   68ffff1f00           | push                0x1fffff
            //   ff15????????         |                     
            //   8bf8                 | mov                 edi, eax

        $sequence_1 = { 50 8bda 8bf1 c78560ffffff94000000 e8???????? 83c40c 8d8560ffffff }
            // n = 7, score = 500
            //   50                   | push                eax
            //   8bda                 | mov                 ebx, edx
            //   8bf1                 | mov                 esi, ecx
            //   c78560ffffff94000000     | mov    dword ptr [ebp - 0xa0], 0x94
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   8d8560ffffff         | lea                 eax, [ebp - 0xa0]

        $sequence_2 = { c64435bc46 8d45bc 50 46 ffd7 3bf0 7ce9 }
            // n = 7, score = 500
            //   c64435bc46           | mov                 byte ptr [ebp + esi - 0x44], 0x46
            //   8d45bc               | lea                 eax, [ebp - 0x44]
            //   50                   | push                eax
            //   46                   | inc                 esi
            //   ffd7                 | call                edi
            //   3bf0                 | cmp                 esi, eax
            //   7ce9                 | jl                  0xffffffeb

        $sequence_3 = { 6a00 6a00 68000000c0 68???????? 46 ffd3 8bf8 }
            // n = 7, score = 500
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   68000000c0           | push                0xc0000000
            //   68????????           |                     
            //   46                   | inc                 esi
            //   ffd3                 | call                ebx
            //   8bf8                 | mov                 edi, eax

        $sequence_4 = { 83c40c 807d0800 7459 8b4c240c 897c2422 8d4306 8944241e }
            // n = 7, score = 500
            //   83c40c               | add                 esp, 0xc
            //   807d0800             | cmp                 byte ptr [ebp + 8], 0
            //   7459                 | je                  0x5b
            //   8b4c240c             | mov                 ecx, dword ptr [esp + 0xc]
            //   897c2422             | mov                 dword ptr [esp + 0x22], edi
            //   8d4306               | lea                 eax, [ebx + 6]
            //   8944241e             | mov                 dword ptr [esp + 0x1e], eax

        $sequence_5 = { 807d0800 89442414 b80a000000 7524 3bdf }
            // n = 5, score = 500
            //   807d0800             | cmp                 byte ptr [ebp + 8], 0
            //   89442414             | mov                 dword ptr [esp + 0x14], eax
            //   b80a000000           | mov                 eax, 0xa
            //   7524                 | jne                 0x26
            //   3bdf                 | cmp                 ebx, edi

        $sequence_6 = { 84c0 75f9 2bd7 5f 7409 51 ff15???????? }
            // n = 7, score = 500
            //   84c0                 | test                al, al
            //   75f9                 | jne                 0xfffffffb
            //   2bd7                 | sub                 edx, edi
            //   5f                   | pop                 edi
            //   7409                 | je                  0xb
            //   51                   | push                ecx
            //   ff15????????         |                     

        $sequence_7 = { 57 8bf9 8b4e28 8955fc 83f803 0f85e5020000 8b5d08 }
            // n = 7, score = 500
            //   57                   | push                edi
            //   8bf9                 | mov                 edi, ecx
            //   8b4e28               | mov                 ecx, dword ptr [esi + 0x28]
            //   8955fc               | mov                 dword ptr [ebp - 4], edx
            //   83f803               | cmp                 eax, 3
            //   0f85e5020000         | jne                 0x2eb
            //   8b5d08               | mov                 ebx, dword ptr [ebp + 8]

        $sequence_8 = { 893d???????? c705????????ecb40110 f30f7e05???????? 660fd64008 }
            // n = 4, score = 500
            //   893d????????         |                     
            //   c705????????ecb40110     |     
            //   f30f7e05????????     |                     
            //   660fd64008           | movq                qword ptr [eax + 8], xmm0

        $sequence_9 = { 50 6a02 ff15???????? 8b7514 c705????????c0b30110 85f6 0f8486010000 }
            // n = 7, score = 500
            //   50                   | push                eax
            //   6a02                 | push                2
            //   ff15????????         |                     
            //   8b7514               | mov                 esi, dword ptr [ebp + 0x14]
            //   c705????????c0b30110     |     
            //   85f6                 | test                esi, esi
            //   0f8486010000         | je                  0x18c

    condition:
        7 of them and filesize < 1810432
}