rule win_thumbthief_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.thumbthief."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.thumbthief"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e9???????? 689c000000 b8???????? e8???????? 33db 8d4db4 895dec }
            // n = 7, score = 100
            //   e9????????           |                     
            //   689c000000           | push                0x9c
            //   b8????????           |                     
            //   e8????????           |                     
            //   33db                 | xor                 ebx, ebx
            //   8d4db4               | lea                 ecx, [ebp - 0x4c]
            //   895dec               | mov                 dword ptr [ebp - 0x14], ebx

        $sequence_1 = { f6431002 0f85e1000000 85f6 0f44f3 89758c b800040000 66854310 }
            // n = 7, score = 100
            //   f6431002             | test                byte ptr [ebx + 0x10], 2
            //   0f85e1000000         | jne                 0xe7
            //   85f6                 | test                esi, esi
            //   0f44f3               | cmove               esi, ebx
            //   89758c               | mov                 dword ptr [ebp - 0x74], esi
            //   b800040000           | mov                 eax, 0x400
            //   66854310             | test                word ptr [ebx + 0x10], ax

        $sequence_2 = { ffb58cfeffff 8d8d30ffffff e8???????? 8d8de0feffff 807def00 7408 ffb5acfeffff }
            // n = 7, score = 100
            //   ffb58cfeffff         | push                dword ptr [ebp - 0x174]
            //   8d8d30ffffff         | lea                 ecx, [ebp - 0xd0]
            //   e8????????           |                     
            //   8d8de0feffff         | lea                 ecx, [ebp - 0x120]
            //   807def00             | cmp                 byte ptr [ebp - 0x11], 0
            //   7408                 | je                  0xa
            //   ffb5acfeffff         | push                dword ptr [ebp - 0x154]

        $sequence_3 = { f20f1085ecfeffff 8d8574ffffff 51 51 f20f110424 50 8d85f4feffff }
            // n = 7, score = 100
            //   f20f1085ecfeffff     | movsd               xmm0, qword ptr [ebp - 0x114]
            //   8d8574ffffff         | lea                 eax, [ebp - 0x8c]
            //   51                   | push                ecx
            //   51                   | push                ecx
            //   f20f110424           | movsd               qword ptr [esp], xmm0
            //   50                   | push                eax
            //   8d85f4feffff         | lea                 eax, [ebp - 0x10c]

        $sequence_4 = { e8???????? c645fc02 8d8d58ffffff e8???????? c645fc03 8d8d18ffffff e8???????? }
            // n = 7, score = 100
            //   e8????????           |                     
            //   c645fc02             | mov                 byte ptr [ebp - 4], 2
            //   8d8d58ffffff         | lea                 ecx, [ebp - 0xa8]
            //   e8????????           |                     
            //   c645fc03             | mov                 byte ptr [ebp - 4], 3
            //   8d8d18ffffff         | lea                 ecx, [ebp - 0xe8]
            //   e8????????           |                     

        $sequence_5 = { bf48030000 8d85a4fcffff 57 6a00 50 e8???????? 83c40c }
            // n = 7, score = 100
            //   bf48030000           | mov                 edi, 0x348
            //   8d85a4fcffff         | lea                 eax, [ebp - 0x35c]
            //   57                   | push                edi
            //   6a00                 | push                0
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc

        $sequence_6 = { eb77 68???????? eb70 68???????? eb69 8bc3 2d04130400 }
            // n = 7, score = 100
            //   eb77                 | jmp                 0x79
            //   68????????           |                     
            //   eb70                 | jmp                 0x72
            //   68????????           |                     
            //   eb69                 | jmp                 0x6b
            //   8bc3                 | mov                 eax, ebx
            //   2d04130400           | sub                 eax, 0x41304

        $sequence_7 = { ff75f8 85c0 743c ff75f4 ba07000000 8bcf e8???????? }
            // n = 7, score = 100
            //   ff75f8               | push                dword ptr [ebp - 8]
            //   85c0                 | test                eax, eax
            //   743c                 | je                  0x3e
            //   ff75f4               | push                dword ptr [ebp - 0xc]
            //   ba07000000           | mov                 edx, 7
            //   8bcf                 | mov                 ecx, edi
            //   e8????????           |                     

        $sequence_8 = { e8???????? b8???????? e9???????? 8d4ddc e9???????? 8d4dbc e9???????? }
            // n = 7, score = 100
            //   e8????????           |                     
            //   b8????????           |                     
            //   e9????????           |                     
            //   8d4ddc               | lea                 ecx, [ebp - 0x24]
            //   e9????????           |                     
            //   8d4dbc               | lea                 ecx, [ebp - 0x44]
            //   e9????????           |                     

        $sequence_9 = { ff15???????? 8b4704 5f 85c0 740a 894508 5d }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   8b4704               | mov                 eax, dword ptr [edi + 4]
            //   5f                   | pop                 edi
            //   85c0                 | test                eax, eax
            //   740a                 | je                  0xc
            //   894508               | mov                 dword ptr [ebp + 8], eax
            //   5d                   | pop                 ebp

    condition:
        7 of them and filesize < 4235264
}