rule win_thunker_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.thunker."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.thunker"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 89c7 50 68???????? 8dbd00feffff 57 e8???????? 83c420 }
            // n = 7, score = 100
            //   89c7                 | mov                 edi, eax
            //   50                   | push                eax
            //   68????????           |                     
            //   8dbd00feffff         | lea                 edi, [ebp - 0x200]
            //   57                   | push                edi
            //   e8????????           |                     
            //   83c420               | add                 esp, 0x20

        $sequence_1 = { e8???????? 89c6 83feff 7420 }
            // n = 4, score = 100
            //   e8????????           |                     
            //   89c6                 | mov                 esi, eax
            //   83feff               | cmp                 esi, -1
            //   7420                 | je                  0x22

        $sequence_2 = { 8d8500feffff 50 56 e8???????? 89c7 83ffff }
            // n = 6, score = 100
            //   8d8500feffff         | lea                 eax, [ebp - 0x200]
            //   50                   | push                eax
            //   56                   | push                esi
            //   e8????????           |                     
            //   89c7                 | mov                 edi, eax
            //   83ffff               | cmp                 edi, -1

        $sequence_3 = { e8???????? 83c40c 89c7 e8???????? 8985ecfdffff }
            // n = 5, score = 100
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   89c7                 | mov                 edi, eax
            //   e8????????           |                     
            //   8985ecfdffff         | mov                 dword ptr [ebp - 0x214], eax

        $sequence_4 = { d1ea 8995e8fdffff 56 e8???????? 6a08 68???????? 68???????? }
            // n = 7, score = 100
            //   d1ea                 | shr                 edx, 1
            //   8995e8fdffff         | mov                 dword ptr [ebp - 0x218], edx
            //   56                   | push                esi
            //   e8????????           |                     
            //   6a08                 | push                8
            //   68????????           |                     
            //   68????????           |                     

        $sequence_5 = { 68204e0000 68d3710000 50 e8???????? 6a00 68804f1200 68dd710000 }
            // n = 7, score = 100
            //   68204e0000           | push                0x4e20
            //   68d3710000           | push                0x71d3
            //   50                   | push                eax
            //   e8????????           |                     
            //   6a00                 | push                0
            //   68804f1200           | push                0x124f80
            //   68dd710000           | push                0x71dd

        $sequence_6 = { 83c40c 8d8544edffff 50 e8???????? 8985c4edffff 8b400c }
            // n = 6, score = 100
            //   83c40c               | add                 esp, 0xc
            //   8d8544edffff         | lea                 eax, [ebp - 0x12bc]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8985c4edffff         | mov                 dword ptr [ebp - 0x123c], eax
            //   8b400c               | mov                 eax, dword ptr [eax + 0xc]

        $sequence_7 = { 7433 7c79 3df1710000 7447 }
            // n = 4, score = 100
            //   7433                 | je                  0x35
            //   7c79                 | jl                  0x7b
            //   3df1710000           | cmp                 eax, 0x71f1
            //   7447                 | je                  0x49

        $sequence_8 = { 8d85f0edffff 50 57 e8???????? 83bdf0eeffff05 752e }
            // n = 6, score = 100
            //   8d85f0edffff         | lea                 eax, [ebp - 0x1210]
            //   50                   | push                eax
            //   57                   | push                edi
            //   e8????????           |                     
            //   83bdf0eeffff05       | cmp                 dword ptr [ebp - 0x1110], 5
            //   752e                 | jne                 0x30

        $sequence_9 = { e8???????? 68???????? e8???????? 83c41c 68???????? 68???????? e8???????? }
            // n = 7, score = 100
            //   e8????????           |                     
            //   68????????           |                     
            //   e8????????           |                     
            //   83c41c               | add                 esp, 0x1c
            //   68????????           |                     
            //   68????????           |                     
            //   e8????????           |                     

    condition:
        7 of them and filesize < 73728
}