rule win_tildeb_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.tildeb."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.tildeb"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d4dbc 51 56 ff15???????? 56 ff15???????? }
            // n = 6, score = 100
            //   8d4dbc               | lea                 ecx, [ebp - 0x44]
            //   51                   | push                ecx
            //   56                   | push                esi
            //   ff15????????         |                     
            //   56                   | push                esi
            //   ff15????????         |                     

        $sequence_1 = { 6a00 6a00 ff15???????? 85c0 0f84f5090000 68???????? }
            // n = 6, score = 100
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   0f84f5090000         | je                  0x9fb
            //   68????????           |                     

        $sequence_2 = { 57 6a40 c644241300 ff15???????? 50 ff15???????? }
            // n = 6, score = 100
            //   57                   | push                edi
            //   6a40                 | push                0x40
            //   c644241300           | mov                 byte ptr [esp + 0x13], 0
            //   ff15????????         |                     
            //   50                   | push                eax
            //   ff15????????         |                     

        $sequence_3 = { 85c0 7445 50 68???????? 68???????? ff15???????? 83c40c }
            // n = 7, score = 100
            //   85c0                 | test                eax, eax
            //   7445                 | je                  0x47
            //   50                   | push                eax
            //   68????????           |                     
            //   68????????           |                     
            //   ff15????????         |                     
            //   83c40c               | add                 esp, 0xc

        $sequence_4 = { e8???????? 6a00 6a08 8d85d4f5ffff 50 }
            // n = 5, score = 100
            //   e8????????           |                     
            //   6a00                 | push                0
            //   6a08                 | push                8
            //   8d85d4f5ffff         | lea                 eax, [ebp - 0xa2c]
            //   50                   | push                eax

        $sequence_5 = { 68???????? 57 56 ff15???????? 8945bc 85c0 7457 }
            // n = 7, score = 100
            //   68????????           |                     
            //   57                   | push                edi
            //   56                   | push                esi
            //   ff15????????         |                     
            //   8945bc               | mov                 dword ptr [ebp - 0x44], eax
            //   85c0                 | test                eax, eax
            //   7457                 | je                  0x59

        $sequence_6 = { c3 b815000000 5e 81c494010000 c3 f7d8 5e }
            // n = 7, score = 100
            //   c3                   | ret                 
            //   b815000000           | mov                 eax, 0x15
            //   5e                   | pop                 esi
            //   81c494010000         | add                 esp, 0x194
            //   c3                   | ret                 
            //   f7d8                 | neg                 eax
            //   5e                   | pop                 esi

        $sequence_7 = { eb40 8d458c 50 68???????? eb35 }
            // n = 5, score = 100
            //   eb40                 | jmp                 0x42
            //   8d458c               | lea                 eax, [ebp - 0x74]
            //   50                   | push                eax
            //   68????????           |                     
            //   eb35                 | jmp                 0x37

        $sequence_8 = { 53 55 8bac2410010000 56 8b35???????? 57 68???????? }
            // n = 7, score = 100
            //   53                   | push                ebx
            //   55                   | push                ebp
            //   8bac2410010000       | mov                 ebp, dword ptr [esp + 0x110]
            //   56                   | push                esi
            //   8b35????????         |                     
            //   57                   | push                edi
            //   68????????           |                     

        $sequence_9 = { 6800000088 68???????? 68???????? 6a00 ff15???????? 8b0d???????? }
            // n = 6, score = 100
            //   6800000088           | push                0x88000000
            //   68????????           |                     
            //   68????????           |                     
            //   6a00                 | push                0
            //   ff15????????         |                     
            //   8b0d????????         |                     

    condition:
        7 of them and filesize < 8532488
}