rule win_tiny_turla_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.tiny_turla."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.tiny_turla"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 4533ed 8b7d7f 488b742450 8d4f02 }
            // n = 4, score = 100
            //   4533ed               | mov                 eax, esi
            //   8b7d7f               | dec                 eax
            //   488b742450           | lea                 edx, [edi + esi]
            //   8d4f02               | inc                 esp

        $sequence_1 = { 0f84f8000000 33d2 488d4da0 448d4268 }
            // n = 4, score = 100
            //   0f84f8000000         | lea                 edx, [eax + 1]
            //   33d2                 | je                  0xc2
            //   488d4da0             | inc                 esp
            //   448d4268             | mov                 esi, dword ptr [ebp + 0x67]

        $sequence_2 = { 488b16 8bd8 894567 41b906000200 488d4577 4533c0 }
            // n = 6, score = 100
            //   488b16               | movzx               ebp, byte ptr [edx]
            //   8bd8                 | dec                 esp
            //   894567               | mov                 dword ptr [esp + 0x20], esp
            //   41b906000200         | dec                 esp
            //   488d4577             | mov                 edi, edx
            //   4533c0               | inc                 ebp

        $sequence_3 = { 48895c2420 ff15???????? 85c0 750e 488bce }
            // n = 5, score = 100
            //   48895c2420           | inc                 ebp
            //   ff15????????         |                     
            //   85c0                 | xor                 ecx, ecx
            //   750e                 | inc                 ebp
            //   488bce               | xor                 ebp, ebp

        $sequence_4 = { ff15???????? 85c0 7516 4533ed }
            // n = 4, score = 100
            //   ff15????????         |                     
            //   85c0                 | inc                 esp
            //   7516                 | mov                 dword ptr [esi + 0x30], edi
            //   4533ed               | dec                 esp

        $sequence_5 = { 440fb62a 44886d6f 44894d7f 4585c0 7540 }
            // n = 5, score = 100
            //   440fb62a             | xor                 ecx, ecx
            //   44886d6f             | test                eax, eax
            //   44894d7f             | je                  0x87
            //   4585c0               | dec                 eax
            //   7540                 | mov                 ecx, dword ptr [ebx + 0x10]

        $sequence_6 = { ff15???????? b005 e9???????? 8b0f 85c9 }
            // n = 5, score = 100
            //   ff15????????         |                     
            //   b005                 | mov                 dword ptr [esp + 0xd0], eax
            //   e9????????           |                     
            //   8b0f                 | dec                 eax
            //   85c9                 | lea                 eax, [esp + 0x70]

        $sequence_7 = { 418d511b ff15???????? 488bcb 85c0 0f849b000000 8b7d50 }
            // n = 6, score = 100
            //   418d511b             | mov                 ecx, edi
            //   ff15????????         |                     
            //   488bcb               | dec                 eax
            //   85c0                 | mov                 ecx, edi
            //   0f849b000000         | inc                 ecx
            //   8b7d50               | cmp                 eax, esi

        $sequence_8 = { 48c74308ffffffff 488b4b18 4883f9ff 740e ff15???????? }
            // n = 5, score = 100
            //   48c74308ffffffff     | xor                 eax, eax
            //   488b4b18             | dec                 eax
            //   4883f9ff             | add                 esp, 0x50
            //   740e                 | pop                 ebx
            //   ff15????????         |                     

        $sequence_9 = { 4883ec18 c7042400000000 33c0 83f801 7441 8b0424 488b4c2420 }
            // n = 7, score = 100
            //   4883ec18             | mov                 ecx, edi
            //   c7042400000000       | dec                 eax
            //   33c0                 | cmp                 eax, -3
            //   83f801               | ja                  0x456
            //   7441                 | xor                 edx, edx
            //   8b0424               | inc                 ecx
            //   488b4c2420           | mov                 eax, 0x18

    condition:
        7 of them and filesize < 51200
}