rule win_tinytyphon_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.tinytyphon."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.tinytyphon"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c745b430144000 c745b834144000 c745bc38144000 c745c03c144000 c745c440144000 }
            // n = 5, score = 200
            //   c745b430144000       | mov                 dword ptr [ebp - 0x4c], 0x401430
            //   c745b834144000       | mov                 dword ptr [ebp - 0x48], 0x401434
            //   c745bc38144000       | mov                 dword ptr [ebp - 0x44], 0x401438
            //   c745c03c144000       | mov                 dword ptr [ebp - 0x40], 0x40143c
            //   c745c440144000       | mov                 dword ptr [ebp - 0x3c], 0x401440

        $sequence_1 = { 50 8b0d???????? 51 e8???????? 83c420 8b955cffffff 52 }
            // n = 7, score = 200
            //   50                   | push                eax
            //   8b0d????????         |                     
            //   51                   | push                ecx
            //   e8????????           |                     
            //   83c420               | add                 esp, 0x20
            //   8b955cffffff         | mov                 edx, dword ptr [ebp - 0xa4]
            //   52                   | push                edx

        $sequence_2 = { 68???????? 8d85e8feffff 50 ff15???????? 8d8dccfdffff 51 }
            // n = 6, score = 200
            //   68????????           |                     
            //   8d85e8feffff         | lea                 eax, [ebp - 0x118]
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8d8dccfdffff         | lea                 ecx, [ebp - 0x234]
            //   51                   | push                ecx

        $sequence_3 = { 034df4 034df0 894dd4 8b5508 }
            // n = 4, score = 200
            //   034df4               | add                 ecx, dword ptr [ebp - 0xc]
            //   034df0               | add                 ecx, dword ptr [ebp - 0x10]
            //   894dd4               | mov                 dword ptr [ebp - 0x2c], ecx
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]

        $sequence_4 = { 034df8 0fbe11 85d2 0f84fe010000 8b4508 0345f8 }
            // n = 6, score = 200
            //   034df8               | add                 ecx, dword ptr [ebp - 8]
            //   0fbe11               | movsx               edx, byte ptr [ecx]
            //   85d2                 | test                edx, edx
            //   0f84fe010000         | je                  0x204
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   0345f8               | add                 eax, dword ptr [ebp - 8]

        $sequence_5 = { 0345c0 8a08 880a ebdf 8d55d8 52 }
            // n = 6, score = 200
            //   0345c0               | add                 eax, dword ptr [ebp - 0x40]
            //   8a08                 | mov                 cl, byte ptr [eax]
            //   880a                 | mov                 byte ptr [edx], cl
            //   ebdf                 | jmp                 0xffffffe1
            //   8d55d8               | lea                 edx, [ebp - 0x28]
            //   52                   | push                edx

        $sequence_6 = { eba9 68a01f0000 ff15???????? 6a0f 8d8df0feffff 51 }
            // n = 6, score = 200
            //   eba9                 | jmp                 0xffffffab
            //   68a01f0000           | push                0x1fa0
            //   ff15????????         |                     
            //   6a0f                 | push                0xf
            //   8d8df0feffff         | lea                 ecx, [ebp - 0x110]
            //   51                   | push                ecx

        $sequence_7 = { 034a58 8b45f8 8d8c0878a46ad7 894df8 8b55f8 c1e207 8b45f8 }
            // n = 7, score = 200
            //   034a58               | add                 ecx, dword ptr [edx + 0x58]
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   8d8c0878a46ad7       | lea                 ecx, [eax + ecx - 0x28955b88]
            //   894df8               | mov                 dword ptr [ebp - 8], ecx
            //   8b55f8               | mov                 edx, dword ptr [ebp - 8]
            //   c1e207               | shl                 edx, 7
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]

        $sequence_8 = { 83bde4feffffff 750a c785e4feffff00000000 83bde4feffff00 7505 }
            // n = 5, score = 200
            //   83bde4feffffff       | cmp                 dword ptr [ebp - 0x11c], -1
            //   750a                 | jne                 0xc
            //   c785e4feffff00000000     | mov    dword ptr [ebp - 0x11c], 0
            //   83bde4feffff00       | cmp                 dword ptr [ebp - 0x11c], 0
            //   7505                 | jne                 7

        $sequence_9 = { 52 8d85f0feffff 50 8d8dd0fdffff }
            // n = 4, score = 200
            //   52                   | push                edx
            //   8d85f0feffff         | lea                 eax, [ebp - 0x110]
            //   50                   | push                eax
            //   8d8dd0fdffff         | lea                 ecx, [ebp - 0x230]

    condition:
        7 of them and filesize < 90112
}