rule win_transbox_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.transbox."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.transbox"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 64a300000000 eb24 8b048d90b60110 41 50 890d???????? ff15???????? }
            // n = 7, score = 100
            //   64a300000000         | mov                 dword ptr fs:[0], eax
            //   eb24                 | jmp                 0x26
            //   8b048d90b60110       | mov                 eax, dword ptr [ecx*4 + 0x1001b690]
            //   41                   | inc                 ecx
            //   50                   | push                eax
            //   890d????????         |                     
            //   ff15????????         |                     

        $sequence_1 = { 33c9 83c414 85c0 0f9fc1 8bc1 8b4dfc 33cd }
            // n = 7, score = 100
            //   33c9                 | xor                 ecx, ecx
            //   83c414               | add                 esp, 0x14
            //   85c0                 | test                eax, eax
            //   0f9fc1               | setg                cl
            //   8bc1                 | mov                 eax, ecx
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   33cd                 | xor                 ecx, ebp

        $sequence_2 = { 8d4e04 c706???????? 832100 83610400 51 50 ff15???????? }
            // n = 7, score = 100
            //   8d4e04               | lea                 ecx, [esi + 4]
            //   c706????????         |                     
            //   832100               | and                 dword ptr [ecx], 0
            //   83610400             | and                 dword ptr [ecx + 4], 0
            //   51                   | push                ecx
            //   50                   | push                eax
            //   ff15????????         |                     

        $sequence_3 = { e9???????? 55 8bec 56 8b7508 57 bf???????? }
            // n = 7, score = 100
            //   e9????????           |                     
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   56                   | push                esi
            //   8b7508               | mov                 esi, dword ptr [ebp + 8]
            //   57                   | push                edi
            //   bf????????           |                     

        $sequence_4 = { f7fb 56 8bf0 bbe0077e00 8bc3 2bc6 83f801 }
            // n = 7, score = 100
            //   f7fb                 | idiv                ebx
            //   56                   | push                esi
            //   8bf0                 | mov                 esi, eax
            //   bbe0077e00           | mov                 ebx, 0x7e07e0
            //   8bc3                 | mov                 eax, ebx
            //   2bc6                 | sub                 eax, esi
            //   83f801               | cmp                 eax, 1

        $sequence_5 = { f77dfc 50 51 e8???????? 83c40c 69c708020000 5f }
            // n = 7, score = 100
            //   f77dfc               | idiv                dword ptr [ebp - 4]
            //   50                   | push                eax
            //   51                   | push                ecx
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   69c708020000         | imul                eax, edi, 0x208
            //   5f                   | pop                 edi

        $sequence_6 = { 8bbdbcd3ffff 53 6a01 8d8d28e1ffff 885dfc }
            // n = 5, score = 100
            //   8bbdbcd3ffff         | mov                 edi, dword ptr [ebp - 0x2c44]
            //   53                   | push                ebx
            //   6a01                 | push                1
            //   8d8d28e1ffff         | lea                 ecx, [ebp - 0x1ed8]
            //   885dfc               | mov                 byte ptr [ebp - 4], bl

        $sequence_7 = { 8d85e8fdffff 6808020000 895dfc 53 50 89bddcfdffff 899de4fdffff }
            // n = 7, score = 100
            //   8d85e8fdffff         | lea                 eax, [ebp - 0x218]
            //   6808020000           | push                0x208
            //   895dfc               | mov                 dword ptr [ebp - 4], ebx
            //   53                   | push                ebx
            //   50                   | push                eax
            //   89bddcfdffff         | mov                 dword ptr [ebp - 0x224], edi
            //   899de4fdffff         | mov                 dword ptr [ebp - 0x21c], ebx

        $sequence_8 = { 33c9 8985dcfcffff 51 50 }
            // n = 4, score = 100
            //   33c9                 | xor                 ecx, ecx
            //   8985dcfcffff         | mov                 dword ptr [ebp - 0x324], eax
            //   51                   | push                ecx
            //   50                   | push                eax

        $sequence_9 = { 8d85f8faffff 50 e8???????? 8bd0 8b02 85c0 7402 }
            // n = 7, score = 100
            //   8d85f8faffff         | lea                 eax, [ebp - 0x508]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8bd0                 | mov                 edx, eax
            //   8b02                 | mov                 eax, dword ptr [edx]
            //   85c0                 | test                eax, eax
            //   7402                 | je                  4

    condition:
        7 of them and filesize < 288768
}