rule win_treasurehunter_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.treasurehunter."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.treasurehunter"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 75f9 2bf0 e8???????? 8bd0 }
            // n = 4, score = 300
            //   75f9                 | jne                 0xfffffffb
            //   2bf0                 | sub                 esi, eax
            //   e8????????           |                     
            //   8bd0                 | mov                 edx, eax

        $sequence_1 = { 53 56 8b35???????? 8bd9 8b4d08 57 }
            // n = 6, score = 300
            //   53                   | push                ebx
            //   56                   | push                esi
            //   8b35????????         |                     
            //   8bd9                 | mov                 ebx, ecx
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   57                   | push                edi

        $sequence_2 = { 8bf8 e8???????? 68???????? 57 e8???????? }
            // n = 5, score = 300
            //   8bf8                 | mov                 edi, eax
            //   e8????????           |                     
            //   68????????           |                     
            //   57                   | push                edi
            //   e8????????           |                     

        $sequence_3 = { 8bd9 8b4d08 57 8955fc e8???????? 8bce 8bf8 }
            // n = 7, score = 300
            //   8bd9                 | mov                 ebx, ecx
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   57                   | push                edi
            //   8955fc               | mov                 dword ptr [ebp - 4], edx
            //   e8????????           |                     
            //   8bce                 | mov                 ecx, esi
            //   8bf8                 | mov                 edi, eax

        $sequence_4 = { 57 8bf9 8bca e8???????? 8b7508 }
            // n = 5, score = 300
            //   57                   | push                edi
            //   8bf9                 | mov                 edi, ecx
            //   8bca                 | mov                 ecx, edx
            //   e8????????           |                     
            //   8b7508               | mov                 esi, dword ptr [ebp + 8]

        $sequence_5 = { 56 50 8903 ff15???????? 8b4dfc }
            // n = 5, score = 300
            //   56                   | push                esi
            //   50                   | push                eax
            //   8903                 | mov                 dword ptr [ebx], eax
            //   ff15????????         |                     
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]

        $sequence_6 = { 7e0b 4a e8???????? 0fafc6 5e c3 }
            // n = 6, score = 300
            //   7e0b                 | jle                 0xd
            //   4a                   | dec                 edx
            //   e8????????           |                     
            //   0fafc6               | imul                eax, esi
            //   5e                   | pop                 esi
            //   c3                   | ret                 

        $sequence_7 = { e8???????? b9???????? a3???????? e8???????? 5f 5e a3???????? }
            // n = 7, score = 300
            //   e8????????           |                     
            //   b9????????           |                     
            //   a3????????           |                     
            //   e8????????           |                     
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   a3????????           |                     

    condition:
        7 of them and filesize < 229376
}