rule win_trickbot_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.trickbot."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.trickbot"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 83c002 eb0d 2500000080 f7d8 1bc0 83e007 40 }
            // n = 7, score = 4500
            //   83c002               | add                 eax, 2
            //   eb0d                 | jmp                 0xf
            //   2500000080           | and                 eax, 0x80000000
            //   f7d8                 | neg                 eax
            //   1bc0                 | sbb                 eax, eax
            //   83e007               | and                 eax, 7
            //   40                   | inc                 eax

        $sequence_1 = { 1bc0 83e020 83c020 eb36 }
            // n = 4, score = 4500
            //   1bc0                 | sbb                 eax, eax
            //   83e020               | and                 eax, 0x20
            //   83c020               | add                 eax, 0x20
            //   eb36                 | jmp                 0x38

        $sequence_2 = { eb36 2500000080 f7d8 1bc0 83e070 83c010 }
            // n = 6, score = 4500
            //   eb36                 | jmp                 0x38
            //   2500000080           | and                 eax, 0x80000000
            //   f7d8                 | neg                 eax
            //   1bc0                 | sbb                 eax, eax
            //   83e070               | and                 eax, 0x70
            //   83c010               | add                 eax, 0x10

        $sequence_3 = { f7d8 1bc0 83e002 83c002 eb0d }
            // n = 5, score = 4500
            //   f7d8                 | neg                 eax
            //   1bc0                 | sbb                 eax, eax
            //   83e002               | and                 eax, 2
            //   83c002               | add                 eax, 2
            //   eb0d                 | jmp                 0xf

        $sequence_4 = { 83e070 83c010 eb25 a900000040 7411 2500000080 }
            // n = 6, score = 4500
            //   83e070               | and                 eax, 0x70
            //   83c010               | add                 eax, 0x10
            //   eb25                 | jmp                 0x27
            //   a900000040           | test                eax, 0x40000000
            //   7411                 | je                  0x13
            //   2500000080           | and                 eax, 0x80000000

        $sequence_5 = { 7429 a900000040 7411 2500000080 f7d8 1bc0 83e020 }
            // n = 7, score = 4500
            //   7429                 | je                  0x2b
            //   a900000040           | test                eax, 0x40000000
            //   7411                 | je                  0x13
            //   2500000080           | and                 eax, 0x80000000
            //   f7d8                 | neg                 eax
            //   1bc0                 | sbb                 eax, eax
            //   83e020               | and                 eax, 0x20

        $sequence_6 = { 8b07 a900000020 7429 a900000040 }
            // n = 4, score = 4300
            //   8b07                 | mov                 eax, dword ptr [edi]
            //   a900000020           | test                eax, 0x20000000
            //   7429                 | je                  0x2b
            //   a900000040           | test                eax, 0x40000000

        $sequence_7 = { c705????????fdffffff c705????????feffffff c705????????ffffffff e8???????? }
            // n = 4, score = 3700
            //   c705????????fdffffff     |     
            //   c705????????feffffff     |     
            //   c705????????ffffffff     |     
            //   e8????????           |                     

        $sequence_8 = { 895df4 895dec 66c745f00005 895dfc }
            // n = 4, score = 3500
            //   895df4               | neg                 eax
            //   895dec               | je                  0x13
            //   66c745f00005         | and                 eax, 0x80000000
            //   895dfc               | neg                 eax

        $sequence_9 = { 33ff 57 6880000000 6a02 57 6a01 68000000c0 }
            // n = 7, score = 3400
            //   33ff                 | dec                 eax
            //   57                   | mov                 dword ptr [esp + 0x40], eax
            //   6880000000           | dec                 eax
            //   6a02                 | mov                 eax, dword ptr [ecx + 0x48]
            //   57                   | dec                 eax
            //   6a01                 | mov                 dword ptr [esp + 0x38], eax
            //   68000000c0           | dec                 eax

        $sequence_10 = { 41 83c028 3bce 7ce9 }
            // n = 4, score = 3000
            //   41                   | inc                 ecx
            //   83c028               | add                 eax, 0x28
            //   3bce                 | cmp                 ecx, esi
            //   7ce9                 | jl                  0xffffffeb

        $sequence_11 = { 488b01 4c8b4120 488b5118 488b4910 }
            // n = 4, score = 2800
            //   488b01               | dec                 eax
            //   4c8b4120             | mov                 dword ptr [esp + 0x30], eax
            //   488b5118             | dec                 eax
            //   488b4910             | mov                 eax, dword ptr [ecx + 0x38]

        $sequence_12 = { 53 6a03 53 6a01 6800010000 }
            // n = 5, score = 2800
            //   53                   | mov                 eax, dword ptr [ecx + 0x40]
            //   6a03                 | dec                 eax
            //   53                   | mov                 dword ptr [esp + 0x30], eax
            //   6a01                 | dec                 eax
            //   6800010000           | mov                 eax, dword ptr [ecx + 0x50]

        $sequence_13 = { 4889442428 488b4130 488b4910 4889442420 41ffd2 }
            // n = 5, score = 2800
            //   4889442428           | dec                 eax
            //   488b4130             | mov                 dword ptr [esp + 0x30], eax
            //   488b4910             | dec                 eax
            //   4889442420           | mov                 eax, dword ptr [ecx + 0x38]
            //   41ffd2               | dec                 eax

        $sequence_14 = { 488b01 488b5118 488b4910 ffd0 }
            // n = 4, score = 2800
            //   488b01               | dec                 eax
            //   488b5118             | mov                 eax, dword ptr [ecx + 0x48]
            //   488b4910             | dec                 esp
            //   ffd0                 | mov                 edx, dword ptr [ecx]

        $sequence_15 = { 4c8b4928 4c8b4120 488b5118 4889442438 488b4140 }
            // n = 5, score = 2800
            //   4c8b4928             | mov                 ecx, dword ptr [ecx + 0x28]
            //   4c8b4120             | dec                 esp
            //   488b5118             | mov                 eax, dword ptr [ecx + 0x20]
            //   4889442438           | dec                 eax
            //   488b4140             | mov                 edx, dword ptr [ecx + 0x18]

        $sequence_16 = { 488b4148 4c8b11 4c8b4928 4c8b4120 }
            // n = 4, score = 2800
            //   488b4148             | mov                 dword ptr [esp + 0x20], eax
            //   4c8b11               | inc                 ecx
            //   4c8b4928             | call                edx
            //   4c8b4120             | dec                 eax

        $sequence_17 = { 4889442430 488b4138 4889442428 488b4130 }
            // n = 4, score = 2800
            //   4889442430           | dec                 eax
            //   488b4138             | mov                 dword ptr [esp + 0x28], eax
            //   4889442428           | dec                 eax
            //   488b4130             | mov                 eax, dword ptr [ecx + 0x30]

        $sequence_18 = { 488b5118 4889442440 488b4148 4889442438 488b4140 }
            // n = 5, score = 2800
            //   488b5118             | mov                 edx, dword ptr [ecx + 0x18]
            //   4889442440           | dec                 eax
            //   488b4148             | mov                 dword ptr [esp + 0x40], eax
            //   4889442438           | dec                 eax
            //   488b4140             | mov                 eax, dword ptr [ecx + 0x48]

        $sequence_19 = { 4889442438 488b4140 4889442430 488b4138 }
            // n = 4, score = 2800
            //   4889442438           | dec                 eax
            //   488b4140             | mov                 dword ptr [esp + 0x38], eax
            //   4889442430           | dec                 eax
            //   488b4138             | mov                 eax, dword ptr [ecx + 0x40]

        $sequence_20 = { 6820bf0200 68905f0100 68905f0100 50 ff15???????? }
            // n = 5, score = 2000
            //   6820bf0200           | dec                 eax
            //   68905f0100           | mov                 dword ptr [esp + 0x38], eax
            //   68905f0100           | dec                 eax
            //   50                   | mov                 eax, dword ptr [ecx + 0x40]
            //   ff15????????         |                     

        $sequence_21 = { 2bc2 d1e8 03c2 c1e806 6bc05f }
            // n = 5, score = 2000
            //   2bc2                 | mov                 eax, dword ptr [ecx + 0x50]
            //   d1e8                 | dec                 esp
            //   03c2                 | mov                 edx, dword ptr [ecx]
            //   c1e806               | dec                 esp
            //   6bc05f               | mov                 ecx, dword ptr [ecx + 0x28]

        $sequence_22 = { 83780400 7404 8b4008 c3 }
            // n = 4, score = 2000
            //   83780400             | mov                 eax, dword ptr [ecx + 0x30]
            //   7404                 | dec                 eax
            //   8b4008               | mov                 ecx, dword ptr [ecx + 0x10]
            //   c3                   | dec                 eax

        $sequence_23 = { 51 68e9fd0000 50 e8???????? }
            // n = 4, score = 1800
            //   51                   | dec                 eax
            //   68e9fd0000           | mov                 eax, dword ptr [ecx + 0x48]
            //   50                   | dec                 eax
            //   e8????????           |                     

        $sequence_24 = { 6a40 6800300000 6a70 6a00 }
            // n = 4, score = 1800
            //   6a40                 | mov                 eax, dword ptr [ecx + 0x38]
            //   6800300000           | dec                 eax
            //   6a70                 | mov                 dword ptr [esp + 0x28], eax
            //   6a00                 | dec                 eax

        $sequence_25 = { 833800 751c 83781000 7516 }
            // n = 4, score = 1600
            //   833800               | mov                 eax, dword ptr [ecx + 0x50]
            //   751c                 | dec                 esp
            //   83781000             | mov                 edx, dword ptr [ecx]
            //   7516                 | dec                 esp

        $sequence_26 = { c3 6a01 ff15???????? 50 }
            // n = 4, score = 1500
            //   c3                   | ret                 
            //   6a01                 | push                1
            //   ff15????????         |                     
            //   50                   | push                eax

        $sequence_27 = { 8b01 59 03d0 52 }
            // n = 4, score = 1300
            //   8b01                 | mov                 edx, dword ptr [ecx + 0x18]
            //   59                   | dec                 eax
            //   03d0                 | mov                 dword ptr [esp + 0x38], eax
            //   52                   | dec                 eax

        $sequence_28 = { 85c0 7f0b e8???????? 8b05???????? }
            // n = 4, score = 1300
            //   85c0                 | mov                 dword ptr [esp + 0x20], eax
            //   7f0b                 | inc                 ecx
            //   e8????????           |                     
            //   8b05????????         |                     

        $sequence_29 = { 03d0 52 ebdc 89450c }
            // n = 4, score = 1300
            //   03d0                 | mov                 eax, dword ptr [ecx + 0x38]
            //   52                   | dec                 eax
            //   ebdc                 | mov                 dword ptr [esp + 0x28], eax
            //   89450c               | dec                 eax

        $sequence_30 = { 8bc1 66ad 85c0 741c }
            // n = 4, score = 1300
            //   8bc1                 | mov                 ecx, dword ptr [ecx + 0x28]
            //   66ad                 | dec                 esp
            //   85c0                 | mov                 eax, dword ptr [ecx + 0x20]
            //   741c                 | dec                 eax

        $sequence_31 = { e8???????? 83f801 7411 ba0a000000 }
            // n = 4, score = 1300
            //   e8????????           |                     
            //   83f801               | mov                 dword ptr [esp + 0x30], eax
            //   7411                 | dec                 eax
            //   ba0a000000           | mov                 eax, dword ptr [ecx + 0x38]

        $sequence_32 = { 85c0 741c 3bc1 7213 }
            // n = 4, score = 1200
            //   85c0                 | mov                 dword ptr [esp + 0x20], eax
            //   741c                 | dec                 eax
            //   3bc1                 | mov                 eax, dword ptr [ecx + 0x38]
            //   7213                 | dec                 eax

        $sequence_33 = { 7405 e8???????? ff15???????? 8bc3 }
            // n = 4, score = 1200
            //   7405                 | dec                 eax
            //   e8????????           |                     
            //   ff15????????         |                     
            //   8bc3                 | mov                 dword ptr [esp + 0x28], eax

        $sequence_34 = { c1e102 2bc1 8b00 894508 }
            // n = 4, score = 1200
            //   c1e102               | dec                 esp
            //   2bc1                 | mov                 eax, dword ptr [ecx + 0x20]
            //   8b00                 | dec                 eax
            //   894508               | mov                 edx, dword ptr [ecx + 0x18]

        $sequence_35 = { 50 8b450c ff4d0c ba28000000 }
            // n = 4, score = 1200
            //   50                   | mov                 ecx, dword ptr [ecx + 0x28]
            //   8b450c               | dec                 esp
            //   ff4d0c               | mov                 eax, dword ptr [ecx + 0x20]
            //   ba28000000           | dec                 eax

        $sequence_36 = { 895510 8b4a04 ff5508 8b5510 8b4a0c }
            // n = 5, score = 1100
            //   895510               | neg                 eax
            //   8b4a04               | sbb                 eax, eax
            //   ff5508               | sbb                 eax, eax
            //   8b5510               | and                 eax, 2
            //   8b4a0c               | add                 eax, 2

        $sequence_37 = { 2bc1 8b00 3bc7 72f2 }
            // n = 4, score = 1100
            //   2bc1                 | dec                 esp
            //   8b00                 | mov                 eax, dword ptr [ecx + 0x20]
            //   3bc7                 | dec                 eax
            //   72f2                 | mov                 edx, dword ptr [ecx + 0x18]

        $sequence_38 = { 8b4a04 ff5508 50 51 }
            // n = 4, score = 1100
            //   8b4a04               | mov                 dword ptr [esp + 0x38], eax
            //   ff5508               | dec                 eax
            //   50                   | mov                 eax, dword ptr [ecx + 0x40]
            //   51                   | dec                 eax

        $sequence_39 = { ff4d0c ba28000000 f7e2 8d9500040000 03d0 895510 }
            // n = 6, score = 1000
            //   ff4d0c               | dec                 eax
            //   ba28000000           | mov                 dword ptr [esp + 0x40], eax
            //   f7e2                 | dec                 eax
            //   8d9500040000         | mov                 eax, dword ptr [ecx + 0x48]
            //   03d0                 | dec                 eax
            //   895510               | mov                 dword ptr [esp + 0x38], eax

        $sequence_40 = { 740f 8bc8 e8???????? 8bc3 }
            // n = 4, score = 900
            //   740f                 | jmp                 0x36
            //   8bc8                 | test                eax, 0x20000000
            //   e8????????           |                     
            //   8bc3                 | je                  0x2b

        $sequence_41 = { 58 41 41 41 41 }
            // n = 5, score = 900
            //   58                   | dec                 eax
            //   41                   | mov                 edx, dword ptr [ecx + 0x18]
            //   41                   | dec                 eax
            //   41                   | mov                 dword ptr [esp + 0x40], eax
            //   41                   | dec                 eax

        $sequence_42 = { 8bcf e8???????? 8bf0 85ed }
            // n = 4, score = 900
            //   8bcf                 | mov                 dword ptr [esp + 0x30], eax
            //   e8????????           |                     
            //   8bf0                 | dec                 eax
            //   85ed                 | mov                 eax, dword ptr [ecx + 0x38]

        $sequence_43 = { 85c0 7911 8bc8 e8???????? bb11000000 }
            // n = 5, score = 900
            //   85c0                 | test                eax, 0x40000000
            //   7911                 | je                  0x20
            //   8bc8                 | and                 eax, 0x80000000
            //   e8????????           |                     
            //   bb11000000           | neg                 eax

        $sequence_44 = { e8???????? 85c0 7507 e8???????? eb5b }
            // n = 5, score = 900
            //   e8????????           |                     
            //   85c0                 | jmp                 0x27
            //   7507                 | test                eax, 0x40000000
            //   e8????????           |                     
            //   eb5b                 | je                  0x1a

        $sequence_45 = { 89742428 c744242000001f00 ff15???????? 85c0 7911 }
            // n = 5, score = 900
            //   89742428             | add                 eax, 0x20
            //   c744242000001f00     | jmp                 0x40
            //   ff15????????         |                     
            //   85c0                 | jmp                 0x38
            //   7911                 | and                 eax, 0x80000000

        $sequence_46 = { 7c22 3c39 7f1e 0fbec0 }
            // n = 4, score = 900
            //   7c22                 | test                eax, 0x40000000
            //   3c39                 | je                  0x1a
            //   7f1e                 | and                 eax, 0x80000000
            //   0fbec0               | add                 eax, 0x10

        $sequence_47 = { 3bd1 0f8293000000 038e8c000000 3bd1 0f8385000000 }
            // n = 5, score = 900
            //   3bd1                 | add                 eax, 0x20
            //   0f8293000000         | jmp                 0x38
            //   038e8c000000         | and                 eax, 0x80000000
            //   3bd1                 | neg                 eax
            //   0f8385000000         | add                 eax, 0x20

        $sequence_48 = { ffc1 663938 75f5 6603c9 }
            // n = 4, score = 900
            //   ffc1                 | and                 eax, 2
            //   663938               | add                 eax, 2
            //   75f5                 | jmp                 0x15
            //   6603c9               | and                 eax, 0x80000000

        $sequence_49 = { ff15???????? 8bf0 c1ee1f 83f601 }
            // n = 4, score = 900
            //   ff15????????         |                     
            //   8bf0                 | dec                 eax
            //   c1ee1f               | mov                 eax, dword ptr [ecx + 0x40]
            //   83f601               | dec                 eax

        $sequence_50 = { 85d2 745b 3bd1 0f8293000000 }
            // n = 4, score = 900
            //   85d2                 | neg                 eax
            //   745b                 | and                 eax, 0x70
            //   3bd1                 | add                 eax, 0x10
            //   0f8293000000         | jmp                 0x2d

        $sequence_51 = { 41 50 2bc1 8b00 }
            // n = 4, score = 800
            //   41                   | mov                 eax, dword ptr [ecx + 0x30]
            //   50                   | dec                 eax
            //   2bc1                 | mov                 eax, dword ptr [ecx + 0x50]
            //   8b00                 | dec                 esp

        $sequence_52 = { 8bc8 33c0 85c9 0f95c0 eb02 }
            // n = 5, score = 800
            //   8bc8                 | dec                 eax
            //   33c0                 | mov                 dword ptr [esp + 0x28], eax
            //   85c9                 | dec                 eax
            //   0f95c0               | mov                 eax, dword ptr [ecx + 0x30]
            //   eb02                 | dec                 eax

        $sequence_53 = { 894504 68f0ff0000 59 8bf7 8bd7 }
            // n = 5, score = 700
            //   894504               | sbb                 eax, eax
            //   68f0ff0000           | and                 eax, 0x20
            //   59                   | add                 eax, 2
            //   8bf7                 | jmp                 0xf
            //   8bd7                 | and                 eax, 0x80000000

        $sequence_54 = { 8bc7 e8???????? 85c0 0f849f000000 }
            // n = 4, score = 700
            //   8bc7                 | mov                 dword ptr [esp + 0x28], eax
            //   e8????????           |                     
            //   85c0                 | dec                 eax
            //   0f849f000000         | mov                 eax, dword ptr [ecx + 0x30]

        $sequence_55 = { 8bf7 8bd7 fc 8bc1 }
            // n = 4, score = 700
            //   8bf7                 | jmp                 0x38
            //   8bd7                 | and                 eax, 0x80000000
            //   fc                   | neg                 eax
            //   8bc1                 | sbb                 eax, eax

        $sequence_56 = { 59 50 e2fd 8bc7 }
            // n = 4, score = 700
            //   59                   | add                 eax, 0x10
            //   50                   | and                 eax, 2
            //   e2fd                 | add                 eax, 2
            //   8bc7                 | jmp                 0x12

        $sequence_57 = { 8dbf00500310 8bd6 897d08 3bc8 }
            // n = 4, score = 200
            //   8dbf00500310         | mov                 dword ptr [esp + 0x28], eax
            //   8bd6                 | dec                 eax
            //   897d08               | mov                 eax, dword ptr [ecx + 0x30]
            //   3bc8                 | dec                 eax

        $sequence_58 = { 6a00 ff15???????? 6a00 6a00 6a00 8d45dc }
            // n = 6, score = 200
            //   6a00                 | mov                 dword ptr [esp + 0x38], eax
            //   ff15????????         |                     
            //   6a00                 | dec                 eax
            //   6a00                 | mov                 eax, dword ptr [ecx + 0x40]
            //   6a00                 | dec                 eax
            //   8d45dc               | mov                 dword ptr [esp + 0x30], eax

        $sequence_59 = { 8b7d10 2bf9 53 50 }
            // n = 4, score = 200
            //   8b7d10               | mov                 ecx, dword ptr [ecx + 0x10]
            //   2bf9                 | dec                 eax
            //   53                   | mov                 dword ptr [esp + 0x20], eax
            //   50                   | dec                 eax

        $sequence_60 = { 83c001 8945d4 8b4dfc 51 8b55d4 }
            // n = 5, score = 100
            //   83c001               | mov                 dword ptr [esp + 0x28], eax
            //   8945d4               | dec                 eax
            //   8b4dfc               | mov                 eax, dword ptr [ecx + 0x30]
            //   51                   | dec                 eax
            //   8b55d4               | mov                 ecx, dword ptr [ecx + 0x10]

        $sequence_61 = { 8b4dd0 894dd8 837dd840 760b 8b55d8 }
            // n = 5, score = 100
            //   8b4dd0               | dec                 eax
            //   894dd8               | mov                 edx, dword ptr [ecx + 0x18]
            //   837dd840             | dec                 eax
            //   760b                 | mov                 dword ptr [esp + 0x38], eax
            //   8b55d8               | dec                 eax

        $sequence_62 = { 8d3c0e 2b75f8 33c7 2bd0 ff4dfc 75ba 8b4508 }
            // n = 7, score = 100
            //   8d3c0e               | neg                 eax
            //   2b75f8               | and                 eax, 0x20
            //   33c7                 | add                 eax, 0x20
            //   2bd0                 | jmp                 0x3b
            //   ff4dfc               | and                 eax, 0x80000000
            //   75ba                 | neg                 eax
            //   8b4508               | sbb                 eax, eax

        $sequence_63 = { 42 42 3b5508 7202 8bd6 83c104 }
            // n = 6, score = 100
            //   42                   | mov                 edx, dword ptr [ecx + 0x18]
            //   42                   | dec                 eax
            //   3b5508               | mov                 ecx, dword ptr [ecx + 0x10]
            //   7202                 | dec                 eax
            //   8bd6                 | mov                 eax, dword ptr [ecx + 0x50]
            //   83c104               | dec                 esp

        $sequence_64 = { bf31e7bf31 e7bf 31e7 bf31e7bf31 e7bf }
            // n = 5, score = 100
            //   bf31e7bf31           | add                 eax, 2
            //   e7bf                 | jmp                 0x15
            //   31e7                 | and                 eax, 0x80000000
            //   bf31e7bf31           | neg                 eax
            //   e7bf                 | test                eax, 0x20000000

        $sequence_65 = { 8b01 3302 52 8bd0 51 03cf 51 }
            // n = 7, score = 100
            //   8b01                 | mov                 ecx, dword ptr [ecx + 0x28]
            //   3302                 | dec                 esp
            //   52                   | mov                 eax, dword ptr [ecx + 0x20]
            //   8bd0                 | dec                 eax
            //   51                   | mov                 edx, dword ptr [ecx + 0x18]
            //   03cf                 | dec                 eax
            //   51                   | mov                 dword ptr [esp + 0x38], eax

        $sequence_66 = { 56 57 33f6 bf???????? 833cf594f3000101 }
            // n = 5, score = 100
            //   56                   | add                 eax, 2
            //   57                   | jmp                 0xf
            //   33f6                 | and                 eax, 0x80000000
            //   bf????????           |                     
            //   833cf594f3000101     | neg                 eax

        $sequence_67 = { 8945cc ebee 8b45d8 48 50 8b45cc 40 }
            // n = 7, score = 100
            //   8945cc               | dec                 eax
            //   ebee                 | mov                 eax, dword ptr [ecx + 0x38]
            //   8b45d8               | dec                 eax
            //   48                   | mov                 eax, dword ptr [ecx + 0x48]
            //   50                   | dec                 esp
            //   8b45cc               | mov                 edx, dword ptr [ecx]
            //   40                   | dec                 esp

        $sequence_68 = { ff75f8 ff15???????? 8945fc 837dfc00 750d }
            // n = 5, score = 100
            //   ff75f8               | mov                 edx, dword ptr [ecx]
            //   ff15????????         |                     
            //   8945fc               | dec                 esp
            //   837dfc00             | mov                 ecx, dword ptr [ecx + 0x28]
            //   750d                 | dec                 esp

        $sequence_69 = { 6a00 6858020000 ff15???????? 837dfc00 74ce }
            // n = 5, score = 100
            //   6a00                 | mov                 eax, dword ptr [ecx + 0x20]
            //   6858020000           | dec                 eax
            //   ff15????????         |                     
            //   837dfc00             | mov                 dword ptr [esp + 0x40], eax
            //   74ce                 | dec                 eax

        $sequence_70 = { e8???????? 03c6 50 e8???????? 8b7710 83c40c 2bf3 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   03c6                 | neg                 eax
            //   50                   | sbb                 eax, eax
            //   e8????????           |                     
            //   8b7710               | and                 eax, 0x80000000
            //   83c40c               | neg                 eax
            //   2bf3                 | sbb                 eax, eax

        $sequence_71 = { 55 8bec 83ec34 c745cc00000000 6a00 685b020000 6a00 }
            // n = 7, score = 100
            //   55                   | mov                 eax, dword ptr [ecx + 0x40]
            //   8bec                 | dec                 eax
            //   83ec34               | mov                 dword ptr [esp + 0x30], eax
            //   c745cc00000000       | dec                 eax
            //   6a00                 | mov                 eax, dword ptr [ecx]
            //   685b020000           | dec                 esp
            //   6a00                 | mov                 eax, dword ptr [ecx + 0x20]

        $sequence_72 = { 42 42 8b01 83c202 33c3 890439 }
            // n = 6, score = 100
            //   42                   | dec                 eax
            //   42                   | mov                 ecx, dword ptr [ecx + 0x10]
            //   8b01                 | dec                 eax
            //   83c202               | mov                 dword ptr [esp + 0x20], eax
            //   33c3                 | inc                 ecx
            //   890439               | call                edx

        $sequence_73 = { 8945e4 3bc6 7305 8b750c }
            // n = 4, score = 100
            //   8945e4               | je                  0x2b
            //   3bc6                 | test                eax, 0x40000000
            //   7305                 | je                  0x1a
            //   8b750c               | and                 eax, 0x80000000

        $sequence_74 = { 9c 000f 9c 000f 9c f7a053f7a053 }
            // n = 6, score = 100
            //   9c                   | je                  0x1a
            //   000f                 | sbb                 eax, eax
            //   9c                   | and                 eax, 2
            //   000f                 | add                 eax, 2
            //   9c                   | jmp                 0x15
            //   f7a053f7a053         | and                 eax, 0x80000000

        $sequence_75 = { 8bec e8???????? 8b4d08 e8???????? 5d c20400 }
            // n = 6, score = 100
            //   8bec                 | and                 eax, 0x70
            //   e8????????           |                     
            //   8b4d08               | add                 eax, 0x10
            //   e8????????           |                     
            //   5d                   | jmp                 0x27
            //   c20400               | test                eax, 0x40000000

        $sequence_76 = { c705????????ad380001 8935???????? a3???????? ff15???????? a3???????? 83f8ff 0f84c1000000 }
            // n = 7, score = 100
            //   c705????????ad380001     |     
            //   8935????????         |                     
            //   a3????????           |                     
            //   ff15????????         |                     
            //   a3????????           |                     
            //   83f8ff               | and                 eax, 0x70
            //   0f84c1000000         | add                 eax, 0x10

    condition:
        7 of them and filesize < 712704
}