rule win_turnedup_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.turnedup."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.turnedup"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b4dfc 5f 5e 33cd 895004 5b }
            // n = 6, score = 400
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   33cd                 | xor                 ecx, ebp
            //   895004               | mov                 dword ptr [eax + 4], edx
            //   5b                   | pop                 ebx

        $sequence_1 = { 7706 891d???????? ff0d???????? 7506 891d???????? 6a01 }
            // n = 6, score = 400
            //   7706                 | ja                  8
            //   891d????????         |                     
            //   ff0d????????         |                     
            //   7506                 | jne                 8
            //   891d????????         |                     
            //   6a01                 | push                1

        $sequence_2 = { 8b07 8b4004 03c7 33d2 8955dc c645e001 8b4838 }
            // n = 7, score = 400
            //   8b07                 | mov                 eax, dword ptr [edi]
            //   8b4004               | mov                 eax, dword ptr [eax + 4]
            //   03c7                 | add                 eax, edi
            //   33d2                 | xor                 edx, edx
            //   8955dc               | mov                 dword ptr [ebp - 0x24], edx
            //   c645e001             | mov                 byte ptr [ebp - 0x20], 1
            //   8b4838               | mov                 ecx, dword ptr [eax + 0x38]

        $sequence_3 = { 895dfc 752b 6a00 8d4df8 e8???????? 833d????????00 }
            // n = 6, score = 400
            //   895dfc               | mov                 dword ptr [ebp - 4], ebx
            //   752b                 | jne                 0x2d
            //   6a00                 | push                0
            //   8d4df8               | lea                 ecx, [ebp - 8]
            //   e8????????           |                     
            //   833d????????00       |                     

        $sequence_4 = { 68???????? 8819 e8???????? 8d7dac }
            // n = 4, score = 400
            //   68????????           |                     
            //   8819                 | mov                 byte ptr [ecx], bl
            //   e8????????           |                     
            //   8d7dac               | lea                 edi, [ebp - 0x54]

        $sequence_5 = { c746180f000000 894614 56 884604 e8???????? 83c404 }
            // n = 6, score = 400
            //   c746180f000000       | mov                 dword ptr [esi + 0x18], 0xf
            //   894614               | mov                 dword ptr [esi + 0x14], eax
            //   56                   | push                esi
            //   884604               | mov                 byte ptr [esi + 4], al
            //   e8????????           |                     
            //   83c404               | add                 esp, 4

        $sequence_6 = { 830801 8b4dd8 394dc0 741e 837dd000 }
            // n = 5, score = 400
            //   830801               | or                  dword ptr [eax], 1
            //   8b4dd8               | mov                 ecx, dword ptr [ebp - 0x28]
            //   394dc0               | cmp                 dword ptr [ebp - 0x40], ecx
            //   741e                 | je                  0x20
            //   837dd000             | cmp                 dword ptr [ebp - 0x30], 0

        $sequence_7 = { 8945bc 8975b0 8b55f4 8b45e0 83fa10 7303 8d45e0 }
            // n = 7, score = 400
            //   8945bc               | mov                 dword ptr [ebp - 0x44], eax
            //   8975b0               | mov                 dword ptr [ebp - 0x50], esi
            //   8b55f4               | mov                 edx, dword ptr [ebp - 0xc]
            //   8b45e0               | mov                 eax, dword ptr [ebp - 0x20]
            //   83fa10               | cmp                 edx, 0x10
            //   7303                 | jae                 5
            //   8d45e0               | lea                 eax, [ebp - 0x20]

        $sequence_8 = { 8ad5 c0ea04 80e203 02d0 8a45f6 8855f8 8ad0 }
            // n = 7, score = 400
            //   8ad5                 | mov                 dl, ch
            //   c0ea04               | shr                 dl, 4
            //   80e203               | and                 dl, 3
            //   02d0                 | add                 dl, al
            //   8a45f6               | mov                 al, byte ptr [ebp - 0xa]
            //   8855f8               | mov                 byte ptr [ebp - 8], dl
            //   8ad0                 | mov                 dl, al

        $sequence_9 = { 8b45bc 8a11 8810 8b0b 40 }
            // n = 5, score = 400
            //   8b45bc               | mov                 eax, dword ptr [ebp - 0x44]
            //   8a11                 | mov                 dl, byte ptr [ecx]
            //   8810                 | mov                 byte ptr [eax], dl
            //   8b0b                 | mov                 ecx, dword ptr [ebx]
            //   40                   | inc                 eax

    condition:
        7 of them and filesize < 892928
}