rule win_unidentified_003_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.unidentified_003."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.unidentified_003"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8945ec a1???????? 0fb7506f 0fb7406d c1e210 0bd0 }
            // n = 6, score = 100
            //   8945ec               | mov                 dword ptr [ebp - 0x14], eax
            //   a1????????           |                     
            //   0fb7506f             | movzx               edx, word ptr [eax + 0x6f]
            //   0fb7406d             | movzx               eax, word ptr [eax + 0x6d]
            //   c1e210               | shl                 edx, 0x10
            //   0bd0                 | or                  edx, eax

        $sequence_1 = { c68564ffffff01 33c0 8a88c2100900 888c0566ffffff 40 }
            // n = 5, score = 100
            //   c68564ffffff01       | mov                 byte ptr [ebp - 0x9c], 1
            //   33c0                 | xor                 eax, eax
            //   8a88c2100900         | mov                 cl, byte ptr [eax + 0x910c2]
            //   888c0566ffffff       | mov                 byte ptr [ebp + eax - 0x9a], cl
            //   40                   | inc                 eax

        $sequence_2 = { e8???????? 83c40c 8b07 5d c3 55 8bec }
            // n = 7, score = 100
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   8b07                 | mov                 eax, dword ptr [edi]
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp

        $sequence_3 = { a1???????? ff75f0 ff7028 ff15???????? eb0a }
            // n = 5, score = 100
            //   a1????????           |                     
            //   ff75f0               | push                dword ptr [ebp - 0x10]
            //   ff7028               | push                dword ptr [eax + 0x28]
            //   ff15????????         |                     
            //   eb0a                 | jmp                 0xc

        $sequence_4 = { 395da0 740f ff75a4 ff15???????? 895da0 }
            // n = 5, score = 100
            //   395da0               | cmp                 dword ptr [ebp - 0x60], ebx
            //   740f                 | je                  0x11
            //   ff75a4               | push                dword ptr [ebp - 0x5c]
            //   ff15????????         |                     
            //   895da0               | mov                 dword ptr [ebp - 0x60], ebx

        $sequence_5 = { 3bfe 7502 8bfb 39742410 }
            // n = 4, score = 100
            //   3bfe                 | cmp                 edi, esi
            //   7502                 | jne                 4
            //   8bfb                 | mov                 edi, ebx
            //   39742410             | cmp                 dword ptr [esp + 0x10], esi

        $sequence_6 = { 59 85c0 7417 47 81c614010000 3b3d???????? 72c8 }
            // n = 7, score = 100
            //   59                   | pop                 ecx
            //   85c0                 | test                eax, eax
            //   7417                 | je                  0x19
            //   47                   | inc                 edi
            //   81c614010000         | add                 esi, 0x114
            //   3b3d????????         |                     
            //   72c8                 | jb                  0xffffffca

        $sequence_7 = { 8bec 81ec20080000 53 56 57 8d85e0fdffff 8945ec }
            // n = 7, score = 100
            //   8bec                 | mov                 ebp, esp
            //   81ec20080000         | sub                 esp, 0x820
            //   53                   | push                ebx
            //   56                   | push                esi
            //   57                   | push                edi
            //   8d85e0fdffff         | lea                 eax, [ebp - 0x220]
            //   8945ec               | mov                 dword ptr [ebp - 0x14], eax

        $sequence_8 = { 7575 385d6e 743b 39bd5cffffff 750a c705????????07000000 399d5cffffff }
            // n = 7, score = 100
            //   7575                 | jne                 0x77
            //   385d6e               | cmp                 byte ptr [ebp + 0x6e], bl
            //   743b                 | je                  0x3d
            //   39bd5cffffff         | cmp                 dword ptr [ebp - 0xa4], edi
            //   750a                 | jne                 0xc
            //   c705????????07000000     |     
            //   399d5cffffff         | cmp                 dword ptr [ebp - 0xa4], ebx

        $sequence_9 = { ff15???????? 85c0 0f88b4010000 8b45e4 3bc3 0f84a9010000 8b08 }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   0f88b4010000         | js                  0x1ba
            //   8b45e4               | mov                 eax, dword ptr [ebp - 0x1c]
            //   3bc3                 | cmp                 eax, ebx
            //   0f84a9010000         | je                  0x1af
            //   8b08                 | mov                 ecx, dword ptr [eax]

    condition:
        7 of them and filesize < 57344
}