rule win_unidentified_037_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.unidentified_037."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.unidentified_037"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 85c0 a3???????? 740c 8b4c2408 8b542404 51 52 }
            // n = 7, score = 100
            //   85c0                 | test                eax, eax
            //   a3????????           |                     
            //   740c                 | je                  0xe
            //   8b4c2408             | mov                 ecx, dword ptr [esp + 8]
            //   8b542404             | mov                 edx, dword ptr [esp + 4]
            //   51                   | push                ecx
            //   52                   | push                edx

        $sequence_1 = { 33c0 33d2 33ff 8a0c1f 80f920 7405 80f930 }
            // n = 7, score = 100
            //   33c0                 | xor                 eax, eax
            //   33d2                 | xor                 edx, edx
            //   33ff                 | xor                 edi, edi
            //   8a0c1f               | mov                 cl, byte ptr [edi + ebx]
            //   80f920               | cmp                 cl, 0x20
            //   7405                 | je                  7
            //   80f930               | cmp                 cl, 0x30

        $sequence_2 = { 7506 8b15???????? 8d8424b8040000 52 50 ff15???????? }
            // n = 6, score = 100
            //   7506                 | jne                 8
            //   8b15????????         |                     
            //   8d8424b8040000       | lea                 eax, [esp + 0x4b8]
            //   52                   | push                edx
            //   50                   | push                eax
            //   ff15????????         |                     

        $sequence_3 = { 8a56ff 83e23f 41 4d 8a82d00c0110 8841ff 759c }
            // n = 7, score = 100
            //   8a56ff               | mov                 dl, byte ptr [esi - 1]
            //   83e23f               | and                 edx, 0x3f
            //   41                   | inc                 ecx
            //   4d                   | dec                 ebp
            //   8a82d00c0110         | mov                 al, byte ptr [edx + 0x10010cd0]
            //   8841ff               | mov                 byte ptr [ecx - 1], al
            //   759c                 | jne                 0xffffff9e

        $sequence_4 = { 8b4d20 8b5500 8b4504 8bb424f0040000 51 52 50 }
            // n = 7, score = 100
            //   8b4d20               | mov                 ecx, dword ptr [ebp + 0x20]
            //   8b5500               | mov                 edx, dword ptr [ebp]
            //   8b4504               | mov                 eax, dword ptr [ebp + 4]
            //   8bb424f0040000       | mov                 esi, dword ptr [esp + 0x4f0]
            //   51                   | push                ecx
            //   52                   | push                edx
            //   50                   | push                eax

        $sequence_5 = { ff15???????? 84c0 742d 8b4608 8b5604 8d8dccfcffff }
            // n = 6, score = 100
            //   ff15????????         |                     
            //   84c0                 | test                al, al
            //   742d                 | je                  0x2f
            //   8b4608               | mov                 eax, dword ptr [esi + 8]
            //   8b5604               | mov                 edx, dword ptr [esi + 4]
            //   8d8dccfcffff         | lea                 ecx, [ebp - 0x334]

        $sequence_6 = { 8841ff 759c 5d eb04 8b742410 85ff 7667 }
            // n = 7, score = 100
            //   8841ff               | mov                 byte ptr [ecx - 1], al
            //   759c                 | jne                 0xffffff9e
            //   5d                   | pop                 ebp
            //   eb04                 | jmp                 6
            //   8b742410             | mov                 esi, dword ptr [esp + 0x10]
            //   85ff                 | test                edi, edi
            //   7667                 | jbe                 0x69

        $sequence_7 = { 743e 80f920 7439 80f930 7c0d 80f937 7f08 }
            // n = 7, score = 100
            //   743e                 | je                  0x40
            //   80f920               | cmp                 cl, 0x20
            //   7439                 | je                  0x3b
            //   80f930               | cmp                 cl, 0x30
            //   7c0d                 | jl                  0xf
            //   80f937               | cmp                 cl, 0x37
            //   7f08                 | jg                  0xa

        $sequence_8 = { 8b5c2408 8b4314 83f8ff 0f84b1000000 c1e005 8bd0 a1???????? }
            // n = 7, score = 100
            //   8b5c2408             | mov                 ebx, dword ptr [esp + 8]
            //   8b4314               | mov                 eax, dword ptr [ebx + 0x14]
            //   83f8ff               | cmp                 eax, -1
            //   0f84b1000000         | je                  0xb7
            //   c1e005               | shl                 eax, 5
            //   8bd0                 | mov                 edx, eax
            //   a1????????           |                     

        $sequence_9 = { 5e 8b8c241c100000 64890d00000000 81c428100000 c3 83c1fe }
            // n = 6, score = 100
            //   5e                   | pop                 esi
            //   8b8c241c100000       | mov                 ecx, dword ptr [esp + 0x101c]
            //   64890d00000000       | mov                 dword ptr fs:[0], ecx
            //   81c428100000         | add                 esp, 0x1028
            //   c3                   | ret                 
            //   83c1fe               | add                 ecx, -2

    condition:
        7 of them and filesize < 167936
}