rule win_unidentified_042_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.unidentified_042."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.unidentified_042"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 85c0 754f 6a02 53 56 8d8d9cfeffff 57 }
            // n = 7, score = 100
            //   85c0                 | test                eax, eax
            //   754f                 | jne                 0x51
            //   6a02                 | push                2
            //   53                   | push                ebx
            //   56                   | push                esi
            //   8d8d9cfeffff         | lea                 ecx, [ebp - 0x164]
            //   57                   | push                edi

        $sequence_1 = { 56 8d8d68e1ffff 51 8d9554f7ffff 52 89b550f7ffff }
            // n = 6, score = 100
            //   56                   | push                esi
            //   8d8d68e1ffff         | lea                 ecx, [ebp - 0x1e98]
            //   51                   | push                ecx
            //   8d9554f7ffff         | lea                 edx, [ebp - 0x8ac]
            //   52                   | push                edx
            //   89b550f7ffff         | mov                 dword ptr [ebp - 0x8b0], esi

        $sequence_2 = { 5b 85c0 78dd 8b45fc 8b55f8 0fb64c3801 4a }
            // n = 7, score = 100
            //   5b                   | pop                 ebx
            //   85c0                 | test                eax, eax
            //   78dd                 | js                  0xffffffdf
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   8b55f8               | mov                 edx, dword ptr [ebp - 8]
            //   0fb64c3801           | movzx               ecx, byte ptr [eax + edi + 1]
            //   4a                   | dec                 edx

        $sequence_3 = { 8b4db8 895640 8b9518fdffff 895620 8b9520fdffff 894e44 8b8d1cfdffff }
            // n = 7, score = 100
            //   8b4db8               | mov                 ecx, dword ptr [ebp - 0x48]
            //   895640               | mov                 dword ptr [esi + 0x40], edx
            //   8b9518fdffff         | mov                 edx, dword ptr [ebp - 0x2e8]
            //   895620               | mov                 dword ptr [esi + 0x20], edx
            //   8b9520fdffff         | mov                 edx, dword ptr [ebp - 0x2e0]
            //   894e44               | mov                 dword ptr [esi + 0x44], ecx
            //   8b8d1cfdffff         | mov                 ecx, dword ptr [ebp - 0x2e4]

        $sequence_4 = { 8d8580cbffff 50 6a00 ff15???????? 85c0 7527 8b1d???????? }
            // n = 7, score = 100
            //   8d8580cbffff         | lea                 eax, [ebp - 0x3480]
            //   50                   | push                eax
            //   6a00                 | push                0
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7527                 | jne                 0x29
            //   8b1d????????         |                     

        $sequence_5 = { 5e 8bc7 5f 5d c3 8b7514 85f6 }
            // n = 7, score = 100
            //   5e                   | pop                 esi
            //   8bc7                 | mov                 eax, edi
            //   5f                   | pop                 edi
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   8b7514               | mov                 esi, dword ptr [ebp + 0x14]
            //   85f6                 | test                esi, esi

        $sequence_6 = { 8bc3 2bc2 8d0c91 2bf0 42 8d3c87 3bf2 }
            // n = 7, score = 100
            //   8bc3                 | mov                 eax, ebx
            //   2bc2                 | sub                 eax, edx
            //   8d0c91               | lea                 ecx, [ecx + edx*4]
            //   2bf0                 | sub                 esi, eax
            //   42                   | inc                 edx
            //   8d3c87               | lea                 edi, [edi + eax*4]
            //   3bf2                 | cmp                 esi, edx

        $sequence_7 = { 85db 0f85af000000 8d45ac 8bf0 8d5d9c 50 }
            // n = 6, score = 100
            //   85db                 | test                ebx, ebx
            //   0f85af000000         | jne                 0xb5
            //   8d45ac               | lea                 eax, [ebp - 0x54]
            //   8bf0                 | mov                 esi, eax
            //   8d5d9c               | lea                 ebx, [ebp - 0x64]
            //   50                   | push                eax

        $sequence_8 = { 8d4df8 51 8d5df4 e8???????? 83c408 85c0 780d }
            // n = 7, score = 100
            //   8d4df8               | lea                 ecx, [ebp - 8]
            //   51                   | push                ecx
            //   8d5df4               | lea                 ebx, [ebp - 0xc]
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   85c0                 | test                eax, eax
            //   780d                 | js                  0xf

        $sequence_9 = { 52 50 8d4b70 e8???????? 83c408 85c0 0f850b020000 }
            // n = 7, score = 100
            //   52                   | push                edx
            //   50                   | push                eax
            //   8d4b70               | lea                 ecx, [ebx + 0x70]
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   85c0                 | test                eax, eax
            //   0f850b020000         | jne                 0x211

    condition:
        7 of them and filesize < 516096
}