rule win_unidentified_045_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.unidentified_045."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.unidentified_045"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 50 e8???????? 83c40c 68???????? 68???????? 68???????? e8???????? }
            // n = 7, score = 100
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   68????????           |                     
            //   68????????           |                     
            //   68????????           |                     
            //   e8????????           |                     

        $sequence_1 = { 8930 8935???????? eb2b 837d0c02 7528 8b35???????? }
            // n = 6, score = 100
            //   8930                 | mov                 dword ptr [eax], esi
            //   8935????????         |                     
            //   eb2b                 | jmp                 0x2d
            //   837d0c02             | cmp                 dword ptr [ebp + 0xc], 2
            //   7528                 | jne                 0x2a
            //   8b35????????         |                     

        $sequence_2 = { 8bc7 eb5c 33f6 85f6 7609 }
            // n = 5, score = 100
            //   8bc7                 | mov                 eax, edi
            //   eb5c                 | jmp                 0x5e
            //   33f6                 | xor                 esi, esi
            //   85f6                 | test                esi, esi
            //   7609                 | jbe                 0xb

        $sequence_3 = { 6804010000 8d44244c 57 50 e8???????? 8b35???????? }
            // n = 6, score = 100
            //   6804010000           | push                0x104
            //   8d44244c             | lea                 eax, [esp + 0x4c]
            //   57                   | push                edi
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b35????????         |                     

        $sequence_4 = { ff15???????? 33f6 56 56 6a02 56 56 }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   33f6                 | xor                 esi, esi
            //   56                   | push                esi
            //   56                   | push                esi
            //   6a02                 | push                2
            //   56                   | push                esi
            //   56                   | push                esi

        $sequence_5 = { 6a01 56 56 ff7508 897dac 56 }
            // n = 6, score = 100
            //   6a01                 | push                1
            //   56                   | push                esi
            //   56                   | push                esi
            //   ff7508               | push                dword ptr [ebp + 8]
            //   897dac               | mov                 dword ptr [ebp - 0x54], edi
            //   56                   | push                esi

        $sequence_6 = { 3345fc 5e c9 c3 803d????????00 }
            // n = 5, score = 100
            //   3345fc               | xor                 eax, dword ptr [ebp - 4]
            //   5e                   | pop                 esi
            //   c9                   | leave               
            //   c3                   | ret                 
            //   803d????????00       |                     

        $sequence_7 = { 6a0c 50 57 8975f4 }
            // n = 4, score = 100
            //   6a0c                 | push                0xc
            //   50                   | push                eax
            //   57                   | push                edi
            //   8975f4               | mov                 dword ptr [ebp - 0xc], esi

    condition:
        7 of them and filesize < 73728
}