rule win_unidentified_071_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.unidentified_071."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.unidentified_071"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? ff35???????? a3???????? a1???????? 0faf05???????? a3???????? e8???????? }
            // n = 7, score = 400
            //   e8????????           |                     
            //   ff35????????         |                     
            //   a3????????           |                     
            //   a1????????           |                     
            //   0faf05????????       |                     
            //   a3????????           |                     
            //   e8????????           |                     

        $sequence_1 = { 6a20 8901 83c8ff 5a 895104 894108 d1e8 }
            // n = 7, score = 400
            //   6a20                 | push                0x20
            //   8901                 | mov                 dword ptr [ecx], eax
            //   83c8ff               | or                  eax, 0xffffffff
            //   5a                   | pop                 edx
            //   895104               | mov                 dword ptr [ecx + 4], edx
            //   894108               | mov                 dword ptr [ecx + 8], eax
            //   d1e8                 | shr                 eax, 1

        $sequence_2 = { 8bd9 8b4b10 2bc1 894c2404 3bc2 0f82a7000000 8b4314 }
            // n = 7, score = 400
            //   8bd9                 | mov                 ebx, ecx
            //   8b4b10               | mov                 ecx, dword ptr [ebx + 0x10]
            //   2bc1                 | sub                 eax, ecx
            //   894c2404             | mov                 dword ptr [esp + 4], ecx
            //   3bc2                 | cmp                 eax, edx
            //   0f82a7000000         | jb                  0xad
            //   8b4314               | mov                 eax, dword ptr [ebx + 0x14]

        $sequence_3 = { 6a10 5a 0f44ca 51 50 ff15???????? }
            // n = 6, score = 400
            //   6a10                 | push                0x10
            //   5a                   | pop                 edx
            //   0f44ca               | cmove               ecx, edx
            //   51                   | push                ecx
            //   50                   | push                eax
            //   ff15????????         |                     

        $sequence_4 = { c3 33c0 c3 8b5108 b8ffffff0f }
            // n = 5, score = 400
            //   c3                   | ret                 
            //   33c0                 | xor                 eax, eax
            //   c3                   | ret                 
            //   8b5108               | mov                 edx, dword ptr [ecx + 8]
            //   b8ffffff0f           | mov                 eax, 0xfffffff

        $sequence_5 = { ff36 e8???????? 8b0e 8b4608 2bc1 894df8 6a18 }
            // n = 7, score = 400
            //   ff36                 | push                dword ptr [esi]
            //   e8????????           |                     
            //   8b0e                 | mov                 ecx, dword ptr [esi]
            //   8b4608               | mov                 eax, dword ptr [esi + 8]
            //   2bc1                 | sub                 eax, ecx
            //   894df8               | mov                 dword ptr [ebp - 8], ecx
            //   6a18                 | push                0x18

        $sequence_6 = { 8b4c2420 8d346d00000000 8b542428 56 ff742428 8d044a }
            // n = 6, score = 400
            //   8b4c2420             | mov                 ecx, dword ptr [esp + 0x20]
            //   8d346d00000000       | lea                 esi, [ebp*2]
            //   8b542428             | mov                 edx, dword ptr [esp + 0x28]
            //   56                   | push                esi
            //   ff742428             | push                dword ptr [esp + 0x28]
            //   8d044a               | lea                 eax, [edx + ecx*2]

        $sequence_7 = { c20400 55 8bec 8b450c ff7510 2b4508 c1f804 }
            // n = 7, score = 400
            //   c20400               | ret                 4
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   8b450c               | mov                 eax, dword ptr [ebp + 0xc]
            //   ff7510               | push                dword ptr [ebp + 0x10]
            //   2b4508               | sub                 eax, dword ptr [ebp + 8]
            //   c1f804               | sar                 eax, 4

        $sequence_8 = { 0f8290000000 8b4314 55 56 57 8d3c11 }
            // n = 6, score = 400
            //   0f8290000000         | jb                  0x96
            //   8b4314               | mov                 eax, dword ptr [ebx + 0x14]
            //   55                   | push                ebp
            //   56                   | push                esi
            //   57                   | push                edi
            //   8d3c11               | lea                 edi, [ecx + edx]

        $sequence_9 = { 85c0 8b4314 740d 25ffffff82 0d00000002 894314 0fb64b01 }
            // n = 7, score = 400
            //   85c0                 | test                eax, eax
            //   8b4314               | mov                 eax, dword ptr [ebx + 0x14]
            //   740d                 | je                  0xf
            //   25ffffff82           | and                 eax, 0x82ffffff
            //   0d00000002           | or                  eax, 0x2000000
            //   894314               | mov                 dword ptr [ebx + 0x14], eax
            //   0fb64b01             | movzx               ecx, byte ptr [ebx + 1]

    condition:
        7 of them and filesize < 1220608
}