rule win_unidentified_077_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.unidentified_077."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.unidentified_077"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 89442420 488bcf ff15???????? 85c0 }
            // n = 4, score = 600
            //   89442420             | lea                 edx, [0xdde2]
            //   488bcf               | mov                 ecx, 7
            //   ff15????????         |                     
            //   85c0                 | dec                 esp

        $sequence_1 = { 488bcf ff15???????? 498bce ff15???????? 488bce }
            // n = 5, score = 600
            //   488bcf               | xor                 edx, edx
            //   ff15????????         |                     
            //   498bce               | inc                 ebp
            //   ff15????????         |                     
            //   488bce               | xor                 esi, esi

        $sequence_2 = { 488bb424f00d0000 488b8dd00c0000 4833cc e8???????? 4881c4f80d0000 }
            // n = 5, score = 600
            //   488bb424f00d0000     | dec                 ecx
            //   488b8dd00c0000       | add                 ecx, esp
            //   4833cc               | test                eax, eax
            //   e8????????           |                     
            //   4881c4f80d0000       | je                  0x370

        $sequence_3 = { 0f8559ffffff 488bcf ff15???????? 498bce ff15???????? 488bce ff15???????? }
            // n = 7, score = 600
            //   0f8559ffffff         | dec                 edx
            //   488bcf               | mov                 ecx, dword ptr [ecx + esi + 0x28]
            //   ff15????????         |                     
            //   498bce               | test                eax, eax
            //   ff15????????         |                     
            //   488bce               | dec                 eax
            //   ff15????????         |                     

        $sequence_4 = { 498784f180bf0100 eb25 488bc3 498784f180bf0100 4885c0 }
            // n = 5, score = 600
            //   498784f180bf0100     | dec                 eax
            //   eb25                 | test                edi, edi
            //   488bc3               | dec                 eax
            //   498784f180bf0100     | lea                 ecx, [0xc8d2]
            //   4885c0               | dec                 eax

        $sequence_5 = { 4d8be1 498be8 4c8bea 4b8b8cf7e0c70100 4c8b15???????? }
            // n = 5, score = 600
            //   4d8be1               | lea                 eax, [0x7623]
            //   498be8               | dec                 ecx
            //   4c8bea               | mov                 ecx, esi
            //   4b8b8cf7e0c70100     | inc                 ebp
            //   4c8b15????????       |                     

        $sequence_6 = { 33db 33ff 4c8bea 4c8be1 4883fa40 7312 }
            // n = 6, score = 600
            //   33db                 | lea                 ecx, [0xffffcbd3]
            //   33ff                 | dec                 esp
            //   4c8bea               | mov                 ebp, edx
            //   4c8be1               | dec                 esp
            //   4883fa40             | lea                 edi, [0x112d7]
            //   7312                 | dec                 ecx

        $sequence_7 = { f30f6f0418 660fefc1 f30f7f0418 8d4210 83c220 f30f6f0418 660fefc1 }
            // n = 7, score = 600
            //   f30f6f0418           | dec                 eax
            //   660fefc1             | mov                 dword ptr [ebp + 0x2f], eax
            //   f30f7f0418           | dec                 eax
            //   8d4210               | mov                 dword ptr [esi + 4], eax
            //   83c220               | mov                 ecx, 6
            //   f30f6f0418           | dec                 eax
            //   660fefc1             | mov                 dword ptr [esi + 0x220], eax

        $sequence_8 = { 0f8559ffffff 488bcf ff15???????? 498bce }
            // n = 4, score = 600
            //   0f8559ffffff         | xor                 edx, edx
            //   488bcf               | dec                 eax
            //   ff15????????         |                     
            //   498bce               | mov                 ecx, edi

        $sequence_9 = { e8???????? 85c0 0f85c6000000 448b442468 }
            // n = 4, score = 600
            //   e8????????           |                     
            //   85c0                 | dec                 esp
            //   0f85c6000000         | mov                 esi, dword ptr [esp + 0xde0]
            //   448b442468           | dec                 eax

    condition:
        7 of them and filesize < 270336
}