rule win_unidentified_078_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.unidentified_078."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.unidentified_078"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 7d21 8a440b10 3c5c 7419 }
            // n = 4, score = 200
            //   7d21                 | dec                 ecx
            //   8a440b10             | mov                 ecx, dword ptr [ecx]
            //   3c5c                 | dec                 eax
            //   7419                 | cmp                 ecx, 7

        $sequence_1 = { e8???????? 84c0 7467 f60701 }
            // n = 4, score = 200
            //   e8????????           |                     
            //   84c0                 | dec                 eax
            //   7467                 | dec                 eax
            //   f60701               | lea                 edx, [0x21e0a]

        $sequence_2 = { e9???????? 80fa5b 7f3c 80fa28 0f8d94010000 }
            // n = 5, score = 200
            //   e9????????           |                     
            //   80fa5b               | lea                 edx, [ebx + 0x30a8]
            //   7f3c                 | dec                 esp
            //   80fa28               | mov                 ecx, ebx
            //   0f8d94010000         | dec                 ebp

        $sequence_3 = { 80fa0d 0f8421010000 80fa1b 0f8576010000 ba02000000 e8???????? }
            // n = 6, score = 200
            //   80fa0d               | dec                 edx
            //   0f8421010000         | test                dword ptr [eax + eax*8 + 0x10], edx
            //   80fa1b               | setne               dl
            //   0f8576010000         | mov                 eax, edx
            //   ba02000000           | dec                 ecx
            //   e8????????           |                     

        $sequence_4 = { 80fa7e 0f8f02010000 e9???????? ba02000000 }
            // n = 4, score = 200
            //   80fa7e               | mov                 ecx, dword ptr [edx + edx*8]
            //   0f8f02010000         | dec                 ebp
            //   e9????????           |                     
            //   ba02000000           | mov                 dword ptr [ebx], ecx

        $sequence_5 = { b901010000 ff15???????? 85c0 740e e8???????? }
            // n = 5, score = 200
            //   b901010000           | mov                 ecx, ecx
            //   ff15????????         |                     
            //   85c0                 | dec                 eax
            //   740e                 | and                 ecx, 0xfffff000
            //   e8????????           |                     

        $sequence_6 = { 0f8cee000000 80fa0d 0f8421010000 80fa1b 0f8576010000 }
            // n = 5, score = 200
            //   0f8cee000000         | movsx               edx, byte ptr [esp + esi + 0x10]
            //   80fa0d               | dec                 eax
            //   0f8421010000         | mov                 ecx, dword ptr [ebx]
            //   80fa1b               | inc                 ecx
            //   0f8576010000         | mov                 ecx, edi

        $sequence_7 = { 0f8f18010000 80fa23 0f8d82010000 ba02000000 }
            // n = 4, score = 200
            //   0f8f18010000         | jmp                 0x1b
            //   80fa23               | mov                 ecx, 0x3b0001
            //   0f8d82010000         | dec                 eax
            //   ba02000000           | ja                  0x138

        $sequence_8 = { 753f a900004011 7521 a900000600 }
            // n = 4, score = 200
            //   753f                 | dec                 ebp
            //   a900004011           | test                ebx, ebx
            //   7521                 | je                  0x9b
            //   a900000600           | dec                 ecx

        $sequence_9 = { 0f8d94010000 80fa26 0f8f18010000 80fa23 0f8d82010000 }
            // n = 5, score = 200
            //   0f8d94010000         | sub                 esi, edi
            //   80fa26               | xor                 edx, edx
            //   0f8f18010000         | dec                 eax
            //   80fa23               | mov                 ecx, ebp
            //   0f8d82010000         | inc                 esp

    condition:
        7 of them and filesize < 688128
}