rule win_unidentified_095_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.unidentified_095."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.unidentified_095"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ffc8 6641833c465c 7505 6641892c46 4c8bbc24e8000000 }
            // n = 5, score = 100
            //   ffc8                 | dec                 eax
            //   6641833c465c         | mov                 ebx, eax
            //   7505                 | dec                 eax
            //   6641892c46           | test                eax, eax
            //   4c8bbc24e8000000     | je                  0xae0

        $sequence_1 = { 85c0 7553 488bcf ff15???????? 488d4c2430 }
            // n = 5, score = 100
            //   85c0                 | je                  0xa37
            //   7553                 | dec                 eax
            //   488bcf               | lea                 edx, [0x135fc]
            //   ff15????????         |                     
            //   488d4c2430           | dec                 esp

        $sequence_2 = { 488bd0 48d3ca 4933d0 4b8794fe90440200 eb2d }
            // n = 5, score = 100
            //   488bd0               | inc                 ecx
            //   48d3ca               | mov                 esi, 0x100
            //   4933d0               | dec                 esp
            //   4b8794fe90440200     | lea                 edi, [0x11b9f]
            //   eb2d                 | inc                 sp

        $sequence_3 = { 48c7c102000080 897c2420 ff15???????? 85c0 740c 8bc8 ff15???????? }
            // n = 7, score = 100
            //   48c7c102000080       | xor                 edx, 1
            //   897c2420             | add                 edx, edx
            //   ff15????????         |                     
            //   85c0                 | mov                 eax, edx
            //   740c                 | dec                 eax
            //   8bc8                 | add                 eax, ecx
            //   ff15????????         |                     

        $sequence_4 = { 488d1519de0000 488d0df2dd0000 e8???????? 488d1516de0000 488d0d07de0000 e8???????? 488b4308 }
            // n = 7, score = 100
            //   488d1519de0000       | je                  0x18e8
            //   488d0df2dd0000       | dec                 esp
            //   e8????????           |                     
            //   488d1516de0000       | mov                 dword ptr [esp + 0x30], edi
            //   488d0d07de0000       | inc                 esp
            //   e8????????           |                     
            //   488b4308             | mov                 edi, edx

        $sequence_5 = { 4881c490000000 5d c3 4053 4883ec20 488bd9 }
            // n = 6, score = 100
            //   4881c490000000       | inc                 ecx
            //   5d                   | mov                 edi, 1
            //   c3                   | dec                 eax
            //   4053                 | mov                 edi, dword ptr [esp + 0x260]
            //   4883ec20             | dec                 ecx
            //   488bd9               | mov                 dword ptr [esi], eax

        $sequence_6 = { 660f28c1 4c8d0dfb9e0000 f20f101d???????? f20f100d???????? f20f59da }
            // n = 5, score = 100
            //   660f28c1             | dec                 esp
            //   4c8d0dfb9e0000       | mov                 dword ptr [eax - 0x40], edi
            //   f20f101d????????     |                     
            //   f20f100d????????     |                     
            //   f20f59da             | inc                 esp

        $sequence_7 = { 85c0 0f8502010000 837c243c04 7516 }
            // n = 4, score = 100
            //   85c0                 | lea                 ecx, [ecx + 1]
            //   0f8502010000         | jne                 0xf65
            //   837c243c04           | dec                 eax
            //   7516                 | lea                 ecx, [ecx*2 + 0xa]

        $sequence_8 = { eb19 488d3d3a440100 eb10 488d3d41440100 eb07 488d3d20440100 4883a4248000000000 }
            // n = 7, score = 100
            //   eb19                 | cmove               esi, ecx
            //   488d3d3a440100       | mov                 ebx, eax
            //   eb10                 | dec                 eax
            //   488d3d41440100       | test                ebp, ebp
            //   eb07                 | je                  0xc0
            //   488d3d20440100       | dec                 eax
            //   4883a4248000000000     | mov    ecx, ebp

        $sequence_9 = { 75ed 488bcb 85d2 7507 e8???????? eb08 498bd1 }
            // n = 7, score = 100
            //   75ed                 | mov                 dword ptr [eax], edi
            //   488bcb               | dec                 eax
            //   85d2                 | lea                 ebx, [0x18d6b]
            //   7507                 | dec                 eax
            //   e8????????           |                     
            //   eb08                 | test                eax, eax
            //   498bd1               | je                  0x1e80

    condition:
        7 of them and filesize < 339968
}