rule win_unidentified_098_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.unidentified_098."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.unidentified_098"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { c644247f00 e9???????? 41bdffffffff 4885db 7412 488b4310 483b4318 }
            // n = 7, score = 400
            //   c644247f00           | cmp                 eax, dword ptr [ebx + 8]
            //   e9????????           |                     
            //   41bdffffffff         | je                  0x2df2
            //   4885db               | dec                 eax
            //   7412                 | mov                 eax, dword ptr [eax - 8]
            //   488b4310             | dec                 eax
            //   483b4318             | test                eax, eax

        $sequence_1 = { e9???????? 8d48bf 83f905 0f8716ffffff 83e837 c1e00c 89c6 }
            // n = 7, score = 400
            //   e9????????           |                     
            //   8d48bf               | dec                 esp
            //   83f905               | lea                 eax, [esp + 0xb0]
            //   0f8716ffffff         | mov                 edx, 0x65
            //   83e837               | vmovups             xmm4, xmmword ptr [edi + 0x48]
            //   c1e00c               | dec                 eax
            //   89c6                 | mov                 eax, dword ptr [edi + 0x58]

        $sequence_2 = { 7eac 85c0 78a8 488b4318 31d2 4885c0 75ab }
            // n = 7, score = 400
            //   7eac                 | inc                 ecx
            //   85c0                 | mov                 ecx, 0x80000000
            //   78a8                 | dec                 esp
            //   488b4318             | cmp                 eax, ecx
            //   31d2                 | jl                  0xad
            //   4885c0               | dec                 esi
            //   75ab                 | lea                 eax, [ecx + eax*2]

        $sequence_3 = { f6c202 410f45c0 4883c102 01d2 668941fe 4939c9 75ce }
            // n = 7, score = 400
            //   f6c202               | mov                 edx, dword ptr [edi + 0x38]
            //   410f45c0             | dec                 eax
            //   4883c102             | cmp                 edx, dword ptr [edi + 0x40]
            //   01d2                 | je                  0x355
            //   668941fe             | dec                 esp
            //   4939c9               | mov                 dword ptr [edx], eax
            //   75ce                 | vmovups             xmmword ptr [esp + 0xa0], xmm1

        $sequence_4 = { b801000000 4d85c0 7486 488b542450 4c89e1 e8???????? 85c0 }
            // n = 7, score = 400
            //   b801000000           | pop                 edi
            //   4d85c0               | ret                 
            //   7486                 | dec                 eax
            //   488b542450           | lea                 ecx, [0x16f8df]
            //   4c89e1               | je                  0x36d
            //   e8????????           |                     
            //   85c0                 | dec                 eax

        $sequence_5 = { ff15???????? 410fb61424 e9???????? 4c89f8 4829d8 4801c7 4d85ed }
            // n = 7, score = 400
            //   ff15????????         |                     
            //   410fb61424           | dec                 esp
            //   e9????????           |                     
            //   4c89f8               | lea                 ebp, [ebx + 0x10]
            //   4829d8               | dec                 eax
            //   4801c7               | mov                 esi, dword ptr [edi + 8]
            //   4d85ed               | dec                 esp

        $sequence_6 = { 85d2 0f88d5000000 4c8d5904 4189d2 4c8d4910 83fa0f 7e33 }
            // n = 7, score = 400
            //   85d2                 | vmovups             xmm4, xmmword ptr [edi + 0x48]
            //   0f88d5000000         | dec                 eax
            //   4c8d5904             | mov                 eax, dword ptr [edi + 0x58]
            //   4189d2               | dec                 esp
            //   4c8d4910             | lea                 ebp, [esp + 0x190]
            //   83fa0f               | mov                 word ptr [esp + 0x134], 0x77c3
            //   7e33                 | mov                 byte ptr [esp + 0x136], 0xcc

        $sequence_7 = { 488d542440 4939d4 7411 4c89e1 8844242f e8???????? 0fb644242f }
            // n = 7, score = 400
            //   488d542440           | dec                 eax
            //   4939d4               | mov                 edx, dword ptr [esp + 0x100]
            //   7411                 | dec                 eax
            //   4c89e1               | mov                 edi, 0x61766e69
            //   8844242f             | insb                byte ptr es:[edi], dx
            //   e8????????           |                     
            //   0fb644242f           | imul                esp, dword ptr [edi + ebx*2 + 0x48], 0x657469bd

        $sequence_8 = { 897c2450 41bd01000000 44894c2434 4889442458 e9???????? 488b03 4489442434 }
            // n = 7, score = 400
            //   897c2450             | je                  0x1bcb
            //   41bd01000000         | dec                 eax
            //   44894c2434           | lea                 eax, [0x1752ab]
            //   4889442458           | dec                 eax
            //   e9????????           |                     
            //   488b03               | add                 esp, 0x38
            //   4489442434           | ret                 

        $sequence_9 = { e9???????? 498b4610 493b4618 0f838d010000 0fb700 6683f8ff b900000000 }
            // n = 7, score = 400
            //   e9????????           |                     
            //   498b4610             | dec                 eax
            //   493b4618             | lea                 ecx, [0x17593e]
            //   0f838d010000         | vmovups             xmm1, xmmword ptr [esp + 0x20]
            //   0fb700               | dec                 eax
            //   6683f8ff             | mov                 eax, dword ptr [esp + 0x30]
            //   b900000000           | dec                 eax

    condition:
        7 of them and filesize < 3345408
}