rule win_valley_rat_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.valley_rat."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.valley_rat"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b4910 e8???????? 2500020000 33d2 0bc2 7506 32c0 }
            // n = 7, score = 100
            //   8b4910               | mov                 ecx, dword ptr [ecx + 0x10]
            //   e8????????           |                     
            //   2500020000           | and                 eax, 0x200
            //   33d2                 | xor                 edx, edx
            //   0bc2                 | or                  eax, edx
            //   7506                 | jne                 8
            //   32c0                 | xor                 al, al

        $sequence_1 = { e8???????? 50 8d4708 50 e8???????? 8bbdf0efffff 83c414 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   50                   | push                eax
            //   8d4708               | lea                 eax, [edi + 8]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8bbdf0efffff         | mov                 edi, dword ptr [ebp - 0x1010]
            //   83c414               | add                 esp, 0x14

        $sequence_2 = { 8bf0 83c404 85f6 742f e8???????? 84c0 ba???????? }
            // n = 7, score = 100
            //   8bf0                 | mov                 esi, eax
            //   83c404               | add                 esp, 4
            //   85f6                 | test                esi, esi
            //   742f                 | je                  0x31
            //   e8????????           |                     
            //   84c0                 | test                al, al
            //   ba????????           |                     

        $sequence_3 = { 50 e8???????? 8b5654 33c9 8b4508 83c408 894d08 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b5654               | mov                 edx, dword ptr [esi + 0x54]
            //   33c9                 | xor                 ecx, ecx
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   83c408               | add                 esp, 8
            //   894d08               | mov                 dword ptr [ebp + 8], ecx

        $sequence_4 = { 8d04dd00000000 50 e8???????? 8bf0 83c404 85f6 7447 }
            // n = 7, score = 100
            //   8d04dd00000000       | lea                 eax, [ebx*8]
            //   50                   | push                eax
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax
            //   83c404               | add                 esp, 4
            //   85f6                 | test                esi, esi
            //   7447                 | je                  0x49

        $sequence_5 = { 8bc2 c1e81f 03c2 8d0c40 8b07 8d04c8 894704 }
            // n = 7, score = 100
            //   8bc2                 | mov                 eax, edx
            //   c1e81f               | shr                 eax, 0x1f
            //   03c2                 | add                 eax, edx
            //   8d0c40               | lea                 ecx, [eax + eax*2]
            //   8b07                 | mov                 eax, dword ptr [edi]
            //   8d04c8               | lea                 eax, [eax + ecx*8]
            //   894704               | mov                 dword ptr [edi + 4], eax

        $sequence_6 = { 8b55f4 4f 75ce 8b4df8 8b7d08 8b5510 3bca }
            // n = 7, score = 100
            //   8b55f4               | mov                 edx, dword ptr [ebp - 0xc]
            //   4f                   | dec                 edi
            //   75ce                 | jne                 0xffffffd0
            //   8b4df8               | mov                 ecx, dword ptr [ebp - 8]
            //   8b7d08               | mov                 edi, dword ptr [ebp + 8]
            //   8b5510               | mov                 edx, dword ptr [ebp + 0x10]
            //   3bca                 | cmp                 ecx, edx

        $sequence_7 = { 8b36 c6043e00 5f 5e 5d c3 55 }
            // n = 7, score = 100
            //   8b36                 | mov                 esi, dword ptr [esi]
            //   c6043e00             | mov                 byte ptr [esi + edi], 0
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   55                   | push                ebp

        $sequence_8 = { eb64 33c0 668945e4 e8???????? ff75dc 8b7b04 8d45e3 }
            // n = 7, score = 100
            //   eb64                 | jmp                 0x66
            //   33c0                 | xor                 eax, eax
            //   668945e4             | mov                 word ptr [ebp - 0x1c], ax
            //   e8????????           |                     
            //   ff75dc               | push                dword ptr [ebp - 0x24]
            //   8b7b04               | mov                 edi, dword ptr [ebx + 4]
            //   8d45e3               | lea                 eax, [ebp - 0x1d]

        $sequence_9 = { c745fc00000000 53 8bce e8???????? 8b06 83f801 741e }
            // n = 7, score = 100
            //   c745fc00000000       | mov                 dword ptr [ebp - 4], 0
            //   53                   | push                ebx
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     
            //   8b06                 | mov                 eax, dword ptr [esi]
            //   83f801               | cmp                 eax, 1
            //   741e                 | je                  0x20

    condition:
        7 of them and filesize < 2256896
}