rule win_varenyky_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.varenyky."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.varenyky"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b3d???????? 8b542418 6a00 52 8d8424c0130000 50 55 }
            // n = 7, score = 100
            //   8b3d????????         |                     
            //   8b542418             | mov                 edx, dword ptr [esp + 0x18]
            //   6a00                 | push                0
            //   52                   | push                edx
            //   8d8424c0130000       | lea                 eax, [esp + 0x13c0]
            //   50                   | push                eax
            //   55                   | push                ebp

        $sequence_1 = { 8d542435 6a00 52 c644243c00 e8???????? }
            // n = 5, score = 100
            //   8d542435             | lea                 edx, [esp + 0x35]
            //   6a00                 | push                0
            //   52                   | push                edx
            //   c644243c00           | mov                 byte ptr [esp + 0x3c], 0
            //   e8????????           |                     

        $sequence_2 = { 6880000000 8bd6 52 ff15???????? 6803010000 8d842485020000 }
            // n = 6, score = 100
            //   6880000000           | push                0x80
            //   8bd6                 | mov                 edx, esi
            //   52                   | push                edx
            //   ff15????????         |                     
            //   6803010000           | push                0x103
            //   8d842485020000       | lea                 eax, [esp + 0x285]

        $sequence_3 = { 83c40c 6a40 898424a4010000 898c249c010000 8a0d???????? 899424a0010000 8d442450 }
            // n = 7, score = 100
            //   83c40c               | add                 esp, 0xc
            //   6a40                 | push                0x40
            //   898424a4010000       | mov                 dword ptr [esp + 0x1a4], eax
            //   898c249c010000       | mov                 dword ptr [esp + 0x19c], ecx
            //   8a0d????????         |                     
            //   899424a0010000       | mov                 dword ptr [esp + 0x1a0], edx
            //   8d442450             | lea                 eax, [esp + 0x50]

        $sequence_4 = { 03f0 0fbe01 3bc3 75f0 }
            // n = 4, score = 100
            //   03f0                 | add                 esi, eax
            //   0fbe01               | movsx               eax, byte ptr [ecx]
            //   3bc3                 | cmp                 eax, ebx
            //   75f0                 | jne                 0xfffffff2

        $sequence_5 = { 57 e8???????? 83c404 3c32 }
            // n = 4, score = 100
            //   57                   | push                edi
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   3c32                 | cmp                 al, 0x32

        $sequence_6 = { 8d84244d030000 53 50 c744242404010000 889c2454030000 e8???????? }
            // n = 6, score = 100
            //   8d84244d030000       | lea                 eax, [esp + 0x34d]
            //   53                   | push                ebx
            //   50                   | push                eax
            //   c744242404010000     | mov                 dword ptr [esp + 0x24], 0x104
            //   889c2454030000       | mov                 byte ptr [esp + 0x354], bl
            //   e8????????           |                     

        $sequence_7 = { 51 ffd6 68???????? 8d542474 52 ffd7 }
            // n = 6, score = 100
            //   51                   | push                ecx
            //   ffd6                 | call                esi
            //   68????????           |                     
            //   8d542474             | lea                 edx, [esp + 0x74]
            //   52                   | push                edx
            //   ffd7                 | call                edi

        $sequence_8 = { 56 57 6803010000 8d44243d 53 50 885c2444 }
            // n = 7, score = 100
            //   56                   | push                esi
            //   57                   | push                edi
            //   6803010000           | push                0x103
            //   8d44243d             | lea                 eax, [esp + 0x3d]
            //   53                   | push                ebx
            //   50                   | push                eax
            //   885c2444             | mov                 byte ptr [esp + 0x44], bl

        $sequence_9 = { 41 03e8 0fbe01 3bc3 75f0 0fbe842440020000 }
            // n = 6, score = 100
            //   41                   | inc                 ecx
            //   03e8                 | add                 ebp, eax
            //   0fbe01               | movsx               eax, byte ptr [ecx]
            //   3bc3                 | cmp                 eax, ebx
            //   75f0                 | jne                 0xfffffff2
            //   0fbe842440020000     | movsx               eax, byte ptr [esp + 0x240]

    condition:
        7 of them and filesize < 24846336
}