rule win_void_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.void."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.void"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 6a09 8d4c2410 51 50 e8???????? 85c0 7518 }
            // n = 7, score = 200
            //   6a09                 | push                9
            //   8d4c2410             | lea                 ecx, [esp + 0x10]
            //   51                   | push                ecx
            //   50                   | push                eax
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   7518                 | jne                 0x1a

        $sequence_1 = { 5d c20c00 6a00 ff750c 50 e8???????? 50 }
            // n = 7, score = 200
            //   5d                   | pop                 ebp
            //   c20c00               | ret                 0xc
            //   6a00                 | push                0
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   50                   | push                eax
            //   e8????????           |                     
            //   50                   | push                eax

        $sequence_2 = { 807d6b00 0f8483000000 6a02 8d4dc4 e8???????? 8d45c4 c745fc02000000 }
            // n = 7, score = 200
            //   807d6b00             | cmp                 byte ptr [ebp + 0x6b], 0
            //   0f8483000000         | je                  0x89
            //   6a02                 | push                2
            //   8d4dc4               | lea                 ecx, [ebp - 0x3c]
            //   e8????????           |                     
            //   8d45c4               | lea                 eax, [ebp - 0x3c]
            //   c745fc02000000       | mov                 dword ptr [ebp - 4], 2

        $sequence_3 = { 0f43c6 50 ff7514 8d45ac ff7510 50 53 }
            // n = 7, score = 200
            //   0f43c6               | cmovae              eax, esi
            //   50                   | push                eax
            //   ff7514               | push                dword ptr [ebp + 0x14]
            //   8d45ac               | lea                 eax, [ebp - 0x54]
            //   ff7510               | push                dword ptr [ebp + 0x10]
            //   50                   | push                eax
            //   53                   | push                ebx

        $sequence_4 = { 5b 8bc1 8b4c2440 5e 5d 33cc e8???????? }
            // n = 7, score = 200
            //   5b                   | pop                 ebx
            //   8bc1                 | mov                 eax, ecx
            //   8b4c2440             | mov                 ecx, dword ptr [esp + 0x40]
            //   5e                   | pop                 esi
            //   5d                   | pop                 ebp
            //   33cc                 | xor                 ecx, esp
            //   e8????????           |                     

        $sequence_5 = { 7473 8d4dec 8975ec e8???????? 53 8bcf 8b00 }
            // n = 7, score = 200
            //   7473                 | je                  0x75
            //   8d4dec               | lea                 ecx, [ebp - 0x14]
            //   8975ec               | mov                 dword ptr [ebp - 0x14], esi
            //   e8????????           |                     
            //   53                   | push                ebx
            //   8bcf                 | mov                 ecx, edi
            //   8b00                 | mov                 eax, dword ptr [eax]

        $sequence_6 = { 854110 7419 8d45e4 6a01 50 e8???????? 83c408 }
            // n = 7, score = 200
            //   854110               | test                dword ptr [ecx + 0x10], eax
            //   7419                 | je                  0x1b
            //   8d45e4               | lea                 eax, [ebp - 0x1c]
            //   6a01                 | push                1
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c408               | add                 esp, 8

        $sequence_7 = { 894610 c1e102 51 8d0490 6a00 50 e8???????? }
            // n = 7, score = 200
            //   894610               | mov                 dword ptr [esi + 0x10], eax
            //   c1e102               | shl                 ecx, 2
            //   51                   | push                ecx
            //   8d0490               | lea                 eax, [eax + edx*4]
            //   6a00                 | push                0
            //   50                   | push                eax
            //   e8????????           |                     

    condition:
        7 of them and filesize < 2744320
}