rule win_voidoor_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.voidoor."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.voidoor"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 83c410 83bfb40b000000 752e ff33 83bf500b000000 ffb608400000 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10
            //   83bfb40b000000       | cmp                 dword ptr [edi + 0xbb4], 0
            //   752e                 | jne                 0x30
            //   ff33                 | push                dword ptr [ebx]
            //   83bf500b000000       | cmp                 dword ptr [edi + 0xb50], 0
            //   ffb608400000         | push                dword ptr [esi + 0x4008]

        $sequence_1 = { c645fc10 e8???????? c78574feffff0f000000 c78570feffff00000000 c68560feffff00 8d9560feffff 8d8d78feffff }
            // n = 7, score = 100
            //   c645fc10             | mov                 byte ptr [ebp - 4], 0x10
            //   e8????????           |                     
            //   c78574feffff0f000000     | mov    dword ptr [ebp - 0x18c], 0xf
            //   c78570feffff00000000     | mov    dword ptr [ebp - 0x190], 0
            //   c68560feffff00       | mov                 byte ptr [ebp - 0x1a0], 0
            //   8d9560feffff         | lea                 edx, [ebp - 0x1a0]
            //   8d8d78feffff         | lea                 ecx, [ebp - 0x188]

        $sequence_2 = { 03f5 7458 803e2f 7509 83f804 7d04 40 }
            // n = 7, score = 100
            //   03f5                 | add                 esi, ebp
            //   7458                 | je                  0x5a
            //   803e2f               | cmp                 byte ptr [esi], 0x2f
            //   7509                 | jne                 0xb
            //   83f804               | cmp                 eax, 4
            //   7d04                 | jge                 6
            //   40                   | inc                 eax

        $sequence_3 = { 55 8bd8 ff15???????? 83c414 85db 0f85c3010000 8b542440 }
            // n = 7, score = 100
            //   55                   | push                ebp
            //   8bd8                 | mov                 ebx, eax
            //   ff15????????         |                     
            //   83c414               | add                 esp, 0x14
            //   85db                 | test                ebx, ebx
            //   0f85c3010000         | jne                 0x1c9
            //   8b542440             | mov                 edx, dword ptr [esp + 0x40]

        $sequence_4 = { 8b742414 c744240800000000 83bec802000000 8b1e 57 8b834c010000 8dbe68050000 }
            // n = 7, score = 100
            //   8b742414             | mov                 esi, dword ptr [esp + 0x14]
            //   c744240800000000     | mov                 dword ptr [esp + 8], 0
            //   83bec802000000       | cmp                 dword ptr [esi + 0x2c8], 0
            //   8b1e                 | mov                 ebx, dword ptr [esi]
            //   57                   | push                edi
            //   8b834c010000         | mov                 eax, dword ptr [ebx + 0x14c]
            //   8dbe68050000         | lea                 edi, [esi + 0x568]

        $sequence_5 = { c60201 8b10 2bca 83f906 7d0a b801000000 5e }
            // n = 7, score = 100
            //   c60201               | mov                 byte ptr [edx], 1
            //   8b10                 | mov                 edx, dword ptr [eax]
            //   2bca                 | sub                 ecx, edx
            //   83f906               | cmp                 ecx, 6
            //   7d0a                 | jge                 0xc
            //   b801000000           | mov                 eax, 1
            //   5e                   | pop                 esi

        $sequence_6 = { 33c0 5f 59 c3 56 57 e8???????? }
            // n = 7, score = 100
            //   33c0                 | xor                 eax, eax
            //   5f                   | pop                 edi
            //   59                   | pop                 ecx
            //   c3                   | ret                 
            //   56                   | push                esi
            //   57                   | push                edi
            //   e8????????           |                     

        $sequence_7 = { b91b000000 5e 0f44d9 5d 8bc3 5b 83c408 }
            // n = 7, score = 100
            //   b91b000000           | mov                 ecx, 0x1b
            //   5e                   | pop                 esi
            //   0f44d9               | cmove               ebx, ecx
            //   5d                   | pop                 ebp
            //   8bc3                 | mov                 eax, ebx
            //   5b                   | pop                 ebx
            //   83c408               | add                 esp, 8

        $sequence_8 = { e8???????? 83c40c 89442418 8983ac030000 68???????? 53 e8???????? }
            // n = 7, score = 100
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   89442418             | mov                 dword ptr [esp + 0x18], eax
            //   8983ac030000         | mov                 dword ptr [ebx + 0x3ac], eax
            //   68????????           |                     
            //   53                   | push                ebx
            //   e8????????           |                     

        $sequence_9 = { c6434501 3944241c 7520 85f6 0f8565ffffff 837c243020 7337 }
            // n = 7, score = 100
            //   c6434501             | mov                 byte ptr [ebx + 0x45], 1
            //   3944241c             | cmp                 dword ptr [esp + 0x1c], eax
            //   7520                 | jne                 0x22
            //   85f6                 | test                esi, esi
            //   0f8565ffffff         | jne                 0xffffff6b
            //   837c243020           | cmp                 dword ptr [esp + 0x30], 0x20
            //   7337                 | jae                 0x39

    condition:
        7 of them and filesize < 1744896
}