rule win_wannacryptor_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.wannacryptor."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.wannacryptor"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 56 8bf1 57 8b7c241c 8b4670 }
            // n = 5, score = 700
            //   56                   | push                esi
            //   8bf1                 | mov                 esi, ecx
            //   57                   | push                edi
            //   8b7c241c             | mov                 edi, dword ptr [esp + 0x1c]
            //   8b4670               | mov                 eax, dword ptr [esi + 0x70]

        $sequence_1 = { 8854243c 8b44243c 50 51 8bce }
            // n = 5, score = 700
            //   8854243c             | mov                 byte ptr [esp + 0x3c], dl
            //   8b44243c             | mov                 eax, dword ptr [esp + 0x3c]
            //   50                   | push                eax
            //   51                   | push                ecx
            //   8bce                 | mov                 ecx, esi

        $sequence_2 = { b801000000 33ff 85c0 7e76 8bd8 8b5500 03cf }
            // n = 7, score = 700
            //   b801000000           | mov                 eax, 1
            //   33ff                 | xor                 edi, edi
            //   85c0                 | test                eax, eax
            //   7e76                 | jle                 0x78
            //   8bd8                 | mov                 ebx, eax
            //   8b5500               | mov                 edx, dword ptr [ebp]
            //   03cf                 | add                 ecx, edi

        $sequence_3 = { 8bce e8???????? 8a4649 84c0 7419 8b4620 }
            // n = 6, score = 700
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     
            //   8a4649               | mov                 al, byte ptr [esi + 0x49]
            //   84c0                 | test                al, al
            //   7419                 | je                  0x1b
            //   8b4620               | mov                 eax, dword ptr [esi + 0x20]

        $sequence_4 = { ff15???????? 50 e8???????? 85c0 742e 8b4004 8d542404 }
            // n = 7, score = 700
            //   ff15????????         |                     
            //   50                   | push                eax
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   742e                 | je                  0x30
            //   8b4004               | mov                 eax, dword ptr [eax + 4]
            //   8d542404             | lea                 edx, [esp + 4]

        $sequence_5 = { 8b4674 c6464801 85c0 7509 6a00 }
            // n = 5, score = 700
            //   8b4674               | mov                 eax, dword ptr [esi + 0x74]
            //   c6464801             | mov                 byte ptr [esi + 0x48], 1
            //   85c0                 | test                eax, eax
            //   7509                 | jne                 0xb
            //   6a00                 | push                0

        $sequence_6 = { 50 ff15???????? 50 e8???????? 8b4820 6a00 6a00 }
            // n = 7, score = 700
            //   50                   | push                eax
            //   ff15????????         |                     
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b4820               | mov                 ecx, dword ptr [eax + 0x20]
            //   6a00                 | push                0
            //   6a00                 | push                0

        $sequence_7 = { 8b4678 8d7e44 85c0 755f 8b17 }
            // n = 5, score = 700
            //   8b4678               | mov                 eax, dword ptr [esi + 0x78]
            //   8d7e44               | lea                 edi, [esi + 0x44]
            //   85c0                 | test                eax, eax
            //   755f                 | jne                 0x61
            //   8b17                 | mov                 edx, dword ptr [edi]

        $sequence_8 = { e8???????? 8d4648 8d4c2410 50 c744243000000000 }
            // n = 5, score = 700
            //   e8????????           |                     
            //   8d4648               | lea                 eax, [esi + 0x48]
            //   8d4c2410             | lea                 ecx, [esp + 0x10]
            //   50                   | push                eax
            //   c744243000000000     | mov                 dword ptr [esp + 0x30], 0

        $sequence_9 = { 57 8b7c241c 8b4670 85c0 7503 }
            // n = 5, score = 700
            //   57                   | push                edi
            //   8b7c241c             | mov                 edi, dword ptr [esp + 0x1c]
            //   8b4670               | mov                 eax, dword ptr [esi + 0x70]
            //   85c0                 | test                eax, eax
            //   7503                 | jne                 5

    condition:
        7 of them and filesize < 540672
}