rule win_wastedlocker_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.wastedlocker."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.wastedlocker"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 8bf0 ff7508 6a00 ff35???????? ff15???????? 5f }
            // n = 7, score = 1000
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax
            //   ff7508               | push                dword ptr [ebp + 8]
            //   6a00                 | push                0
            //   ff35????????         |                     
            //   ff15????????         |                     
            //   5f                   | pop                 edi

        $sequence_1 = { 8945e4 8d45dc 50 c745dc18000000 897de0 }
            // n = 5, score = 1000
            //   8945e4               | mov                 dword ptr [ebp - 0x1c], eax
            //   8d45dc               | lea                 eax, [ebp - 0x24]
            //   50                   | push                eax
            //   c745dc18000000       | mov                 dword ptr [ebp - 0x24], 0x18
            //   897de0               | mov                 dword ptr [ebp - 0x20], edi

        $sequence_2 = { 50 e8???????? 83c40c 56 8d85c8f1ffff 53 50 }
            // n = 7, score = 1000
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   56                   | push                esi
            //   8d85c8f1ffff         | lea                 eax, [ebp - 0xe38]
            //   53                   | push                ebx
            //   50                   | push                eax

        $sequence_3 = { ffd3 8bf8 85ff 7419 6a20 57 ffd3 }
            // n = 7, score = 1000
            //   ffd3                 | call                ebx
            //   8bf8                 | mov                 edi, eax
            //   85ff                 | test                edi, edi
            //   7419                 | je                  0x1b
            //   6a20                 | push                0x20
            //   57                   | push                edi
            //   ffd3                 | call                ebx

        $sequence_4 = { 8d45ec 50 8d45d4 50 6816011200 }
            // n = 5, score = 1000
            //   8d45ec               | lea                 eax, [ebp - 0x14]
            //   50                   | push                eax
            //   8d45d4               | lea                 eax, [ebp - 0x2c]
            //   50                   | push                eax
            //   6816011200           | push                0x120116

        $sequence_5 = { 3b45d0 0f8382000000 894dd8 394de0 740b 0fb703 034710 }
            // n = 7, score = 1000
            //   3b45d0               | cmp                 eax, dword ptr [ebp - 0x30]
            //   0f8382000000         | jae                 0x88
            //   894dd8               | mov                 dword ptr [ebp - 0x28], ecx
            //   394de0               | cmp                 dword ptr [ebp - 0x20], ecx
            //   740b                 | je                  0xd
            //   0fb703               | movzx               eax, word ptr [ebx]
            //   034710               | add                 eax, dword ptr [edi + 0x10]

        $sequence_6 = { ff35???????? ff15???????? 5f ff75f8 ff15???????? }
            // n = 5, score = 1000
            //   ff35????????         |                     
            //   ff15????????         |                     
            //   5f                   | pop                 edi
            //   ff75f8               | push                dword ptr [ebp - 8]
            //   ff15????????         |                     

        $sequence_7 = { 6a00 ff35???????? ff15???????? 8bd8 85db 7469 8b450c }
            // n = 7, score = 1000
            //   6a00                 | push                0
            //   ff35????????         |                     
            //   ff15????????         |                     
            //   8bd8                 | mov                 ebx, eax
            //   85db                 | test                ebx, ebx
            //   7469                 | je                  0x6b
            //   8b450c               | mov                 eax, dword ptr [ebp + 0xc]

        $sequence_8 = { 2500f0ffff 56 0500100000 50 56 b812345607 }
            // n = 6, score = 1000
            //   2500f0ffff           | and                 eax, 0xfffff000
            //   56                   | push                esi
            //   0500100000           | add                 eax, 0x1000
            //   50                   | push                eax
            //   56                   | push                esi
            //   b812345607           | mov                 eax, 0x7563412

        $sequence_9 = { bf04010000 ffd3 8bf0 85f6 746a 57 56 }
            // n = 7, score = 1000
            //   bf04010000           | mov                 edi, 0x104
            //   ffd3                 | call                ebx
            //   8bf0                 | mov                 esi, eax
            //   85f6                 | test                esi, esi
            //   746a                 | je                  0x6c
            //   57                   | push                edi
            //   56                   | push                esi

    condition:
        7 of them and filesize < 147456
}