rule win_waterspout_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.waterspout."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.waterspout"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { fec8 53 8841ff 8d4c2418 ff15???????? eb3a 3bf3 }
            // n = 7, score = 200
            //   fec8                 | dec                 al
            //   53                   | push                ebx
            //   8841ff               | mov                 byte ptr [ecx - 1], al
            //   8d4c2418             | lea                 ecx, [esp + 0x18]
            //   ff15????????         |                     
            //   eb3a                 | jmp                 0x3c
            //   3bf3                 | cmp                 esi, ebx

        $sequence_1 = { c684243a01000023 c684243b0100003d c684243c010000ee c684243d0100004c c684243e01000095 c684243f0100000b c684244001000042 }
            // n = 7, score = 200
            //   c684243a01000023     | mov                 byte ptr [esp + 0x13a], 0x23
            //   c684243b0100003d     | mov                 byte ptr [esp + 0x13b], 0x3d
            //   c684243c010000ee     | mov                 byte ptr [esp + 0x13c], 0xee
            //   c684243d0100004c     | mov                 byte ptr [esp + 0x13d], 0x4c
            //   c684243e01000095     | mov                 byte ptr [esp + 0x13e], 0x95
            //   c684243f0100000b     | mov                 byte ptr [esp + 0x13f], 0xb
            //   c684244001000042     | mov                 byte ptr [esp + 0x140], 0x42

        $sequence_2 = { 8d4c244c 68???????? 51 ff15???????? 8d7c2454 83c9ff 33c0 }
            // n = 7, score = 200
            //   8d4c244c             | lea                 ecx, [esp + 0x4c]
            //   68????????           |                     
            //   51                   | push                ecx
            //   ff15????????         |                     
            //   8d7c2454             | lea                 edi, [esp + 0x54]
            //   83c9ff               | or                  ecx, 0xffffffff
            //   33c0                 | xor                 eax, eax

        $sequence_3 = { 51 52 ff15???????? 85c0 7415 a1???????? 3bc3 }
            // n = 7, score = 200
            //   51                   | push                ecx
            //   52                   | push                edx
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7415                 | je                  0x17
            //   a1????????           |                     
            //   3bc3                 | cmp                 eax, ebx

        $sequence_4 = { 50 8b842410200000 51 52 68???????? 50 }
            // n = 6, score = 200
            //   50                   | push                eax
            //   8b842410200000       | mov                 eax, dword ptr [esp + 0x2010]
            //   51                   | push                ecx
            //   52                   | push                edx
            //   68????????           |                     
            //   50                   | push                eax

        $sequence_5 = { 6a00 a4 ff15???????? 50 ff15???????? 8b742460 }
            // n = 6, score = 200
            //   6a00                 | push                0
            //   a4                   | movsb               byte ptr es:[edi], byte ptr [esi]
            //   ff15????????         |                     
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8b742460             | mov                 esi, dword ptr [esp + 0x60]

        $sequence_6 = { 0f84aa000000 6a00 56 55 }
            // n = 4, score = 200
            //   0f84aa000000         | je                  0xb0
            //   6a00                 | push                0
            //   56                   | push                esi
            //   55                   | push                ebp

        $sequence_7 = { 8d542414 51 52 ffd6 83f801 74db 5f }
            // n = 7, score = 200
            //   8d542414             | lea                 edx, [esp + 0x14]
            //   51                   | push                ecx
            //   52                   | push                edx
            //   ffd6                 | call                esi
            //   83f801               | cmp                 eax, 1
            //   74db                 | je                  0xffffffdd
            //   5f                   | pop                 edi

        $sequence_8 = { a3???????? 8b442428 68???????? 6a00 6a6b }
            // n = 5, score = 200
            //   a3????????           |                     
            //   8b442428             | mov                 eax, dword ptr [esp + 0x28]
            //   68????????           |                     
            //   6a00                 | push                0
            //   6a6b                 | push                0x6b

        $sequence_9 = { 33c0 8dbdfcfeffff 85f6 f3ab 7511 8d85fcfeffff 50 }
            // n = 7, score = 200
            //   33c0                 | xor                 eax, eax
            //   8dbdfcfeffff         | lea                 edi, [ebp - 0x104]
            //   85f6                 | test                esi, esi
            //   f3ab                 | rep stosd           dword ptr es:[edi], eax
            //   7511                 | jne                 0x13
            //   8d85fcfeffff         | lea                 eax, [ebp - 0x104]
            //   50                   | push                eax

    condition:
        7 of them and filesize < 98304
}