rule win_webc2_bolid_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.webc2_bolid."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.webc2_bolid"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 741e 8b4c240c 51 ff15???????? 56 68???????? e8???????? }
            // n = 7, score = 100
            //   741e                 | je                  0x20
            //   8b4c240c             | mov                 ecx, dword ptr [esp + 0xc]
            //   51                   | push                ecx
            //   ff15????????         |                     
            //   56                   | push                esi
            //   68????????           |                     
            //   e8????????           |                     

        $sequence_1 = { e8???????? 8d8c24d4000000 c684242c02000004 51 8bcd e8???????? 8b15???????? }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8d8c24d4000000       | lea                 ecx, [esp + 0xd4]
            //   c684242c02000004     | mov                 byte ptr [esp + 0x22c], 4
            //   51                   | push                ecx
            //   8bcd                 | mov                 ecx, ebp
            //   e8????????           |                     
            //   8b15????????         |                     

        $sequence_2 = { 8bcb e8???????? 85c0 0f84fa000000 8b550c 42 }
            // n = 6, score = 100
            //   8bcb                 | mov                 ecx, ebx
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   0f84fa000000         | je                  0x100
            //   8b550c               | mov                 edx, dword ptr [ebp + 0xc]
            //   42                   | inc                 edx

        $sequence_3 = { 49 885c2454 51 68???????? 8d4c2444 }
            // n = 5, score = 100
            //   49                   | dec                 ecx
            //   885c2454             | mov                 byte ptr [esp + 0x54], bl
            //   51                   | push                ecx
            //   68????????           |                     
            //   8d4c2444             | lea                 ecx, [esp + 0x44]

        $sequence_4 = { 83c40c 8b15???????? 8d4de4 52 }
            // n = 4, score = 100
            //   83c40c               | add                 esp, 0xc
            //   8b15????????         |                     
            //   8d4de4               | lea                 ecx, [ebp - 0x1c]
            //   52                   | push                edx

        $sequence_5 = { e8???????? 6a01 8d4c2440 c644245800 e8???????? 8b4c2460 }
            // n = 6, score = 100
            //   e8????????           |                     
            //   6a01                 | push                1
            //   8d4c2440             | lea                 ecx, [esp + 0x40]
            //   c644245800           | mov                 byte ptr [esp + 0x58], 0
            //   e8????????           |                     
            //   8b4c2460             | mov                 ecx, dword ptr [esp + 0x60]

        $sequence_6 = { f3a4 8b35???????? 8d4c2410 51 6a26 52 89442420 }
            // n = 7, score = 100
            //   f3a4                 | rep movsb           byte ptr es:[edi], byte ptr [esi]
            //   8b35????????         |                     
            //   8d4c2410             | lea                 ecx, [esp + 0x10]
            //   51                   | push                ecx
            //   6a26                 | push                0x26
            //   52                   | push                edx
            //   89442420             | mov                 dword ptr [esp + 0x20], eax

        $sequence_7 = { 8b458c 3bc3 7505 b8???????? }
            // n = 4, score = 100
            //   8b458c               | mov                 eax, dword ptr [ebp - 0x74]
            //   3bc3                 | cmp                 eax, ebx
            //   7505                 | jne                 7
            //   b8????????           |                     

        $sequence_8 = { 50 ff5104 33db 6a01 }
            // n = 4, score = 100
            //   50                   | push                eax
            //   ff5104               | call                dword ptr [ecx + 4]
            //   33db                 | xor                 ebx, ebx
            //   6a01                 | push                1

        $sequence_9 = { 53 880e 8bce e8???????? 8b15???????? 8d44245c }
            // n = 6, score = 100
            //   53                   | push                ebx
            //   880e                 | mov                 byte ptr [esi], cl
            //   8bce                 | mov                 ecx, esi
            //   e8????????           |                     
            //   8b15????????         |                     
            //   8d44245c             | lea                 eax, [esp + 0x5c]

    condition:
        7 of them and filesize < 163840
}