rule win_webc2_cson_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.webc2_cson."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.webc2_cson"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 8d85f0feffff 50 e8???????? 6a1e 8db5f6feffff 59 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8d85f0feffff         | lea                 eax, [ebp - 0x110]
            //   50                   | push                eax
            //   e8????????           |                     
            //   6a1e                 | push                0x1e
            //   8db5f6feffff         | lea                 esi, [ebp - 0x10a]
            //   59                   | pop                 ecx

        $sequence_1 = { be???????? 8dbd74ffffff 6a0a f3a5 a4 be???????? 56 }
            // n = 7, score = 100
            //   be????????           |                     
            //   8dbd74ffffff         | lea                 edi, [ebp - 0x8c]
            //   6a0a                 | push                0xa
            //   f3a5                 | rep movsd           dword ptr es:[edi], dword ptr [esi]
            //   a4                   | movsb               byte ptr es:[edi], byte ptr [esi]
            //   be????????           |                     
            //   56                   | push                esi

        $sequence_2 = { 50 e8???????? 59 59 ff7508 8d85acfcffff 50 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx
            //   ff7508               | push                dword ptr [ebp + 8]
            //   8d85acfcffff         | lea                 eax, [ebp - 0x354]
            //   50                   | push                eax

        $sequence_3 = { e8???????? 59 59 68???????? ff15???????? 53 bf???????? }
            // n = 7, score = 100
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   59                   | pop                 ecx
            //   68????????           |                     
            //   ff15????????         |                     
            //   53                   | push                ebx
            //   bf????????           |                     

        $sequence_4 = { 83c410 85ff 743f 85c0 743b 2bc7 }
            // n = 6, score = 100
            //   83c410               | add                 esp, 0x10
            //   85ff                 | test                edi, edi
            //   743f                 | je                  0x41
            //   85c0                 | test                eax, eax
            //   743b                 | je                  0x3d
            //   2bc7                 | sub                 eax, edi

        $sequence_5 = { 8bec 81ec54030000 53 56 8b35???????? 57 33db }
            // n = 7, score = 100
            //   8bec                 | mov                 ebp, esp
            //   81ec54030000         | sub                 esp, 0x354
            //   53                   | push                ebx
            //   56                   | push                esi
            //   8b35????????         |                     
            //   57                   | push                edi
            //   33db                 | xor                 ebx, ebx

        $sequence_6 = { 83f803 0f859c010000 53 53 53 53 }
            // n = 6, score = 100
            //   83f803               | cmp                 eax, 3
            //   0f859c010000         | jne                 0x1a2
            //   53                   | push                ebx
            //   53                   | push                ebx
            //   53                   | push                ebx
            //   53                   | push                ebx

        $sequence_7 = { 8d7d81 885d80 f3ab 66ab aa 6a0f 33c0 }
            // n = 7, score = 100
            //   8d7d81               | lea                 edi, [ebp - 0x7f]
            //   885d80               | mov                 byte ptr [ebp - 0x80], bl
            //   f3ab                 | rep stosd           dword ptr es:[edi], eax
            //   66ab                 | stosw               word ptr es:[edi], ax
            //   aa                   | stosb               byte ptr es:[edi], al
            //   6a0f                 | push                0xf
            //   33c0                 | xor                 eax, eax

        $sequence_8 = { 8bec 81ec3c060000 53 56 be04010000 }
            // n = 5, score = 100
            //   8bec                 | mov                 ebp, esp
            //   81ec3c060000         | sub                 esp, 0x63c
            //   53                   | push                ebx
            //   56                   | push                esi
            //   be04010000           | mov                 esi, 0x104

        $sequence_9 = { 5e 5b c9 c20400 c605????????01 be00900100 6800040000 }
            // n = 7, score = 100
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx
            //   c9                   | leave               
            //   c20400               | ret                 4
            //   c605????????01       |                     
            //   be00900100           | mov                 esi, 0x19000
            //   6800040000           | push                0x400

    condition:
        7 of them and filesize < 98304
}