rule win_webc2_qbp_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.webc2_qbp."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.webc2_qbp"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 85c0 7511 8d85e8fcffff 50 ff15???????? }
            // n = 5, score = 100
            //   85c0                 | test                eax, eax
            //   7511                 | jne                 0x13
            //   8d85e8fcffff         | lea                 eax, [ebp - 0x318]
            //   50                   | push                eax
            //   ff15????????         |                     

        $sequence_1 = { 3b9090830000 0f8e9d000000 8b4df0 8b819c830000 0345fc 6bc003 99 }
            // n = 7, score = 100
            //   3b9090830000         | cmp                 edx, dword ptr [eax + 0x8390]
            //   0f8e9d000000         | jle                 0xa3
            //   8b4df0               | mov                 ecx, dword ptr [ebp - 0x10]
            //   8b819c830000         | mov                 eax, dword ptr [ecx + 0x839c]
            //   0345fc               | add                 eax, dword ptr [ebp - 4]
            //   6bc003               | imul                eax, eax, 3
            //   99                   | cdq                 

        $sequence_2 = { 83c40c c785e0fcffff01000000 ff15???????? 8985f4feffff 8b95e0fcffff 52 8b85f0feffff }
            // n = 7, score = 100
            //   83c40c               | add                 esp, 0xc
            //   c785e0fcffff01000000     | mov    dword ptr [ebp - 0x320], 1
            //   ff15????????         |                     
            //   8985f4feffff         | mov                 dword ptr [ebp - 0x10c], eax
            //   8b95e0fcffff         | mov                 edx, dword ptr [ebp - 0x320]
            //   52                   | push                edx
            //   8b85f0feffff         | mov                 eax, dword ptr [ebp - 0x110]

        $sequence_3 = { b9fa000000 2bc8 898dd8fcffff 8b95e8fdffff 52 e8???????? 83c404 }
            // n = 7, score = 100
            //   b9fa000000           | mov                 ecx, 0xfa
            //   2bc8                 | sub                 ecx, eax
            //   898dd8fcffff         | mov                 dword ptr [ebp - 0x328], ecx
            //   8b95e8fdffff         | mov                 edx, dword ptr [ebp - 0x218]
            //   52                   | push                edx
            //   e8????????           |                     
            //   83c404               | add                 esp, 4

        $sequence_4 = { 83ec0c 56 894df4 66c745fc0000 eb0c 668b45fc 66050100 }
            // n = 7, score = 100
            //   83ec0c               | sub                 esp, 0xc
            //   56                   | push                esi
            //   894df4               | mov                 dword ptr [ebp - 0xc], ecx
            //   66c745fc0000         | mov                 word ptr [ebp - 4], 0
            //   eb0c                 | jmp                 0xe
            //   668b45fc             | mov                 ax, word ptr [ebp - 4]
            //   66050100             | add                 ax, 1

        $sequence_5 = { 85c0 746d 8d4dfc 51 8d55f8 52 e8???????? }
            // n = 7, score = 100
            //   85c0                 | test                eax, eax
            //   746d                 | je                  0x6f
            //   8d4dfc               | lea                 ecx, [ebp - 4]
            //   51                   | push                ecx
            //   8d55f8               | lea                 edx, [ebp - 8]
            //   52                   | push                edx
            //   e8????????           |                     

        $sequence_6 = { 8b450c 25ffff0000 50 8b4dec 51 ff15???????? 8945fc }
            // n = 7, score = 100
            //   8b450c               | mov                 eax, dword ptr [ebp + 0xc]
            //   25ffff0000           | and                 eax, 0xffff
            //   50                   | push                eax
            //   8b4dec               | mov                 ecx, dword ptr [ebp - 0x14]
            //   51                   | push                ecx
            //   ff15????????         |                     
            //   8945fc               | mov                 dword ptr [ebp - 4], eax

        $sequence_7 = { 0fbf4dec 3bc1 7d7d 8b4de4 e8???????? 668945f4 0fbf55f4 }
            // n = 7, score = 100
            //   0fbf4dec             | movsx               ecx, word ptr [ebp - 0x14]
            //   3bc1                 | cmp                 eax, ecx
            //   7d7d                 | jge                 0x7f
            //   8b4de4               | mov                 ecx, dword ptr [ebp - 0x1c]
            //   e8????????           |                     
            //   668945f4             | mov                 word ptr [ebp - 0xc], ax
            //   0fbf55f4             | movsx               edx, word ptr [ebp - 0xc]

        $sequence_8 = { 81eafd000000 668955ec 66c745e80000 eb0c 668b45e8 66050100 668945e8 }
            // n = 7, score = 100
            //   81eafd000000         | sub                 edx, 0xfd
            //   668955ec             | mov                 word ptr [ebp - 0x14], dx
            //   66c745e80000         | mov                 word ptr [ebp - 0x18], 0
            //   eb0c                 | jmp                 0xe
            //   668b45e8             | mov                 ax, word ptr [ebp - 0x18]
            //   66050100             | add                 ax, 1
            //   668945e8             | mov                 word ptr [ebp - 0x18], ax

        $sequence_9 = { 83bde8fdffff00 7574 6800010000 6a00 8d85ecfdffff 50 }
            // n = 6, score = 100
            //   83bde8fdffff00       | cmp                 dword ptr [ebp - 0x218], 0
            //   7574                 | jne                 0x76
            //   6800010000           | push                0x100
            //   6a00                 | push                0
            //   8d85ecfdffff         | lea                 eax, [ebp - 0x214]
            //   50                   | push                eax

    condition:
        7 of them and filesize < 630784
}