rule win_webc2_ugx_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.webc2_ugx."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.webc2_ugx"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d458c 895dec 50 8d8568ffffff 50 }
            // n = 5, score = 100
            //   8d458c               | lea                 eax, [ebp - 0x74]
            //   895dec               | mov                 dword ptr [ebp - 0x14], ebx
            //   50                   | push                eax
            //   8d8568ffffff         | lea                 eax, [ebp - 0x98]
            //   50                   | push                eax

        $sequence_1 = { 59 745e 8d4640 50 ff750c ffd3 59 }
            // n = 7, score = 100
            //   59                   | pop                 ecx
            //   745e                 | je                  0x60
            //   8d4640               | lea                 eax, [esi + 0x40]
            //   50                   | push                eax
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   ffd3                 | call                ebx
            //   59                   | pop                 ecx

        $sequence_2 = { 50 ff15???????? 85c0 7455 8d85a8feffff 53 50 }
            // n = 7, score = 100
            //   50                   | push                eax
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7455                 | je                  0x57
            //   8d85a8feffff         | lea                 eax, [ebp - 0x158]
            //   53                   | push                ebx
            //   50                   | push                eax

        $sequence_3 = { ff9698060000 8bf8 85ff 0f84b5000000 8d866e0c0000 50 57 }
            // n = 7, score = 100
            //   ff9698060000         | call                dword ptr [esi + 0x698]
            //   8bf8                 | mov                 edi, eax
            //   85ff                 | test                edi, edi
            //   0f84b5000000         | je                  0xbb
            //   8d866e0c0000         | lea                 eax, [esi + 0xc6e]
            //   50                   | push                eax
            //   57                   | push                edi

        $sequence_4 = { 8d85a8feffff 68???????? 50 ffd6 }
            // n = 4, score = 100
            //   8d85a8feffff         | lea                 eax, [ebp - 0x158]
            //   68????????           |                     
            //   50                   | push                eax
            //   ffd6                 | call                esi

        $sequence_5 = { 50 ff55fc 8bc3 eb48 ff15???????? 56 }
            // n = 6, score = 100
            //   50                   | push                eax
            //   ff55fc               | call                dword ptr [ebp - 4]
            //   8bc3                 | mov                 eax, ebx
            //   eb48                 | jmp                 0x4a
            //   ff15????????         |                     
            //   56                   | push                esi

        $sequence_6 = { 8d8584fdffff 50 ff55bc 50 8d8584fdffff 50 }
            // n = 6, score = 100
            //   8d8584fdffff         | lea                 eax, [ebp - 0x27c]
            //   50                   | push                eax
            //   ff55bc               | call                dword ptr [ebp - 0x44]
            //   50                   | push                eax
            //   8d8584fdffff         | lea                 eax, [ebp - 0x27c]
            //   50                   | push                eax

        $sequence_7 = { 8d8584f9ffff 57 50 ff55f0 }
            // n = 4, score = 100
            //   8d8584f9ffff         | lea                 eax, [ebp - 0x67c]
            //   57                   | push                edi
            //   50                   | push                eax
            //   ff55f0               | call                dword ptr [ebp - 0x10]

        $sequence_8 = { ff5508 ff7510 e9???????? 53 }
            // n = 4, score = 100
            //   ff5508               | call                dword ptr [ebp + 8]
            //   ff7510               | push                dword ptr [ebp + 0x10]
            //   e9????????           |                     
            //   53                   | push                ebx

        $sequence_9 = { 8d85a8feffff 68???????? 50 ffd6 8d85a8feffff 68???????? 50 }
            // n = 7, score = 100
            //   8d85a8feffff         | lea                 eax, [ebp - 0x158]
            //   68????????           |                     
            //   50                   | push                eax
            //   ffd6                 | call                esi
            //   8d85a8feffff         | lea                 eax, [ebp - 0x158]
            //   68????????           |                     
            //   50                   | push                eax

    condition:
        7 of them and filesize < 57344
}