rule win_whiskerspy_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.whiskerspy."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.whiskerspy"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b06 8bcf d3e8 a801 }
            // n = 4, score = 300
            //   8b06                 | mov                 eax, dword ptr [esi]
            //   8bcf                 | mov                 ecx, edi
            //   d3e8                 | shr                 eax, cl
            //   a801                 | test                al, 1

        $sequence_1 = { 488bcf c645e57d c645e67d c645e77d c645e87d }
            // n = 5, score = 200
            //   488bcf               | lea                 edx, [ebp + 0x2c0]
            //   c645e57d             | dec                 eax
            //   c645e67d             | lea                 ecx, [ebp + 0x180]
            //   c645e77d             | dec                 eax
            //   c645e87d             | lea                 ecx, [esp + 0x60]

        $sequence_2 = { 458bc6 488d95c0020000 488d8d80010000 ff15???????? 488d4c2460 ff15???????? }
            // n = 6, score = 200
            //   458bc6               | mov                 edi, ecx
            //   488d95c0020000       | dec                 eax
            //   488d8d80010000       | lea                 edx, [0xc107]
            //   ff15????????         |                     
            //   488d4c2460           | mov                 ecx, 3
            //   ff15????????         |                     

        $sequence_3 = { 5d c3 418bca 48899c2440020000 }
            // n = 4, score = 200
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   418bca               | inc                 ecx
            //   48899c2440020000     | mov                 ecx, edx

        $sequence_4 = { 33c0 e9???????? c685c0020000c8 c685c1020000d3 }
            // n = 4, score = 200
            //   33c0                 | xor                 eax, eax
            //   e9????????           |                     
            //   c685c0020000c8       | mov                 byte ptr [ebp + 0x2c0], 0xc8
            //   c685c1020000d3       | mov                 byte ptr [ebp + 0x2c1], 0xd3

        $sequence_5 = { e8???????? 0f2805???????? 4c8d45b0 0f280d???????? 488d55f0 }
            // n = 5, score = 200
            //   e8????????           |                     
            //   0f2805????????       |                     
            //   4c8d45b0             | dec                 eax
            //   0f280d????????       |                     
            //   488d55f0             | mov                 dword ptr [esp + 0x240], ebx

        $sequence_6 = { 8bf9 488d1507c10000 b903000000 4c8d05f3c00000 e8???????? }
            // n = 5, score = 200
            //   8bf9                 | dec                 esp
            //   488d1507c10000       | lea                 eax, [ebp - 0x50]
            //   b903000000           | dec                 eax
            //   4c8d05f3c00000       | lea                 edx, [ebp - 0x10]
            //   e8????????           |                     

        $sequence_7 = { 85c0 7428 817c245000040000 74b4 eb1c }
            // n = 5, score = 200
            //   85c0                 | dec                 esp
            //   7428                 | lea                 eax, [0xc0f3]
            //   817c245000040000     | inc                 ebp
            //   74b4                 | mov                 eax, esi
            //   eb1c                 | dec                 eax

        $sequence_8 = { 0fbec1 83e820 83e07f 8b04c5d43f4300 }
            // n = 4, score = 100
            //   0fbec1               | jmp                 0x2c
            //   83e820               | dec                 eax
            //   83e07f               | mov                 ecx, edi
            //   8b04c5d43f4300       | mov                 byte ptr [ebp - 0x1b], 0x7d

        $sequence_9 = { 33c5 8945fc 53 8bd9 899540ffffff 8b4d0c }
            // n = 6, score = 100
            //   33c5                 | mov                 ebp, ebx
            //   8945fc               | dec                 eax
            //   53                   | lea                 esi, [0x11557]
            //   8bd9                 | xor                 edi, edi
            //   899540ffffff         | mov                 eax, dword ptr [esi]
            //   8b4d0c               | mov                 ecx, edi

        $sequence_10 = { f30f38f6f8 897de4 b800000000 8b7de8 660f38f6f9 }
            // n = 5, score = 100
            //   f30f38f6f8           | mov                 byte ptr [ebp - 0x19], 0x7d
            //   897de4               | mov                 byte ptr [ebp - 0x18], 0x7d
            //   b800000000           | or                  eax, 0xffffffff
            //   8b7de8               | jmp                 0x8d
            //   660f38f6f9           | dec                 eax

        $sequence_11 = { 8b45ec 3bc6 7c3a 7f04 }
            // n = 4, score = 100
            //   8b45ec               | shr                 eax, cl
            //   3bc6                 | test                al, 1
            //   7c3a                 | movsx               eax, cl
            //   7f04                 | sub                 eax, 0x20

        $sequence_12 = { 6af6 ff15???????? 8b04bd403d4400 834c0318ff 33c0 }
            // n = 5, score = 100
            //   6af6                 | mov                 ecx, edi
            //   ff15????????         |                     
            //   8b04bd403d4400       | shr                 eax, cl
            //   834c0318ff           | mov                 eax, dword ptr [esi]
            //   33c0                 | mov                 ecx, edi

        $sequence_13 = { 75f8 8bfe 8bca 8bb588feffff }
            // n = 4, score = 100
            //   75f8                 | shr                 eax, cl
            //   8bfe                 | test                al, 1
            //   8bca                 | xor                 edi, edi
            //   8bb588feffff         | mov                 eax, dword ptr [esi]

        $sequence_14 = { a3???????? 8bcf e8???????? 8325????????00 8325????????00 }
            // n = 5, score = 100
            //   a3????????           |                     
            //   8bcf                 | mov                 byte ptr [ebp - 0x1a], 0x7d
            //   e8????????           |                     
            //   8325????????00       |                     
            //   8325????????00       |                     

    condition:
        7 of them and filesize < 591872
}