rule win_winordll64_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.winordll64."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.winordll64"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { e8???????? 488d4dbc ff15???????? 488d15ae1c0100 488bc8 e8???????? 85c0 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   488d4dbc             | dec                 eax
            //   ff15????????         |                     
            //   488d15ae1c0100       | mov                 ecx, dword ptr [esi]
            //   488bc8               | call                dword ptr [esi + 0x20]
            //   e8????????           |                     
            //   85c0                 | mov                 edx, 0x238

        $sequence_1 = { 4833c4 488985581d0000 488bd9 b838070000 48ffc8 c6040100 75f7 }
            // n = 7, score = 100
            //   4833c4               | lea                 esi, [0xfd04]
            //   488985581d0000       | and                 ebx, 0x1f
            //   488bd9               | jae                 0x16a
            //   b838070000           | dec                 eax
            //   48ffc8               | mov                 ebx, edi
            //   c6040100             | dec                 esp
            //   75f7                 | mov                 ebp, edi

        $sequence_2 = { 48897c2420 ff15???????? 85c0 7426 448b842490000000 4c8d4c2430 }
            // n = 6, score = 100
            //   48897c2420           | mov                 eax, dword ptr [esi + eax + 0x10]
            //   ff15????????         |                     
            //   85c0                 | mov                 dword ptr [ebp - 0x2c], eax
            //   7426                 | mov                 esi, edi
            //   448b842490000000     | dec                 eax
            //   4c8d4c2430           | lea                 edx, [esp + 0x78]

        $sequence_3 = { e9???????? ba12000000 ebf0 48897c2440 897c2448 488d442448 4889442420 }
            // n = 7, score = 100
            //   e9????????           |                     
            //   ba12000000           | mov                 ecx, dword ptr [esp]
            //   ebf0                 | inc                 ebp
            //   48897c2440           | test                esi, esi
            //   897c2448             | je                  0x312
            //   488d442448           | mov                 edx, 0x11
            //   4889442420           | jne                 0x2b3

        $sequence_4 = { e8???????? 4c8d0513c50000 41b903000000 488d4c45bc 488bc1 492bc5 }
            // n = 6, score = 100
            //   e8????????           |                     
            //   4c8d0513c50000       | dec                 eax
            //   41b903000000         | cmovne              esi, ebx
            //   488d4c45bc           | js                  0x138
            //   488bc1               | inc                 ebp
            //   492bc5               | xor                 eax, eax

        $sequence_5 = { 488bcf c744243001000000 448be8 ff15???????? }
            // n = 4, score = 100
            //   488bcf               | test                ebx, ebx
            //   c744243001000000     | dec                 eax
            //   448be8               | add                 eax, 2
            //   ff15????????         |                     

        $sequence_6 = { 663918 75f5 4c8d4da0 48837db808 4c0f434da0 486307 }
            // n = 6, score = 100
            //   663918               | lea                 esi, [esp + 0x70]
            //   75f5                 | dec                 eax
            //   4c8d4da0             | cmp                 dword ptr [ebp - 0x78], 8
            //   48837db808           | dec                 eax
            //   4c0f434da0           | cmovae              esi, dword ptr [esp + 0x70]
            //   486307               | dec                 eax

        $sequence_7 = { 7423 83fefe 741e 488bce 488bc6 488d1554370100 83e11f }
            // n = 7, score = 100
            //   7423                 | dec                 esp
            //   83fefe               | lea                 ebx, [0x4a9b]
            //   741e                 | dec                 eax
            //   488bce               | lea                 edx, [0x640c]
            //   488bc6               | dec                 eax
            //   488d1554370100       | lea                 ecx, [ebp - 0x11]
            //   83e11f               | dec                 esp

        $sequence_8 = { 7767 488d4d98 482bcb 48b8abaaaaaaaaaaaa2a 48f7e9 488bf2 }
            // n = 6, score = 100
            //   7767                 | dec                 eax
            //   488d4d98             | mov                 dword ptr [eax + 8], esi
            //   482bcb               | push                ebp
            //   48b8abaaaaaaaaaaaa2a     | pop    esi
            //   48f7e9               | ret                 
            //   488bf2               | inc                 eax

        $sequence_9 = { 0f84bd010000 488b4c2450 4533c0 418bd5 ff15???????? 85c0 0f847b010000 }
            // n = 7, score = 100
            //   0f84bd010000         | xor                 ecx, esp
            //   488b4c2450           | dec                 eax
            //   4533c0               | mov                 ebx, dword ptr [esp + 0x380]
            //   418bd5               | dec                 eax
            //   ff15????????         |                     
            //   85c0                 | add                 esp, 0x330
            //   0f847b010000         | mov                 eax, esi

    condition:
        7 of them and filesize < 278528
}