rule win_wmighost_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.wmighost."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.wmighost"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 52 e8???????? 83c40c 68e8030000 ff15???????? e9???????? }
            // n = 6, score = 100
            //   52                   | push                edx
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   68e8030000           | push                0x3e8
            //   ff15????????         |                     
            //   e9????????           |                     

        $sequence_1 = { 83c408 68???????? 8d8df0fcffff 51 }
            // n = 4, score = 100
            //   83c408               | add                 esp, 8
            //   68????????           |                     
            //   8d8df0fcffff         | lea                 ecx, [ebp - 0x310]
            //   51                   | push                ecx

        $sequence_2 = { c745fc00000000 8d4d08 e8???????? 50 8b45e8 8b08 }
            // n = 6, score = 100
            //   c745fc00000000       | mov                 dword ptr [ebp - 4], 0
            //   8d4d08               | lea                 ecx, [ebp + 8]
            //   e8????????           |                     
            //   50                   | push                eax
            //   8b45e8               | mov                 eax, dword ptr [ebp - 0x18]
            //   8b08                 | mov                 ecx, dword ptr [eax]

        $sequence_3 = { 8945fc 837dfcff 7505 e9???????? 6a02 }
            // n = 5, score = 100
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   837dfcff             | cmp                 dword ptr [ebp - 4], -1
            //   7505                 | jne                 7
            //   e9????????           |                     
            //   6a02                 | push                2

        $sequence_4 = { 8b550c 52 8d85f0fcffff 50 e8???????? 83c408 }
            // n = 6, score = 100
            //   8b550c               | mov                 edx, dword ptr [ebp + 0xc]
            //   52                   | push                edx
            //   8d85f0fcffff         | lea                 eax, [ebp - 0x310]
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c408               | add                 esp, 8

        $sequence_5 = { 33c1 8b55f8 8882c8304000 8b45f8 0fbe88c8304000 33d2 8a15???????? }
            // n = 7, score = 100
            //   33c1                 | xor                 eax, ecx
            //   8b55f8               | mov                 edx, dword ptr [ebp - 8]
            //   8882c8304000         | mov                 byte ptr [edx + 0x4030c8], al
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   0fbe88c8304000       | movsx               ecx, byte ptr [eax + 0x4030c8]
            //   33d2                 | xor                 edx, edx
            //   8a15????????         |                     

        $sequence_6 = { 66ab aa c685f0fcffff00 b940000000 33c0 8dbdf1fcffff }
            // n = 6, score = 100
            //   66ab                 | stosw               word ptr es:[edi], ax
            //   aa                   | stosb               byte ptr es:[edi], al
            //   c685f0fcffff00       | mov                 byte ptr [ebp - 0x310], 0
            //   b940000000           | mov                 ecx, 0x40
            //   33c0                 | xor                 eax, eax
            //   8dbdf1fcffff         | lea                 edi, [ebp - 0x30f]

        $sequence_7 = { 50 8b4df0 51 e8???????? c745fcffffffff 8d4d08 e8???????? }
            // n = 7, score = 100
            //   50                   | push                eax
            //   8b4df0               | mov                 ecx, dword ptr [ebp - 0x10]
            //   51                   | push                ecx
            //   e8????????           |                     
            //   c745fcffffffff       | mov                 dword ptr [ebp - 4], 0xffffffff
            //   8d4d08               | lea                 ecx, [ebp + 8]
            //   e8????????           |                     

        $sequence_8 = { 8dbdfdfeffff f3ab 66ab aa c685f0fcffff00 b940000000 }
            // n = 6, score = 100
            //   8dbdfdfeffff         | lea                 edi, [ebp - 0x103]
            //   f3ab                 | rep stosd           dword ptr es:[edi], eax
            //   66ab                 | stosw               word ptr es:[edi], ax
            //   aa                   | stosb               byte ptr es:[edi], al
            //   c685f0fcffff00       | mov                 byte ptr [ebp - 0x310], 0
            //   b940000000           | mov                 ecx, 0x40

        $sequence_9 = { 8955e4 8b45ec 50 8b4de4 51 6aff }
            // n = 6, score = 100
            //   8955e4               | mov                 dword ptr [ebp - 0x1c], edx
            //   8b45ec               | mov                 eax, dword ptr [ebp - 0x14]
            //   50                   | push                eax
            //   8b4de4               | mov                 ecx, dword ptr [ebp - 0x1c]
            //   51                   | push                ecx
            //   6aff                 | push                -1

    condition:
        7 of them and filesize < 49152
}