rule win_woodyrat_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.woodyrat."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.woodyrat"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b75ec 8985a4ebffff ffb5bcebffff e8???????? 8b7de4 83c404 837de800 }
            // n = 7, score = 100
            //   8b75ec               | mov                 esi, dword ptr [ebp - 0x14]
            //   8985a4ebffff         | mov                 dword ptr [ebp - 0x145c], eax
            //   ffb5bcebffff         | push                dword ptr [ebp - 0x1444]
            //   e8????????           |                     
            //   8b7de4               | mov                 edi, dword ptr [ebp - 0x1c]
            //   83c404               | add                 esp, 4
            //   837de800             | cmp                 dword ptr [ebp - 0x18], 0

        $sequence_1 = { 8d4e4c 54 6a00 e8???????? 8bc8 e8???????? 8d4dd8 }
            // n = 7, score = 100
            //   8d4e4c               | lea                 ecx, [esi + 0x4c]
            //   54                   | push                esp
            //   6a00                 | push                0
            //   e8????????           |                     
            //   8bc8                 | mov                 ecx, eax
            //   e8????????           |                     
            //   8d4dd8               | lea                 ecx, [ebp - 0x28]

        $sequence_2 = { 8d4710 50 8d45cc 50 e8???????? 84c0 7403 }
            // n = 7, score = 100
            //   8d4710               | lea                 eax, [edi + 0x10]
            //   50                   | push                eax
            //   8d45cc               | lea                 eax, [ebp - 0x34]
            //   50                   | push                eax
            //   e8????????           |                     
            //   84c0                 | test                al, al
            //   7403                 | je                  5

        $sequence_3 = { e8???????? c645fc03 8b55cc 83fa10 722c 8b4db8 42 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   c645fc03             | mov                 byte ptr [ebp - 4], 3
            //   8b55cc               | mov                 edx, dword ptr [ebp - 0x34]
            //   83fa10               | cmp                 edx, 0x10
            //   722c                 | jb                  0x2e
            //   8b4db8               | mov                 ecx, dword ptr [ebp - 0x48]
            //   42                   | inc                 edx

        $sequence_4 = { 8b4328 8bd8 3bfb 742d 8b0f 8b01 ff5008 }
            // n = 7, score = 100
            //   8b4328               | mov                 eax, dword ptr [ebx + 0x28]
            //   8bd8                 | mov                 ebx, eax
            //   3bfb                 | cmp                 edi, ebx
            //   742d                 | je                  0x2f
            //   8b0f                 | mov                 ecx, dword ptr [edi]
            //   8b01                 | mov                 eax, dword ptr [ecx]
            //   ff5008               | call                dword ptr [eax + 8]

        $sequence_5 = { 8bc8 83781410 7202 8b08 83781004 753b 8b01 }
            // n = 7, score = 100
            //   8bc8                 | mov                 ecx, eax
            //   83781410             | cmp                 dword ptr [eax + 0x14], 0x10
            //   7202                 | jb                  4
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   83781004             | cmp                 dword ptr [eax + 0x10], 4
            //   753b                 | jne                 0x3d
            //   8b01                 | mov                 eax, dword ptr [ecx]

        $sequence_6 = { 83c408 8d4508 6a00 84db 7428 837d1c08 6800000002 }
            // n = 7, score = 100
            //   83c408               | add                 esp, 8
            //   8d4508               | lea                 eax, [ebp + 8]
            //   6a00                 | push                0
            //   84db                 | test                bl, bl
            //   7428                 | je                  0x2a
            //   837d1c08             | cmp                 dword ptr [ebp + 0x1c], 8
            //   6800000002           | push                0x2000000

        $sequence_7 = { 50 e8???????? 8b7d80 83c404 e9???????? c645fc00 }
            // n = 6, score = 100
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b7d80               | mov                 edi, dword ptr [ebp - 0x80]
            //   83c404               | add                 esp, 4
            //   e9????????           |                     
            //   c645fc00             | mov                 byte ptr [ebp - 4], 0

        $sequence_8 = { 7607 be55555515 eb07 03f1 3bf2 0f42f2 }
            // n = 6, score = 100
            //   7607                 | jbe                 9
            //   be55555515           | mov                 esi, 0x15555555
            //   eb07                 | jmp                 9
            //   03f1                 | add                 esi, ecx
            //   3bf2                 | cmp                 esi, edx
            //   0f42f2               | cmovb               esi, edx

        $sequence_9 = { 745d 40 50 e8???????? 8bf0 8b45c8 40 }
            // n = 7, score = 100
            //   745d                 | je                  0x5f
            //   40                   | inc                 eax
            //   50                   | push                eax
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax
            //   8b45c8               | mov                 eax, dword ptr [ebp - 0x38]
            //   40                   | inc                 eax

    condition:
        7 of them and filesize < 785408
}