rule win_wscspl_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.wscspl."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.wscspl"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 740b b855000000 66a3???????? 8b4c2404 51 }
            // n = 5, score = 400
            //   740b                 | je                  0xd
            //   b855000000           | mov                 eax, 0x55
            //   66a3????????         |                     
            //   8b4c2404             | mov                 ecx, dword ptr [esp + 4]
            //   51                   | push                ecx

        $sequence_1 = { 8bcd 8d742414 8d442418 e8???????? 0fbf442414 50 8d4c241c }
            // n = 7, score = 400
            //   8bcd                 | mov                 ecx, ebp
            //   8d742414             | lea                 esi, [esp + 0x14]
            //   8d442418             | lea                 eax, [esp + 0x18]
            //   e8????????           |                     
            //   0fbf442414           | movsx               eax, word ptr [esp + 0x14]
            //   50                   | push                eax
            //   8d4c241c             | lea                 ecx, [esp + 0x1c]

        $sequence_2 = { 8d442430 50 68???????? 6a00 6a00 c744244000000000 }
            // n = 6, score = 400
            //   8d442430             | lea                 eax, [esp + 0x30]
            //   50                   | push                eax
            //   68????????           |                     
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   c744244000000000     | mov                 dword ptr [esp + 0x40], 0

        $sequence_3 = { 8b74240c 3bf7 7435 8b3d???????? 8d4900 8b4618 8b4004 }
            // n = 7, score = 400
            //   8b74240c             | mov                 esi, dword ptr [esp + 0xc]
            //   3bf7                 | cmp                 esi, edi
            //   7435                 | je                  0x37
            //   8b3d????????         |                     
            //   8d4900               | lea                 ecx, [ecx]
            //   8b4618               | mov                 eax, dword ptr [esi + 0x18]
            //   8b4004               | mov                 eax, dword ptr [eax + 4]

        $sequence_4 = { 8d642400 8b0c18 8d1418 bf05000000 }
            // n = 4, score = 400
            //   8d642400             | lea                 esp, [esp]
            //   8b0c18               | mov                 ecx, dword ptr [eax + ebx]
            //   8d1418               | lea                 edx, [eax + ebx]
            //   bf05000000           | mov                 edi, 5

        $sequence_5 = { 3bc1 763a 03c9 3bc1 }
            // n = 4, score = 400
            //   3bc1                 | cmp                 eax, ecx
            //   763a                 | jbe                 0x3c
            //   03c9                 | add                 ecx, ecx
            //   3bc1                 | cmp                 eax, ecx

        $sequence_6 = { 663bf8 752f e8???????? 8b0d???????? }
            // n = 4, score = 400
            //   663bf8               | cmp                 di, ax
            //   752f                 | jne                 0x31
            //   e8????????           |                     
            //   8b0d????????         |                     

        $sequence_7 = { 51 ff15???????? ff15???????? 6888130000 }
            // n = 4, score = 400
            //   51                   | push                ecx
            //   ff15????????         |                     
            //   ff15????????         |                     
            //   6888130000           | push                0x1388

        $sequence_8 = { 8b1d???????? 55 33c0 56 83c1fb }
            // n = 5, score = 400
            //   8b1d????????         |                     
            //   55                   | push                ebp
            //   33c0                 | xor                 eax, eax
            //   56                   | push                esi
            //   83c1fb               | add                 ecx, -5

        $sequence_9 = { 687c230000 8d44240c 6a01 50 ff15???????? 687c230000 68c10b0000 }
            // n = 7, score = 400
            //   687c230000           | push                0x237c
            //   8d44240c             | lea                 eax, [esp + 0xc]
            //   6a01                 | push                1
            //   50                   | push                eax
            //   ff15????????         |                     
            //   687c230000           | push                0x237c
            //   68c10b0000           | push                0xbc1

    condition:
        7 of them and filesize < 901120
}