rule win_xiangoop_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.xiangoop."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.xiangoop"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { b801000000 d1e0 8b55f4 0fb6440208 25ff000000 }
            // n = 5, score = 100
            //   b801000000           | mov                 eax, 1
            //   d1e0                 | shl                 eax, 1
            //   8b55f4               | mov                 edx, dword ptr [ebp - 0xc]
            //   0fb6440208           | movzx               eax, byte ptr [edx + eax + 8]
            //   25ff000000           | and                 eax, 0xff

        $sequence_1 = { c1e903 8d540906 8b4508 8990e0010000 c745ec00000000 8b4d08 }
            // n = 6, score = 100
            //   c1e903               | shr                 ecx, 3
            //   8d540906             | lea                 edx, [ecx + ecx + 6]
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   8990e0010000         | mov                 dword ptr [eax + 0x1e0], edx
            //   c745ec00000000       | mov                 dword ptr [ebp - 0x14], 0
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]

        $sequence_2 = { ebe3 8b45f0 8b0c85a8b00110 8b45ec 807c082800 }
            // n = 5, score = 100
            //   ebe3                 | jmp                 0xffffffe5
            //   8b45f0               | mov                 eax, dword ptr [ebp - 0x10]
            //   8b0c85a8b00110       | mov                 ecx, dword ptr [eax*4 + 0x1001b0a8]
            //   8b45ec               | mov                 eax, dword ptr [ebp - 0x14]
            //   807c082800           | cmp                 byte ptr [eax + ecx + 0x28], 0

        $sequence_3 = { c1e008 0bc8 ba01000000 6bc203 8b550c 0fb644020c 25ff000000 }
            // n = 7, score = 100
            //   c1e008               | shl                 eax, 8
            //   0bc8                 | or                  ecx, eax
            //   ba01000000           | mov                 edx, 1
            //   6bc203               | imul                eax, edx, 3
            //   8b550c               | mov                 edx, dword ptr [ebp + 0xc]
            //   0fb644020c           | movzx               eax, byte ptr [edx + eax + 0xc]
            //   25ff000000           | and                 eax, 0xff

        $sequence_4 = { 8955c8 6804010000 8d85bcfdffff 50 8b4dc8 }
            // n = 5, score = 100
            //   8955c8               | mov                 dword ptr [ebp - 0x38], edx
            //   6804010000           | push                0x104
            //   8d85bcfdffff         | lea                 eax, [ebp - 0x244]
            //   50                   | push                eax
            //   8b4dc8               | mov                 ecx, dword ptr [ebp - 0x38]

        $sequence_5 = { 81e2ff000000 b801000000 6bc800 8b4510 8854080c 8b4dec }
            // n = 6, score = 100
            //   81e2ff000000         | and                 edx, 0xff
            //   b801000000           | mov                 eax, 1
            //   6bc800               | imul                ecx, eax, 0
            //   8b4510               | mov                 eax, dword ptr [ebp + 0x10]
            //   8854080c             | mov                 byte ptr [eax + ecx + 0xc], dl
            //   8b4dec               | mov                 ecx, dword ptr [ebp - 0x14]

        $sequence_6 = { c3 b001 c3 c705????????80a50110 b001 c3 68???????? }
            // n = 7, score = 100
            //   c3                   | ret                 
            //   b001                 | mov                 al, 1
            //   c3                   | ret                 
            //   c705????????80a50110     |     
            //   b001                 | mov                 al, 1
            //   c3                   | ret                 
            //   68????????           |                     

        $sequence_7 = { 8b45fc 8b4dfc 034804 894dfc e9???????? b801000000 8be5 }
            // n = 7, score = 100
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   034804               | add                 ecx, dword ptr [eax + 4]
            //   894dfc               | mov                 dword ptr [ebp - 4], ecx
            //   e9????????           |                     
            //   b801000000           | mov                 eax, 1
            //   8be5                 | mov                 esp, ebp

        $sequence_8 = { 890c02 8b45ec 83c001 8945ec 837dec08 7502 }
            // n = 6, score = 100
            //   890c02               | mov                 dword ptr [edx + eax], ecx
            //   8b45ec               | mov                 eax, dword ptr [ebp - 0x14]
            //   83c001               | add                 eax, 1
            //   8945ec               | mov                 dword ptr [ebp - 0x14], eax
            //   837dec08             | cmp                 dword ptr [ebp - 0x14], 8
            //   7502                 | jne                 4

        $sequence_9 = { 8b45f4 83c028 8945f4 ebcb }
            // n = 4, score = 100
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]
            //   83c028               | add                 eax, 0x28
            //   8945f4               | mov                 dword ptr [ebp - 0xc], eax
            //   ebcb                 | jmp                 0xffffffcd

    condition:
        7 of them and filesize < 246784
}