rule win_xsplus_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.xsplus."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.xsplus"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b761c 8b4608 8b7e20 8b36 66394f18 75f2 }
            // n = 6, score = 400
            //   8b761c               | mov                 esi, dword ptr [esi + 0x1c]
            //   8b4608               | mov                 eax, dword ptr [esi + 8]
            //   8b7e20               | mov                 edi, dword ptr [esi + 0x20]
            //   8b36                 | mov                 esi, dword ptr [esi]
            //   66394f18             | cmp                 word ptr [edi + 0x18], cx
            //   75f2                 | jne                 0xfffffff4

        $sequence_1 = { 0fb602 33c1 8b4d0c 034dfc 8801 }
            // n = 5, score = 300
            //   0fb602               | movzx               eax, byte ptr [edx]
            //   33c1                 | xor                 eax, ecx
            //   8b4d0c               | mov                 ecx, dword ptr [ebp + 0xc]
            //   034dfc               | add                 ecx, dword ptr [ebp - 4]
            //   8801                 | mov                 byte ptr [ecx], al

        $sequence_2 = { 83c408 8945f0 837df000 750f }
            // n = 4, score = 300
            //   83c408               | add                 esp, 8
            //   8945f0               | mov                 dword ptr [ebp - 0x10], eax
            //   837df000             | cmp                 dword ptr [ebp - 0x10], 0
            //   750f                 | jne                 0x11

        $sequence_3 = { e9???????? 8be5 5d c3 3b0d???????? }
            // n = 5, score = 300
            //   e9????????           |                     
            //   8be5                 | mov                 esp, ebp
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   3b0d????????         |                     

        $sequence_4 = { 8b45f4 83c001 8945f4 ebbf eb2c 6a08 8d4df8 }
            // n = 7, score = 300
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]
            //   83c001               | add                 eax, 1
            //   8945f4               | mov                 dword ptr [ebp - 0xc], eax
            //   ebbf                 | jmp                 0xffffffc1
            //   eb2c                 | jmp                 0x2e
            //   6a08                 | push                8
            //   8d4df8               | lea                 ecx, [ebp - 8]

        $sequence_5 = { 895018 8b4df8 8b511c 83ea01 }
            // n = 4, score = 300
            //   895018               | mov                 dword ptr [eax + 0x18], edx
            //   8b4df8               | mov                 ecx, dword ptr [ebp - 8]
            //   8b511c               | mov                 edx, dword ptr [ecx + 0x1c]
            //   83ea01               | sub                 edx, 1

        $sequence_6 = { c6864b01000043 c74668e0a34000 6a0d e8???????? 59 8365fc00 }
            // n = 6, score = 300
            //   c6864b01000043       | mov                 byte ptr [esi + 0x14b], 0x43
            //   c74668e0a34000       | mov                 dword ptr [esi + 0x68], 0x40a3e0
            //   6a0d                 | push                0xd
            //   e8????????           |                     
            //   59                   | pop                 ecx
            //   8365fc00             | and                 dword ptr [ebp - 4], 0

        $sequence_7 = { 0345fc 8a08 880a c745f800000000 }
            // n = 4, score = 300
            //   0345fc               | add                 eax, dword ptr [ebp - 4]
            //   8a08                 | mov                 cl, byte ptr [eax]
            //   880a                 | mov                 byte ptr [edx], cl
            //   c745f800000000       | mov                 dword ptr [ebp - 8], 0

        $sequence_8 = { 8d8df4fdffff 51 ff15???????? 8985ecfcffff 83bdecfcffffff 7565 6804010000 }
            // n = 7, score = 300
            //   8d8df4fdffff         | lea                 ecx, [ebp - 0x20c]
            //   51                   | push                ecx
            //   ff15????????         |                     
            //   8985ecfcffff         | mov                 dword ptr [ebp - 0x314], eax
            //   83bdecfcffffff       | cmp                 dword ptr [ebp - 0x314], -1
            //   7565                 | jne                 0x67
            //   6804010000           | push                0x104

        $sequence_9 = { 8b5118 d1e2 8b45f8 895018 8b4df8 }
            // n = 5, score = 300
            //   8b5118               | mov                 edx, dword ptr [ecx + 0x18]
            //   d1e2                 | shl                 edx, 1
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   895018               | mov                 dword ptr [eax + 0x18], edx
            //   8b4df8               | mov                 ecx, dword ptr [ebp - 8]

        $sequence_10 = { c745fc04000000 eb2d 8b5510 83e204 }
            // n = 4, score = 300
            //   c745fc04000000       | mov                 dword ptr [ebp - 4], 4
            //   eb2d                 | jmp                 0x2f
            //   8b5510               | mov                 edx, dword ptr [ebp + 0x10]
            //   83e204               | and                 edx, 4

        $sequence_11 = { 83c101 898de8feffff 8b550c 52 e8???????? }
            // n = 5, score = 300
            //   83c101               | add                 ecx, 1
            //   898de8feffff         | mov                 dword ptr [ebp - 0x118], ecx
            //   8b550c               | mov                 edx, dword ptr [ebp + 0xc]
            //   52                   | push                edx
            //   e8????????           |                     

        $sequence_12 = { 8a800ca84000 08443b1d 0fb64601 47 3bf8 76ea }
            // n = 6, score = 300
            //   8a800ca84000         | mov                 al, byte ptr [eax + 0x40a80c]
            //   08443b1d             | or                  byte ptr [ebx + edi + 0x1d], al
            //   0fb64601             | movzx               eax, byte ptr [esi + 1]
            //   47                   | inc                 edi
            //   3bf8                 | cmp                 edi, eax
            //   76ea                 | jbe                 0xffffffec

        $sequence_13 = { 8a15???????? 889500ffffff b93f000000 33c0 8dbd01ffffff f3ab 66ab }
            // n = 7, score = 300
            //   8a15????????         |                     
            //   889500ffffff         | mov                 byte ptr [ebp - 0x100], dl
            //   b93f000000           | mov                 ecx, 0x3f
            //   33c0                 | xor                 eax, eax
            //   8dbd01ffffff         | lea                 edi, [ebp - 0xff]
            //   f3ab                 | rep stosd           dword ptr es:[edi], eax
            //   66ab                 | stosw               word ptr es:[edi], ax

        $sequence_14 = { f3a5 8b45fc ffd0 5f 5e 8be5 }
            // n = 6, score = 300
            //   f3a5                 | rep movsd           dword ptr es:[edi], dword ptr [esi]
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   ffd0                 | call                eax
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   8be5                 | mov                 esp, ebp

        $sequence_15 = { 8b4d08 51 ff15???????? b801000000 e9???????? 6a00 ff15???????? }
            // n = 7, score = 300
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   51                   | push                ecx
            //   ff15????????         |                     
            //   b801000000           | mov                 eax, 1
            //   e9????????           |                     
            //   6a00                 | push                0
            //   ff15????????         |                     

        $sequence_16 = { 8975e0 8db120a84000 8975e4 eb2a 8a4601 }
            // n = 5, score = 300
            //   8975e0               | mov                 dword ptr [ebp - 0x20], esi
            //   8db120a84000         | lea                 esi, [ecx + 0x40a820]
            //   8975e4               | mov                 dword ptr [ebp - 0x1c], esi
            //   eb2a                 | jmp                 0x2c
            //   8a4601               | mov                 al, byte ptr [esi + 1]

    condition:
        7 of them and filesize < 597872
}