rule win_zedhou_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.zedhou."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.zedhou"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b4dac 894dd8 8d55d0 52 8d45d4 50 }
            // n = 6, score = 100
            //   8b4dac               | mov                 ecx, dword ptr [ebp - 0x54]
            //   894dd8               | mov                 dword ptr [ebp - 0x28], ecx
            //   8d55d0               | lea                 edx, [ebp - 0x30]
            //   52                   | push                edx
            //   8d45d4               | lea                 eax, [ebp - 0x2c]
            //   50                   | push                eax

        $sequence_1 = { ff5030 5f 5e 5b c9 c22400 }
            // n = 6, score = 100
            //   ff5030               | call                dword ptr [eax + 0x30]
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   5b                   | pop                 ebx
            //   c9                   | leave               
            //   c22400               | ret                 0x24

        $sequence_2 = { 57 ff7508 56 ff15???????? ff7508 ff15???????? 8bc6 }
            // n = 7, score = 100
            //   57                   | push                edi
            //   ff7508               | push                dword ptr [ebp + 8]
            //   56                   | push                esi
            //   ff15????????         |                     
            //   ff7508               | push                dword ptr [ebp + 8]
            //   ff15????????         |                     
            //   8bc6                 | mov                 eax, esi

        $sequence_3 = { 8d4da4 51 8b5508 8b02 8b4d08 51 ff9008070000 }
            // n = 7, score = 100
            //   8d4da4               | lea                 ecx, [ebp - 0x5c]
            //   51                   | push                ecx
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]
            //   8b02                 | mov                 eax, dword ptr [edx]
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   51                   | push                ecx
            //   ff9008070000         | call                dword ptr [eax + 0x708]

        $sequence_4 = { ff15???????? 8d4dc0 ff15???????? 0fbf4598 85c0 742a c745fc06000000 }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   8d4dc0               | lea                 ecx, [ebp - 0x40]
            //   ff15????????         |                     
            //   0fbf4598             | movsx               eax, word ptr [ebp - 0x68]
            //   85c0                 | test                eax, eax
            //   742a                 | je                  0x2c
            //   c745fc06000000       | mov                 dword ptr [ebp - 4], 6

        $sequence_5 = { 68???????? 8b85acfeffff 50 8b8da8feffff 51 ff15???????? 8985c4fdffff }
            // n = 7, score = 100
            //   68????????           |                     
            //   8b85acfeffff         | mov                 eax, dword ptr [ebp - 0x154]
            //   50                   | push                eax
            //   8b8da8feffff         | mov                 ecx, dword ptr [ebp - 0x158]
            //   51                   | push                ecx
            //   ff15????????         |                     
            //   8985c4fdffff         | mov                 dword ptr [ebp - 0x23c], eax

        $sequence_6 = { 33c0 f3a6 0f85653a0000 85d2 }
            // n = 4, score = 100
            //   33c0                 | xor                 eax, eax
            //   f3a6                 | repe cmpsb          byte ptr [esi], byte ptr es:[edi]
            //   0f85653a0000         | jne                 0x3a6b
            //   85d2                 | test                edx, edx

        $sequence_7 = { ff15???????? 83c41c c745fc04000000 8b5508 8b02 8b4d08 51 }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   83c41c               | add                 esp, 0x1c
            //   c745fc04000000       | mov                 dword ptr [ebp - 4], 4
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]
            //   8b02                 | mov                 eax, dword ptr [edx]
            //   8b4d08               | mov                 ecx, dword ptr [ebp + 8]
            //   51                   | push                ecx

        $sequence_8 = { ff15???????? c745fc7f000000 8b5508 8b4238 50 68???????? ff15???????? }
            // n = 7, score = 100
            //   ff15????????         |                     
            //   c745fc7f000000       | mov                 dword ptr [ebp - 4], 0x7f
            //   8b5508               | mov                 edx, dword ptr [ebp + 8]
            //   8b4238               | mov                 eax, dword ptr [edx + 0x38]
            //   50                   | push                eax
            //   68????????           |                     
            //   ff15????????         |                     

        $sequence_9 = { e8???????? 894604 8b430c 59 8b04c5fc201822 59 6a01 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   894604               | mov                 dword ptr [esi + 4], eax
            //   8b430c               | mov                 eax, dword ptr [ebx + 0xc]
            //   59                   | pop                 ecx
            //   8b04c5fc201822       | mov                 eax, dword ptr [eax*8 + 0x221820fc]
            //   59                   | pop                 ecx
            //   6a01                 | push                1

    condition:
        7 of them and filesize < 499712
}