rule win_zeoticus_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.zeoticus."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.zeoticus"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { b901000000 8b442404 0f44f1 85c0 7407 50 ff15???????? }
            // n = 7, score = 100
            //   b901000000           | mov                 ecx, 1
            //   8b442404             | mov                 eax, dword ptr [esp + 4]
            //   0f44f1               | cmove               esi, ecx
            //   85c0                 | test                eax, eax
            //   7407                 | je                  9
            //   50                   | push                eax
            //   ff15????????         |                     

        $sequence_1 = { 6a00 6a02 6a01 6a00 6a00 6a00 6890010000 }
            // n = 7, score = 100
            //   6a00                 | push                0
            //   6a02                 | push                2
            //   6a01                 | push                1
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   6890010000           | push                0x190

        $sequence_2 = { 53 68???????? 50 89048d00574300 ff15???????? a1???????? 83c410 }
            // n = 7, score = 100
            //   53                   | push                ebx
            //   68????????           |                     
            //   50                   | push                eax
            //   89048d00574300       | mov                 dword ptr [ecx*4 + 0x435700], eax
            //   ff15????????         |                     
            //   a1????????           |                     
            //   83c410               | add                 esp, 0x10

        $sequence_3 = { 8b0d???????? 8d442420 6a00 6a00 6a00 6a25 6800800000 }
            // n = 7, score = 100
            //   8b0d????????         |                     
            //   8d442420             | lea                 eax, [esp + 0x20]
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   6a25                 | push                0x25
            //   6800800000           | push                0x8000

        $sequence_4 = { 8d4c2430 6a18 51 ffd0 a1???????? 83c408 85c0 }
            // n = 7, score = 100
            //   8d4c2430             | lea                 ecx, [esp + 0x30]
            //   6a18                 | push                0x18
            //   51                   | push                ecx
            //   ffd0                 | call                eax
            //   a1????????           |                     
            //   83c408               | add                 esp, 8
            //   85c0                 | test                eax, eax

        $sequence_5 = { 42 88440e14 8b4c2424 41 894c2424 83fa0b }
            // n = 6, score = 100
            //   42                   | inc                 edx
            //   88440e14             | mov                 byte ptr [esi + ecx + 0x14], al
            //   8b4c2424             | mov                 ecx, dword ptr [esp + 0x24]
            //   41                   | inc                 ecx
            //   894c2424             | mov                 dword ptr [esp + 0x24], ecx
            //   83fa0b               | cmp                 edx, 0xb

        $sequence_6 = { 56 57 8b7c2414 894c2418 390f 0f86df010000 }
            // n = 6, score = 100
            //   56                   | push                esi
            //   57                   | push                edi
            //   8b7c2414             | mov                 edi, dword ptr [esp + 0x14]
            //   894c2418             | mov                 dword ptr [esp + 0x18], ecx
            //   390f                 | cmp                 dword ptr [edi], ecx
            //   0f86df010000         | jbe                 0x1e5

        $sequence_7 = { a3???????? c705????????00000000 c705????????00000000 c705????????00000000 e8???????? 8b4c2408 8b542404 }
            // n = 7, score = 100
            //   a3????????           |                     
            //   c705????????00000000     |     
            //   c705????????00000000     |     
            //   c705????????00000000     |     
            //   e8????????           |                     
            //   8b4c2408             | mov                 ecx, dword ptr [esp + 8]
            //   8b542404             | mov                 edx, dword ptr [esp + 4]

        $sequence_8 = { 56 57 894c2410 8b7810 8bf7 90 }
            // n = 6, score = 100
            //   56                   | push                esi
            //   57                   | push                edi
            //   894c2410             | mov                 dword ptr [esp + 0x10], ecx
            //   8b7810               | mov                 edi, dword ptr [eax + 0x10]
            //   8bf7                 | mov                 esi, edi
            //   90                   | nop                 

        $sequence_9 = { 83c408 a3???????? ff742420 ffd0 85c0 754a }
            // n = 6, score = 100
            //   83c408               | add                 esp, 8
            //   a3????????           |                     
            //   ff742420             | push                dword ptr [esp + 0x20]
            //   ffd0                 | call                eax
            //   85c0                 | test                eax, eax
            //   754a                 | jne                 0x4c

    condition:
        7 of them and filesize < 468992
}