rule win_zeus_mailsniffer_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.zeus_mailsniffer."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.zeus_mailsniffer"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 6a01 56 e8???????? 83c40c 85c0 7473 807b0e02 }
            // n = 7, score = 100
            //   6a01                 | push                1
            //   56                   | push                esi
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   85c0                 | test                eax, eax
            //   7473                 | je                  0x75
            //   807b0e02             | cmp                 byte ptr [ebx + 0xe], 2

        $sequence_1 = { 53 6880000000 6a03 53 53 68000000c0 8bc6 }
            // n = 7, score = 100
            //   53                   | push                ebx
            //   6880000000           | push                0x80
            //   6a03                 | push                3
            //   53                   | push                ebx
            //   53                   | push                ebx
            //   68000000c0           | push                0xc0000000
            //   8bc6                 | mov                 eax, esi

        $sequence_2 = { 68???????? ff750c ff15???????? 83c40c 85c0 0f85bc000000 ffd6 }
            // n = 7, score = 100
            //   68????????           |                     
            //   ff750c               | push                dword ptr [ebp + 0xc]
            //   ff15????????         |                     
            //   83c40c               | add                 esp, 0xc
            //   85c0                 | test                eax, eax
            //   0f85bc000000         | jne                 0xc2
            //   ffd6                 | call                esi

        $sequence_3 = { 0f84e2020000 53 8d4594 50 8d4588 50 c7459401000000 }
            // n = 7, score = 100
            //   0f84e2020000         | je                  0x2e8
            //   53                   | push                ebx
            //   8d4594               | lea                 eax, [ebp - 0x6c]
            //   50                   | push                eax
            //   8d4588               | lea                 eax, [ebp - 0x78]
            //   50                   | push                eax
            //   c7459401000000       | mov                 dword ptr [ebp - 0x6c], 1

        $sequence_4 = { 8b4510 0118 ff45d8 837dc800 0f8480000000 ff75f4 }
            // n = 6, score = 100
            //   8b4510               | mov                 eax, dword ptr [ebp + 0x10]
            //   0118                 | add                 dword ptr [eax], ebx
            //   ff45d8               | inc                 dword ptr [ebp - 0x28]
            //   837dc800             | cmp                 dword ptr [ebp - 0x38], 0
            //   0f8480000000         | je                  0x86
            //   ff75f4               | push                dword ptr [ebp - 0xc]

        $sequence_5 = { 33f6 e8???????? 83c40c 84c0 0f843d020000 8b45f4 }
            // n = 6, score = 100
            //   33f6                 | xor                 esi, esi
            //   e8????????           |                     
            //   83c40c               | add                 esp, 0xc
            //   84c0                 | test                al, al
            //   0f843d020000         | je                  0x243
            //   8b45f4               | mov                 eax, dword ptr [ebp - 0xc]

        $sequence_6 = { 56 ff75fc e8???????? 83c414 8bf8 8b35???????? ff15???????? }
            // n = 7, score = 100
            //   56                   | push                esi
            //   ff75fc               | push                dword ptr [ebp - 4]
            //   e8????????           |                     
            //   83c414               | add                 esp, 0x14
            //   8bf8                 | mov                 edi, eax
            //   8b35????????         |                     
            //   ff15????????         |                     

        $sequence_7 = { 0f8c5b010000 40 3b442410 72dd e9???????? 50 }
            // n = 6, score = 100
            //   0f8c5b010000         | jl                  0x161
            //   40                   | inc                 eax
            //   3b442410             | cmp                 eax, dword ptr [esp + 0x10]
            //   72dd                 | jb                  0xffffffdf
            //   e9????????           |                     
            //   50                   | push                eax

        $sequence_8 = { 74f4 6a08 8d442430 53 }
            // n = 4, score = 100
            //   74f4                 | je                  0xfffffff6
            //   6a08                 | push                8
            //   8d442430             | lea                 eax, [esp + 0x30]
            //   53                   | push                ebx

        $sequence_9 = { 2bd1 eb99 55 8bec 83e4f8 81ecfc0e0000 53 }
            // n = 7, score = 100
            //   2bd1                 | sub                 edx, ecx
            //   eb99                 | jmp                 0xffffff9b
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   83e4f8               | and                 esp, 0xfffffff8
            //   81ecfc0e0000         | sub                 esp, 0xefc
            //   53                   | push                ebx

    condition:
        7 of them and filesize < 368640
}