rule win_zlob_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.zlob."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.zlob"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { ffd6 ffd7 68???????? e8???????? c70424???????? 68???????? }
            // n = 6, score = 200
            //   ffd6                 | call                esi
            //   ffd7                 | call                edi
            //   68????????           |                     
            //   e8????????           |                     
            //   c70424????????       |                     
            //   68????????           |                     

        $sequence_1 = { 50 ff742434 ff15???????? ff742414 e8???????? ff74242c 8b4c243c }
            // n = 7, score = 200
            //   50                   | push                eax
            //   ff742434             | push                dword ptr [esp + 0x34]
            //   ff15????????         |                     
            //   ff742414             | push                dword ptr [esp + 0x14]
            //   e8????????           |                     
            //   ff74242c             | push                dword ptr [esp + 0x2c]
            //   8b4c243c             | mov                 ecx, dword ptr [esp + 0x3c]

        $sequence_2 = { 5d 8bcb 5b 83c404 ff6024 51 51 }
            // n = 7, score = 200
            //   5d                   | pop                 ebp
            //   8bcb                 | mov                 ecx, ebx
            //   5b                   | pop                 ebx
            //   83c404               | add                 esp, 4
            //   ff6024               | jmp                 dword ptr [eax + 0x24]
            //   51                   | push                ecx
            //   51                   | push                ecx

        $sequence_3 = { 50 e8???????? 8b4508 83c410 83780400 7533 8d85f0eaffff }
            // n = 7, score = 200
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   83c410               | add                 esp, 0x10
            //   83780400             | cmp                 dword ptr [eax + 4], 0
            //   7533                 | jne                 0x35
            //   8d85f0eaffff         | lea                 eax, [ebp - 0x1510]

        $sequence_4 = { 58 2bc2 03c8 f644240c02 7504 8d4c7102 8bc1 }
            // n = 7, score = 200
            //   58                   | pop                 eax
            //   2bc2                 | sub                 eax, edx
            //   03c8                 | add                 ecx, eax
            //   f644240c02           | test                byte ptr [esp + 0xc], 2
            //   7504                 | jne                 6
            //   8d4c7102             | lea                 ecx, [ecx + esi*2 + 2]
            //   8bc1                 | mov                 eax, ecx

        $sequence_5 = { 56 8b35???????? 57 8b3d???????? 0f8407020000 837d10ff }
            // n = 6, score = 200
            //   56                   | push                esi
            //   8b35????????         |                     
            //   57                   | push                edi
            //   8b3d????????         |                     
            //   0f8407020000         | je                  0x20d
            //   837d10ff             | cmp                 dword ptr [ebp + 0x10], -1

        $sequence_6 = { ffd7 8b442414 6a01 6a00 6a00 ff30 ff15???????? }
            // n = 7, score = 200
            //   ffd7                 | call                edi
            //   8b442414             | mov                 eax, dword ptr [esp + 0x14]
            //   6a01                 | push                1
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   ff30                 | push                dword ptr [eax]
            //   ff15????????         |                     

        $sequence_7 = { ff74242c 8901 50 e8???????? 83c410 ffd3 }
            // n = 6, score = 200
            //   ff74242c             | push                dword ptr [esp + 0x2c]
            //   8901                 | mov                 dword ptr [ecx], eax
            //   50                   | push                eax
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10
            //   ffd3                 | call                ebx

        $sequence_8 = { ff75e8 8d4dbc e8???????? ff45f8 8b45f8 3b45e4 0f8cedfdffff }
            // n = 7, score = 200
            //   ff75e8               | push                dword ptr [ebp - 0x18]
            //   8d4dbc               | lea                 ecx, [ebp - 0x44]
            //   e8????????           |                     
            //   ff45f8               | inc                 dword ptr [ebp - 8]
            //   8b45f8               | mov                 eax, dword ptr [ebp - 8]
            //   3b45e4               | cmp                 eax, dword ptr [ebp - 0x1c]
            //   0f8cedfdffff         | jl                  0xfffffdf3

        $sequence_9 = { 57 8b3d???????? 89442410 8b4508 8b4c2410 }
            // n = 5, score = 200
            //   57                   | push                edi
            //   8b3d????????         |                     
            //   89442410             | mov                 dword ptr [esp + 0x10], eax
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   8b4c2410             | mov                 ecx, dword ptr [esp + 0x10]

    condition:
        7 of them and filesize < 98304
}