rule win_ccleaner_backdoor_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.ccleaner_backdoor."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.ccleaner_backdoor"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 57 ffd6 50 ff15???????? 8b3d???????? }
            // n = 5, score = 200
            //   57                   | push                edi
            //   ffd6                 | call                esi
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8b3d????????         |                     

        $sequence_1 = { ff15???????? 8b3d???????? 59 ffd7 }
            // n = 4, score = 200
            //   ff15????????         |                     
            //   8b3d????????         |                     
            //   59                   | pop                 ecx
            //   ffd7                 | call                edi

        $sequence_2 = { 750a b857000780 e9???????? e8???????? }
            // n = 4, score = 200
            //   750a                 | jne                 0xc
            //   b857000780           | mov                 eax, 0x80070057
            //   e9????????           |                     
            //   e8????????           |                     

        $sequence_3 = { 01460c 488b3f 493bfc 0f8554ffffff }
            // n = 4, score = 100
            //   01460c               | dec                 eax
            //   488b3f               | mov                 edx, dword ptr [ecx]
            //   493bfc               | dec                 eax
            //   0f8554ffffff         | sub                 edx, 0x18

        $sequence_4 = { 00cc cc 4883ec28 488b11 }
            // n = 4, score = 100
            //   00cc                 | add                 ah, cl
            //   cc                   | int3                
            //   4883ec28             | inc                 eax
            //   488b11               | push                edi

        $sequence_5 = { 49 75f9 ffd3 6800400000 }
            // n = 4, score = 100
            //   49                   | dec                 ecx
            //   75f9                 | jne                 0xfffffffb
            //   ffd3                 | call                ebx
            //   6800400000           | push                0x4000

        $sequence_6 = { ff75f0 ff15???????? 85c0 0f850c010000 8b35???????? 53 }
            // n = 6, score = 100
            //   ff75f0               | call                dword ptr [eax + 8]
            //   ff15????????         |                     
            //   85c0                 | dec                 eax
            //   0f850c010000         | mov                 ecx, dword ptr [ebx + 0x28]
            //   8b35????????         |                     
            //   53                   | add                 eax, esi

        $sequence_7 = { 01442424 eb30 8b4508 897518 }
            // n = 4, score = 100
            //   01442424             | xor                 eax, eax
            //   eb30                 | pop                 edi
            //   8b4508               | pop                 esi
            //   897518               | pop                 ebp

        $sequence_8 = { 03c0 894340 8b7340 418bc4 }
            // n = 4, score = 100
            //   03c0                 | add                 dword ptr [esi + 0xc], eax
            //   894340               | dec                 eax
            //   8b7340               | mov                 edi, dword ptr [edi]
            //   418bc4               | dec                 ecx

        $sequence_9 = { 03c6 4863d0 4c8d0c12 4c8d4718 }
            // n = 4, score = 100
            //   03c6                 | int3                
            //   4863d0               | dec                 eax
            //   4c8d0c12             | mov                 dword ptr [esp + 8], ebx
            //   4c8d4718             | push                edi

        $sequence_10 = { 03c6 85c0 7f09 488b0a 488b01 ff5008 488b4b28 }
            // n = 7, score = 100
            //   03c6                 | mov                 eax, esp
            //   85c0                 | add                 eax, eax
            //   7f09                 | mov                 dword ptr [ebx + 0x40], eax
            //   488b0a               | mov                 esi, dword ptr [ebx + 0x40]
            //   488b01               | inc                 ecx
            //   ff5008               | mov                 eax, esp
            //   488b4b28             | dec                 eax

        $sequence_11 = { 891d???????? 68???????? 6a03 53 68???????? ff742424 891d???????? }
            // n = 7, score = 100
            //   891d????????         |                     
            //   68????????           |                     
            //   6a03                 | dec                 esp
            //   53                   | lea                 ecx, [edx + edx]
            //   68????????           |                     
            //   ff742424             | dec                 esp
            //   891d????????         |                     

        $sequence_12 = { 6a04 50 8d45e0 6a04 50 8d85e0feffff 50 }
            // n = 7, score = 100
            //   6a04                 | push                4
            //   50                   | push                eax
            //   8d45e0               | lea                 eax, [ebp - 0x20]
            //   6a04                 | push                4
            //   50                   | push                eax
            //   8d85e0feffff         | lea                 eax, [ebp - 0x120]
            //   50                   | push                eax

        $sequence_13 = { c1e008 8d8418a1000000 50 e8???????? 85c0 7545 }
            // n = 6, score = 100
            //   c1e008               | shl                 eax, 8
            //   8d8418a1000000       | lea                 eax, [eax + ebx + 0xa1]
            //   50                   | push                eax
            //   e8????????           |                     
            //   85c0                 | test                eax, eax
            //   7545                 | jne                 0x47

        $sequence_14 = { 012e 33c0 5f 5e 5d }
            // n = 5, score = 100
            //   012e                 | add                 eax, esi
            //   33c0                 | test                eax, eax
            //   5f                   | jg                  0xd
            //   5e                   | dec                 eax
            //   5d                   | mov                 ecx, dword ptr [edx]

        $sequence_15 = { 00cc cc 4057 4883ec50 4533db }
            // n = 5, score = 100
            //   00cc                 | add                 ah, cl
            //   cc                   | int3                
            //   4057                 | inc                 eax
            //   4883ec50             | push                edi
            //   4533db               | dec                 eax

        $sequence_16 = { 8b7df8 0faff8 ffd6 33f8 }
            // n = 4, score = 100
            //   8b7df8               | mov                 edi, dword ptr [ebp - 8]
            //   0faff8               | imul                edi, eax
            //   ffd6                 | call                esi
            //   33f8                 | xor                 edi, eax

        $sequence_17 = { 01442454 03d1 294c2450 8b4c2410 }
            // n = 4, score = 100
            //   01442454             | cmp                 ecx, eax
            //   03d1                 | jae                 0x2d
            //   294c2450             | mov                 eax, dword ptr [esi*4 + 0x100297d8]
            //   8b4c2410             | add                 eax, 0x800

        $sequence_18 = { 50 68???????? ff742418 ff15???????? 85c0 0f8579010000 }
            // n = 6, score = 100
            //   50                   | test                eax, eax
            //   68????????           |                     
            //   ff742418             | jg                  0xd
            //   ff15????????         |                     
            //   85c0                 | dec                 eax
            //   0f8579010000         | mov                 ecx, dword ptr [edx]

        $sequence_19 = { c7471854b40210 c1e803 3bc1 7302 8bc8 6afd }
            // n = 6, score = 100
            //   c7471854b40210       | lea                 eax, [edi + 0x18]
            //   c1e803               | dec                 eax
            //   3bc1                 | add                 edx, edx
            //   7302                 | dec                 eax
            //   8bc8                 | lea                 ecx, [ebx + 0x18]
            //   6afd                 | add                 eax, esi

        $sequence_20 = { 3bc2 7661 89450c 8a06 46 50 e8???????? }
            // n = 7, score = 100
            //   3bc2                 | cmp                 eax, edx
            //   7661                 | jbe                 0x63
            //   89450c               | mov                 dword ptr [ebp + 0xc], eax
            //   8a06                 | mov                 al, byte ptr [esi]
            //   46                   | inc                 esi
            //   50                   | push                eax
            //   e8????????           |                     

        $sequence_21 = { 013d???????? 8b04b5d8970210 0500080000 3bc8 }
            // n = 4, score = 100
            //   013d????????         |                     
            //   8b04b5d8970210       | call                esi
            //   0500080000           | push                eax
            //   3bc8                 | pop                 ecx

        $sequence_22 = { 3b7d10 0f8264010000 3bfa 0f835c010000 2bda 8d4602 }
            // n = 6, score = 100
            //   3b7d10               | dec                 eax
            //   0f8264010000         | mov                 eax, dword ptr [ecx]
            //   3bfa                 | call                dword ptr [eax + 8]
            //   0f835c010000         | dec                 eax
            //   2bda                 | mov                 edx, dword ptr [ebx + 0x40]
            //   8d4602               | add                 eax, esi

        $sequence_23 = { 013e 33c0 8b16 83c410 }
            // n = 4, score = 100
            //   013e                 | call                edi
            //   33c0                 | push                edi
            //   8b16                 | call                esi
            //   83c410               | push                eax

        $sequence_24 = { e8???????? 8b4510 59 f7d8 }
            // n = 4, score = 100
            //   e8????????           |                     
            //   8b4510               | mov                 eax, dword ptr [ebp + 0x10]
            //   59                   | pop                 ecx
            //   f7d8                 | neg                 eax

        $sequence_25 = { 01442418 03c8 8954242c 8b542470 }
            // n = 4, score = 100
            //   01442418             | jne                 0x114
            //   03c8                 | push                ebx
            //   8954242c             | push                eax
            //   8b542470             | push                dword ptr [esp + 0x18]

        $sequence_26 = { 01461c 8b542424 85d2 7405 }
            // n = 4, score = 100
            //   01461c               | add                 dword ptr [esi], edi
            //   8b542424             | xor                 eax, eax
            //   85d2                 | mov                 edx, dword ptr [esi]
            //   7405                 | add                 esp, 0x10

        $sequence_27 = { 01cc cc 48895c2408 57 }
            // n = 4, score = 100
            //   01cc                 | lock xadd           dword ptr [edx + 0x10], eax
            //   cc                   | add                 dword ptr [esi + 0xc], eax
            //   48895c2408           | dec                 eax
            //   57                   | mov                 edi, dword ptr [edi]

        $sequence_28 = { 4c 8bca c1e002 4c 03d5 48 }
            // n = 6, score = 100
            //   4c                   | test                eax, eax
            //   8bca                 | jg                  0xd
            //   c1e002               | dec                 eax
            //   4c                   | mov                 ecx, dword ptr [edx]
            //   03d5                 | dec                 eax
            //   48                   | mov                 eax, dword ptr [ecx]

    condition:
        7 of them and filesize < 377856
}