rule win_keylogger_apt3_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.keylogger_apt3."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.keylogger_apt3"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8be8 8d442458 50 55 57 }
            // n = 5, score = 300
            //   8be8                 | mov                 ebp, eax
            //   8d442458             | lea                 eax, [esp + 0x58]
            //   50                   | push                eax
            //   55                   | push                ebp
            //   57                   | push                edi

        $sequence_1 = { 3bf3 7523 68???????? ff15???????? 5f }
            // n = 5, score = 300
            //   3bf3                 | cmp                 esi, ebx
            //   7523                 | jne                 0x25
            //   68????????           |                     
            //   ff15????????         |                     
            //   5f                   | pop                 edi

        $sequence_2 = { 8b35???????? 8d6b08 55 50 ffd6 }
            // n = 5, score = 300
            //   8b35????????         |                     
            //   8d6b08               | lea                 ebp, [ebx + 8]
            //   55                   | push                ebp
            //   50                   | push                eax
            //   ffd6                 | call                esi

        $sequence_3 = { 7453 53 8b5c240c 55 56 8b35???????? 8d6b08 }
            // n = 7, score = 300
            //   7453                 | je                  0x55
            //   53                   | push                ebx
            //   8b5c240c             | mov                 ebx, dword ptr [esp + 0xc]
            //   55                   | push                ebp
            //   56                   | push                esi
            //   8b35????????         |                     
            //   8d6b08               | lea                 ebp, [ebx + 8]

        $sequence_4 = { 89442420 3bf8 7216 5b 5f }
            // n = 5, score = 300
            //   89442420             | mov                 dword ptr [esp + 0x20], eax
            //   3bf8                 | cmp                 edi, eax
            //   7216                 | jb                  0x18
            //   5b                   | pop                 ebx
            //   5f                   | pop                 edi

        $sequence_5 = { ffd6 50 ffd7 ffd3 89442420 83f8ff 7551 }
            // n = 7, score = 300
            //   ffd6                 | call                esi
            //   50                   | push                eax
            //   ffd7                 | call                edi
            //   ffd3                 | call                ebx
            //   89442420             | mov                 dword ptr [esp + 0x20], eax
            //   83f8ff               | cmp                 eax, -1
            //   7551                 | jne                 0x53

        $sequence_6 = { 0fb69695010000 50 0fb68694010000 51 52 50 }
            // n = 6, score = 300
            //   0fb69695010000       | movzx               edx, byte ptr [esi + 0x195]
            //   50                   | push                eax
            //   0fb68694010000       | movzx               eax, byte ptr [esi + 0x194]
            //   51                   | push                ecx
            //   52                   | push                edx
            //   50                   | push                eax

        $sequence_7 = { 84c0 75f8 2be9 8d5501 52 }
            // n = 5, score = 300
            //   84c0                 | test                al, al
            //   75f8                 | jne                 0xfffffffa
            //   2be9                 | sub                 ebp, ecx
            //   8d5501               | lea                 edx, [ebp + 1]
            //   52                   | push                edx

        $sequence_8 = { e8???????? 68???????? 68???????? 8d4d7c e8???????? 8b45dc }
            // n = 6, score = 300
            //   e8????????           |                     
            //   68????????           |                     
            //   68????????           |                     
            //   8d4d7c               | lea                 ecx, [ebp + 0x7c]
            //   e8????????           |                     
            //   8b45dc               | mov                 eax, dword ptr [ebp - 0x24]

        $sequence_9 = { c7442434d8174300 ffd6 8d542404 52 89442434 }
            // n = 5, score = 300
            //   c7442434d8174300     | mov                 dword ptr [esp + 0x34], 0x4317d8
            //   ffd6                 | call                esi
            //   8d542404             | lea                 edx, [esp + 4]
            //   52                   | push                edx
            //   89442434             | mov                 dword ptr [esp + 0x34], eax

    condition:
        7 of them and filesize < 761856
}