rule win_ransomexx_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.ransomexx."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.ransomexx"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8bc3 8d75e0 e8???????? 8bf0 85f6 0f85f8020000 eb07 }
            // n = 7, score = 100
            //   8bc3                 | mov                 eax, ebx
            //   8d75e0               | lea                 esi, [ebp - 0x20]
            //   e8????????           |                     
            //   8bf0                 | mov                 esi, eax
            //   85f6                 | test                esi, esi
            //   0f85f8020000         | jne                 0x2fe
            //   eb07                 | jmp                 9

        $sequence_1 = { 6884010000 6a08 c745fc04010000 ffd7 50 ff15???????? 8bf0 }
            // n = 7, score = 100
            //   6884010000           | push                0x184
            //   6a08                 | push                8
            //   c745fc04010000       | mov                 dword ptr [ebp - 4], 0x104
            //   ffd7                 | call                edi
            //   50                   | push                eax
            //   ff15????????         |                     
            //   8bf0                 | mov                 esi, eax

        $sequence_2 = { 8b4f08 3bce 7425 8b4704 03c0 03c0 }
            // n = 6, score = 100
            //   8b4f08               | mov                 ecx, dword ptr [edi + 8]
            //   3bce                 | cmp                 ecx, esi
            //   7425                 | je                  0x27
            //   8b4704               | mov                 eax, dword ptr [edi + 4]
            //   03c0                 | add                 eax, eax
            //   03c0                 | add                 eax, eax

        $sequence_3 = { 8bf8 85ff 752c 8d55f8 c70601000000 6a02 }
            // n = 6, score = 100
            //   8bf8                 | mov                 edi, eax
            //   85ff                 | test                edi, edi
            //   752c                 | jne                 0x2e
            //   8d55f8               | lea                 edx, [ebp - 8]
            //   c70601000000         | mov                 dword ptr [esi], 1
            //   6a02                 | push                2

        $sequence_4 = { c1ee0a 33fe 8bf7 8b7dfc 039c3da4feffff 03f3 }
            // n = 6, score = 100
            //   c1ee0a               | shr                 esi, 0xa
            //   33fe                 | xor                 edi, esi
            //   8bf7                 | mov                 esi, edi
            //   8b7dfc               | mov                 edi, dword ptr [ebp - 4]
            //   039c3da4feffff       | add                 ebx, dword ptr [ebp + edi - 0x15c]
            //   03f3                 | add                 esi, ebx

        $sequence_5 = { c1ee03 33fe 03df 8b7dfc 039c3db8feffff 8bb43d94feffff 03f3 }
            // n = 7, score = 100
            //   c1ee03               | shr                 esi, 3
            //   33fe                 | xor                 edi, esi
            //   03df                 | add                 ebx, edi
            //   8b7dfc               | mov                 edi, dword ptr [ebp - 4]
            //   039c3db8feffff       | add                 ebx, dword ptr [ebp + edi - 0x148]
            //   8bb43d94feffff       | mov                 esi, dword ptr [ebp + edi - 0x16c]
            //   03f3                 | add                 esi, ebx

        $sequence_6 = { 837df801 0f8612010000 8b4df8 8b5f04 49 b801000000 d3e0 }
            // n = 7, score = 100
            //   837df801             | cmp                 dword ptr [ebp - 8], 1
            //   0f8612010000         | jbe                 0x118
            //   8b4df8               | mov                 ecx, dword ptr [ebp - 8]
            //   8b5f04               | mov                 ebx, dword ptr [edi + 4]
            //   49                   | dec                 ecx
            //   b801000000           | mov                 eax, 1
            //   d3e0                 | shl                 eax, cl

        $sequence_7 = { 8b55f0 8b4508 8d4dd0 51 52 57 50 }
            // n = 7, score = 100
            //   8b55f0               | mov                 edx, dword ptr [ebp - 0x10]
            //   8b4508               | mov                 eax, dword ptr [ebp + 8]
            //   8d4dd0               | lea                 ecx, [ebp - 0x30]
            //   51                   | push                ecx
            //   52                   | push                edx
            //   57                   | push                edi
            //   50                   | push                eax

        $sequence_8 = { 56 50 e8???????? 8b07 83c40c 8975fc }
            // n = 6, score = 100
            //   56                   | push                esi
            //   50                   | push                eax
            //   e8????????           |                     
            //   8b07                 | mov                 eax, dword ptr [edi]
            //   83c40c               | add                 esp, 0xc
            //   8975fc               | mov                 dword ptr [ebp - 4], esi

        $sequence_9 = { 39742420 0f862e010000 8d642400 837c242001 7540 837c242400 7539 }
            // n = 7, score = 100
            //   39742420             | cmp                 dword ptr [esp + 0x20], esi
            //   0f862e010000         | jbe                 0x134
            //   8d642400             | lea                 esp, [esp]
            //   837c242001           | cmp                 dword ptr [esp + 0x20], 1
            //   7540                 | jne                 0x42
            //   837c242400           | cmp                 dword ptr [esp + 0x24], 0
            //   7539                 | jne                 0x3b

    condition:
        7 of them and filesize < 372736
}