rule win_sysraw_stealer_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.sysraw_stealer."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.sysraw_stealer"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 50 8d9504ffffff 51 8d8508ffffff 52 8d8d0cffffff }
            // n = 6, score = 700
            //   50                   | push                eax
            //   8d9504ffffff         | lea                 edx, [ebp - 0xfc]
            //   51                   | push                ecx
            //   8d8508ffffff         | lea                 eax, [ebp - 0xf8]
            //   52                   | push                edx
            //   8d8d0cffffff         | lea                 ecx, [ebp - 0xf4]

        $sequence_1 = { ffd6 a1???????? ba???????? 8b4814 c1e102 8bf9 8b480c }
            // n = 7, score = 700
            //   ffd6                 | call                esi
            //   a1????????           |                     
            //   ba????????           |                     
            //   8b4814               | mov                 ecx, dword ptr [eax + 0x14]
            //   c1e102               | shl                 ecx, 2
            //   8bf9                 | mov                 edi, ecx
            //   8b480c               | mov                 ecx, dword ptr [eax + 0xc]

        $sequence_2 = { 51 89558c ffd7 8b558c f7d8 1bc0 f7d8 }
            // n = 7, score = 700
            //   51                   | push                ecx
            //   89558c               | mov                 dword ptr [ebp - 0x74], edx
            //   ffd7                 | call                edi
            //   8b558c               | mov                 edx, dword ptr [ebp - 0x74]
            //   f7d8                 | neg                 eax
            //   1bc0                 | sbb                 eax, eax
            //   f7d8                 | neg                 eax

        $sequence_3 = { 7507 c745ec01000000 8b4514 8b7de8 2bc7 6800000040 }
            // n = 6, score = 700
            //   7507                 | jne                 9
            //   c745ec01000000       | mov                 dword ptr [ebp - 0x14], 1
            //   8b4514               | mov                 eax, dword ptr [ebp + 0x14]
            //   8b7de8               | mov                 edi, dword ptr [ebp - 0x18]
            //   2bc7                 | sub                 eax, edi
            //   6800000040           | push                0x40000000

        $sequence_4 = { ff15???????? 8b4dc0 894dd4 8d55c4 52 }
            // n = 5, score = 700
            //   ff15????????         |                     
            //   8b4dc0               | mov                 ecx, dword ptr [ebp - 0x40]
            //   894dd4               | mov                 dword ptr [ebp - 0x2c], ecx
            //   8d55c4               | lea                 edx, [ebp - 0x3c]
            //   52                   | push                edx

        $sequence_5 = { c7400807000000 c7400c0f000000 c740101f000000 c740143f000000 c740187f000000 }
            // n = 5, score = 700
            //   c7400807000000       | mov                 dword ptr [eax + 8], 7
            //   c7400c0f000000       | mov                 dword ptr [eax + 0xc], 0xf
            //   c740101f000000       | mov                 dword ptr [eax + 0x10], 0x1f
            //   c740143f000000       | mov                 dword ptr [eax + 0x14], 0x3f
            //   c740187f000000       | mov                 dword ptr [eax + 0x18], 0x7f

        $sequence_6 = { 89bde0feffff ffd6 8b3d???????? 50 }
            // n = 4, score = 700
            //   89bde0feffff         | mov                 dword ptr [ebp - 0x120], edi
            //   ffd6                 | call                esi
            //   8b3d????????         |                     
            //   50                   | push                eax

        $sequence_7 = { c7420485ae67bb 8b4590 c7400872f36e3c 8b4d90 c7410c3af54fa5 }
            // n = 5, score = 700
            //   c7420485ae67bb       | mov                 dword ptr [edx + 4], 0xbb67ae85
            //   8b4590               | mov                 eax, dword ptr [ebp - 0x70]
            //   c7400872f36e3c       | mov                 dword ptr [eax + 8], 0x3c6ef372
            //   8b4d90               | mov                 ecx, dword ptr [ebp - 0x70]
            //   c7410c3af54fa5       | mov                 dword ptr [ecx + 0xc], 0xa54ff53a

        $sequence_8 = { 53 56 57 8bd0 8bf1 8bf8 8bd9 }
            // n = 7, score = 700
            //   53                   | push                ebx
            //   56                   | push                esi
            //   57                   | push                edi
            //   8bd0                 | mov                 edx, eax
            //   8bf1                 | mov                 esi, ecx
            //   8bf8                 | mov                 edi, eax
            //   8bd9                 | mov                 ebx, ecx

        $sequence_9 = { 8975c8 8975b8 8975a8 ff15???????? 8b45d0 8975cc 50 }
            // n = 7, score = 700
            //   8975c8               | mov                 dword ptr [ebp - 0x38], esi
            //   8975b8               | mov                 dword ptr [ebp - 0x48], esi
            //   8975a8               | mov                 dword ptr [ebp - 0x58], esi
            //   ff15????????         |                     
            //   8b45d0               | mov                 eax, dword ptr [ebp - 0x30]
            //   8975cc               | mov                 dword ptr [ebp - 0x34], esi
            //   50                   | push                eax

    condition:
        7 of them and filesize < 1540096
}