rule win_unidentified_013_korean_malware_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.unidentified_013_korean_malware."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.unidentified_013_korean_malware"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 3bd7 7cf5 7f04 3bc5 72ef }
            // n = 5, score = 200
            //   3bd7                 | cmp                 edx, edi
            //   7cf5                 | jl                  0xfffffff7
            //   7f04                 | jg                  6
            //   3bc5                 | cmp                 eax, ebp
            //   72ef                 | jb                  0xfffffff1

        $sequence_1 = { 57 a1???????? 33c4 50 8d842458060000 64a300000000 68???????? }
            // n = 7, score = 200
            //   57                   | push                edi
            //   a1????????           |                     
            //   33c4                 | xor                 eax, esp
            //   50                   | push                eax
            //   8d842458060000       | lea                 eax, [esp + 0x658]
            //   64a300000000         | mov                 dword ptr fs:[0], eax
            //   68????????           |                     

        $sequence_2 = { 6800040000 8d4c241c 51 57 ffd5 85c0 743f }
            // n = 7, score = 200
            //   6800040000           | push                0x400
            //   8d4c241c             | lea                 ecx, [esp + 0x1c]
            //   51                   | push                ecx
            //   57                   | push                edi
            //   ffd5                 | call                ebp
            //   85c0                 | test                eax, eax
            //   743f                 | je                  0x41

        $sequence_3 = { 81c40c040000 c3 8b2d???????? 8d44240c 50 }
            // n = 5, score = 200
            //   81c40c040000         | add                 esp, 0x40c
            //   c3                   | ret                 
            //   8b2d????????         |                     
            //   8d44240c             | lea                 eax, [esp + 0xc]
            //   50                   | push                eax

        $sequence_4 = { e8???????? 83c424 8bd8 8d542414 8d8c2454030000 }
            // n = 5, score = 200
            //   e8????????           |                     
            //   83c424               | add                 esp, 0x24
            //   8bd8                 | mov                 ebx, eax
            //   8d542414             | lea                 edx, [esp + 0x14]
            //   8d8c2454030000       | lea                 ecx, [esp + 0x354]

        $sequence_5 = { 8b44243c ff4c241c 3bf8 7605 e8???????? 8b44242c bb10000000 }
            // n = 7, score = 200
            //   8b44243c             | mov                 eax, dword ptr [esp + 0x3c]
            //   ff4c241c             | dec                 dword ptr [esp + 0x1c]
            //   3bf8                 | cmp                 edi, eax
            //   7605                 | jbe                 7
            //   e8????????           |                     
            //   8b44242c             | mov                 eax, dword ptr [esp + 0x2c]
            //   bb10000000           | mov                 ebx, 0x10

        $sequence_6 = { 83c428 c3 3c03 0f8558ffffff 83f901 }
            // n = 5, score = 200
            //   83c428               | add                 esp, 0x28
            //   c3                   | ret                 
            //   3c03                 | cmp                 al, 3
            //   0f8558ffffff         | jne                 0xffffff5e
            //   83f901               | cmp                 ecx, 1

        $sequence_7 = { 8d442414 50 c744242003000000 ff15???????? b902000000 }
            // n = 5, score = 200
            //   8d442414             | lea                 eax, [esp + 0x14]
            //   50                   | push                eax
            //   c744242003000000     | mov                 dword ptr [esp + 0x20], 3
            //   ff15????????         |                     
            //   b902000000           | mov                 ecx, 2

        $sequence_8 = { 68???????? 68???????? e8???????? 83c410 e8???????? b230 }
            // n = 6, score = 200
            //   68????????           |                     
            //   68????????           |                     
            //   e8????????           |                     
            //   83c410               | add                 esp, 0x10
            //   e8????????           |                     
            //   b230                 | mov                 dl, 0x30

        $sequence_9 = { 6a00 6a00 6a00 8bf2 6a00 6a00 8bf9 }
            // n = 7, score = 200
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   8bf2                 | mov                 esi, edx
            //   6a00                 | push                0
            //   6a00                 | push                0
            //   8bf9                 | mov                 edi, ecx

    condition:
        7 of them and filesize < 204800
}